@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -100,29 +98,27 @@ struct GroupExpressionTerm {
     /**
      * Determines whether this and the given term contain identical data.
      *
-     * \param other the term with which this term will be compared.
      * \return \c true if and only if this and the given term have both the
      * same generator and exponent.
      */
-    bool operator == (const GroupExpressionTerm& other) const;
-    /**
-     * Determines whether this and the given term do not contain identical data.
-     *
-     * \param other the term with which this term will be compared.
-     * \return \c true if and only if this and the given term do not have
-     * both the same generator and exponent.
-     */
-    bool operator != (const GroupExpressionTerm& other) const;
+    bool operator == (const GroupExpressionTerm&) const = default;
 
     /**
-     * Imposes an ordering on terms.
-     * Terms are ordered lexigraphically as (generator, exponent) pairs.
+     * Compares two terms lexicographically.
+     * Specifically, this operator imposes a total order on terms by comparing
+     * them lexicographically as (generator, exponent) pairs.
      *
-     * \param other the term to compare with this.
-     * \return true if and only if this term is lexicographically
-     * smaller than \a other.
+     * This generates all of the usual comparison operators, including
+     * `<`, `<=`, `>`, and `>=`.
+     *
+     * \python This spaceship operator `x <=> y` is not available, but the
+     * other comparison operators that it generates _are_ available.
+     *
+     * \return The result of the lexicographical comparison between this
+     * and the given term.
      */
-    bool operator < (const GroupExpressionTerm& other) const;
+    std::strong_ordering operator <=> (const GroupExpressionTerm&) const =
+        default;
 
     /**
      * Returns the inverse of this term.  The inverse has the same
@@ -316,16 +312,6 @@ class GroupExpression : public ShortOutput<GroupExpression, true> {
          */
         bool operator == (const GroupExpression& comp) const;
 
-        /**
-         * Inequality operator. Checks to see whether or not these two words
-         * represent different literal strings.
-         *
-         * \param comp the expression to compare against this.
-         * \return \c true if this and the given string literal are not
-         * identical.
-         */
-        bool operator != (const GroupExpression& comp) const;
-
         /**
          * Returns the list of terms in this expression.
          * These are the actual terms stored internally; any
@@ -353,9 +339,10 @@ class GroupExpression : public ShortOutput<GroupExpression, true> {
          * consisting of three terms `g1^2`, `g3^-1` and
          * `g6^1` in that order.
          *
-         * \python The list itself is not returned by reference
-         * (instead this routine returns a new Python list).  However,
-         * the terms within this list are still returned by reference.
+         * \nopython In Python, this function is non-const (and in particular
+         * the returned list contains references that allow you to modify
+         * individual terms).  See the non-const function documentation for
+         * further details.
          *
          * \return the list of terms.
          */
@@ -670,6 +657,8 @@ class GroupExpression : public ShortOutput<GroupExpression, true> {
          */
         void writeTeX(std::ostream& out) const;
 
+        // Make sure the compiler can see the zero-argument string output
+        // routines, since we declare alternative versions of these below.
         using ShortOutput<GroupExpression, true>::str;
         using ShortOutput<GroupExpression, true>::utf8;
 
@@ -929,14 +918,12 @@ class GroupPresentation : public Output<GroupPresentation> {
         /**
          * Returns the list of all relations in this group presentation.
          *
-         * \python This routine returns a python list of copied
-         * GroupExpression objects.  In particular, modifying this
-         * list or the relations within it will not modify the group
-         * presentation from which they came.
-         *
-         * \python The list itself is not returned by reference
-         * (instead this routine returns a new Python list).  However,
-         * the relations within this list are still returned by reference.
+         * \python The list itself is not returned by reference (instead this
+         * routine returns a new Python list).  However, the relations within
+         * this list are still returned by reference.  This means that in
+         * theory you could use the references in this list to modify each
+         * relation individually, although since this is a const function (which
+         * Python does not understand or respect), you should _not_ do this.
          *
          * \return the list of relations.
          */
@@ -956,7 +943,7 @@ class GroupPresentation : public Output<GroupPresentation> {
         bool isValid() const;
 
         /**
-         * Attempts to simplify the group presentation as intelligently
+         * Attempts to simplify this group presentation as intelligently
          * as possible without further input.
          *
          * The current simplification method uses a combination of small
@@ -981,7 +968,22 @@ class GroupPresentation : public Output<GroupPresentation> {
          * original presentation to the new presentation, or \nullopt if
          * this presentation was not changed.
          */
-        std::optional<HomGroupPresentation> intelligentSimplify();
+        std::optional<HomGroupPresentation> simplify();
+
+        /**
+         * Deprecated alias for simplify(), which attempts to simplify this
+         * group presentation as intelligently as possible without further
+         * input.
+         *
+         * \deprecated This routine has been renamed to simplify().
+         * See simplify() for further details.
+         *
+         * \return an isomorphism describing the reduction map from the
+         * original presentation to the new presentation, or \nullopt if
+         * this presentation was not changed.
+         */
+        [[deprecated]] std::optional<HomGroupPresentation>
+            intelligentSimplify();
 
         /**
          * Attempts to simplify the group presentation using small cancellation
@@ -1034,7 +1036,7 @@ class GroupPresentation : public Output<GroupPresentation> {
          * potentially conjugate.
          *
          * \warning This routine is only as good as the relator table for the
-         * group.  You might want to consider running intelligentSimplify(),
+         * group.  You might want to consider running simplify(),
          * possibly in concert with proliferateRelators(), before using this
          * routine for any significant tasks.
          *
@@ -1075,7 +1077,7 @@ class GroupPresentation : public Output<GroupPresentation> {
         /**
          * Attempts to recognise the group corresponding to this
          * presentation.  This routine is much more likely to be
-         * successful if you have already called intelligentSimplify().
+         * successful if you have already called simplify().
          *
          * Currently, the groups this routine recognises include:
          * the trivial group, abelian groups, free groups,
@@ -1184,7 +1186,7 @@ class GroupPresentation : public Output<GroupPresentation> {
          *
          * \warning If you have not adequately simplified this presentation
          * this routine will most likely return \c false.  Consider running
-         * intelligentSimplify, possibly in concert with proliferateRelators(),
+         * simplify(), possibly in concert with proliferateRelators(),
          * in order to discover adequately many commutators.
          *
          * \return \c true if the group is shown to be abelian, or
@@ -1270,7 +1272,20 @@ class GroupPresentation : public Output<GroupPresentation> {
          * original presentation to the new presentation, or \nullopt if
          * this presentation was not changed.
          */
-        std::optional<HomGroupPresentation> intelligentNielsen();
+        std::optional<HomGroupPresentation> nielsen();
+
+        /**
+         * Deprecated alias for nielsen(), which looks for Nielsen moves that
+         * will simplify the presentation.
+         *
+         * \deprecated This routine has been renamed to nielsen().
+         * See nielsen() for further details.
+         *
+         * \return an isomorphism describing the map from the
+         * original presentation to the new presentation, or \nullopt if
+         * this presentation was not changed.
+         */
+        [[deprecated]] std::optional<HomGroupPresentation> intelligentNielsen();
 
         /**
          * Rewrites the presentation so that generators
@@ -1358,21 +1373,6 @@ class GroupPresentation : public Output<GroupPresentation> {
          */
         bool operator == (const GroupPresentation& other) const;
 
-        /**
-         * Determines whether this and the given group presentation are
-         * not identical.
-         *
-         * This routine does _not_ test for isomorphism (which in
-         * general is an undecidable problem).  Instead it tests whether
-         * this and the given presentation use exactly the same generators
-         * and exactly the same relations, presented in exactly the same order.
-         *
-         * \param other the group presentation to compare with this.
-         * \return \c true if and only if this and the given group presentation
-         * are not identical.
-         */
-        bool operator != (const GroupPresentation& other) const;
-
         /**
          * Attempts to prove that this and the given group presentation are
          * _simply isomorphic_.
@@ -1840,16 +1840,6 @@ inline GroupExpressionTerm::GroupExpressionTerm(unsigned long gen, long exp) :
         generator(gen), exponent(exp) {
 }
 
-inline bool GroupExpressionTerm::operator == (
-        const GroupExpressionTerm& other) const {
-    return (generator == other.generator) && (exponent == other.exponent);
-}
-
-inline bool GroupExpressionTerm::operator != (
-        const GroupExpressionTerm& other) const {
-    return (generator != other.generator) || (exponent != other.exponent);
-}
-
 inline GroupExpressionTerm GroupExpressionTerm::inverse() const {
     return GroupExpressionTerm(generator, -exponent);
 }
@@ -1863,13 +1853,6 @@ inline bool GroupExpressionTerm::operator += (
         return false;
 }
 
-inline bool GroupExpressionTerm::operator < (
-        const GroupExpressionTerm& other) const {
-    return ( (generator < other.generator) ||
-             ( (generator == other.generator) &&
-               ( exponent < other.exponent ) ) );
-}
-
 // Inline functions for GroupExpression
 
 inline GroupExpression::GroupExpression(const GroupExpressionTerm& term) {
@@ -1893,10 +1876,6 @@ inline bool GroupExpression::operator ==(const GroupExpression& comp) const {
     return terms_ == comp.terms_;
 }
 
-inline bool GroupExpression::operator !=(const GroupExpression& comp) const {
-    return terms_ != comp.terms_;
-}
-
 inline std::list<GroupExpressionTerm>& GroupExpression::terms() {
     return terms_;
 }
@@ -2031,11 +2010,6 @@ inline bool GroupPresentation::operator == (const GroupPresentation& other)
     return nGenerators_ == other.nGenerators_ && relations_ == other.relations_;
 }
 
-inline bool GroupPresentation::operator != (const GroupPresentation& other)
-        const {
-    return nGenerators_ != other.nGenerators_ || relations_ != other.relations_;
-}
-
 inline void swap(GroupPresentation& lhs, GroupPresentation& rhs) noexcept {
     lhs.swap(rhs);
 }
@@ -2048,6 +2022,16 @@ inline void swap(GroupPresentation& lhs, GroupPresentation& rhs) noexcept {
 
 namespace regina {
 
+inline std::optional<HomGroupPresentation>
+        GroupPresentation::intelligentSimplify() {
+    return simplify();
+}
+
+inline std::optional<HomGroupPresentation>
+        GroupPresentation::intelligentNielsen() {
+    return nielsen();
+}
+
 template <int index, typename Action, typename... Args>
 inline size_t GroupPresentation::enumerateCovers(
         Action&& action, Args&&... args) const {
