@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -197,19 +195,6 @@ class CensusDB {
          * the same database.
          */
         bool operator == (const CensusDB& rhs) const;
-        /**
-         * Tests whether this and the given object represent different
-         * databases.
-         *
-         * Two databases are considered the same if they have identical
-         * filenames (as returned by the filename() function).  The database
-         * descriptions are irrelevant here.
-         *
-         * \param rhs the database to compare this against.
-         * \return \c true if and only if this and the given object represent
-         * different databases.
-         */
-        bool operator != (const CensusDB& rhs) const;
 };
 
 /**
@@ -304,18 +289,6 @@ class CensusHit {
          * \return \c true if and only if this and the given hit are the same.
          */
         bool operator == (const CensusHit& rhs) const;
-        /**
-         * Tests whether this and the given object represent different
-         * census hits.
-         *
-         * Two census hits are considered the same if they have the same
-         * human-readable name and also come from the same database
-         * (as identified by the CensusDB comparison operators).
-         *
-         * \param rhs the census hit to compare this against.
-         * \return \c true if and only if this and the given hit are different.
-         */
-        bool operator != (const CensusHit& rhs) const;
 
     private:
         /**
@@ -485,10 +458,6 @@ inline bool CensusDB::operator == (const CensusDB& rhs) const {
     return filename_ == rhs.filename_;
 }
 
-inline bool CensusDB::operator != (const CensusDB& rhs) const {
-    return filename_ != rhs.filename_;
-}
-
 inline void swap(CensusDB& a, CensusDB& b) noexcept {
     a.swap(b);
 }
@@ -520,10 +489,6 @@ inline bool CensusHit::operator == (const CensusHit& rhs) const {
     return ((*db_) == (*rhs.db_) && name_ == rhs.name_);
 }
 
-inline bool CensusHit::operator != (const CensusHit& rhs) const {
-    return ((*db_) != (*rhs.db_) || name_ != rhs.name_);
-}
-
 inline void swap(CensusHit& a, CensusHit& b) noexcept {
     a.swap(b);
 }
