@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -38,11 +36,10 @@ namespace regina {
 
 GluingPermSearcher<3>::GluingPermSearcher(
         FacetPairing<3> pairing, FacetPairing<3>::IsoList autos,
-        bool orientableOnly, bool finiteOnly, CensusPurge whichPurge) :
+        bool orientableOnly, bool finiteOnly, Flags<CensusPurge> purge) :
         perms_(std::move(pairing)), autos_(std::move(autos)),
         // pairing and autos are no longer usable
-        orientableOnly_(orientableOnly), finiteOnly_(finiteOnly),
-        whichPurge_(whichPurge),
+        orientableOnly_(orientableOnly), finiteOnly_(finiteOnly), purge_(purge),
         started(false), orientation(new int[perms_.size()]) {
     // Initialise arrays.
     size_t nTets = perms_.size();
@@ -127,7 +124,7 @@ void GluingPermSearcher<3>::searchImpl(long maxDepth, ActionWrapper&& action_) {
 
         // We are sitting on a new permutation to try.
         perms_.permIndex(adj) =
-            Perm<3>::S3[perms_.permIndex(face)].inverse().S3Index();
+            Perm<3>::Sn[perms_.permIndex(face)].inverse().S3Index();
 
         // Is this going to lead to an unwanted triangulation?
         //
@@ -136,7 +133,7 @@ void GluingPermSearcher<3>::searchImpl(long maxDepth, ActionWrapper&& action_) {
         // subclass of GluingPermSearcher<3> with its own custom
         // implementation of runSearch().
         if (lowDegreeEdge(face, false /* degree 1,2 */,
-                whichPurge_.has(PURGE_NON_MINIMAL)))
+                purge_.has(CensusPurge::NonMinimal)))
             continue;
         if (! orientableOnly_)
             if (badEdgeLink(face))
@@ -207,7 +204,7 @@ void GluingPermSearcher<3>::dumpData(std::ostream& out) const {
     out << (orientableOnly_ ? 'o' : '.');
     out << (finiteOnly_ ? 'f' : '.');
     out << (started ? 's' : '.');
-    out << ' ' << whichPurge_.intValue() << std::endl;
+    out << ' ' << purge_.intValue() << std::endl;
 
     size_t nTets = perms_.size();
 
@@ -237,9 +234,9 @@ void GluingPermSearcher<3>::writeTextShort(std::ostream& out) const {
         out << ", orientable only";
     if (finiteOnly_)
         out << ", finite only";
-    if (whichPurge_ != PURGE_NONE)
+    if (purge_ != CensusPurge::None)
         out << ", purge 0x" << std::hex << std::setw(2) << std::setfill('0')
-            << whichPurge_.intValue();
+            << purge_.intValue();
 
     out << ": stage " << orderElt << ", order:";
     for (size_t i = 0; i < orderSize; ++i)
@@ -280,9 +277,9 @@ GluingPermSearcher<3>::GluingPermSearcher(std::istream& in) :
             "while attempting to read GluingPermSearcher<3>");
 
     {
-        int whichPurge;
-        in >> whichPurge;
-        whichPurge_ = CensusPurge::fromInt(whichPurge);
+        int purge;
+        in >> purge;
+        purge_ = Flags<CensusPurge>::fromInt(purge);
     }
 
     size_t nTets = perms_.size();
