@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Create a census database from a list of key-value pairs               *
  *                                                                        *
- *  Copyright (c) 2014-2023, Ben Burton                                   *
+ *  Copyright (c) 2014-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -45,7 +43,6 @@
   #include <villa.h>
   #define DB_CLOSE(x) vlclose(x);
 #elif defined(REGINA_KVSTORE_TOKYOCABINET)
-  #include <cstdbool>
   #include <cstdint>
   #include <tcbdb.h>
   #include <tcutil.h>
