@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -335,15 +333,15 @@ class HilbertDual {
                 inline bool operator == (const VecSpec& other) const;
 
                 /**
-                 * Determines if every element of this vector is less
-                 * than or equal to every element of the given vector.
+                 * Determines if every element of this vector is less than or
+                 * equal to the corresponding element of the given vector.
                  *
                  * \param other the vector to compare with this.
-                 * \return \c true if every element of this vector is
-                 * less than or equal to every element of \a other, or
-                 * \c false otherwise.
+                 * \return \c true if the <i>k</i>th element of this vector is
+                 * less than or equal to the <i>k</i>th element of \a other
+                 * for all \a k, or \c false otherwise.
                  */
-                inline bool operator <= (const VecSpec& other) const;
+                inline bool dominatedBy(const VecSpec& other) const;
 
                 using Vector<IntegerType>::operator [];
         };
@@ -548,7 +546,7 @@ inline bool HilbertDual::VecSpec<IntegerType, BitmaskType>::operator == (
 }
 
 template <class IntegerType, class BitmaskType>
-inline bool HilbertDual::VecSpec<IntegerType, BitmaskType>::operator <= (
+inline bool HilbertDual::VecSpec<IntegerType, BitmaskType>::dominatedBy(
         const HilbertDual::VecSpec<IntegerType, BitmaskType>& other) const {
     // Begin with simple tests that give us a fast way of saying no.
     if (! (mask_ <= other.mask_))
