@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 2011-2023, Ben Burton                                   *
+ *  Copyright (c) 2011-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -381,7 +379,7 @@ class TreeTraversal : public ShortOutput<
          *
          * \exception FailedPrecondition We are not working with normal or
          * almost normal surfaces (i.e., the coordinate system passed to the
-         * TreeTraversal constructor was NS_ANGLE).
+         * TreeTraversal constructor was NormalCoords::Angle).
          *
          * \return a normal surface that has been found at the current stage
          * of the search.
@@ -408,7 +406,7 @@ class TreeTraversal : public ShortOutput<
          *
          * \exception FailedPrecondition We are not working with angle
          * structure coordinates (i.e., the coordinate system passed to the
-         * TreeTraversal constructor was not NS_ANGLE).
+         * TreeTraversal constructor was not NormalCoords::Angle).
          *
          * \return the taut angle structure that has been found at the
          * current stage of the search.
@@ -500,8 +498,8 @@ class TreeTraversal : public ShortOutput<
          *
          * \pre We are working in standard normal or almost normal
          * coordinates.  That is, the coordinate system passed to the
-         * TreeTraversal constructor was one of NS_STANDARD
-         * or NS_AN_STANDARD.
+         * TreeTraversal constructor was one of NormalCoords::Standard
+         * or NormalCoords::AlmostNormal.
          *
          * \pre The argument \a startFrom is at least \a nTets_ (i.e.,
          * it is at least as large as the index of the first triangle type).
@@ -579,11 +577,12 @@ class TreeTraversal : public ShortOutput<
  * additional constraints (such as positive Euler characteristic), then
  * use the class TreeSingleSoln instead, which is optimised for this purpose.
  *
- * This tree traversal can only enumerate surfaces in quadrilateral normal
- * coordinates (NS_QUAD), standard normal coordinates (NS_STANDARD),
- * quadrilateral-octagon almost normal coordinates (NS_AN_QUAD_OCT), or
- * standard almost normal coordinates (NS_AN_STANDARD).  For almost
- * normal surfaces, we allow any number of octagons (including zero),
+ * This tree traversal can only enumerate surfaces in
+ * quadrilateral normal coordinates (NormalCoords::Quad),
+ * standard normal coordinates (NormalCoords::Standard),
+ * quadrilateral-octagon almost normal coordinates (NormalCoords::QuadOct), or
+ * standard almost normal coordinates (NormalCoords::AlmostNormal).
+ * For almost normal surfaces, we allow any number of octagons (including zero),
  * but we only allow at most one octagon _type_ in the entire triangulation.
  * No coordinate systems other than these are supported.
  *
@@ -624,7 +623,8 @@ class TreeTraversal : public ShortOutput<
  * _much_ slower than in quadrilateral or quadrilateral-octagon coordinates
  * respectively.  Instead you should enumerate vertex solutions using
  * quadrilateral or quadrilateral-octagon coordinates, and then use the
- * "transform constructor" `NormalSurfaces(..., NS_CONV_REDUCED_TO_STD)`.
+ * "transform constructor"
+ * `NormalSurfaces(..., NormalTransform::ConvertReducedToStandard)`.
  *
  * \headers Parts of this template class are implemented in a separate header
  * (treetraversal-impl.h), which is not included automatically by this file.
@@ -1301,11 +1301,12 @@ class TautEnumeration :
  * triangulation (instead of finding just one), you should use the class
  * TreeEnumeration instead.
  *
- * This tree traversal can only enumerate surfaces in quadrilateral normal
- * coordinates (NS_QUAD), standard normal coordinates (NS_STANDARD),
- * quadrilateral-octagon almost normal coordinates (NS_AN_QUAD_OCT), or
- * standard almost normal coordinates (NS_AN_STANDARD).  For almost
- * normal surfaces, we allow any number of octagons (including zero),
+ * This tree traversal can only enumerate surfaces in
+ * quadrilateral normal coordinates (NormalCoords::Quad),
+ * standard normal coordinates (NormalCoords::Standard),
+ * quadrilateral-octagon almost normal coordinates (NormalCoords::QuadOct), or
+ * standard almost normal coordinates (NormalCoords::AlmostNormal).
+ * For almost normal surfaces, we allow any number of octagons (including zero),
  * but we only allow at most one octagon _type_ in the entire triangulation.
  * No coordinate systems other than these are supported.
  *
@@ -1661,7 +1662,8 @@ template <class LPConstraint, typename BanConstraint, typename IntType>
 template <typename... BanArgs>
 inline TautEnumeration<LPConstraint, BanConstraint, IntType>::TautEnumeration(
         const Triangulation<3>& tri, BanArgs&&... banArgs) :
-        TreeTraversal<LPConstraint, BanConstraint, IntType>(tri, NS_ANGLE,
+        TreeTraversal<LPConstraint, BanConstraint, IntType>(tri,
+            NormalCoords::Angle,
             3 /* branches per quad */,
             0 /* branches per triangle; irrelevant here */,
             true /* enumeration */,
