@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -54,7 +52,7 @@ namespace regina {
  *
  * \ingroup hypersurface
  */
-enum HyperCoords {
+enum class HyperCoords {
     /**
      * Represents standard tetrahedron-prism coordinates for
      * normal hypersurfaces.
@@ -62,7 +60,7 @@ enum HyperCoords {
      * Regina can both enumerate and view hypersurfaces in this
      * coordinate system.
      */
-    HS_STANDARD = 0,
+    Standard = 0,
 
     /**
      * Represents prism coordinates for normal hypersurfaces.
@@ -70,7 +68,7 @@ enum HyperCoords {
      * Regina can both enumerate and view hypersurfaces in this
      * coordinate system.
      */
-    HS_PRISM = 1,
+    Prism = 1,
 
     /**
      * Represents edge weight coordinates for normal hypersurfaces.
@@ -79,9 +77,34 @@ enum HyperCoords {
      * in this coordinate system, but it cannot use it to enumerate or create
      * hypersurfaces.
      */
-    HS_EDGE_WEIGHT = 200
+    Edge = 200
 };
 
+/**
+ * A deprecated alias for standard tetrahedron-prism coordinates for normal
+ * hypersurfaces.
+ *
+ * \deprecated This has been renamed to the scoped enumeration constant
+ * HyperCoords::Standard.
+ */
+[[deprecated]] inline constexpr HyperCoords HS_STANDARD = HyperCoords::Standard;
+
+/**
+ * A deprecated alias for prism coordinates for normal hypersurfaces.
+ *
+ * \deprecated This has been renamed to the scoped enumeration constant
+ * HyperCoords::Prism.
+ */
+[[deprecated]] inline constexpr HyperCoords HS_PRISM = HyperCoords::Prism;
+
+/**
+ * A deprecated alias for edge weight coordinates for normal hypersurfaces.
+ *
+ * \deprecated This has been renamed to the scoped enumeration constant
+ * HyperCoords::Edge.
+ */
+[[deprecated]] inline constexpr HyperCoords HS_EDGE_WEIGHT = HyperCoords::Edge;
+
 /**
  * Indicates precisely how a normal hypersurface within a 4-manifold
  * triangulation is encoded by an integer vector.
@@ -179,11 +202,11 @@ class HyperEncoding {
          */
         constexpr HyperEncoding(HyperCoords coords) : flags_(INVALID) {
             switch (coords) {
-                case HS_STANDARD:
+                case HyperCoords::Standard:
                     flags_ = 15 | COULD_BE_VERTEX_LINK | STORES_TETRAHEDRA;
                     break;
 
-                case HS_PRISM:
+                case HyperCoords::Prism:
                     flags_ = 10 | COULD_BE_NON_COMPACT;
                     break;
 
@@ -211,15 +234,6 @@ class HyperEncoding {
         constexpr bool operator == (const HyperEncoding& other) const {
             return flags_ == other.flags_;
         }
-        /**
-         * Determines whether this and the given encoding are different.
-         *
-         * \param other the encoding to compare with this.
-         * \return \c true if and only if both encodings are different.
-         */
-        constexpr bool operator != (const HyperEncoding& other) const {
-            return flags_ != other.flags_;
-        }
 
         /**
          * Returns whether this describes a vector encoding of normal
@@ -403,11 +417,11 @@ class HyperInfo {
          */
         constexpr static const char* name(HyperCoords coordSystem) {
             switch (coordSystem) {
-                case HS_STANDARD:
+                case HyperCoords::Standard:
                     return "Standard normal (tet-prism)";
-                case HS_PRISM:
+                case HyperCoords::Prism:
                     return "Prism normal";
-                case HS_EDGE_WEIGHT:
+                case HyperCoords::Edge:
                     return "Edge weight";
                 default:
                     return "Unknown";
