@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -96,7 +94,7 @@ class ProgressTracker;
  *   NormalHypersurfaces interface.
  *
  * - If you are adding new functions to this class that edit the list,
- *   you must still remember to create a ChangeEventSpan.  This will ensure
+ *   you must still remember to create a PacketChangeSpan.  This will ensure
  *   that, if the list is being managed by a PacketOf<NormalHypersurfaces>,
  *   then the appropriate packet change events will be fired.
  *   All other events (aside from packetToBeChanged() and packetWasChanged()
@@ -124,13 +122,13 @@ class NormalHypersurfaces : public PacketData<NormalHypersurfaces>,
         HyperCoords coords_;
             /**< The coordinate system that was originally used to enumerate
                  the normal hypersurfaces in this list. */
-        HyperList which_;
+        Flags<HyperList> which_;
             /**< Indicates which normal hypersurfaces these represent
                  within the underlying triangulation. */
-        HyperAlg algorithm_;
+        Flags<HyperAlg> algorithm_;
             /**< Stores the details of the enumeration algorithm that
                  was used to generate this list.  This might not be the
-                 same as the \a algorithmHints flag that was originally
+                 same as the \a algHints flag that was originally
                  passed to the enumeration routine (e.g., if invalid or
                  inappropriate flags were passed). */
 
@@ -146,21 +144,21 @@ class NormalHypersurfaces : public PacketData<NormalHypersurfaces>,
          * produced, since vertex/fundamental surfaces in one system are not
          * necessarily vertex/fundamental in another.
          *
-         * The HyperList argument is a combination of flags that
+         * The \a whichList argument is a combination of flags that
          * allows you to specify exactly which normal hypersurfaces you require.
-         * This includes (i) whether you want all vertex hypersurfaces
-         * or all fundamental hypersurfaces, which defaults to HS_VERTEX
+         * This includes (i) whether you want all vertex hypersurfaces or all
+         * fundamental hypersurfaces, which defaults to HyperList::Vertex
          * if you specify neither or both; and (ii) whether you want only
          * properly embedded surfaces or you also wish to include
          * immersed and/or singular hypersurfaces, which defaults to
-         * HS_EMBEDDED_ONLY if you specify neither or both.
+         * HyperList::EmbeddedOnly if you specify neither or both.
          *
-         * The HyperAlg argument is a combination of flags that allows
+         * The \a algHints argument is a combination of flags that allows
          * you to control the underlying enumeration algorithm.  These
          * flags are treated as hints only: if your selection of
          * algorithm is invalid, unavailable or unsupported then Regina
          * will choose something more appropriate.  Unless you have
-         * some specialised need, the default HS_ALG_DEFAULT (which
+         * some specialised need, the default HyperAlg::Default (which
          * makes no hints at all) will allow Regina to choose what it
          * thinks will be the most efficient method.
          *
@@ -219,7 +217,7 @@ class NormalHypersurfaces : public PacketData<NormalHypersurfaces>,
          * \param coords the coordinate system to be used.  This must be
          * one of the system that Regina is able to use for enumeration;
          * this is documented alongside each HyperCoords enum value.
-         * \param which indicates which normal hypersurfaces should be
+         * \param whichList indicates which normal hypersurfaces should be
          * enumerated.
          * \param algHints passes requests to Regina for which specific
          * enumeration algorithm should be used.
@@ -229,8 +227,8 @@ class NormalHypersurfaces : public PacketData<NormalHypersurfaces>,
         NormalHypersurfaces(
             const Triangulation<4>& triangulation,
             HyperCoords coords,
-            HyperList which = HS_LIST_DEFAULT,
-            HyperAlg algHints = HS_ALG_DEFAULT,
+            Flags<HyperList> whichList = HyperList::Default,
+            Flags<HyperAlg> algHints = HyperAlg::Default,
             ProgressTracker* tracker = nullptr);
 
         /**
@@ -304,19 +302,19 @@ class NormalHypersurfaces : public PacketData<NormalHypersurfaces>,
          * Returns details of which normal hypersurfaces this list represents
          * within the underlying triangulation.
          *
-         * This may not be the same HyperList that was passed to the class
+         * These may not be the same list flags that were passed to the class
          * constructor.  In particular, default values will have been explicitly
-         * filled in (such as HS_VERTEX and/or HS_EMBEDDED_ONLY), and
-         * invalid and/or redundant values will have been removed.
+         * filled in (such as HyperList::Vertex and/or HyperList::EmbeddedOnly),
+         * and invalid and/or redundant values will have been removed.
          *
          * \return details of what this list represents.
          */
-        HyperList which() const;
+        Flags<HyperList> which() const;
         /**
          * Returns details of the algorithm that was used to enumerate
          * this list.
          *
-         * These may not be the same HyperAlg flags that were passed to the
+         * These may not be the same algorithm flags that were passed to the
          * class constructor.  In particular, default values will have been
          * explicitly filled in, invalid and/or redundant values will have
          * been removed, and unavailable and/or unsupported combinations
@@ -325,7 +323,7 @@ class NormalHypersurfaces : public PacketData<NormalHypersurfaces>,
          *
          * \return details of the algorithm used to enumerate this list.
          */
-        HyperAlg algorithm() const;
+        Flags<HyperAlg> algorithm() const;
         /**
          * Determines if the coordinate system that was used for enumeration
          * allows for non-compact hypersurfaces.
@@ -507,40 +505,6 @@ class NormalHypersurfaces : public PacketData<NormalHypersurfaces>,
          */
         bool operator == (const NormalHypersurfaces& other) const;
 
-        /**
-         * Determines whether this and the given list contain different
-         * sets of normal hypersurfaces.
-         *
-         * The lists will be compared as multisets: the order of the
-         * hypersurfaces in each list does not matter; however, in the unusual
-         * scenario where a list the same hypersurface multiple times,
-         * multiplicity does matter.
-         *
-         * Like the comparison operators for NormalHypersurface, it does not
-         * matter whether the lists work with different triangulations,
-         * or different encodings, or if one but not the other supports
-         * non-compact hypersurfaces.  The individual hypersurfaces will
-         * simply be compared by examining or computing the number of
-         * normal pieces of each type.
-         *
-         * In particular, this routine is safe to call even if this and the
-         * given list work with different triangulations:
-         *
-         * - If the two triangulations have the same size, then this routine
-         *   will compare hypersurfaces as though they were transplanted into
-         *   the same triangulation using the same pentachoron numbering and
-         *   the same normal piece types.
-         *
-         * - If the two triangulations have different sizes, then this
-         *   comparison will return \c true (i.e., the lists will be
-         *   considered different).
-         *
-         * \param other the list to be compared with this list.
-         * \return \c true if both lists do not represent the same multiset of
-         * normal hypersurfaces, or \c false if they do.
-         */
-        bool operator != (const NormalHypersurfaces& other) const;
-
         /**
          * Writes a short text representation of this object to the
          * given output stream.
@@ -673,39 +637,24 @@ class NormalHypersurfaces : public PacketData<NormalHypersurfaces>,
 
                 /**
                  * Creates a copy of the given iterator.
-                 *
-                 * \param cloneMe the iterator to clone.
                  */
-                VectorIterator(const VectorIterator& cloneMe) = default;
+                VectorIterator(const VectorIterator&) = default;
 
                 /**
                  * Makes this a copy of the given iterator.
                  *
-                 * \param cloneMe the iterator to clone.
                  * \return a reference to this iterator.
                  */
-                VectorIterator& operator = (const VectorIterator& cloneMe) =
-                    default;
+                VectorIterator& operator = (const VectorIterator&) = default;
 
                 /**
                  * Compares this with the given iterator for equality.
                  *
-                 * \param other the iterator to compare this with.
                  * \return \c true if the iterators point to the same
-                 * element of the same normal surface list, or \c false
+                 * element of the same normal hypersurface list, or \c false
                  * if they do not.
                  */
-                bool operator == (const VectorIterator& other) const;
-
-                /**
-                 * Compares this with the given iterator for inequality.
-                 *
-                 * \param other the iterator to compare this with.
-                 * \return \c false if the iterators point to the same
-                 * element of the same normal surface list, or \c true
-                 * if they do not.
-                 */
-                bool operator != (const VectorIterator& other) const;
+                bool operator == (const VectorIterator&) const = default;
 
                 /**
                  * Returns the raw vector for the normal hypersurface that this
@@ -764,15 +713,15 @@ class NormalHypersurfaces : public PacketData<NormalHypersurfaces>,
          * Creates an empty list of normal hypersurfaces with the given
          * parameters.
          */
-        NormalHypersurfaces(HyperCoords coords, HyperList which,
-            HyperAlg algorithm, const Triangulation<4>& triangulation);
+        NormalHypersurfaces(HyperCoords coords, Flags<HyperList> whichList,
+            Flags<HyperAlg> algorithm, const Triangulation<4>& triangulation);
 
         /**
          * Creates an empty list of normal hypersurfaces with the given
          * parameters.
          */
-        NormalHypersurfaces(HyperCoords coords, HyperList which,
-            HyperAlg algorithm,
+        NormalHypersurfaces(HyperCoords coords, Flags<HyperList> whichList,
+            Flags<HyperAlg> algorithm,
             const SnapshotRef<Triangulation<4>>& triangulation);
 
     private:
@@ -995,8 +944,8 @@ MatrixInt makeMatchingEquations(const Triangulation<4>& triangulation,
  * relative to the given coordinate system.
  *
  * These are the constraints that will be used when enumerating embedded
- * hypersurfaces in the given coordinate system (i.e., when the default
- * HS_EMBEDDED_ONLY flag is used).  They will not be used when the enumeration
+ * hypersurfaces in the given coordinate system (i.e., when the default flag
+ * HyperList::EmbeddedOnly is used).  They will not be used when the enumeration
  * allows for immersed and/or singular hypersurfaces.
  *
  * \param triangulation the triangulation upon which these validity constraints
@@ -1015,9 +964,11 @@ ValidityConstraints makeEmbeddedConstraints(
 
 inline NormalHypersurfaces::NormalHypersurfaces(
         const Triangulation<4>& triangulation,
-        HyperCoords coords, HyperList which, HyperAlg algHints,
+        HyperCoords coords,
+        Flags<HyperList> whichList,
+        Flags<HyperAlg> algHints,
         ProgressTracker* tracker) :
-        triangulation_(triangulation), coords_(coords), which_(which),
+        triangulation_(triangulation), coords_(coords), which_(whichList),
         algorithm_(algHints) {
     try {
         Enumerator(this, makeMatchingEquations(triangulation, coords),
@@ -1031,7 +982,7 @@ inline NormalHypersurfaces::NormalHypersurfaces(
 
 inline NormalHypersurfaces& NormalHypersurfaces::operator = (
         const NormalHypersurfaces& src) {
-    ChangeEventSpan span(*this);
+    PacketChangeSpan span(*this);
 
     surfaces_ = src.surfaces_;
     triangulation_ = src.triangulation_;
@@ -1044,7 +995,7 @@ inline NormalHypersurfaces& NormalHypersurfaces::operator = (
 
 inline NormalHypersurfaces& NormalHypersurfaces::operator = (
         NormalHypersurfaces&& src) {
-    ChangeEventSpan span(*this);
+    PacketChangeSpan span(*this);
 
     surfaces_ = std::move(src.surfaces_);
     triangulation_ = std::move(src.triangulation_);
@@ -1061,16 +1012,16 @@ inline HyperCoords NormalHypersurfaces::coords() const {
     return coords_;
 }
 
-inline HyperList NormalHypersurfaces::which() const {
+inline Flags<HyperList> NormalHypersurfaces::which() const {
     return which_;
 }
 
-inline HyperAlg NormalHypersurfaces::algorithm() const {
+inline Flags<HyperAlg> NormalHypersurfaces::algorithm() const {
     return algorithm_;
 }
 
 inline bool NormalHypersurfaces::isEmbeddedOnly() const {
-    return which_.has(HS_EMBEDDED_ONLY);
+    return which_.has(HyperList::EmbeddedOnly);
 }
 
 inline const Triangulation<4>& NormalHypersurfaces::triangulation() const {
@@ -1105,7 +1056,7 @@ inline bool NormalHypersurfaces::allowsNonCompact() const {
 
 template <typename Comparison>
 inline void NormalHypersurfaces::sort(Comparison&& comp) {
-    ChangeEventSpan span(*this);
+    PacketChangeSpan span(*this);
     std::stable_sort(surfaces_.begin(), surfaces_.end(), comp);
 }
 
@@ -1119,16 +1070,6 @@ inline MatrixInt NormalHypersurfaces::recreateMatchingEquations() const {
     return makeMatchingEquations(triangulation(), coords_);
 }
 
-inline bool NormalHypersurfaces::VectorIterator::operator ==(
-        const NormalHypersurfaces::VectorIterator& other) const {
-    return (it_ == other.it_);
-}
-
-inline bool NormalHypersurfaces::VectorIterator::operator !=(
-        const NormalHypersurfaces::VectorIterator& other) const {
-    return (it_ != other.it_);
-}
-
 inline const Vector<LargeInteger>&
         NormalHypersurfaces::VectorIterator::operator *() const {
     return it_->vector();
@@ -1170,22 +1111,17 @@ inline NormalHypersurfaces::VectorIterator
     return VectorIterator(surfaces_.end());
 }
 
-inline bool NormalHypersurfaces::operator != (const NormalHypersurfaces& other)
-        const {
-    return ! ((*this) == other);
-}
-
 inline NormalHypersurfaces::NormalHypersurfaces(HyperCoords coords,
-        HyperList which, HyperAlg algorithm,
+        Flags<HyperList> whichList, Flags<HyperAlg> algorithm,
         const Triangulation<4>& triangulation) :
-        triangulation_(triangulation), coords_(coords), which_(which),
+        triangulation_(triangulation), coords_(coords), which_(whichList),
         algorithm_(algorithm) {
 }
 
 inline NormalHypersurfaces::NormalHypersurfaces(HyperCoords coords,
-        HyperList which, HyperAlg algorithm,
+        Flags<HyperList> whichList, Flags<HyperAlg> algorithm,
         const SnapshotRef<Triangulation<4>>& triangulation) :
-        triangulation_(triangulation), coords_(coords), which_(which),
+        triangulation_(triangulation), coords_(coords), which_(whichList),
         algorithm_(algorithm) {
 }
 
