@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -61,7 +59,7 @@ Link Link::fromDT(Iterator begin, Iterator end) {
     // Extract the number of crossings.
     size_t n = end - begin;
     if (n == 0)
-        return Link(1); // zero-crossing unknot
+        return { 1 }; // zero-crossing unknot
 
     // Some basic sanity checking.
     // We ensure that the integers are in range, but we do not yet check
@@ -90,14 +88,13 @@ Link Link::fromDT(Iterator begin, Iterator end) {
     // 1) Cache the absolute values of the entries in the D-T code, and
     // switch from 1-based indexing to 0-based indexing.
     size_t i;
-    auto* abs = new size_t[n];
+    FixedArray<size_t> abs(n);
     for (it = begin, i = 0; it != end; ++it, ++i)
         abs[i] = std::abs(*it) - 1;
 
     // 2) Build the involution that relates the two passes through each
     // crossing (one at an even index, and one at an odd index).
-    auto* inv = new size_t[2 * n];
-    std::fill(inv, inv + 2 * n, 1 /* does not appear in abs[] */);
+    FixedArray<size_t> inv(2 * n, 1 /* does not appear in abs[] */);
     for (i = 0; i < n; i++) {
         if (inv[abs[i]] != 1 /* the initial value */)
             throw InvalidArgument("fromDT(): repeated |entry| in code");
@@ -105,12 +102,10 @@ Link Link::fromDT(Iterator begin, Iterator end) {
         inv[abs[i]] = 2 * i;
     }
 
-    delete[] abs;
-
     // 3) For each crossing, identify the two positions in inv[] where it
     // occurs.  We will use 1-based indexing for the crossings, since that is
     // what the Gauss code will need.
-    auto* crossingForPos = new InputInt[2 * n];
+    FixedArray<InputInt> crossingForPos(2 * n);
     InputInt nextUnused = 1;
     for (i = 0; i < 2 * n; ++i) {
         // Examine position i from the involution.
@@ -125,7 +120,7 @@ Link Link::fromDT(Iterator begin, Iterator end) {
 
     // At this point we are done following the SnapPea kernel.  Use the data
     // we have just extracted to build the classical Gauss code.
-    auto* gauss = new InputInt[2 * n];
+    FixedArray<InputInt> gauss(2 * n);
     for (i = 0; i < 2 * n; ++i) {
         if (i % 2 == 0) {
             // This is an odd index in the original 1-based indexing.
@@ -142,15 +137,10 @@ Link Link::fromDT(Iterator begin, Iterator end) {
         }
     }
 
-    delete[] inv;
-    delete[] crossingForPos;
-
     // Now that we have a classical Gauss code, we can reconstruct the precise
     // planar embedding of the knot diagram using Regina's Gauss code
     // reconstruction routine.
-    Link ans = fromGauss(gauss, gauss + 2 * n);
-    delete[] gauss;
-    return ans;
+    return fromGauss(gauss.begin(), gauss.end());
 }
 
 } // namespace regina
