@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -38,11 +36,11 @@
 
 namespace regina {
 
-bool Link::intelligentSimplify() {
+bool Link::simplify() {
     bool changed;
 
-    { // Begin scope for change event block.
-        ChangeEventSpan span(*this);
+    { // Begin scope for change event group.
+        PacketChangeGroup span(*this);
 
         // Reduce to a local minimum.
         changed = simplifyToLocalMinimum(true);
@@ -72,7 +70,7 @@ bool Link::intelligentSimplify() {
                 type3Available.clear();
                 for (Crossing* c : use->crossings_)
                     for (side = 0; side < 2; ++side)
-                        if (use->r3(c, side, true, false))
+                        if (use->hasR3(c, side))
                             type3Available.emplace_back(c, side);
 
                 // Increment type3Cap if needed.
@@ -86,7 +84,8 @@ bool Link::intelligentSimplify() {
                 // Perform a random type III move on the clone.
                 type3Choice = type3Available[
                     RandomEngine::rand(type3Available.size())];
-                use->r3(type3Choice.first, type3Choice.second, false, true);
+                use->internalR3(type3Choice.first, type3Choice.second,
+                    false /* do not check */, true);
 
                 // See if we can simplify now.
                 if (use->simplifyToLocalMinimum(true)) {
@@ -117,39 +116,19 @@ bool Link::intelligentSimplify() {
 }
 
 bool Link::simplifyToLocalMinimum(bool perform) {
-    bool changed = false;   // Has anything changed ever (for return value)?
-    bool changedNow = true; // Did we just change something (for loop control)?
-
-    { // Begin scope for change event span.
-        ChangeEventSpan span(*this);
-
-        while (changedNow) {
-            changedNow = false;
-
-            // Look for type I or II Reidemeister moves.
-            for (Crossing* c : crossings_) {
-                if (r1(c, true, perform)) {
-                    changedNow = changed = true;
-                    break;
-                }
-                if (r2(c, true, perform)) {
-                    changedNow = changed = true;
-                    break;
-                }
-            }
-            if (changedNow) {
-                if (perform)
-                    continue;
-                else
-                    return true;
-            }
+    if (! perform) {
+        // Look for type I or II Reidemeister moves.
+        for (Crossing* c : crossings_) {
+            if (hasR1(c))
+                return true;
+            if (hasR2(StrandRef(c, 1)))
+                return true;
         }
-    } // End scope for change event span.
+        return false;
+    }
 
-    return changed;
-}
+    PacketChangeGroup span(*this);
 
-bool Tangle::simplifyToLocalMinimum(bool perform) {
     bool changed = false;   // Has anything changed ever (for return value)?
     bool changedNow = true; // Did we just change something (for loop control)?
 
@@ -158,21 +137,53 @@ bool Tangle::simplifyToLocalMinimum(bool perform) {
 
         // Look for type I or II Reidemeister moves.
         for (Crossing* c : crossings_) {
-            if (r1(c, true, perform)) {
+            if (r1(c)) {
                 changedNow = changed = true;
                 break;
             }
-            if (r2(c, true, perform)) {
+            if (r2(StrandRef(c, 1))) {
                 changedNow = changed = true;
                 break;
             }
         }
-        if (changedNow) {
-            if (perform)
-                continue;
-            else
+        if (changedNow)
+            continue;
+    }
+
+    return changed;
+}
+
+bool Tangle::simplifyToLocalMinimum(bool perform) {
+    if (! perform) {
+        // Look for type I or II Reidemeister moves.
+        for (Crossing* c : crossings_) {
+            if (hasR1(c))
+                return true;
+            if (hasR2(StrandRef(c, 1)))
                 return true;
         }
+        return false;
+    }
+
+    bool changed = false;   // Has anything changed ever (for return value)?
+    bool changedNow = true; // Did we just change something (for loop control)?
+
+    while (changedNow) {
+        changedNow = false;
+
+        // Look for type I or II Reidemeister moves.
+        for (Crossing* c : crossings_) {
+            if (r1(c)) {
+                changedNow = changed = true;
+                break;
+            }
+            if (r2(StrandRef(c, 1))) {
+                changedNow = changed = true;
+                break;
+            }
+        }
+        if (changedNow)
+            continue;
     }
 
     return changed;
