@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -332,22 +330,6 @@ class SFSAlt : public ShortOutput<SFSAlt> {
          */
         bool operator == (const SFSAlt& other) const;
 
-        /**
-         * Determines whether this and the given alternative representation
-         * do not have identical presentations.
-         *
-         * To be considered _identical_, the two alternatives must have equal
-         * alternative SFSpace representations, equal conversion matrices,
-         * and either both must have used a reflection or both must have
-         * not used a reflection.  In other words, this is equivalent to
-         * testing all of alt(), conversion() and reflected() for equality.
-         *
-         * \param other the alternative to compare against this.
-         * \return \c true if and only if this and the given alternative
-         * do not have identical presentations, as described above.
-         */
-        bool operator != (const SFSAlt& other) const;
-
         /**
          * Writes a short text representation of this object to the
          * given output stream.
@@ -422,11 +404,6 @@ inline bool SFSAlt::operator == (const SFSAlt& other) const {
         reflected_ == other.reflected_;
 }
 
-inline bool SFSAlt::operator != (const SFSAlt& other) const {
-    return alt_ != other.alt_ || conversion_ != other.conversion_ ||
-        reflected_ != other.reflected_;
-}
-
 inline void SFSAlt::writeTextShort(std::ostream& out) const {
     alt_.writeTextShort(out);
     out << ", via " << conversion_;
