@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -109,7 +107,7 @@ class SnapPeaCensusManifold : public Manifold {
             /**< The section of the SnapPea census to which this
                  manifold belongs.  This must be one of the section
                  constants defined in this class. */
-        unsigned long index_;
+        size_t index_;
             /**< The index within the given section of this specific
                  manifold.  Note that the first index in each section
                  is zero. */
@@ -127,7 +125,7 @@ class SnapPeaCensusManifold : public Manifold {
          * must be between 0 and <i>k</i>-1, where \a k is the total
          * number of manifolds in the given section.
          */
-        SnapPeaCensusManifold(char section, unsigned long index);
+        SnapPeaCensusManifold(char section, size_t index);
         /**
          * Creates a new copy of the given SnapPea census manifold.
          */
@@ -147,7 +145,7 @@ class SnapPeaCensusManifold : public Manifold {
          *
          * \return the index of this manifold within its section.
          */
-        unsigned long index() const;
+        size_t index() const;
         /**
          * Determines whether this and the given structure represent
          * the same 3-manifold from the SnapPea census.
@@ -162,20 +160,6 @@ class SnapPeaCensusManifold : public Manifold {
          * represent the same SnapPea census manifold.
          */
         bool operator == (const SnapPeaCensusManifold& compare) const;
-        /**
-         * Determines whether this and the given structure represent
-         * different 3-manifolds from the SnapPea census.
-         *
-         * As of Regina 5.0, this test respects the recent discovery that
-         * the manifolds \c x101 and \c x103 are homeomorphic.
-         * For details, see B.B., _A duplicate pair in the SnapPea census_,
-         * Experimental Mathematics, 23:170-173, 2014.
-         *
-         * \param compare the structure with which this will be compared.
-         * \return \c true if and only if this and the given structure
-         * represent different SnapPea census manifolds.
-         */
-        bool operator != (const SnapPeaCensusManifold& compare) const;
 
         /**
          * Sets this to be a copy of the given SnapPea census manifold.
@@ -217,12 +201,12 @@ void swap(SnapPeaCensusManifold& a, SnapPeaCensusManifold& b) noexcept;
 // Inline functions for SnapPeaCensusManifold
 
 inline SnapPeaCensusManifold::SnapPeaCensusManifold(char section,
-        unsigned long index) : section_(section), index_(index) {
+        size_t index) : section_(section), index_(index) {
 }
 inline char SnapPeaCensusManifold::section() const {
     return section_;
 }
-inline unsigned long SnapPeaCensusManifold::index() const {
+inline size_t SnapPeaCensusManifold::index() const {
     return index_;
 }
 inline bool SnapPeaCensusManifold::operator == (
@@ -233,14 +217,6 @@ inline bool SnapPeaCensusManifold::operator == (
         return true;
     return (section_ == compare.section_ && index_ == compare.index_);
 }
-inline bool SnapPeaCensusManifold::operator != (
-        const SnapPeaCensusManifold& compare) const {
-    if (section_ == SEC_6_NOR && compare.section_ == SEC_6_NOR &&
-            (index_ == 101 || index_ == 103) &&
-            (compare.index_ == 101 || compare.index_ == 103))
-        return false;
-    return (section_ != compare.section_ || index_ != compare.index_);
-}
 inline bool SnapPeaCensusManifold::isHyperbolic() const {
     return true;
 }
