@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -169,21 +167,6 @@ class TorusBundle : public Manifold {
          */
         bool operator == (const TorusBundle& compare) const;
 
-        /**
-         * Determines whether this and the given object do not contain
-         * precisely the same presentations of the same torus bundle.
-         *
-         * This routine does _not_ test for homeomorphism; instead it compares
-         * the specific monodromies.  If you have two objects that represent
-         * same torus bundle using two different monodromies, they will
-         * be treated as not equal by this routine.
-         *
-         * \param compare the presentation with which this will be compared.
-         * \return \c true if and only if this and the given object do not
-         * contain identical presentations of the same torus bundle.
-         */
-        bool operator != (const TorusBundle& compare) const;
-
         AbelianGroup homology() const override;
         bool isHyperbolic() const override;
         std::ostream& writeName(std::ostream& out) const override;
@@ -350,10 +333,6 @@ inline bool TorusBundle::operator == (const TorusBundle& compare) const {
     return monodromy_ == compare.monodromy_;
 }
 
-inline bool TorusBundle::operator != (const TorusBundle& compare) const {
-    return monodromy_ != compare.monodromy_;
-}
-
 inline void swap(TorusBundle& a, TorusBundle& b) noexcept {
     a.swap(b);
 }
