@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -59,7 +57,7 @@ namespace regina {
  * `deg(Φ_n) = φ(n)`, where `φ` denotes Euler's totient function.
  * This class stores field elements using such a polynomial representation,
  * and does _not_ store complex numbers directly.  If you require the
- * complex value of a field element (as a floating point approximation),
+ * complex value of a field element (as a floating-point approximation),
  * you can call evaluate().
  *
  * Each object of this class stores both the value of the field element
@@ -85,6 +83,11 @@ class Cyclotomic : public ShortOutput<Cyclotomic, true> {
             /**< The type of each coefficient of the polynomial that is
                  used to store a field element. */
 
+        // Make sure the compiler can see the zero-argument string output
+        // routines, since we declare alternative versions of these below.
+        using ShortOutput<Cyclotomic, true>::str;
+        using ShortOutput<Cyclotomic, true>::utf8;
+
     private:
         size_t field_;
             /**< The order \a n of the underlying cyclotomic field.
@@ -343,8 +346,8 @@ class Cyclotomic : public ShortOutput<Cyclotomic, true> {
          * a non-default constructor, an assignment operator, or by
          * calling init()).
          *
-         * \warning This routine uses floating point arithmetic, and so the
-         * value that it returns is subject to the usual floating point error.
+         * \warning This routine uses floating-point arithmetic, and so the
+         * value that it returns is subject to the usual floating-point error.
          *
          * \param whichRoot indicates which root of unity will be used
          * to convert the polynomial representation of this field
@@ -374,27 +377,6 @@ class Cyclotomic : public ShortOutput<Cyclotomic, true> {
          */
         bool operator == (const Cyclotomic& rhs) const;
 
-        /**
-         * Tests whether or not this and the given argument are the same
-         * element of the same cyclotomic field.
-         *
-         * If this and \a rhs have different underlying fields then
-         * this test will always return \c true (indicating that the
-         * elements are not equal), even if they take the same numerical
-         * value when evaluated as complex numbers.
-         *
-         * If either this or \a rhs have not been initialised (typically
-         * because they were created using the default constructor),
-         * then this comparison will return \c true.  If _both_ field
-         * elements have not been initialised, then this comparison will
-         * return \c false.
-         *
-         * \param rhs the value to compare with this.
-         * \return \c false if this and \a rhs are the same element of the
-         * same cyclotomic field, or \c true if they are not.
-         */
-        bool operator != (const Cyclotomic& rhs) const;
-
         /**
          * Sets this to a copy of the given field element.
          *
@@ -953,15 +935,6 @@ inline bool Cyclotomic::operator == (const Cyclotomic& rhs) const {
     return true;
 }
 
-inline bool Cyclotomic::operator != (const Cyclotomic& rhs) const {
-    if (field_ != rhs.field_)
-        return true;
-    for (size_t i = 0; i < degree_; ++i)
-        if (coeff_[i] != rhs.coeff_[i])
-            return true;
-    return false;
-}
-
 // Self-assignment works, assuming Rational's self-assignment works.
 // NOLINTNEXTLINE(bugprone-unhandled-self-assignment)
 inline Cyclotomic& Cyclotomic::operator = (const Cyclotomic& other) {
