@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -122,11 +120,17 @@ class Laurent :
         Laurent();
 
         /**
-         * Creates the polynomial `x^d` for the given exponent \a d.
+         * Deprecated constructor that creates the polynomial `x^d` for the
+         * given exponent \a d.
+         *
+         * \deprecated This will be removed in a future version of Regina,
+         * since in casual reading of code it is too easy to misread this as
+         * creating a polynomial with only a constant term.  You can still
+         * create `x^d` by calling `initExp(d)` instead.
          *
          * \param exponent the exponent to use for the new polynomial.
          */
-        explicit Laurent(long exponent);
+        [[deprecated]] explicit Laurent(long exponent);
 
         /**
          * Creates a new copy of the given polynomial.
@@ -232,7 +236,19 @@ class Laurent :
          *
          * \param exponent the new exponent to use for this polynomial.
          */
-        void init(long exponent);
+        void initExp(long exponent);
+
+        /**
+         * Deprecated function that sets this to become the polynomial `x^d`
+         * for the given exponent \a d.
+         *
+         * \deprecated This has been renamed to initExp(), since in casual
+         * reading of code it is too easy to misread this as setting this
+         * polynomial to have only a constant term.
+         *
+         * \param exponent the new exponent to use for this polynomial.
+         */
+        [[deprecated]] void init(long exponent);
 
         /**
          * Sets this to become the polynomial described by the given
@@ -341,15 +357,6 @@ class Laurent :
          */
         bool operator == (const Laurent<T>& rhs) const;
 
-        /**
-         * Tests whether this and the given polynomial are not equal.
-         *
-         * \param rhs the polynomial to compare with this.
-         * \return \c true if and only if this and the given polynomial
-         * are not equal.
-         */
-        bool operator != (const Laurent<T>& rhs) const;
-
         /**
          * Compares this against the given polynomial under a total
          * ordering of all one-variable Laurent polynomials.
@@ -360,59 +367,17 @@ class Laurent :
          * is to support algorithms that require a "canonical" choice of
          * polynomial from amongst many alternatives.
          *
-         * \param rhs the polynomial to compare with this.
-         * \return \c true if and only if this is less than the given
-         * polynomial under the total order that Regina uses.
-         */
-        bool operator < (const Laurent<T>& rhs) const;
-
-        /**
-         * Compares this against the given polynomial under a total
-         * ordering of all one-variable Laurent polynomials.
+         * This routine generates all of the usual comparison operators,
+         * including `<`, `<=`, `>`, and `>=`.
          *
-         * The particular total order that Regina uses is not important,
-         * and may change between Regina releases (though such changes
-         * should be very infrequent).  The main purpose of this routine
-         * is to support algorithms that require a "canonical" choice of
-         * polynomial from amongst many alternatives.
+         * \python This spaceship operator `x <=> y` is not available, but the
+         * other comparison operators that it generates _are_ available.
          *
          * \param rhs the polynomial to compare with this.
-         * \return \c true if and only if this is greater than the given
-         * polynomial under the total order that Regina uses.
+         * \return The result of the comparison between this
+         * and the given polynomial.
          */
-        bool operator > (const Laurent<T>& rhs) const;
-
-        /**
-         * Compares this against the given polynomial under a total
-         * ordering of all one-variable Laurent polynomials.
-         *
-         * The particular total order that Regina uses is not important,
-         * and may change between Regina releases (though such changes
-         * should be very infrequent).  The main purpose of this routine
-         * is to support algorithms that require a "canonical" choice of
-         * polynomial from amongst many alternatives.
-         *
-         * \param rhs the polynomial to compare with this.
-         * \return \c true if and only if this is less than or equal to the
-         * given polynomial under the total order that Regina uses.
-         */
-        bool operator <= (const Laurent<T>& rhs) const;
-
-        /**
-         * Compares this against the given polynomial under a total
-         * ordering of all one-variable Laurent polynomials.
-         *
-         * The particular total order that Regina uses is not important,
-         * and may change between Regina releases (though such changes
-         * should be very infrequent).  The main purpose of this routine
-         * is to support algorithms that require a "canonical" choice of
-         * polynomial from amongst many alternatives.
-         *
-         * \param rhs the polynomial to compare with this.
-         * \return \c true if and only if this is greater than or equal to
-         * the given polynomial under the total order that Regina uses.
-         */
-        bool operator >= (const Laurent<T>& rhs) const;
+        std::strong_ordering operator <=> (const Laurent<T>& rhs) const;
 
         /**
          * Sets this to be a copy of the given polynomial.
@@ -502,6 +467,9 @@ class Laurent :
          * \pre All exponents in this polynomial with non-zero coefficients
          * are multiples of \a k.
          *
+         * \exception FailedPrecondition Either \a k is zero, or some exponent
+         * with a non-zero coefficient is not a multiple of \a k.
+         *
          * \param k the scaling factor to divide exponents by.
          */
         void scaleDown(long k);
@@ -655,7 +623,7 @@ class Laurent :
          * The tight encoding will be read from the given input stream.
          * If the input stream contains leading whitespace then it will be
          * treated as an invalid encoding (i.e., this routine will throw an
-         * exception).  The input routine _may_ contain further data: if this
+         * exception).  The input stream _may_ contain further data: if this
          * routine is successful then the input stream will be left positioned
          * immediately after the encoding, without skipping any trailing
          * whitespace.
@@ -747,6 +715,15 @@ class Laurent :
     friend Laurent<U> operator * (const Laurent<U>&, const Laurent<U>&);
 };
 
+#ifndef __DOXYGEN
+// Don't confuse doxygen with specialisations.
+template <typename T>
+struct RingTraits<Laurent<T>> {
+    inline static const Laurent<T> zero;
+    inline static const Laurent<T> one { 0, { 1 } };
+};
+#endif // __DOXYGEN
+
 /**
  * Swaps the contents of the given polynomials.
  *
@@ -1032,13 +1009,18 @@ inline void Laurent<T>::init() {
 }
 
 template <typename T>
-inline void Laurent<T>::init(long exp) {
+inline void Laurent<T>::initExp(long exp) {
     delete[] coeff_;
     minExp_ = maxExp_ = base_ = exp;
     coeff_ = new T[1];
     coeff_[0] = 1;
 }
 
+template <typename T>
+inline void Laurent<T>::init(long exp) {
+    initExp(exp);
+}
+
 template <typename T>
 template <typename iterator>
 void Laurent<T>::init(long minExp, iterator begin, iterator end) {
@@ -1165,65 +1147,24 @@ inline bool Laurent<T>::operator == (const Laurent<T>& rhs) const {
 }
 
 template <typename T>
-inline bool Laurent<T>::operator != (const Laurent<T>& rhs) const {
-    if (minExp_ != rhs.minExp_ || maxExp_ != rhs.maxExp_)
-        return true;
-    for (long i = minExp_; i <= maxExp_; ++i)
-        if ((*this)[i] != rhs[i])
-            return true;
-    return false;
-}
-
-template <typename T>
-bool Laurent<T>::operator < (const Laurent<T>& rhs) const {
+std::strong_ordering Laurent<T>::operator <=> (const Laurent<T>& rhs) const {
     if (minExp_ < rhs.minExp_)
-        return true;
+        return std::strong_ordering::less;
     else if (minExp_ > rhs.minExp_)
-        return false;
+        return std::strong_ordering::greater;
 
     if (maxExp_ < rhs.maxExp_)
-        return true;
+        return std::strong_ordering::less;
     else if (maxExp_ > rhs.maxExp_)
-        return false;
+        return std::strong_ordering::greater;
 
     for (long i = minExp_; i <= maxExp_; ++i)
         if ((*this)[i] < rhs[i])
-            return true;
+            return std::strong_ordering::less;
         else if ((*this)[i] > rhs[i])
-            return false;
+            return std::strong_ordering::greater;
 
-    return false;
-}
-
-template <typename T>
-inline bool Laurent<T>::operator > (const Laurent<T>& rhs) const {
-    return (rhs < *this);
-}
-
-template <typename T>
-bool Laurent<T>::operator <= (const Laurent<T>& rhs) const {
-    if (minExp_ < rhs.minExp_)
-        return true;
-    else if (minExp_ > rhs.minExp_)
-        return false;
-
-    if (maxExp_ < rhs.maxExp_)
-        return true;
-    else if (maxExp_ > rhs.maxExp_)
-        return false;
-
-    for (long i = minExp_; i <= maxExp_; ++i)
-        if ((*this)[i] < rhs[i])
-            return true;
-        else if ((*this)[i] > rhs[i])
-            return false;
-
-    return true;
-}
-
-template <typename T>
-inline bool Laurent<T>::operator >= (const Laurent<T>& rhs) const {
-    return (rhs <= *this);
+    return std::strong_ordering::equal;
 }
 
 template <typename T>
@@ -1329,9 +1270,16 @@ void Laurent<T>::scaleUp(long k) {
 
 template <typename T>
 void Laurent<T>::scaleDown(long k) {
+    if (k == 0)
+        throw FailedPrecondition("scaleDown() requires a non-zero "
+            "scaling factor");
     if (k == 1)
         return;
 
+    if (minExp_ % k != 0)
+        throw FailedPrecondition("scaleDown(k) requires every exponent "
+            "with a non-zero coefficient to be divisible by k");
+
     if (minExp_ == maxExp_ && base_ == minExp_) {
         minExp_ /= k;
         maxExp_ /= k;
@@ -1339,22 +1287,45 @@ void Laurent<T>::scaleDown(long k) {
         return;
     }
 
+    if (maxExp_ % k != 0)
+        throw FailedPrecondition("scaleDown(k) requires every exponent "
+            "with a non-zero coefficient to be divisible by k");
+
     T* newCoeff;
     if (k > 0) {
         newCoeff = new T[(maxExp_ - minExp_) / k + 1];
-        for (long i = 0; i <= (maxExp_ - minExp_) / k; ++i)
-            newCoeff[i] = coeff_[minExp_ - base_ + k * i];
-        minExp_ /= k;
-        maxExp_ /= k;
+        const T* src = coeff_ + (minExp_ - base_);
+        const T* srcEnd = coeff_ + (maxExp_ - base_);
+        T* dest = newCoeff;
+        while (src != srcEnd) {
+            *dest++ = *src++;
+            for (long i = 1; i < k; ++i)
+                if ((*src++) != 0)
+                    throw FailedPrecondition("scaleDown(k) requires every "
+                        "exponent with a non-zero coefficient to be "
+                        "divisible by k");
+        }
+        *dest = *src;
     } else {
         newCoeff = new T[(minExp_ - maxExp_) / k + 1];
-        for (long i = (minExp_ - maxExp_) / k; i >= 0; --i)
-            newCoeff[i] = coeff_[maxExp_ - base_ + k * i];
-        minExp_ /= k;
-        maxExp_ /= k;
+        const T* src = coeff_ + (maxExp_ - base_);
+        const T* srcEnd = coeff_ + (minExp_ - base_);
+        T* dest = newCoeff;
+        while (src != srcEnd) {
+            *dest++ = *src--;
+            for (long i = -1; i > k; --i)
+                if ((*src--) != 0)
+                    throw FailedPrecondition("scaleDown(k) requires every "
+                        "exponent with a non-zero coefficient to be "
+                        "divisible by k");
+        }
+        *dest = *src;
         std::swap(minExp_, maxExp_);
     }
 
+    minExp_ /= k;
+    maxExp_ /= k;
+
     base_ = minExp_;
     delete[] coeff_;
     coeff_ = newCoeff;
