@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -38,6 +36,7 @@
 #include <array>
 #include <iostream>
 #include "regina-core.h"
+#include "maths/ring.h"
 
 /*! \file maths/matrix2.h
  *  \brief Deals with 2x2 integer matrices.
@@ -100,7 +99,7 @@ class Matrix2 {
         void swap(Matrix2& other) noexcept;
 
         /**
-         * Returns a single row of this matrix.
+         * Gives read-only access to a single row of this matrix.
          *
          * This means that the integer in row \a r, column \a c can be
          * accessed as `myMatrix[r][c]` (where \a r and \a c are
@@ -110,19 +109,19 @@ class Matrix2 {
          * \return a two-integer array containing the elements of the
          * requested row.
          */
-        const std::array<long, 2>& operator [] (unsigned row) const;
+        const std::array<long, 2>& operator [] (int row) const;
         /**
-         * Returns a single row of this matrix.
+         * Gives read-write access to a single row of this matrix.
          *
          * This means that the integer in row \a r, column \a c can be
          * accessed as `myMatrix[r][c]` (where \a r and \a c are
          * each 0 or 1).  Each such element may be modified directly.
          *
          * \param row the index of the requested row; this must be 0 or 1.
-         * \return a two-integer array containing the elements of the
-         * requested row.
+         * \return a reference to the two-integer array containing the
+         * elements of the requested row.
          */
-        std::array<long, 2>& operator [] (unsigned row);
+        std::array<long, 2>& operator [] (int row);
 
         /**
          * Calculates the matrix product of this and the given matrix.
@@ -234,18 +233,10 @@ class Matrix2 {
         /**
          * Determines if this is equal to the given matrix.
          *
-         * \param compare the matrix with which this will be compared.
-         * \return \c true if and only if this matrix is equal to \a compare.
+         * \return \c true if and only if this matrix is equal to the given
+         * matrix.
          */
-        bool operator == (const Matrix2& compare) const;
-        /**
-         * Determines if this is not equal to the given matrix.
-         *
-         * \param compare the matrix with which this will be compared.
-         * \return \c true if and only if this matrix is not equal to
-         * \a compare.
-         */
-        bool operator != (const Matrix2& compare) const;
+        bool operator == (const Matrix2&) const = default;
 
         /**
          * Returns the determinant of this matrix.
@@ -271,6 +262,15 @@ class Matrix2 {
     friend std::ostream& operator << (std::ostream& out, const Matrix2& mat);
 };
 
+#ifndef __DOXYGEN
+// Don't confuse doxygen with specialisations.
+template <>
+struct RingTraits<Matrix2> {
+    inline static const Matrix2 zero;
+    inline static const Matrix2 one { 1, 0, 0, 1 };
+};
+#endif // __DOXYGEN
+
 /**
  * Swaps the contents of the two given matrices.
  *
@@ -298,30 +298,75 @@ void swap(Matrix2& a, Matrix2& b) noexcept;
 std::ostream& operator << (std::ostream& out, const Matrix2& mat);
 
 /**
- * Determines whether the first given matrix is more aesthetically
- * pleasing than the second.  The way in which this judgement is made
- * is purely aesthetic on the part of the author, and is subject to
- * change in future versions of Regina.
+ * Compare two matrices to determine which is more aesthetically pleasing.
+ * The way in which this judgement is made is purely aesthetic on the part
+ * of the author, and is subject to change in future versions of Regina.
+ *
+ * \python Instead of a `std::strong_ordering`, this routine returns an
+ * integer -1, 0 or 1 (representing `less`, `equal` or `greater` respectively).
  *
  * \param m1 the first matrix to examine.
  * \param m2 the second matrix to examine.
- * \return \c true if \a m1 is deemed to be more pleasing than \a m2,
- * or \c false if either the matrices are equal or \a m2 is more
- * pleasing than \a m1.
+ * \return `less` if \a m1 is deemed to be more pleasing than \a m2,
+ * `greater` if \a m2 is more pleasing than \a m1, or `equal` if both matrices
+ * are equal.
  *
  * \ingroup maths
  */
-bool simpler(const Matrix2& m1, const Matrix2& m2);
+std::strong_ordering simplerThreeWay(const Matrix2& m1, const Matrix2& m2);
 
 /**
- * Determines whether the first given pair of matrices is more aesthetically
- * pleasing than the second pair.  The way in which this judgement is made
- * is purely aesthetic on the part of the author, and is subject to
- * change in future versions of Regina.
+ * Deprecated routine that determines whether the first given matrix is
+ * more aesthetically pleasing than the second.
+ *
+ * \deprecated This routine is implemented using simplerThreeWay(), and new
+ * code should use that routine instead.  See simplerThreeWay() for further
+ * discussion.
+ *
+ * \param m1 the first matrix to examine.
+ * \param m2 the second matrix to examine.
+ * \return \c true if \a m1 is deemed to be more pleasing than \a m2, or
+ * \c false if either the matrices are equal or \a m2 is more pleasing than
+ * \a m1.
+ *
+ * \ingroup maths
+ */
+[[deprecated]] bool simpler(const Matrix2& m1, const Matrix2& m2);
+
+/**
+ * Compares two ordered pairs of matrices to determine which pair is more
+ * aesthetically pleasing.  The way in which this judgement is made is purely
+ * aesthetic on the part of the author, and is subject to change in future
+ * versions of Regina.
  *
  * Note that pairs are ordered, so the pair (\a M, \a N) may be more
  * (or perhaps less) pleasing than the pair (\a N, \a M).
  *
+ * \python Instead of a `std::strong_ordering`, this routine returns an
+ * integer -1, 0 or 1 (representing `less`, `equal` or `greater` respectively).
+ *
+ * \param pair1first the first matrix of the first pair to examine.
+ * \param pair1second the second matrix of the first pair to examine.
+ * \param pair2first the first matrix of the second pair to examine.
+ * \param pair2second the second matrix of the second pair to examine.
+ * \return `less` if the first pair is deemed to be more pleasing than the
+ * second pair, `greater` if the second pair is more pleasing than the first,
+ * or `equal` if both ordered pairs are equal.
+ *
+ * \ingroup maths
+ */
+std::strong_ordering simplerThreeWay(
+        const Matrix2& pair1first, const Matrix2& pair1second,
+        const Matrix2& pair2first, const Matrix2& pair2second);
+
+/**
+ * Deprecated routine that determines whether the first given pair of matrices
+ * is more aesthetically pleasing than the second pair.
+ *
+ * \deprecated This routine is implemented using simplerThreeWay(), and new
+ * code should use that routine instead.  See simplerThreeWay() for further
+ * discussion.
+ *
  * \param pair1first the first matrix of the first pair to examine.
  * \param pair1second the second matrix of the first pair to examine.
  * \param pair2first the first matrix of the second pair to examine.
@@ -332,7 +377,8 @@ bool simpler(const Matrix2& m1, const Matrix2& m2);
  *
  * \ingroup maths
  */
-bool simpler(const Matrix2& pair1first, const Matrix2& pair1second,
+[[deprecated]] bool simpler(
+        const Matrix2& pair1first, const Matrix2& pair1second,
         const Matrix2& pair2first, const Matrix2& pair2second);
 
 // Inline functions for Matrix2
@@ -348,11 +394,11 @@ inline void Matrix2::swap(Matrix2& other) noexcept {
     data_.swap(other.data_);
 }
 
-inline const std::array<long, 2>& Matrix2::operator [] (unsigned row) const {
+inline const std::array<long, 2>& Matrix2::operator [] (int row) const {
     return data_[row];
 }
 
-inline std::array<long, 2>& Matrix2::operator [] (unsigned row) {
+inline std::array<long, 2>& Matrix2::operator [] (int row) {
     return data_[row];
 }
 
@@ -413,14 +459,6 @@ inline void Matrix2::negate() {
     data_[1][0] = -data_[1][0]; data_[1][1] = -data_[1][1];
 }
 
-inline bool Matrix2::operator == (const Matrix2& compare) const {
-    return data_ == compare.data_;
-}
-
-inline bool Matrix2::operator != (const Matrix2& compare) const {
-    return data_ != compare.data_;
-}
-
 inline long Matrix2::determinant() const {
     return data_[0][0] * data_[1][1] - data_[0][1] * data_[1][0];
 }
@@ -444,6 +482,16 @@ inline void swap(Matrix2& a, Matrix2& b) noexcept {
     a.swap(b);
 }
 
+inline bool simpler(const Matrix2& m1, const Matrix2& m2) {
+    return simplerThreeWay(m1, m2) == std::strong_ordering::less;
+}
+
+inline bool simpler(const Matrix2& pair1first, const Matrix2& pair1second,
+        const Matrix2& pair2first, const Matrix2& pair2second) {
+    return simplerThreeWay(pair1first, pair1second, pair2first, pair2second) ==
+        std::strong_ordering::less;
+}
+
 } // namespace regina
 
 #endif
