@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -59,6 +57,8 @@ namespace regina {
  *
  * \pre \a modBase is strictly positive.
  *
+ * \exception InvalidArgument The argument \a modBase is zero or negative.
+ *
  * \param k the number to reduce modulo \a modBase.
  * \param modBase the modular base in which to work.
  *
@@ -96,14 +96,16 @@ long reducedMod(long k, long modBase);
  * tuple (\a d, \a u, \a v), where \a u and \a v are coefficients for which:
  *
  * - `u⋅a + v⋅b = d`;
- * - `-abs(a)/d < v⋅sign(b) ≤ 0`; and
- * - `1 ≤ u⋅sign(a) ≤ abs(b)/d`.
+ * - `-|a|/d < v⋅sign(b) ≤ 0 < u⋅sign(a) ≤ |b|/d`.
  *
  * In the special case where one of the given integers is zero, the
  * corresponding coefficient will also be zero and the other coefficient
  * will be 1 or -1 so that `u⋅a + v⋅b = d` still holds.  If both
  * given integers are zero, both of the coefficients will be set to zero.
  *
+ * \warning This routine might give incorrect answers if a or b is precisely
+ * LONG_MIN, since this value cannot be correctly negated as a \c long.
+ *
  * \param a the first integer to compute the gcd of.
  * \param b the second integer to compute the gcd of.
  * \return a tuple containing: the greatest common divisor of \a a and \a b;
@@ -121,7 +123,7 @@ std::tuple<long, long, long> gcdWithCoeffs(long a, long b);
  * If either of the arguments is zero, the return value will also be zero.
  *
  * Regarding possible overflow:  This routine does not create any temporary
- * integers that are larger than the final LCM.
+ * integers that are larger in magnitude than the final LCM.
  *
  * \deprecated Simply use std::lcm(), which was introduced with C++17.
  *
@@ -135,10 +137,16 @@ std::tuple<long, long, long> gcdWithCoeffs(long a, long b);
 
 /**
  * Calculates the multiplicative inverse of one integer modulo another.
- * The inverse returned will be between 0 and <i>n</i>-1 inclusive.
+ * Specifically, this computes the inverse of \a k modulo \a n, and
+ * returns a result between 0 and `n - 1` inclusive.
  *
- * \pre \a n and \a k are both strictly positive;
- * \pre \a n and \a k have no common factors.
+ * Note that `n == 1` _is_ allowed, and will return 0 for any \a k.
+ *
+ * \pre \a n is strictly positive;
+ * \pre \a n and \a k are coprime.
+ *
+ * \exception InvalidArgument Either \a n is zero or negative, or the given
+ * arguments are not coprime.
  *
  * \param n the modular base in which to work.
  * \param k the number whose multiplicative inverse should be found.
@@ -146,7 +154,7 @@ std::tuple<long, long, long> gcdWithCoeffs(long a, long b);
  *
  * \ingroup maths
  */
-unsigned long modularInverse(unsigned long n, unsigned long k);
+long modularInverse(long n, long k);
 
 } // namespace regina
 
