@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -144,7 +142,7 @@ PermGroup<n, cached>::PermGroup(NamedPermGroup group) {
     // Remember: all permutations not explicitly set here will be
     // initialised to the identity.
     switch (group) {
-        case PERM_GROUP_SYMMETRIC:
+        case NamedPermGroup::Symmetric:
             for (int k = 1; k < n; ++k)
                 for (int j = 0; j < k; ++j) {
                     // These terms are all self-inverse.
@@ -154,7 +152,7 @@ PermGroup<n, cached>::PermGroup(NamedPermGroup group) {
                 count_[i] = i + 1;
             // Each usable_[i] should be the identity.
             break;
-        case PERM_GROUP_ALTERNATING:
+        case NamedPermGroup::Alternating:
             for (int k = 2; k < n; ++k) {
                 // Each non-trivial term should be a 3-cycle.
                 if constexpr (cached) {
