@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -51,24 +49,49 @@ namespace regina {
  * \a n elements for arbitrary \a n.  (In particular, you can pass them
  * to the PermGroup<n> constructor.)
  */
-enum NamedPermGroup {
+enum class NamedPermGroup {
     /**
      * Represents the trivial group on \a n elements, containing only the
      * identity permutation.
      */
-    PERM_GROUP_TRIVIAL = 0,
+    Trivial = 0,
     /**
      * Represents the symmetric group on \a n elements, containing all `n!`
      * possible permutations.
      */
-    PERM_GROUP_SYMMETRIC = 1,
+    Symmetric = 1,
     /**
      * Represents the alternating group on \a n elements, containing all `n!/2`
      * even permutations.
      */
-    PERM_GROUP_ALTERNATING = 2
+    Alternating = 2
 };
 
+/**
+ * A deprecated constant indicating a well-known class of permutation groups.
+ *
+ * \deprecated This has been renamed to the scoped enumeration constant
+ * NamedPermGroup::Trivial.
+ */
+[[deprecated]] inline constexpr NamedPermGroup PERM_GROUP_TRIVIAL =
+    NamedPermGroup::Trivial;
+/**
+ * A deprecated constant indicating a well-known class of permutation groups.
+ *
+ * \deprecated This has been renamed to the scoped enumeration constant
+ * NamedPermGroup::Symmetric.
+ */
+[[deprecated]] inline constexpr NamedPermGroup PERM_GROUP_SYMMETRIC =
+    NamedPermGroup::Symmetric;
+/**
+ * A deprecated constant indicating a well-known class of permutation groups.
+ *
+ * \deprecated This has been renamed to the scoped enumeration constant
+ * NamedPermGroup::Alternating.
+ */
+[[deprecated]] inline constexpr NamedPermGroup PERM_GROUP_ALTERNATING =
+    NamedPermGroup::Alternating;
+
 /**
  * Represents a group of permutations on \a n elements.  This is a subgroup
  * of the symmetric group `S_n`.
@@ -251,22 +274,6 @@ class PermGroup : public Output<PermGroup<n, cached>> {
                  * permutation, or \c false if they do not.
                  */
                 bool operator == (const iterator& rhs) const;
-                /**
-                 * Compares this with the given iterator for inequality.
-                 *
-                 * To be considered equal, two iterators must be pointing
-                 * to the same permutation within the same group.
-                 * (The second condition means that the underlying PermGroup
-                 * pointers must be the same - it is not enough to have
-                 * two distinct PermGorup objects with identical contents.)
-                 *
-                 * Two past-the-end iterators will always be considered equal.
-                 *
-                 * \param rhs the iterator to compare this with.
-                 * \return \c false if the iterators point to the same
-                 * permutation, or \c true if they do not.
-                 */
-                bool operator != (const iterator& rhs) const;
 
                 /**
                  * The preincrement operator.
@@ -291,9 +298,9 @@ class PermGroup : public Output<PermGroup<n, cached>> {
                 /**
                  * Returns the current permutation and increments this iterator.
                  *
-                 * \nocpp For C++ users, ChildIterator provides the usual
-                 * iterator preincrement, postincrement and dereferencing
-                 * operators (++ and *) instead.
+                 * \nocpp For C++ users, this iterator class provides the usual
+                 * preincrement, postincrement and dereferencing operators
+                 * (++ and *) instead.
                  *
                  * \exception StopIteration The iterator is already past-the-end
                  * when this function is called.
@@ -431,6 +438,9 @@ class PermGroup : public Output<PermGroup<n, cached>> {
         /**
          * Returns the total number of elements in this group.
          *
+         * \python This is also used to implement the Python special
+         * method __len__().
+         *
          * \return the size of this group.
          */
         typename Perm<n>::Index size() const;
@@ -463,23 +473,6 @@ class PermGroup : public Output<PermGroup<n, cached>> {
          * the same permutations.
          */
         bool operator == (const PermGroup& other) const;
-        /**
-         * Indicates whether this and the given group are different.
-         *
-         * This does _not_ test group isomorphism, and it does _not_
-         * test whether the two groups use the same internal representation.
-         * Instead it tests _membership_; that is, whether or not the two
-         * groups contain precisely the same set of permutations.
-         *
-         * As a result, this test is not trivial.  It _is_ small polynomial
-         * time in \a n, but it is not as fast as (for example) directly
-         * comparing the internal representations.
-         *
-         * \param other the group to compare this with.
-         * \return \c true if and only if there is some permutation that
-         * belongs to one group but not the other.
-         */
-        bool operator != (const PermGroup& other) const;
 
         /**
          * Returns a C++ iterator pointing to the first element of this group.
@@ -614,19 +607,6 @@ inline bool PermGroup<n, cached>::iterator::operator == (
     }
 }
 
-template <int n, bool cached>
-inline bool PermGroup<n, cached>::iterator::operator != (
-        const PermGroup<n, cached>::iterator& rhs) const {
-    // See the == operator for an explanation.
-    if (*this) {
-        // This is dereferenceable.
-        return (! rhs) || (current_ != rhs.current_) || (group_ != rhs.group_);
-    } else {
-        // This is past-the-end.
-        return rhs;
-    }
-}
-
 template <int n, bool cached>
 inline typename PermGroup<n, cached>::iterator
         PermGroup<n, cached>::iterator::operator ++(int) {
@@ -780,11 +760,6 @@ inline typename Perm<n>::Index PermGroup<n, cached>::size() const {
     return ans;
 }
 
-template <int n, bool cached>
-inline bool PermGroup<n, cached>::operator != (const PermGroup& other) const {
-    return ! ((*this) == other);
-}
-
 template <int n, bool cached>
 inline typename PermGroup<n, cached>::iterator PermGroup<n, cached>::begin()
         const {
