@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -90,15 +88,15 @@ class Rational {
         /**
          * Represents the available flavours of rational number.
          */
-        enum flavourType {
-            f_infinity,
+        enum class Flavour {
+            Infinity,
                 /**< Infinity; there is only one rational of this type. */
-            f_undefined,
+            Undefined,
                 /**< Undefined; there is only one rational of this type. */
-            f_normal
+            Normal
                 /**< An ordinary rational (the denominator is non-zero). */
         };
-        flavourType flavour;
+        Flavour flavour;
             /**< Stores whether this rational is infinity, undefined or
              *   normal (non-zero denominator). */
         mpq_t data;
@@ -141,8 +139,8 @@ class Rational {
          *
          * \param value the new integer value of this rational.
          */
-        template <bool supportInfinity>
-        Rational(const IntegerBase<supportInfinity>& value);
+        template <bool withInfinity>
+        Rational(const IntegerBase<withInfinity>& value);
         /**
          * Initialises to the given integer value.
          *
@@ -167,9 +165,9 @@ class Rational {
          * \param num the new numerator.
          * \param den the new denominator.
          */
-        template <bool supportInfinity>
-        Rational(const IntegerBase<supportInfinity>& num,
-                  const IntegerBase<supportInfinity>& den);
+        template <bool withInfinity>
+        Rational(const IntegerBase<withInfinity>& num,
+                  const IntegerBase<withInfinity>& den);
         /**
          * Initialises to <i>num</i>/<i>den</i>.
          *
@@ -206,8 +204,8 @@ class Rational {
          * \param value the new value of this rational.
          * \return a reference to this rational with its new value.
          */
-        template <bool supportInfinity>
-        Rational& operator = (const IntegerBase<supportInfinity>& value);
+        template <bool withInfinity>
+        Rational& operator = (const IntegerBase<withInfinity>& value);
         /**
          * Sets this rational to the given integer value.
          *
@@ -355,45 +353,22 @@ class Rational {
          */
         bool operator == (const Rational& compare) const;
         /**
-         * Determines if this is not equal to the given rational.
+         * Compares this to the given rational.
          *
-         * \param compare the rational with which this will be compared.
-         * \return \c true if and only if this rational is not equal to
-         * \a compare.
-         */
-        bool operator != (const Rational& compare) const;
-        /**
-         * Determines if this is less than the given rational.
+         * This is a numerical comparison; that is, it uses the usual ordering
+         * of the rationals.  Infinity is considered greater than any rational,
+         * and undefined is considered less than any rational.
          *
-         * \param compare the rational with which this will be compared.
-         * \return \c true if and only if this rational is less than
-         * \a compare.
-         */
-        bool operator < (const Rational& compare) const;
-        /**
-         * Determines if this is greater than the given rational.
+         * This generates all of the usual comparison operators, including
+         * `<`, `<=`, `>`, and `>=`.
          *
-         * \param compare the rational with which this will be compared.
-         * \return \c true if and only if this rational is greater than
-         * \a compare.
-         */
-        bool operator > (const Rational& compare) const;
-        /**
-         * Determines if this is less than or equal to the given rational.
+         * \python This spaceship operator `x <=> y` is not available, but the
+         * other comparison operators that it generates _are_ available.
          *
-         * \param compare the rational with which this will be compared.
-         * \return \c true if and only if this rational is less than or
-         * equal to \a compare.
+         * \return The result of the numerical comparison between this
+         * and the given rational.
          */
-        bool operator <= (const Rational& compare) const;
-        /**
-         * Determines if this is greater than or equal to the given rational.
-         *
-         * \param compare the rational with which this will be compared.
-         * \return \c true if and only if this rational is greater than
-         * or equal to \a compare.
-         */
-        bool operator >= (const Rational& compare) const;
+        std::strong_ordering operator <=> (const Rational&) const;
 
         /**
          * Attempts to convert this rational to a real number.
@@ -419,6 +394,18 @@ class Rational {
          */
         double doubleApprox() const;
 
+        /**
+         * Returns a string representation of this rational.
+         *
+         * For infinity and undefined rationals, the result will be `Inf` or
+         * `Undef` respectively.  If this rational has denominator one then
+         * the result will simply be the string representation of the numerator.
+         * Otherwise the string returned will be in the form `r/s`.
+         *
+         * \return a string representation of this rational.
+         */
+        std::string str() const;
+
         /**
          * Returns this rational as written using TeX formatting.
          * No leading or trailing dollar signs will be included.
@@ -454,6 +441,15 @@ class Rational {
     friend std::ostream& operator << (std::ostream& out, const Rational& rat);
 };
 
+#ifndef __DOXYGEN
+// Don't confuse doxygen with specialisations.
+template <>
+struct RingTraits<Rational> {
+    inline static const Rational zero;
+    inline static const Rational one { 1 };
+};
+#endif // __DOXYGEN
+
 /**
  * Swaps the contents of the given rationals.
  *
@@ -484,54 +480,54 @@ std::ostream& operator << (std::ostream& out, const Rational& rat);
 
 // Inline functions for Rational
 
-inline Rational::Rational() : flavour(f_normal) {
+inline Rational::Rational() : flavour(Flavour::Normal) {
     mpq_init(data);
 }
 inline Rational::Rational(const Rational& value) : flavour(value.flavour) {
     mpq_init(data);
-    if (flavour == f_normal)
+    if (flavour == Flavour::Normal)
         mpq_set(data, value.data);
 }
 inline Rational::Rational(Rational&& src) noexcept : flavour(src.flavour) {
     mpq_init(data); // we need to leave something for src to destroy.
     mpq_swap(data, src.data);
 }
-template <bool supportInfinity>
-inline Rational::Rational(const IntegerBase<supportInfinity>& value) :
-        flavour(f_normal) {
+template <bool withInfinity>
+inline Rational::Rational(const IntegerBase<withInfinity>& value) :
+        flavour(Flavour::Normal) {
     mpq_init(data);
     if (value.isInfinite())
-        flavour = f_infinity;
+        flavour = Flavour::Infinity;
     else if (value.isNative())
         mpq_set_si(data, value.longValue(), 1);
     else
         mpq_set_z(data, value.rawData());
 }
-inline Rational::Rational(long value) : flavour(f_normal) {
+inline Rational::Rational(long value) : flavour(Flavour::Normal) {
     mpq_init(data);
     mpq_set_si(data, value, 1);
 }
-template <bool supportInfinity>
-Rational::Rational(const IntegerBase<supportInfinity>& num,
-                     const IntegerBase<supportInfinity>& den) {
+template <bool withInfinity>
+Rational::Rational(const IntegerBase<withInfinity>& num,
+        const IntegerBase<withInfinity>& den) {
     mpq_init(data);
     if (den.isZero()) {
         if (num.isZero())
-            flavour = f_undefined;
+            flavour = Flavour::Undefined;
         else
-            flavour = f_infinity;
+            flavour = Flavour::Infinity;
     } else {
-        flavour = f_normal;
+        flavour = Flavour::Normal;
         if (num.isNative() && den.isNative())
             mpq_set_si(data, num.longValue(), den.longValue());
         else if (num.isNative()) {
             // Avoid bloating num with a GMP representation.
-            IntegerBase<supportInfinity> tmp(num);
+            IntegerBase<withInfinity> tmp(num);
             mpz_set(mpq_numref(data), tmp.rawData());
             mpz_set(mpq_denref(data), den.rawData());
         } else if (den.isNative()) {
             // Avoid bloating den with a GMP representation.
-            IntegerBase<supportInfinity> tmp(den);
+            IntegerBase<withInfinity> tmp(den);
             mpz_set(mpq_numref(data), num.rawData());
             mpz_set(mpq_denref(data), tmp.rawData());
         } else {
@@ -550,26 +546,25 @@ inline Rational& Rational::operator = (const Rational& value) {
     // - the libgmpxx classes do not special-case self-assignment.
     // The C++ test suite tests self-assignment of Rationals also.
     flavour = value.flavour;
-    if (flavour == f_normal)
+    if (flavour == Flavour::Normal)
         mpq_set(data, value.data);
     return *this;
 }
-template <bool supportInfinity>
-inline Rational& Rational::operator = (
-        const IntegerBase<supportInfinity>& value) {
+template <bool withInfinity>
+inline Rational& Rational::operator = (const IntegerBase<withInfinity>& value) {
     if (value.isInfinite())
-        flavour = f_infinity;
+        flavour = Flavour::Infinity;
     else if (value.isNative()) {
-        flavour = f_normal;
+        flavour = Flavour::Normal;
         mpq_set_si(data, value.longValue(), 1);
     } else {
-        flavour = f_normal;
+        flavour = Flavour::Normal;
         mpq_set_z(data, value.rawData());
     }
     return *this;
 }
 inline Rational& Rational::operator = (long value) {
-    flavour = f_normal;
+    flavour = Flavour::Normal;
     mpq_set_si(data, value, 1);
     return *this;
 }
@@ -588,20 +583,10 @@ inline void Rational::swap(Rational& other) noexcept {
 }
 
 inline void Rational::negate() {
-    if (flavour == f_normal)
+    if (flavour == Flavour::Normal)
         mpq_neg(data, data);
 }
 
-inline bool Rational::operator <= (const Rational& compare) const {
-    return ! (*this > compare);
-}
-inline bool Rational::operator >= (const Rational& compare) const {
-    return ! (*this < compare);
-}
-inline bool Rational::operator != (const Rational& compare) const {
-    return ! (*this == compare);
-}
-
 inline void swap(Rational& a, Rational& b) noexcept {
     a.swap(b);
 }
