@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -66,9 +64,21 @@ namespace regina {
  * Thus the internal code may be a useful means for passing permutation
  * objects to and from the engine.  For Perm<3>, the internal code is an
  * integer between 0 and 5 inclusive that gives the index of the
- * permutation in the array Perm<3>::S3.  This is consistent with the
+ * permutation in the array Perm<3>::Sn.  This is consistent with the
  * second-generation codes used in classes Perm<4>,...,Perm<7>.
  *
+ * You can iterate through all permutations using a range-based \c for loop
+ * over \a Sn, and this will be extremely fast in both C++ and Python:
+ *
+ * \code{.cpp}
+ * for (auto p : Perm<3>::Sn) { ... }
+ * \endcode
+ *
+ * This behaviour does not generalise to the large permutation classes Perm<n>
+ * with \a n ≥ 8, which are not as tightly optimised: such range-based \c for
+ * loops are still supported for \a n ≥ 8 but will be significantly slower in
+ * Python than in C++.  See the generic Perm class notes for further details.
+ *
  * To use this class, simply include the main permutation header maths/perm.h.
  *
  * \python Since Python does not support templates, this class is
@@ -79,6 +89,15 @@ namespace regina {
 template <>
 class Perm<3> {
     public:
+        /**
+         * The degree of the underlying symmetric group; that is, the
+         * template parameter \a n.
+         *
+         * This compile-time constant allows the programmer to extract \a n
+         * from the type (e.g., when writing templated code).
+         */
+        static constexpr int degree = 3;
+
         /**
          * Denotes a native signed integer type large enough to count all
          * permutations on three elements.  In other words, this is a
@@ -90,7 +109,7 @@ class Perm<3> {
          * Indicates what type of internal permutation code is used by
          * this instance of the Perm class template.
          */
-        static constexpr PermCodeType codeType = PERM_CODE_INDEX;
+        static constexpr PermCodeType codeType = PermCodeType::Index;
 
         /**
          * The total number of permutations on three elements.
@@ -99,10 +118,12 @@ class Perm<3> {
         static constexpr Index nPerms = 6;
 
         /**
-         * The total number of permutations on two elements.
-         * This is the size of the array Sn_1.
+         * Deprecated constant holding the total number of permutations on
+         * two elements.
+         *
+         * \deprecated Just use Perm<2>::nPerms instead.
          */
-        static constexpr Index nPerms_1 = 2;
+        [[deprecated]] static constexpr Index nPerms_1 = 2;
 
         /**
          * Indicates the native unsigned integer type used to store the
@@ -110,132 +131,95 @@ class Perm<3> {
          */
         using Code = uint8_t;
 
-    private:
         /**
-         * A lightweight array-like object used to implement Perm<3>::S3.
+         * An alias for \a Code, indicating the native unsigned integer type
+         * used to store the internal permutation code.
+         *
+         * This alias is provided to assist with generic programming, since
+         * permutation codes for `Perm<3>` are (and always have been) consistent
+         * with the second-generation permutation codes used with medium-sized
+         * permutation types `Perm<4..7>', which represent indices into \a Sn.
          */
-        struct S3Lookup {
-            /**
-             * Returns the permutation at the given index in the array S3.
-             * See Perm<3>::S3 for details.
-             *
-             * This operation is extremely fast (and constant time).
-             *
-             * \param index an index between 0 and 5 inclusive.
-             * \return the corresponding permutation in S3.
-             */
-            constexpr Perm<3> operator[] (int index) const;
-
-            /**
-             * Returns the number of permutations in the array S3.
-             *
-             * \return the size of this array.
-             */
-            static constexpr Index size() { return 6; }
-        };
-
-        /**
-         * A lightweight array-like object used to implement Perm<3>::orderedS3.
-         */
-        struct OrderedS3Lookup {
-            /**
-             * Returns the permutation at the given index in the array
-             * orderedS3.  See Perm<3>::orderedS3 for details.
-             *
-             * This operation is extremely fast (and constant time).
-             *
-             * \param index an index between 0 and 5 inclusive.
-             * \return the corresponding permutation in orderedS3.
-             */
-            constexpr Perm<3> operator[] (int index) const;
-
-            /**
-             * Returns the number of permutations in the array orderedS3.
-             *
-             * \return the size of this array.
-             */
-            static constexpr Index size() { return 6; }
-        };
-
-        /**
-         * A lightweight array-like object used to implement Perm<3>::S2.
-         */
-        struct S2Lookup {
-            /**
-             * Returns the permutation at the given index in the array S2.
-             * See Perm<3>::S2 for details.
-             *
-             * This operation is extremely fast (and constant time).
-             *
-             * \param index an index between 0 and 1 inclusive.
-             * \return the corresponding permutation in S2.
-             */
-            constexpr Perm<3> operator[] (int index) const;
-
-            /**
-             * Returns the number of permutations in the array S2.
-             *
-             * \return the size of this array.
-             */
-            static constexpr Index size() { return 2; }
-        };
+        using Code2 = Code;
 
     public:
         /**
-         * Gives fast array-like access to all possible permutations of
-         * three elements.
+         * Gives fast access to all possible permutations of three elements in
+         * a sign-based order, with support for both array-like indexing and
+         * iteration.
          *
          * To access the permutation at index \a i, you simply use the
          * square bracket operator: `Sn[i]`.  The index \a i must be
          * between 0 and 5 inclusive.
-         * This element access is extremely fast (a fact that is not true for
-         * the larger permutation classes Perm<n> with \a n ≥ 8).
+         *
+         * You can also iterate over all permutations in \a Sn using a
+         * range-based \c for loop:
+         *
+         * \code{.cpp}
+         * for (auto p : Perm<3>::Sn) { ... }
+         * \endcode
+         *
+         * For this class (and all Perm<n> with \a n ≤ 7), such index-based
+         * access and iteration are both extremely fast.
          *
          * The permutations with even indices in the array are the even
-         * permutations, and those with odd indices in the array are the
-         * odd permutations.
+         * permutations, and those with odd indices in the array are the odd
+         * permutations.  The first permutation (at index 0) is the identity.
          *
          * This array is different from Perm<3>::orderedSn, since \a Sn
          * alternates between even and odd permutations, whereas \a orderedSn
-         * stores permutations in lexicographical order.
+         * accesses permutations in lexicographical order.
          *
          * In Regina 6.0.1 and earlier, this was a hard-coded C-style array;
          * since Regina 7.0 it has changed type, but accessing elements as
          * described above remains extremely fast.  This is now a lightweight
          * object, and is defined in the headers only; in particular, you
          * cannot make a reference to it (but you can always make a copy).
+         *
+         * See the PermSn documentation for further details, including time
+         * complexity of lookup and iteration.
          */
-        static constexpr S3Lookup Sn {};
+        static constexpr PermSn<3, PermOrder::Sign> Sn {};
 
         /**
-         * Gives fast array-like access to all possible permutations of
-         * three elements.
+         * Gives fast access to all possible permutations of three elements in
+         * a sign-based order, with support for both array-like indexing and
+         * iteration.
          *
          * This is a dimension-specific alias for Perm<3>::Sn; see that member
          * for further information.  In general, for every \a n there will be
          * a static member Perm<n>::Sn; however, these numerical aliases
-         * Perm<2>::S2, ..., Perm<5>::S5 are only available for small \a n.
+         * Perm<2>::S2, ..., Perm<7>::S7 are only available for small \a n.
          *
          * Note that small permutation classes (Perm<3>, Perm<4>, Perm<5>)
          * have an \a S3 array: these all store the same six permutations in
          * the same order (but of course using different data types).
          */
-        static constexpr S3Lookup S3 {};
+        static constexpr PermSn<3, PermOrder::Sign> S3 {};
 
         /**
-         * Gives fast array-like access to all possible permutations of three
-         * elements in lexicographical order.
+         * Gives fast access to all possible permutations of three elements
+         * in lexicographical order, with support for both array-like indexing
+         * and iteration.
          *
          * To access the permutation at index \a i, you simply use the
          * square bracket operator: `orderedSn[i]`.  The index \a i
          * must be between 0 and 5 inclusive.
-         * This element access is extremely fast (a fact that is not true for
-         * the larger permutation classes Perm<n> with \a n ≥ 8).
+         *
+         * You can also iterate over all permutations in \a orderedSn using a
+         * range-based \c for loop:
+         *
+         * \code{.cpp}
+         * for (auto p : Perm<3>::orderedSn) { ... }
+         * \endcode
+         *
+         * For this class (and all Perm<n> with \a n ≤ 7), such index-based
+         * access and iteration are both extremely fast.
          *
          * Lexicographical ordering treats each permutation \a p as the
-         * ordered pair (\a p[0], \a p[1], \a p[2]).
+         * ordered tuple `(p[0], p[1], p[2])`.
          *
-         * This array is different from Perm<3>::Sn, since \a orderedSn stores
+         * This array is different from Perm<3>::Sn, since \a orderedSn accesses
          * permutations in lexicographical order, whereas \a Sn alternates
          * between even and odd permutations.
          *
@@ -245,55 +229,55 @@ class Perm<3> {
          * object, and is defined in the headers only; in particular, you
          * cannot make a reference to it (but you can always make a copy).
          */
-        static constexpr OrderedS3Lookup orderedSn {};
+        static constexpr PermSn<3, PermOrder::Lex> orderedSn {};
 
         /**
-         * Gives fast array-like access to all possible permutations of three
-         * elements in lexicographical order.
+         * Gives fast access to all possible permutations of three elements
+         * in lexicographical order, with support for both array-like indexing
+         * and iteration.
          *
          * This is a dimension-specific alias for Perm<3>::orderedSn; see that
          * member for further information.  In general, for every \a n there
          * will be a static member Perm<n>::orderedSn; however, these numerical
-         * aliases Perm<2>::orderedS2, ..., Perm<5>::orderedS5 are only
+         * aliases Perm<2>::orderedS2, ..., Perm<7>::orderedS7 are only
          * available for small \a n.
          */
-        static constexpr OrderedS3Lookup orderedS3 {};
+        static constexpr PermSn<3, PermOrder::Lex> orderedS3 {};
 
         /**
-         * Gives fast array-like access to all possible permutations of
+         * Deprecated array-like object that lists all possible permutations of
          * two elements.  In each permutation, 2 maps to 2.
          *
          * To access the permutation at index \a i, you simply use the
-         * square bracket operator: `Sn_1[i]`.  The index \a i must be
-         * between 0 and 1 inclusive.
+         * square bracket operator: `S2[i]`.  The index \a i must be
+         * between 0 and 1 inclusive.  Unlike \a Sn, you cannot iterate over
+         * \a S2 in C++ (though you can still do this in Python).
          *
-         * The permutations with even indices in the array are the even
-         * permutations, and those with odd indices in the array are the
-         * odd permutations.
+         * This array uses the same sign-based ordering as `Perm<2>::S2`:
+         * it begins with the identity and alternates between even and odd
+         * permutations.
          *
          * In Regina 6.0.1 and earlier, this was a hard-coded C-style array;
          * since Regina 7.0 it has changed type, but accessing elements as
          * described above remains extremely fast.  This is now a lightweight
          * object, and is defined in the headers only; in particular, you
          * cannot make a reference to it (but you can always make a copy).
+         *
+         * \deprecated Instead of `Perm<3>::S2[i]`, you can use
+         * `Perm<3>::extend(Perm<2>::Sn[i])`.
          */
-        static constexpr S2Lookup Sn_1 {};
+        [[deprecated]] static constexpr detail::PermSubSn<3, 2> S2 {};
 
         /**
-         * Gives fast array-like access to all possible permutations of
-         * two elements.
+         * Deprecated alias for \a S2, which gives fast array-like access to
+         * all possible permutations of two elements in a sign-based order.
          *
-         * This is a dimension-specific alias for Perm<3>::Sn_1; see that
-         * member for further information.
+         * See the S2 documentation for further information.
          *
-         * Note that all small permutation classes (Perm<2>, ..., Perm<5>)
-         * have an \a S2 array: these all store the same two permutations in
-         * the same order (but of course using different data types).
-         *
-         * There is no corresponding \a orderedS2 array, since the
-         * (trivial) arrays \a S2 and \a orderedS2 are identical.
+         * \deprecated Instead of `Perm<3>::Sn_1[i]`, you can use
+         * `Perm<3>::extend(Perm<2>::Sn[i])`.
          */
-        static constexpr S2Lookup S2 {};
+        [[deprecated]] static constexpr detail::PermSubSn<3, 2> Sn_1 {};
 
         /**
          * The internal code for the permutation (0,1,2).
@@ -720,22 +704,10 @@ class Perm<3> {
          * This is true if and only if both permutations have the same
          * images for 0, 1 and 2.
          *
-         * \param other the permutation with which to compare this.
          * \return \c true if and only if this and the given permutation
          * are equal.
          */
-        constexpr bool operator == (const Perm<3>& other) const;
-
-        /**
-         * Determines if this differs from the given permutation.
-         * This is true if and only if the two permutations have
-         * different images for at least one of 0, 1 or 2.
-         *
-         * \param other the permutation with which to compare this.
-         * \return \c true if and only if this and the given permutation
-         * differ.
-         */
-        constexpr bool operator != (const Perm<3>& other) const;
+        constexpr bool operator == (const Perm&) const = default;
 
         /**
          * Lexicographically compares the images of (0,1,2) under this
@@ -787,18 +759,25 @@ class Perm<3> {
         constexpr Perm<3> operator ++(int);
 
         /**
-         * Determines if this appears earlier than the given permutation
-         * in the array Perm<3>::Sn.
+         * Compares two permutations according to which appears earlier in the
+         * array Perm<3>::Sn.
          *
          * Note that this is _not_ the same ordering of permutations as
-         * the ordering implied by compareWith().  This is, however,
+         * the ordering implied by compareWith().  This ordering is, however,
          * consistent with the ordering implied by the ++ operators,
-         * and this order is also faster to compute than compareWith().
+         * and this ordering is also faster to compute than compareWith().
          *
-         * \param rhs the permutation to compare this against.
-         * \return \c true if and only if this appears before \a rhs in \a Sn.
+         * This generates all of the usual comparison operators, including
+         * `<`, `<=`, `>`, and `>=`.
+         *
+         * \python This spaceship operator `x <=> y` is not available, but the
+         * other comparison operators that it generates _are_ available.
+         *
+         * \return The result that indicates which permutation appears earlier
+         * in \a Sn.
          */
-        constexpr bool operator < (const Perm<3>& rhs) const;
+        constexpr std::strong_ordering operator <=> (const Perm&) const =
+            default;
 
         /**
          * Returns the <i>i</i>th rotation.
@@ -944,7 +923,7 @@ class Perm<3> {
          * The tight encoding will be read from the given input stream.
          * If the input stream contains leading whitespace then it will be
          * treated as an invalid encoding (i.e., this routine will throw an
-         * exception).  The input routine _may_ contain further data: if this
+         * exception).  The input stream _may_ contain further data: if this
          * routine is successful then the input stream will be left positioned
          * immediately after the encoding, without skipping any trailing
          * whitespace.
@@ -965,6 +944,23 @@ class Perm<3> {
          */
         static Perm tightDecode(std::istream& input);
 
+        /**
+         * Hashes this permutation to a non-negative integer, allowing it
+         * to be used for keys in hash tables.
+         *
+         * The implementation currently returns the internal permutation code
+         * (which for Perm<3> will always fit within a \c size_t).  This
+         * implementation (and therefore the specific hash values obtained)
+         * is subject to change in future versions of Regina.
+         *
+         * \python For Python users, this function uses the standard Python
+         * name __hash__().  This allows permutations to be used as keys in
+         * Python dictionaries and sets.
+         *
+         * \return The integer hash of this permutation.
+         */
+        constexpr size_t hash() const;
+
         /**
          * Resets the images of all integers from \a from onwards to the
          * identity map.
@@ -992,7 +988,7 @@ class Perm<3> {
         constexpr Index SnIndex() const;
 
         /**
-         * Returns the index of this permutation in the Perm<3>::S3 array.
+         * Returns the index of this permutation in the Perm<3>::Sn array.
          *
          * This is a dimension-specific alias for SnIndex().  In general,
          * for every \a n there will be a member function Perm<n>::SnIndex();
@@ -1002,7 +998,7 @@ class Perm<3> {
          * See Sn for further information on how these permutations are indexed.
          *
          * \return the index \a i for which this permutation is equal to
-         * Perm<3>::S3[i].  This will be between 0 and 5 inclusive.
+         * Perm<3>::Sn[i].  This will be between 0 and 5 inclusive.
          */
         constexpr Index S3Index() const;
 
@@ -1153,8 +1149,8 @@ class Perm<3> {
 
     private:
         /**
-         * Converts between an index into Perm<3>::S3 and an index into
-         * Perm<3>::orderedS3.  This conversion works in either direction.
+         * Converts between an index into Perm<3>::Sn and an index into
+         * Perm<3>::orderedSn.  This conversion works in either direction.
          *
          * \tparam Int a native integer type; this would typically be
          * either \c int or \a Code.
@@ -1193,28 +1189,18 @@ class Perm<3> {
         template <typename iterator>
         static Perm tightDecode(iterator start, iterator limit,
             bool noTrailingData);
+
+    friend class PermSn<3, PermOrder::Sign>;
+    friend class PermSn<3, PermOrder::Lex>;
 };
 
 // Inline functions for Perm<3>
 
 template <typename Int>
 inline constexpr Int Perm<3>::convOrderedUnordered(Int index) {
-    // S5 is almost the same as orderedS5, except that we
+    // S3 is almost the same as orderedS3, except that we
     // swap indices 2 <--> 3.
-    return ((index == 2 || index == 3) ? (index ^ 1) : index);
-}
-
-inline constexpr Perm<3> Perm<3>::S3Lookup::operator[] (int index) const {
-    return Perm<3>(static_cast<Code>(index));
-}
-
-inline constexpr Perm<3> Perm<3>::OrderedS3Lookup::operator[] (int index)
-        const {
-    return Perm<3>(static_cast<Code>(convOrderedUnordered(index)));
-}
-
-inline constexpr Perm<3> Perm<3>::S2Lookup::operator[] (int index) const {
-    return Perm<3>(index == 0 ? code012 : code102);
+    return ((index & 2) ? (index ^ 1) : index);
 }
 
 inline constexpr void Perm<3>::precompute() {
@@ -1247,8 +1233,7 @@ inline constexpr Perm<3>::Perm(const std::array<int, 3>& image) :
 
 inline constexpr Perm<3>::Perm(int a0, int a1, int b0, int b1, int c0, int c1) :
         code_(0) {
-    // TODO: When we move to C++20, we can get rid of the zero initialisers.
-    int image[3] = { 0, 0, 0 };
+    int image[3];
     image[a0] = a1;
     image[b0] = b1;
     image[c0] = c1;
@@ -1357,14 +1342,6 @@ inline constexpr int Perm<3>::pre(int image) const {
     return imageTable[invS3[code_]][image];
 }
 
-inline constexpr bool Perm<3>::operator == (const Perm<3>& other) const {
-    return (code_ == other.code_);
-}
-
-inline constexpr bool Perm<3>::operator != (const Perm<3>& other) const {
-    return (code_ != other.code_);
-}
-
 inline constexpr int Perm<3>::compareWith(const Perm<3>& other) const {
     // Computing orderedS3Index() is very fast.
     // Use this instead of comparing images one at a time.
@@ -1390,10 +1367,6 @@ inline constexpr Perm<3> Perm<3>::operator ++(int) {
     return ans;
 }
 
-inline constexpr bool Perm<3>::operator < (const Perm<3>& rhs) const {
-    return code_ < rhs.code_;
-}
-
 inline constexpr Perm<3> Perm<3>::rot(int i) {
     switch (i) {
         case 1: return Perm<3>(static_cast<Code>(code120));
@@ -1465,6 +1438,10 @@ Perm<3> Perm<3>::tightDecode(iterator start, iterator limit,
 }
 #endif // __DOXYGEN
 
+inline constexpr size_t Perm<3>::hash() const {
+    return code_;
+}
+
 inline constexpr Perm<3>::Index Perm<3>::S3Index() const {
     return code_;
 }
