@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -59,7 +57,7 @@ class Text;
  * \ingroup packet
  */
 class Text : public Packet {
-    REGINA_PACKET(PACKET_TEXT, "Text")
+    REGINA_PACKET(PacketType::Text, "Text")
 
     private:
         std::string text_;
@@ -134,15 +132,6 @@ class Text : public Packet {
          */
         bool operator == (const Text& other) const;
 
-        /**
-         * Determines if this and the given packet do not contain the same text.
-         *
-         * \param other the text packet to compare with this.
-         * \return \c true if and only if this and the given packet
-         * do not contain the same text.
-         */
-        bool operator != (const Text& other) const;
-
         void writeTextShort(std::ostream& out) const override;
         void writeTextLong(std::ostream& out) const override;
 
@@ -171,14 +160,14 @@ inline Text::Text(std::string text) : text_(std::move(text)) {
 }
 
 inline Text& Text::operator = (const Text& src) {
-    ChangeEventSpan span(*this);
+    PacketChangeSpan span(*this);
     text_ = src.text_;
     return *this;
 }
 
 inline void Text::swap(Text& other) {
-    ChangeEventSpan span1(*this);
-    ChangeEventSpan span2(other);
+    PacketChangeSpan span1(*this);
+    PacketChangeSpan span2(other);
     text_.swap(other.text_);
 }
 
@@ -190,7 +179,7 @@ inline void Text::setText(std::string text) {
     if (text_ == text)
         return; // No change event fired.
 
-    ChangeEventSpan span(*this);
+    PacketChangeSpan span(*this);
     text_ = std::move(text);
 }
 
@@ -198,10 +187,6 @@ inline bool Text::operator == (const Text& other) const {
     return text_ == other.text_;
 }
 
-inline bool Text::operator != (const Text& other) const {
-    return text_ != other.text_;
-}
-
 inline void Text::writeTextShort(std::ostream& o) const {
     if (text_.empty())
         o << "(empty)";
