@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -97,16 +95,16 @@ void Cusp::writeTextShort(std::ostream& out) const {
 }
 
 SnapPeaTriangulation::SnapPeaTriangulation(
-        const std::string& fileNameOrContents) :
+        const std::string& filenameOrContents) :
         data_(nullptr), shape_(nullptr), cusp_(nullptr), filledCusps_(0) {
-    bool isContents = startsWith(fileNameOrContents, "% Triangulation");
+    bool isContents = startsWith(filenameOrContents, "% Triangulation");
     try {
         if (isContents)
             data_ = regina::snappea::read_triangulation_from_string(
-                fileNameOrContents.c_str());
+                filenameOrContents.c_str());
         else
             data_ = regina::snappea::read_triangulation(
-                fileNameOrContents.c_str());
+                filenameOrContents.c_str());
     } catch (regina::SnapPeaFatalError& err) {
         // data_ will be left as null.
     }
@@ -120,8 +118,14 @@ SnapPeaTriangulation::SnapPeaTriangulation(
                 "given file, and/or could not parse its contents");
     }
 
+    // SnapPea no longer removes finite vertices automatically - we need
+    // to do it here ourselves.  Otherwise snappea will crash within sync()
+    // when it tries to initialise the gluing equations.
+    if (data_->num_fake_cusps > 0)
+        regina::snappea::remove_finite_vertices(data_);
+
     sync();
-    Triangulation<3>::heldBy_ = HELD_BY_SNAPPEA;
+    Triangulation<3>::heldBy_ = PacketHeldBy::SnapPea;
 }
 
 // We don't call the Triangulation<3> copy constructor, since sync()
@@ -133,9 +137,9 @@ SnapPeaTriangulation::SnapPeaTriangulation(const SnapPeaTriangulation& tri) :
         regina::snappea::copy_triangulation(tri.data_, &data_);
         sync();
     }
-    Triangulation<3>::heldBy_ = HELD_BY_SNAPPEA;
+    Triangulation<3>::heldBy_ = PacketHeldBy::SnapPea;
 
-    // Do not copy reginaChangeEventSpans_; instead use the default
+    // Do not copy reginaPacketChangeSpans_; instead use the default
     // initialisation to zero.
 }
 
@@ -152,16 +156,16 @@ SnapPeaTriangulation::SnapPeaTriangulation(SnapPeaTriangulation&& src)
     src.shape_ = nullptr;
     src.cusp_ = nullptr;
 
-    Triangulation<3>::heldBy_ = HELD_BY_SNAPPEA;
+    Triangulation<3>::heldBy_ = PacketHeldBy::SnapPea;
 
-    // Do not copy reginaChangeEventSpans_; instead use the default
+    // Do not copy reginaPacketChangeSpans_; instead use the default
     // initialisation to zero.
 }
 
 SnapPeaTriangulation& SnapPeaTriangulation::operator = (
         SnapPeaTriangulation&& src) {
-    ChangeAndSyncSpan span(*this);
-
+    // Use the Triangulation<3> assignment operator instead of sync().
+    SnapPeaChangeSpan<ChangePolicy::TriangulationNoSync> span(*this);
     Triangulation<3>::operator = (std::move(src));
 
     // We have already moved out of src, but this only touches the
@@ -175,7 +179,7 @@ SnapPeaTriangulation& SnapPeaTriangulation::operator = (
     fundGroupFilled_ = std::move(src.fundGroupFilled_);
     h1Filled_ = std::move(src.h1Filled_);
 
-    // The assignment operator should not touch reginaChangeEventSpans_.
+    // The assignment operator should not touch reginaPacketChangeSpans_.
 
     // Let src dispose of the original data_, shape_ and cusp_ in its
     // own destructor.
@@ -187,7 +191,7 @@ SnapPeaTriangulation& SnapPeaTriangulation::operator = (
     if (std::addressof(src) == this)
         return *this;
 
-    ChangeAndSyncSpan span(*this);
+    SnapPeaChangeSpan span(*this);
 
     regina::snappea::free_triangulation(data_);
     if (src.data_)
@@ -195,10 +199,8 @@ SnapPeaTriangulation& SnapPeaTriangulation::operator = (
     else
         data_ = nullptr;
 
-    sync(); // fixes everything else
-
-    // The assignment operator should not touch reginaChangeEventSpans_.
-
+    // The assignment operator should not touch reginaPacketChangeSpans_.
+    // The sync() from the SnapPeaChangeSpan should fix everything else.
     return *this;
 }
 
@@ -210,7 +212,7 @@ SnapPeaTriangulation::SnapPeaTriangulation(const Triangulation<3>& tri, bool) :
             regina::snappea::copy_triangulation(clone->data_, &data_);
             sync();
         }
-        Triangulation<3>::heldBy_ = HELD_BY_SNAPPEA;
+        Triangulation<3>::heldBy_ = PacketHeldBy::SnapPea;
         return;
     }
 
@@ -223,11 +225,11 @@ SnapPeaTriangulation::SnapPeaTriangulation(const Triangulation<3>& tri, bool) :
             (! tri.isConnected()) ||
             (! tri.isValid()) ||
             (! tri.isStandard())) {
-        Triangulation<3>::heldBy_ = HELD_BY_SNAPPEA;
+        Triangulation<3>::heldBy_ = PacketHeldBy::SnapPea;
         return;
     }
     if (tri.size() >= INT_MAX) {
-        Triangulation<3>::heldBy_ = HELD_BY_SNAPPEA;
+        Triangulation<3>::heldBy_ = PacketHeldBy::SnapPea;
         return;
     }
 
@@ -278,7 +280,7 @@ SnapPeaTriangulation::SnapPeaTriangulation(const Triangulation<3>& tri, bool) :
     delete[] tData.tetrahedron_data;
 
     if (! data_) {
-        Triangulation<3>::heldBy_ = HELD_BY_SNAPPEA;
+        Triangulation<3>::heldBy_ = PacketHeldBy::SnapPea;
         return;
     }
 
@@ -303,9 +305,9 @@ SnapPeaTriangulation::SnapPeaTriangulation(const Triangulation<3>& tri, bool) :
     if (tri.isClosed())
         regina::snappea::do_Dehn_filling(data_);
 
-    auto soln = static_cast<SolutionType>(
-        regina::snappea::get_filled_solution_type(data_));
-    if (soln == geometric_solution || soln == nongeometric_solution) {
+    auto soln = regina::snappea::get_filled_solution_type(data_);
+    if (soln == regina::snappea::geometric_solution ||
+            soln == regina::snappea::nongeometric_solution) {
         try {
             regina::snappea::install_shortest_bases(data_);
         } catch (regina::SnapPeaFatalError& err) {
@@ -315,7 +317,7 @@ SnapPeaTriangulation::SnapPeaTriangulation(const Triangulation<3>& tri, bool) :
 
     sync();
 
-    Triangulation<3>::heldBy_ = HELD_BY_SNAPPEA;
+    Triangulation<3>::heldBy_ = PacketHeldBy::SnapPea;
 }
 
 SnapPeaTriangulation::SnapPeaTriangulation(const Link& link) :
@@ -323,6 +325,9 @@ SnapPeaTriangulation::SnapPeaTriangulation(const Link& link) :
     if (link.isEmpty())
         throw InvalidArgument("The SnapPeaTriangulation constructor "
             "requires a non-empty link");
+    if (! link.isClassical())
+        throw InvalidArgument("The SnapPeaTriangulation constructor "
+            "requires a classical (not virtual) link diagram");
 
     // SnapPea uses int (not size_t) to index crossings and components.
     if (link.size() > INT_MAX || link.countComponents() > INT_MAX)
@@ -418,7 +423,7 @@ SnapPeaTriangulation::SnapPeaTriangulation(const Link& link) :
     delete[] proj.crossings;
 
     if (! data_) {
-        Triangulation<3>::heldBy_ = HELD_BY_SNAPPEA;
+        Triangulation<3>::heldBy_ = PacketHeldBy::SnapPea;
         return;
     }
 
@@ -434,7 +439,7 @@ SnapPeaTriangulation::SnapPeaTriangulation(const Link& link) :
     regina::snappea::find_complete_hyperbolic_structure(data_);
 
     sync();
-    Triangulation<3>::heldBy_ = HELD_BY_SNAPPEA;
+    Triangulation<3>::heldBy_ = PacketHeldBy::SnapPea;
 }
 
 SnapPeaTriangulation::~SnapPeaTriangulation() {
@@ -447,10 +452,12 @@ void SnapPeaTriangulation::swap(SnapPeaTriangulation& other) {
     if (this == &other)
         return;
 
-    ChangeAndSyncSpan span1(*this);
-    ChangeAndSyncSpan span2(other);
-
+    // Instead of sync(), we use Triangulation<3>::swap() to update the
+    // regina triangulations.
+    SnapPeaChangeSpan<ChangePolicy::TriangulationNoSync> span1(*this);
+    SnapPeaChangeSpan<ChangePolicy::TriangulationNoSync> span2(other);
     Triangulation<3>::swap(other);
+
     std::swap(data_, other.data_);
     std::swap(shape_, other.shape_);
     std::swap(cusp_, other.cusp_);
@@ -463,22 +470,21 @@ void SnapPeaTriangulation::nullify() {
     if (! data_)
         return;
 
-    ChangeAndSyncSpan span(*this);
+    SnapPeaChangeSpan span(*this);
 
     regina::snappea::free_triangulation(data_);
     data_ = nullptr;
-    sync();
 }
 
 std::string SnapPeaTriangulation::name() const {
     return (data_ ? get_triangulation_name(data_) : "");
 }
 
-SnapPeaTriangulation::SolutionType SnapPeaTriangulation::solutionType()
+SnapPeaTriangulation::Solution SnapPeaTriangulation::solutionType()
         const {
     if (! data_)
-        return SnapPeaTriangulation::not_attempted;
-    return static_cast<SolutionType>(
+        return Solution::NotAttempted;
+    return static_cast<Solution>(
         regina::snappea::get_filled_solution_type(data_));
 }
 
@@ -551,9 +557,7 @@ void SnapPeaTriangulation::unfill(unsigned whichCusp) {
         return;
     }
 
-    // We change the SnapPea data structures but not the inherited
-    // Triangulation<3>, and so a ChangeEventSpan is fine here.
-    PacketData<SnapPeaTriangulation>::ChangeEventSpan span(*this);
+    SnapPeaChangeSpan<ChangePolicy::FillingsOnly> span(*this);
 
     regina::snappea::set_cusp_info(data_, whichCusp, true, 0, 0);
 
@@ -562,7 +566,6 @@ void SnapPeaTriangulation::unfill(unsigned whichCusp) {
     --filledCusps_;
 
     regina::snappea::do_Dehn_filling(data_);
-    fillingsHaveChanged();
 }
 
 bool SnapPeaTriangulation::fill(int m, int l, unsigned whichCusp) {
@@ -598,9 +601,7 @@ bool SnapPeaTriangulation::fill(int m, int l, unsigned whichCusp) {
 
     // Do it.
 
-    // We change the SnapPea data structures but not the inherited
-    // Triangulation<3>, and so a ChangeEventSpan is fine here.
-    PacketData<SnapPeaTriangulation>::ChangeEventSpan span(*this);
+    SnapPeaChangeSpan<ChangePolicy::FillingsOnly> span(*this);
 
     regina::snappea::set_cusp_info(data_, whichCusp, false, mReal, lReal);
 
@@ -611,7 +612,6 @@ bool SnapPeaTriangulation::fill(int m, int l, unsigned whichCusp) {
         ++filledCusps_;
 
     regina::snappea::do_Dehn_filling(data_);
-    fillingsHaveChanged();
     return true;
 }
 
@@ -728,10 +728,8 @@ void SnapPeaTriangulation::randomise() {
     if (! data_)
         return;
 
-    ChangeAndSyncSpan span(*this);
-
+    SnapPeaChangeSpan span(*this);
     regina::snappea::randomize_triangulation(data_);
-    sync();
 }
 
 MatrixInt SnapPeaTriangulation::gluingEquations() const {
@@ -1002,80 +1000,79 @@ SnapPeaTriangulation::SnapPeaTriangulation(
         regina::snappea::Triangulation* data) :
         data_(data), shape_(nullptr), cusp_(nullptr), filledCusps_(0) {
     sync();
-    Triangulation<3>::heldBy_ = HELD_BY_SNAPPEA;
+    Triangulation<3>::heldBy_ = PacketHeldBy::SnapPea;
 }
 
 void SnapPeaTriangulation::sync() {
     // TODO: Check first whether anything has changed, and only resync
     // the Triangulation<3> data if it has.
-    {
-        // Deal with the combinatorial data and cusps first.
-        if (! isEmpty())
-            removeAllTetrahedra();
 
-        delete[] cusp_;
-        filledCusps_ = 0;
+    // Deal with the combinatorial data and cusps first.
+    if (! isEmpty())
+        removeAllTetrahedra();
 
-        if (data_) {
-            fillRegina(data_, *this);
+    delete[] cusp_;
+    filledCusps_ = 0;
 
-            if (regina::snappea::get_filled_solution_type(data_) ==
-                    regina::snappea::not_attempted) {
-                regina::snappea::find_complete_hyperbolic_structure(data_);
-                regina::snappea::do_Dehn_filling(data_);
-            }
+    if (data_) {
+        fillRegina(data_, *this);
 
-            cusp_ = new Cusp[data_->num_cusps];
-            regina::snappea::Cusp* c = data_->cusp_list_begin.next;
-            for (int i = 0; i < data_->num_cusps; ++i) {
-                cusp_[c->index].vertex_ = nullptr;
-                if (c->is_complete) {
-                    cusp_[c->index].m_ = cusp_[c->index].l_ = 0;
-                } else if (c->topology == regina::snappea::Klein_cusp &&
-                        ! (regina::snappea::Dehn_coefficients_are_integers(c)
-                            && c->l == 0 && (c->m == 1 || c->m == -1))) {
-                    // Abort!  Make this a null triangulation.
-                    // We call sync() again, but this is harmless as long as
-                    // we return immediately afterwards.
-                    regina::snappea::free_triangulation(data_);
-                    data_ = nullptr;
-                    sync();
-                    return;
-                } else if (c->topology == regina::snappea::torus_cusp &&
-                        ! regina::snappea::Dehn_coefficients_are_relatively_prime_integers(c)) {
-                    // Abort, as above.
-                    regina::snappea::free_triangulation(data_);
-                    data_ = nullptr;
-                    sync();
-                    return;
-                } else {
-                    cusp_[c->index].m_ = c->m;
-                    cusp_[c->index].l_ = c->l;
-                    ++filledCusps_;
-                }
-                c = c->next;
-            }
-            regina::snappea::Tetrahedron* stet = data_->tet_list_begin.next;
-            for (size_t i = 0; i < size(); ++i) {
-                for (int j = 0; j < 4; ++j) {
-                    c = stet->cusp[j];
-                    if (cusp_[c->index].vertex_ == nullptr)
-                        cusp_[c->index].vertex_ = tetrahedron(i)->vertex(j);
-                }
-                stet = stet->next;
-            }
-        } else {
-            cusp_ = nullptr;
+        if (regina::snappea::get_filled_solution_type(data_) ==
+                regina::snappea::not_attempted) {
+            regina::snappea::find_complete_hyperbolic_structure(data_);
+            regina::snappea::do_Dehn_filling(data_);
         }
 
-        // Next, update all data that depend on the fillings (if any).
-        // Most importantly, this includes the cache of tetrahedron shapes.
-        fillingsHaveChanged();
+        cusp_ = new Cusp[data_->num_cusps];
+        regina::snappea::Cusp* c = data_->cusp_list_begin.next;
+        for (int i = 0; i < data_->num_cusps; ++i) {
+            cusp_[c->index].vertex_ = nullptr;
+            if (c->is_complete) {
+                cusp_[c->index].m_ = cusp_[c->index].l_ = 0;
+            } else if (c->topology == regina::snappea::Klein_cusp &&
+                    ! (regina::snappea::Dehn_coefficients_are_integers(c)
+                        && c->l == 0 && (c->m == 1 || c->m == -1))) {
+                // Abort!  Make this a null triangulation.
+                // We call sync() again, but this is harmless as long as
+                // we return immediately afterwards.
+                regina::snappea::free_triangulation(data_);
+                data_ = nullptr;
+                sync(); // also calls fillingsHaveChanged()
+                return;
+            } else if (c->topology == regina::snappea::torus_cusp &&
+                    ! regina::snappea::Dehn_coefficients_are_relatively_prime_integers(c)) {
+                // Abort, as above.
+                regina::snappea::free_triangulation(data_);
+                data_ = nullptr;
+                sync(); // also calls fillingsHaveChanged()
+                return;
+            } else {
+                cusp_[c->index].m_ = c->m;
+                cusp_[c->index].l_ = c->l;
+                ++filledCusps_;
+            }
+            c = c->next;
+        }
+        regina::snappea::Tetrahedron* stet = data_->tet_list_begin.next;
+        for (size_t i = 0; i < size(); ++i) {
+            for (int j = 0; j < 4; ++j) {
+                c = stet->cusp[j];
+                if (cusp_[c->index].vertex_ == nullptr)
+                    cusp_[c->index].vertex_ = tetrahedron(i)->vertex(j);
+            }
+            stet = stet->next;
+        }
+    } else {
+        cusp_ = nullptr;
     }
+
+    // Next, update all data that depend on the fillings (if any).
+    // Most importantly, this includes the cache of tetrahedron shapes.
+    fillingsHaveChanged();
 }
 
 void SnapPeaTriangulation::fillingsHaveChanged() {
-    // Clear properties that depend on the fillings.
+    // Clear computed properties that depend on the fillings.
     fundGroupFilled_.reset();
     h1Filled_.reset();
 
@@ -1084,9 +1081,9 @@ void SnapPeaTriangulation::fillingsHaveChanged() {
     if (data_) {
         // Refresh the array of tetrahedron shapes.
         regina::snappea::Tetrahedron* stet;
-        auto soln = static_cast<SolutionType>(
-            regina::snappea::get_filled_solution_type(data_));
-        if (soln == not_attempted || soln == no_solution) {
+        auto soln = regina::snappea::get_filled_solution_type(data_);
+        if (soln == regina::snappea::not_attempted ||
+                soln == regina::snappea::no_solution) {
             shape_ = nullptr;
         } else {
             // Fetch the shapes directly from SnapPea's internal
@@ -1110,8 +1107,7 @@ void SnapPeaTriangulation::fillingsHaveChanged() {
 
 void SnapPeaTriangulation::fillRegina(regina::snappea::Triangulation* src,
         Triangulation<3>& dest) {
-    // Ensure only one event pair is fired in this sequence of changes.
-    Triangulation<3>::ChangeEventSpan span(dest);
+    Triangulation<3>::PacketChangeGroup span(dest);
 
     regina::snappea::TriangulationData* tData;
     regina::snappea::triangulation_to_data(src, &tData);
@@ -1134,8 +1130,8 @@ void SnapPeaTriangulation::fillRegina(regina::snappea::Triangulation* src,
 }
 
 size_t SnapPeaTriangulation::enumerateCoversInternal(int sheets,
-        CoverEnumerationType type,
-        std::function<void(SnapPeaTriangulation&&, CoverType)>&& action) const {
+        CoverEnumeration type,
+        std::function<void(SnapPeaTriangulation&&, Cover)>&& action) const {
     if (! data_)
         return 0;
 
@@ -1147,7 +1143,7 @@ size_t SnapPeaTriangulation::enumerateCoversInternal(int sheets,
     for (auto rep = reps->list; rep; rep = rep->next) {
         action(SnapPeaTriangulation(regina::snappea::construct_cover(
                 data_, rep, sheets)),
-            static_cast<CoverType>(rep->covering_type));
+            static_cast<Cover>(rep->covering_type));
         ++ans;
     }
 
