@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -197,15 +195,6 @@ class SigPartialIsomorphism : public ShortOutput<SigPartialIsomorphism> {
          */
         bool operator == (const SigPartialIsomorphism& other) const;
 
-        /**
-         * Determines whether this and the given partial isomorphism are
-         * not identical.
-         *
-         * \param other the partial isomorphism to compare with this.
-         * \return \c true if and only if this and \a other are not identical.
-         */
-        bool operator != (const SigPartialIsomorphism& other) const;
-
         /**
          * Lexicographically compares the results of applying this and
          * the given isomorphism to the given signature.
@@ -398,11 +387,6 @@ inline void SigPartialIsomorphism::swap(SigPartialIsomorphism& other) noexcept {
     std::swap(dir, other.dir);
 }
 
-inline bool SigPartialIsomorphism::operator != (
-        const SigPartialIsomorphism& other) const {
-    return ! ((*this) == other);
-}
-
 inline SigPartialIsomorphism::ShorterCycle::ShorterCycle(
         const Signature& newSig, const SigPartialIsomorphism& newIso) :
         sig(newSig), iso(newIso) {
