@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -254,7 +252,7 @@ std::unique_ptr<Manifold> BlockedSFS::manifold() const {
         // If we have SFS(RP2/n2) with one exceptional fibre, rewrite it as
         // SFS(S2) with three exceptional fibres.
 
-        if (ans.baseClass() == SFSpace::n2 &&
+        if (ans.baseClass() == SFSpace::Class::n2 &&
                 ans.baseGenus() == 1 &&
                 (! ans.baseOrientable()) &&
                 ans.punctures() == 0 &&
