@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -273,26 +271,6 @@ class LayeredChain : public StandardTriangulation {
          */
         bool operator == (const LayeredChain& other) const;
 
-        /**
-         * Determines whether this and the given structure represent
-         * different types of layered chain.
-         *
-         * Specifically, two layered chains will compare as equal if and
-         * only if they have the same index (i.e., the same number of
-         * tetrahedra).
-         *
-         * This test follows the general rule for most subclasses of
-         * StandardTriangulation (excluding fixed structures such as
-         * SnappedBall and TriSolidTorus): two objects compare as equal if and
-         * only if they have the same combinatorial parameters (which for this
-         * subclass means they describe isomorphic structures).
-         *
-         * \param other the structure with which this will be compared.
-         * \return \c true if and only if this and the given structure
-         * represent different types of layered chain.
-         */
-        bool operator != (const LayeredChain& other) const;
-
         std::unique_ptr<Manifold> manifold() const override;
         AbelianGroup homology() const override;
         std::ostream& writeName(std::ostream& out) const override;
@@ -349,10 +327,6 @@ inline bool LayeredChain::operator == (const LayeredChain& other) const {
     return index_ == other.index_;
 }
 
-inline bool LayeredChain::operator != (const LayeredChain& other) const {
-    return index_ != other.index_;
-}
-
 inline std::ostream& LayeredChain::writeName(std::ostream& out) const {
     return out << "Chain(" << index_ << ')';
 }
