@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -169,28 +167,6 @@ class LayeredLensSpace : public StandardTriangulation {
          */
         bool operator == (const LayeredLensSpace& other) const;
 
-        /**
-         * Determines whether this and the given structure represent
-         * different types of layered lens space.
-         *
-         * Specifically, two layered lens spaces will compare as equal if and
-         * only if they are formed from layered solid tori with the same
-         * parameters, closed off in the same way.
-         *
-         * This test follows the general rule for most subclasses of
-         * StandardTriangulation (excluding fixed structures such as
-         * SnappedBall and TriSolidTorus): two objects compare as equal if and
-         * only if they have the same combinatorial parameters (which for this
-         * subclass is more specific than combinatorial isomorphism, since
-         * the same layered lens space can be built from a layered solid
-         * torus starting at either of its two "ends").
-         *
-         * \param other the structure with which this will be compared.
-         * \return \c true if and only if this and the given structure
-         * represent different types of layered lens space.
-         */
-        bool operator != (const LayeredLensSpace& other) const;
-
         /**
          * Determines if the given triangulation component is a layered
          * lens space.
@@ -270,11 +246,6 @@ inline bool LayeredLensSpace::operator == (const LayeredLensSpace& other)
     return torus_ == other.torus_ &&
         mobiusBoundaryGroup_ == other.mobiusBoundaryGroup_;
 }
-inline bool LayeredLensSpace::operator != (const LayeredLensSpace& other)
-        const {
-    return torus_ != other.torus_ ||
-        mobiusBoundaryGroup_ != other.mobiusBoundaryGroup_;
-}
 
 inline void LayeredLensSpace::writeTextLong(std::ostream& out) const {
     out << "Layered lens space ";
