@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -287,32 +285,6 @@ class LayeredSolidTorus : public StandardTriangulation {
          */
         bool operator == (const LayeredSolidTorus& other) const;
 
-        /**
-         * Determines whether this and the given object do not represent the
-         * same type of layered solid torus.
-         *
-         * Specifically, two layered solid tori will compare as equal if
-         * and only if each has the same ordered triple of integer
-         * parameters (describing how many times the three top-level edge
-         * groups cut the meridinal disc).
-         *
-         * Note that it is possible for two non-isomorphic layered solid tori
-         * to compare as equal, since these integer parameters do not
-         * detect the presence of redundant layerings (i.e., consecutive
-         * layerings that topologically cancel each other out).
-         *
-         * This test follows the general rule for most subclasses of
-         * StandardTriangulation (excluding fixed structures such as
-         * SnappedBall and TriSolidTorus): two objects compare as equal if and
-         * only if they have the same combinatorial parameters (which for this
-         * subclass, as noted above, is weaker than combinatorial isomorphism).
-         *
-         * \param other the layered solid torus to compare with this.
-         * \return \c true if and only if this and the given object
-         * do not represent the same type of layered solid torus.
-         */
-        bool operator != (const LayeredSolidTorus& other) const;
-
         /**
          * Flattens this layered solid torus to a Mobius band.
          * A new modified triangulation is returned; the original triangulation
@@ -323,6 +295,11 @@ class LayeredSolidTorus : public StandardTriangulation {
          * different edges of the boundary torus that could become the
          * boundary edge of the new Mobius band.
          *
+         * If any tetrahedra and/or triangles in the layered solid torus are
+         * locked, this will not prevent the operation from occurring (since
+         * the original triangulation will not be changed).  The triangulation
+         * that is returned will have no simplex and/or facet locks at all.
+         *
          * \param mobiusBandBdry the edge group on the boundary of this
          * layered solid torus that will become the boundary of the new
          * Mobius band (the remaining edge groups will become internal
@@ -515,12 +492,6 @@ inline bool LayeredSolidTorus::operator == (const LayeredSolidTorus& other)
         other.meridinalCuts_);
 }
 
-inline bool LayeredSolidTorus::operator != (const LayeredSolidTorus& other)
-        const {
-    return ! std::equal(meridinalCuts_, meridinalCuts_ + 3,
-        other.meridinalCuts_);
-}
-
 inline std::ostream& LayeredSolidTorus::writeName(std::ostream& out) const {
     return out << "LST(" << meridinalCuts_[0] << ',' << meridinalCuts_[1] << ','
         << meridinalCuts_[2] << ')';
