@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -112,7 +110,7 @@ class SnapPeaCensusTri: public StandardTriangulation {
             /**< The section of the SnapPea census to which this
                  triangulation belongs.  This must be one of the section
                  constants defined in this class. */
-        unsigned long index_;
+        size_t index_;
             /**< The index within the given section of this specific
                  triangulation.  Note that the first index in each section
                  is zero. */
@@ -154,7 +152,7 @@ class SnapPeaCensusTri: public StandardTriangulation {
          *
          * \return the index of this triangulation within its section.
          */
-        unsigned long index() const;
+        size_t index() const;
 
         /**
          * Determines whether this and the given structure represent
@@ -177,27 +175,6 @@ class SnapPeaCensusTri: public StandardTriangulation {
          */
         bool operator == (const SnapPeaCensusTri& compare) const;
 
-        /**
-         * Determines whether this and the given structure represent
-         * different triangulations from the SnapPea census.
-         *
-         * The SnapPea census manifolds \c x101 and \c x103 are homeomorphic;
-         * however, the corresponding triangulations represented by
-         * SnapPeaCensusTri will compare as different (since this class
-         * describes the specific triangulation, not the underlying manifold).
-         *
-         * This test follows the general rule for most subclasses of
-         * StandardTriangulation (excluding fixed structures such as
-         * SnappedBall and TriSolidTorus): two objects compare as equal if and
-         * only if they have the same combinatorial parameters (which for this
-         * subclass means they describe isomorphic structures).
-         *
-         * \param compare the structure with which this will be compared.
-         * \return \c true if and only if this and the given structure
-         * represent different SnapPea census triangulations.
-         */
-        bool operator != (const SnapPeaCensusTri& compare) const;
-
         /**
          * Determines if the given triangulation component is one of the
          * smallest SnapPea census triangulations.
@@ -230,7 +207,7 @@ class SnapPeaCensusTri: public StandardTriangulation {
          * Creates a new SnapPea census triangulation with the given
          * parameters.
          */
-        SnapPeaCensusTri(char section, unsigned long index);
+        SnapPeaCensusTri(char section, size_t index);
 
     friend class SnapPeaCensusManifold;
 };
@@ -251,7 +228,7 @@ void swap(SnapPeaCensusTri& a, SnapPeaCensusTri& b) noexcept;
 // Inline functions that need to be defined before *other* inline funtions
 // that use them (this fixes DLL-related warnings in the windows port)
 
-inline SnapPeaCensusTri::SnapPeaCensusTri(char section, unsigned long index) :
+inline SnapPeaCensusTri::SnapPeaCensusTri(char section, size_t index) :
         section_(section), index_(index) {
 }
 
@@ -266,7 +243,7 @@ inline char SnapPeaCensusTri::section() const {
     return section_;
 }
 
-inline unsigned long SnapPeaCensusTri::index() const {
+inline size_t SnapPeaCensusTri::index() const {
     return index_;
 }
 
@@ -275,11 +252,6 @@ inline bool SnapPeaCensusTri::operator == (const SnapPeaCensusTri& compare)
     return (section_ == compare.section_ && index_ == compare.index_);
 }
 
-inline bool SnapPeaCensusTri::operator != (const SnapPeaCensusTri& compare)
-        const {
-    return (section_ != compare.section_ || index_ != compare.index_);
-}
-
 inline void swap(SnapPeaCensusTri& a, SnapPeaCensusTri& b) noexcept {
     a.swap(b);
 }
