@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -157,28 +155,6 @@ class SnappedBall : public StandardTriangulation {
          * the same specific presentation of a snapped 3-ball.
          */
         bool operator == (const SnappedBall& other) const;
-        /**
-         * Determines whether this and the given object represent different
-         * specific presentations of a snapped 3-ball.
-         *
-         * Unlike the parameterised subclasses of StandardTriangulation,
-         * this SnappedBall subclass represents a fixed structure, and
-         * so its comparisons test not for the _structure_ but the precise
-         * _location_ of this structure within the enclosing triangulation.
-         *
-         * Specifically, two snapped 3-balls will compare as equal if and only
-         * if each uses the same numbered tetrahedron, and has the same
-         * numbered equator edge within that tetrahedron.  That is, the
-         * tetrahedra returned by tetrahedron() must have equal indices within
-         * the triangulation, and the edge numbers returned by equatorEdge()
-         * must be equal.  In particular, it is still meaningful to compare
-         * snapped 3-balls within different triangulations.
-         *
-         * \param other the snapped 3-ball to compare with this.
-         * \return \c true if and only if this and the given object represent
-         * different specific presentations of a snapped 3-ball.
-         */
-        bool operator != (const SnappedBall& other) const;
 
         /**
          * Determines if the given tetrahedron forms a snapped 3-ball
@@ -261,9 +237,6 @@ inline int SnappedBall::internalEdge() const {
 inline bool SnappedBall::operator == (const SnappedBall& other) const {
     return tet_->index() == other.tet_->index() && equator_ == other.equator_;
 }
-inline bool SnappedBall::operator != (const SnappedBall& other) const {
-    return tet_->index() != other.tet_->index() || equator_ != other.equator_;
-}
 
 inline std::ostream& SnappedBall::writeName(std::ostream& out) const {
     return out << "Snap";
