@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -219,26 +217,6 @@ class SpiralSolidTorus : public StandardTriangulation {
          */
         bool operator == (const SpiralSolidTorus& other) const;
 
-        /**
-         * Determines whether this and the given structure represent
-         * different types of spiralled solid torus.
-         *
-         * Specifically, two spiralled solid tori will compare as equal if and
-         * only if they have the same size (i.e., the same number of
-         * tetrahedra).
-         *
-         * This test follows the general rule for most subclasses of
-         * StandardTriangulation (excluding fixed structures such as
-         * SnappedBall and TriSolidTorus): two objects compare as equal if and
-         * only if they have the same combinatorial parameters (which for this
-         * subclass means they describe isomorphic structures).
-         *
-         * \param other the structure with which this will be compared.
-         * \return \c true if and only if this and the given structure
-         * represent different types of spiralled solid torus.
-         */
-        bool operator != (const SpiralSolidTorus& other) const;
-
         /**
          * Reverses this spiralled solid torus.
          * Tetrahedra 0, 1, 2, ..., size()-1 will become tetrahedra
@@ -397,11 +375,6 @@ inline bool SpiralSolidTorus::operator == (const SpiralSolidTorus& other)
     return nTet_ == other.nTet_;
 }
 
-inline bool SpiralSolidTorus::operator != (const SpiralSolidTorus& other)
-        const {
-    return nTet_ != other.nTet_;
-}
-
 inline std::ostream& SpiralSolidTorus::writeName(std::ostream& out) const {
     return out << "Spiral(" << nTet_ << ')';
 }
