@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -58,7 +56,7 @@ namespace regina {
 class NormalSurfaces;
 
 /**
- * \defgroup surfaces Normal Surfaces
+ * \defgroup surface Normal Surfaces
  * Normal surfaces in 3-manifold triangulations.
  */
 
@@ -75,7 +73,7 @@ class NormalSurfaces;
  * edge \a i together (and will therefore also keep the vertices of edge
  * \a 5-i together).
  *
- * \ingroup surfaces
+ * \ingroup surface
  */
 inline constexpr int quadSeparating[4][4] = {
     { -1, 0, 1, 2 }, {  0,-1, 2, 1 }, {  1, 2,-1, 0 }, {  2, 1, 0,-1 }
@@ -90,7 +88,7 @@ inline constexpr int quadSeparating[4][4] = {
  * quadrilateral types that meet the edge joining tetrahedron vertices
  * `i` and `j`.
  *
- * \ingroup surfaces
+ * \ingroup surface
  */
 inline constexpr int quadMeeting[4][4][2] = {
     { {-1,-1}, { 1, 2}, { 0, 2}, { 0, 1} },
@@ -119,7 +117,7 @@ inline constexpr int quadMeeting[4][4][2] = {
  * this will give the same results for \a j = 0 and 1, but it might
  * switch the results for \a j = 2 and 3.
  *
- * \ingroup surfaces
+ * \ingroup surface
  */
 inline constexpr int quadDefn[3][4] = {
     { 0, 1, 2, 3 }, { 0, 2, 1, 3 }, { 0, 3, 1, 2 }
@@ -134,7 +132,7 @@ inline constexpr int quadDefn[3][4] = {
  * Quadrilateral type \c i pairs vertex \c v with
  * vertex `quadPartner[i][v]`.
  *
- * \ingroup surfaces
+ * \ingroup surface
  */
 inline constexpr int quadPartner[3][4] = {
     { 1, 0, 3, 2}, { 2, 3, 0, 1}, { 3, 2, 1, 0}
@@ -150,13 +148,18 @@ inline constexpr int quadPartner[3][4] = {
  * is of the form `02/13`, which in this case is the quadrilateral type
  * that splits vertices 0,2 from vertices 1,3.
  *
- * For Regina 7.3.1 only this is merely `inline const`, since C++17 does
- * not support constexpr strings.  In Regina 7.4 (which moves to C++20),
- * this array will again be `constexpr`.
+ * Some older compilers (such as GCC 10 and GCC 11) do not support constexpr
+ * strings.  In such cases, this constant will be marked `inline const`
+ * but not `constexpr`.
  *
- * \ingroup surfaces
+ * \ingroup surface
  */
+#if defined(__APIDOCS) || __cpp_lib_constexpr_string >= 201907L
+inline constexpr std::string quadString[3] = { "01/23", "02/13", "03/12" };
+#else
+// The compiler does not support constexpr strings. Fall back to const.
 inline const std::string quadString[3] = { "01/23", "02/13", "03/12" };
+#endif
 
 /**
  * Lists in consecutive order the directed normal arcs that form the
@@ -170,7 +173,7 @@ inline const std::string quadString[3] = { "01/23", "02/13", "03/12" };
  *
  * Note that every permutation in this array is even.
  *
- * \ingroup surfaces
+ * \ingroup surface
  */
 inline constexpr Perm<4> triDiscArcs[4][3] = {
     Perm<4>(0,1,2,3), Perm<4>(0,2,3,1), Perm<4>(0,3,1,2),
@@ -192,7 +195,7 @@ inline constexpr Perm<4> triDiscArcs[4][3] = {
  * Note that permutation `quadDiscArcs[i][j]` will be even
  * precisely when `j` is even.
  *
- * \ingroup surfaces
+ * \ingroup surface
  */
 inline constexpr Perm<4> quadDiscArcs[3][4] = {
     Perm<4>(0,2,3,1), Perm<4>(3,0,1,2), Perm<4>(1,3,2,0), Perm<4>(2,1,0,3),
@@ -213,7 +216,7 @@ inline constexpr Perm<4> quadDiscArcs[3][4] = {
  * Note that permutation `octDiscArcs[i][j]` will be even
  * precisely when `j` is 0, 1, 4 or 5.
  *
- * \ingroup surfaces
+ * \ingroup surface
  */
 inline constexpr Perm<4> octDiscArcs[3][8] = {
     Perm<4>(0,3,1,2), Perm<4>(0,1,2,3), Perm<4>(2,0,3,1), Perm<4>(2,3,1,0),
@@ -224,8 +227,8 @@ inline constexpr Perm<4> octDiscArcs[3][8] = {
     Perm<4>(3,1,0,2), Perm<4>(3,0,2,1), Perm<4>(2,3,1,0), Perm<4>(2,1,0,3)
 };
 
-template <typename, bool> class Matrix;
-using MatrixInt = Matrix<Integer, true>;
+template <typename> class Matrix;
+using MatrixInt = Matrix<Integer>;
 
 /**
  * Represents a single normal surface in a 3-manifold triangulation.
@@ -278,7 +281,7 @@ using MatrixInt = Matrix<Integer, true>;
  * \todo \featurelong Determine which faces in the solution space a
  * normal surface belongs to.
  *
- * \ingroup surfaces
+ * \ingroup surface
  */
 class NormalSurface : public ShortOutput<NormalSurface> {
     protected:
@@ -424,8 +427,12 @@ class NormalSurface : public ShortOutput<NormalSurface> {
          * surface inside the given triangulation, using the given encoding.
          * This will not be checked!
          *
-         * \python Instead of a Vector<LargeInteger>, you may (if
-         * you prefer) pass a Python list of integers.
+         * \python The supported types for the template parameter \a U are
+         * regina::Integer and regina::LargeInteger.  You may also, if you
+         * prefer, pass \a vector as a Python list of integers.
+         *
+         * \tparam U the type of object held by the given vector.  It must be
+         * possible to assign an object of type \a U to a regina::LargeInteger.
          *
          * \param triang the triangulation in which this normal surface resides.
          * \param enc indicates precisely how the given vector encodes a normal
@@ -433,8 +440,9 @@ class NormalSurface : public ShortOutput<NormalSurface> {
          * \param vector a vector containing the coordinates of the normal
          * surface.
          */
+        template <typename U>
         NormalSurface(const Triangulation<3>& triang, NormalEncoding enc,
-            const Vector<LargeInteger>& vector);
+            const Vector<U>& vector);
 
         /**
          * Creates a new normal surface inside the given triangulation with the
@@ -486,6 +494,9 @@ class NormalSurface : public ShortOutput<NormalSurface> {
          *
          * \nopython Instead use the version that takes a "pure" triangulation.
          *
+         * \tparam U the type of object held by the given vector.  It must be
+         * possible to assign an object of type \a U to a regina::LargeInteger.
+         *
          * \param triang a snapshot, frozen in time, of the
          * triangulation in which this normal surface resides.
          * \param enc indicates precisely how the given vector encodes a normal
@@ -493,8 +504,9 @@ class NormalSurface : public ShortOutput<NormalSurface> {
          * \param vector a vector containing the coordinates of the normal
          * surface.
          */
+        template <typename U>
         NormalSurface(const SnapshotRef<Triangulation<3>>& triang,
-            NormalEncoding enc, const Vector<LargeInteger>& vector);
+            NormalEncoding enc, const Vector<U>& vector);
 
         /**
          * Creates a new normal surface inside the given triangulation with the
@@ -550,8 +562,12 @@ class NormalSurface : public ShortOutput<NormalSurface> {
          * surface inside the given triangulation, using the encoding
          * `NormalEncoding(coords)`.  This will not be checked!
          *
-         * \python Instead of a Vector<LargeInteger>, you may (if
-         * you prefer) pass a Python list of integers.
+         * \python The supported types for the template parameter \a U are
+         * regina::Integer and regina::LargeInteger.  You may also, if you
+         * prefer, pass \a vector as a Python list of integers.
+         *
+         * \tparam U the type of object held by the given vector.  It must be
+         * possible to assign an object of type \a U to a regina::LargeInteger.
          *
          * \param triang the triangulation in which this normal surface resides.
          * \param coords the coordinate system from which the vector
@@ -559,8 +575,9 @@ class NormalSurface : public ShortOutput<NormalSurface> {
          * \param vector a vector containing the coordinates of the normal
          * surface.
          */
+        template <typename U>
         NormalSurface(const Triangulation<3>& triang, NormalCoords coords,
-            const Vector<LargeInteger>& vector);
+            const Vector<U>& vector);
 
         /**
          * Creates a new normal surface inside the given triangulation with the
@@ -620,6 +637,9 @@ class NormalSurface : public ShortOutput<NormalSurface> {
          *
          * \nopython Instead use the version that takes a "pure" triangulation.
          *
+         * \tparam U the type of object held by the given vector.  It must be
+         * possible to assign an object of type \a U to a regina::LargeInteger.
+         *
          * \param triang a snapshot, frozen in time, of the
          * triangulation in which this normal surface resides.
          * \param coords the coordinate system from which the vector
@@ -627,8 +647,9 @@ class NormalSurface : public ShortOutput<NormalSurface> {
          * \param vector a vector containing the coordinates of the normal
          * surface.
          */
+        template <typename U>
         NormalSurface(const SnapshotRef<Triangulation<3>>& triang,
-            NormalCoords coords, const Vector<LargeInteger>& vector);
+            NormalCoords coords, const Vector<U>& vector);
 
         /**
          * Creates a new normal surface inside the given triangulation with the
@@ -953,8 +974,9 @@ class NormalSurface : public ShortOutput<NormalSurface> {
          * \param out the output stream to which the XML should be written.
          * \param format indicates which of Regina's XML file formats to write.
          * \param list the enclosing normal surface list.  Currently this
-         * is only relevant when writing to the older REGINA_XML_GEN_2 format;
-         * it will be ignored (and may be \c null) for newer file formats.
+         * is only relevant when writing to the older FileFormat::XmlGen2
+         * format; it will be ignored (and may be \c null) for newer file
+         * formats.
          */
         void writeXMLData(std::ostream& out, FileFormat format,
             const NormalSurfaces* list) const;
@@ -990,6 +1012,17 @@ class NormalSurface : public ShortOutput<NormalSurface> {
         /**
          * Returns the Euler characteristic of this surface.
          *
+         * For properly embedded surfaces, this is of course just the ordinary
+         * Euler characteristic of the surface.
+         *
+         * For immersed or singular surfaces, the situation is more complex
+         * since Regina does not know how many branch points there are (if any).
+         * Regina's approach is to compute everything locally, assuming that
+         * the surface is an immersion.  This means that eulerChar() will
+         * report the correct result for an immersed surface, but for singular
+         * surfaces it will report a _larger_ number than it should since it
+         * essentially counts each branch point as multiple vertices.
+         *
          * This routine caches its results, which means that once it has
          * been called for a particular surface, subsequent calls return
          * the answer immediately.
@@ -1422,6 +1455,20 @@ class NormalSurface : public ShortOutput<NormalSurface> {
          * now handle octagons, including cases with multiple octagons in the
          * same tetrahedron and/or octagons in multiple tetrahedra.
          *
+         * This operation does _not_ preserve orientation.  That is,
+         * even if the original triangulation is oriented, there are no
+         * guarantees regarding the orientation of the tetrahedra in the
+         * cut-open triangulation.  The cut-open triangulation might have the
+         * same or opposite orientation as the original, or it might not be
+         * oriented at all.  If you need to preserve orientation, consider
+         * whether crush() (which _does_ preserve orientation) might work for
+         * you instead.
+         *
+         * This routine will ignore any locks on tetrahedra and/or triangles
+         * of the original triangulation (and of course the original
+         * triangulation will be left safely unchanged).  The triangulation
+         * that is returned will not have any locks at all.
+         *
          * \warning The number of tetrahedra in the new triangulation
          * can be _very_ large.
          *
@@ -1456,6 +1503,14 @@ class NormalSurface : public ShortOutput<NormalSurface> {
          * small Lens spaces and so on; a full list of possible changes
          * is beyond the scope of this API documentation.
          *
+         * If the original triangulation is oriented, then the crushing
+         * operation will preserve this orientation.
+         *
+         * This routine will ignore any locks on tetrahedra and/or triangles
+         * of the original triangulation (and of course the original
+         * triangulation will be left safely unchanged).  The triangulation
+         * that is returned will not have any locks at all.
+         *
          * \warning This routine can have unintended topological
          * side-effects, as described above.
          *
@@ -1499,6 +1554,14 @@ class NormalSurface : public ShortOutput<NormalSurface> {
          * Note: this routine can happily cope with multiple octagons in the
          * same tetrahedron, and/or multiple tetrahedra containing octagons.
          *
+         * This routine ignores tetrahedron locks entirely. If there are
+         * octagons present and the triangulation does change, then the new
+         * triangulation will have no tetrahedron or triangle locks at all.
+         * In particular, such locks will not stop this routine from
+         * subdividing those tetrahedra that contain octagons.
+         * Of course, the original triangulation will remain untouched,
+         * with all of its locks intact.
+         *
          * \pre This surface is embedded.
          *
          * \return an isotopic normal (not almost normal) surface \a s,
@@ -1537,39 +1600,10 @@ class NormalSurface : public ShortOutput<NormalSurface> {
         bool operator == (const NormalSurface& other) const;
 
         /**
-         * Determines whether this and the given surface represent
-         * different normal (or almost normal) surfaces.
+         * Compares this against the given surface under a total
+         * ordering of all normal and almost normal surfaces.
          *
-         * Specifically, this routine examines (or computes) the number of
-         * normal or almost normal discs of each type, and returns \c true
-         * if and only if these counts are not the same for both surfaces.
-         *
-         * It does not matter what vector encodings the two surfaces
-         * use.  In particular, it does not matter if the two surfaces
-         * use different encodings, or if one but not the other supports
-         * almost normal and/or spun-normal surfaces.
-         *
-         * This routine is safe to call even if this and the given
-         * surface do not belong to the same triangulation:
-         *
-         * - If the two triangulations have the same size, then this routine
-         *   will test whether this surface, if transplanted into the
-         *   other triangulation using the same tetrahedron numbering and the
-         *   same normal disc types, would be different from \a other.
-         *
-         * - If the two triangulations have different sizes, then this
-         *   routine will return \c true.
-         *
-         * \param other the surface to be compared with this surface.
-         * \return \c true if both surfaces represent different normal or
-         * almost normal surface, or \c false if not.
-         */
-        bool operator != (const NormalSurface& other) const;
-
-        /**
-         * Imposes a total order on all normal and almost normal surfaces.
-         *
-         * This order is not mathematically meaningful; it is merely
+         * This ordering is not mathematically meaningful; it is merely
          * provided for scenarios where you need to be able to sort
          * surfaces (e.g., when using them as keys in a map).
          *
@@ -1585,11 +1619,20 @@ class NormalSurface : public ShortOutput<NormalSurface> {
          * other supports non-compact or almost normal surfaces.
          * See the equality test operator==() for further details.
          *
-         * \param other the surface to be compared with this surface.
-         * \return \c true if and only if this appears before the given
-         * surface in the total order.
+         * This routine generates all of the usual comparison operators,
+         * including `<`, `<=`, `>`, and `>=`.
+         *
+         * \python This spaceship operator `x <=> y` is not available, but the
+         * other comparison operators that it generates _are_ available.
+         *
+         * \param rhs the surface to compare this surface with.
+         * \return The result of the comparison between this and the given
+         * surface.  This is marked as a weak ordering (not a strong
+         * ordering) to reflect the fact that (for example) surfaces in
+         * different triangulations or using different encodings could be
+         * considered equal under this comparison.
          */
-        bool operator < (const NormalSurface& other) const;
+        std::weak_ordering operator <=> (const NormalSurface& rhs) const;
 
         /**
          * Determines whether this surface contains only triangle and/or
@@ -1913,14 +1956,15 @@ class NormalSurface : public ShortOutput<NormalSurface> {
  * \param a the first normal surface whose contents should be swapped.
  * \param b the second normal surface whose contents should be swapped.
  *
- * \ingroup surfaces
+ * \ingroup surface
  */
 void swap(NormalSurface& a, NormalSurface& b) noexcept;
 
 // Inline functions for NormalSurface
 
+template <typename U>
 inline NormalSurface::NormalSurface(const Triangulation<3>& tri,
-        NormalEncoding enc, const Vector<LargeInteger>& vector) :
+        NormalEncoding enc, const Vector<U>& vector) :
         enc_(enc), vector_(vector), triangulation_(tri) {
     // This call to storesTriangles() is unnecessary, but we'd like it
     // accessible to the inline version.  (Same goes for the similar
@@ -1936,9 +1980,10 @@ inline NormalSurface::NormalSurface(const Triangulation<3>& tri,
         enc_ = reconstructTriangles(tri, vector_, enc_);
 }
 
+template <typename U>
 inline NormalSurface::NormalSurface(
         const SnapshotRef<Triangulation<3>>& tri,
-        NormalEncoding enc, const Vector<LargeInteger>& vector) :
+        NormalEncoding enc, const Vector<U>& vector) :
         enc_(enc), vector_(vector), triangulation_(tri) {
     if (! enc_.storesTriangles())
         enc_ = reconstructTriangles(*tri, vector_, enc_);
@@ -1952,8 +1997,9 @@ inline NormalSurface::NormalSurface(
         enc_ = reconstructTriangles(*tri, vector_, enc_);
 }
 
+template <typename U>
 inline NormalSurface::NormalSurface(const Triangulation<3>& tri,
-        NormalCoords coords, const Vector<LargeInteger>& vector) :
+        NormalCoords coords, const Vector<U>& vector) :
         enc_(coords), vector_(vector), triangulation_(tri) {
     if (! enc_.storesTriangles())
         enc_ = reconstructTriangles(tri, vector_, enc_);
@@ -1967,9 +2013,10 @@ inline NormalSurface::NormalSurface(const Triangulation<3>& tri,
         enc_ = reconstructTriangles(tri, vector_, enc_);
 }
 
+template <typename U>
 inline NormalSurface::NormalSurface(
         const SnapshotRef<Triangulation<3>>& tri,
-        NormalCoords coords, const Vector<LargeInteger>& vector) :
+        NormalCoords coords, const Vector<U>& vector) :
         enc_(coords), vector_(vector), triangulation_(tri) {
     if (! enc_.storesTriangles())
         enc_ = reconstructTriangles(*tri, vector_, enc_);
@@ -2091,10 +2138,6 @@ inline size_t NormalSurface::countBoundaries() const {
     return *boundaries_;
 }
 
-inline bool NormalSurface::operator != (const NormalSurface& other) const {
-    return ! ((*this) == other);
-}
-
 inline bool NormalSurface::normal() const {
     return ! octPosition();
 }
