@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -70,7 +68,7 @@ class SurfaceFilterProperties;
  * \param id the corresponding SurfaceFilterType constant.
  * \param name a human-readable name for this filter type.
  *
- * \ingroup surfaces
+ * \ingroup surface
  */
 #define REGINA_SURFACE_FILTER(id, name) \
     public: \
@@ -109,10 +107,10 @@ class SurfaceFilterProperties;
  * filter content, not the packet infrastructure (e.g., they do not touch
  * packet labels, or the packet tree, or event listeners).
  *
- * \ingroup surfaces
+ * \ingroup surface
  */
 class SurfaceFilter : public Packet {
-    REGINA_PACKET(PACKET_SURFACEFILTER, "Surface filter")
+    REGINA_PACKET(PacketType::SurfaceFilter, "Surface filter")
 
     public:
         /**
@@ -174,10 +172,10 @@ class SurfaceFilter : public Packet {
  * infrastructure (e.g., they do not touch packet labels, or the packet
  * tree, or event listeners).
  *
- * \ingroup surfaces
+ * \ingroup surface
  */
 class SurfaceFilterCombination : public SurfaceFilter {
-    REGINA_SURFACE_FILTER(NS_FILTER_COMBINATION, "Combination filter")
+    REGINA_SURFACE_FILTER(SurfaceFilterType::Combination, "Combination filter")
 
     private:
         bool usesAnd_;
@@ -250,16 +248,6 @@ class SurfaceFilterCombination : public SurfaceFilter {
          */
         bool operator == (const SurfaceFilterCombination& other) const;
 
-        /**
-         * Determines if this and the given filter do not use the same
-         * boolean operation.
-         *
-         * \param other the filter to compare with this.
-         * \return \c true if and only if this and the given filter
-         * use different boolean operations.
-         */
-        bool operator != (const SurfaceFilterCombination& other) const;
-
         bool accept(const NormalSurface& surface) const override;
         void writeTextShort(std::ostream& o) const override;
 
@@ -279,7 +267,7 @@ class SurfaceFilterCombination : public SurfaceFilter {
  * \param a the first filter whose contents should be swapped.
  * \param b the second filter whose contents should be swapped.
  *
- * \ingroup surfaces
+ * \ingroup surface
  */
 void swap(SurfaceFilterCombination& a, SurfaceFilterCombination& b);
 
@@ -301,10 +289,10 @@ void swap(SurfaceFilterCombination& a, SurfaceFilterCombination& b);
  * infrastructure (e.g., they do not touch packet labels, or the packet
  * tree, or event listeners).
  *
- * \ingroup surfaces
+ * \ingroup surface
  */
 class SurfaceFilterProperties : public SurfaceFilter {
-    REGINA_SURFACE_FILTER(NS_FILTER_PROPERTIES, "Filter by basic properties")
+    REGINA_SURFACE_FILTER(SurfaceFilterType::Properties, "Filter by basic properties")
 
     private:
         std::set<LargeInteger> eulerChar_;
@@ -501,23 +489,6 @@ class SurfaceFilterProperties : public SurfaceFilter {
          */
         bool operator == (const SurfaceFilterProperties& other) const;
 
-        /**
-         * Determines if this and the given filter are configured to
-         * filter on the different sets of constraints.
-         *
-         * Even if both filters are designed to reject _every_ surface
-         * by having an empty BoolSet for one of the boolean conditions,
-         * they will still compare as different unless they use an empty
-         * BoolSet for the _same_ boolean condition(s).  In other words,
-         * this test compares the precise configurations of the filters,
-         * not their deduced behaviour.
-         *
-         * \param other the filter to compare with this.
-         * \return \c true if and only if this and the given filters are
-         * not identical.
-         */
-        bool operator != (const SurfaceFilterProperties& other) const;
-
         bool accept(const NormalSurface& surface) const override;
         void writeTextShort(std::ostream& o) const override;
 
@@ -537,7 +508,7 @@ class SurfaceFilterProperties : public SurfaceFilter {
  * \param a the first filter whose contents should be swapped.
  * \param b the second filter whose contents should be swapped.
  *
- * \ingroup surfaces
+ * \ingroup surface
  */
 void swap(SurfaceFilterProperties& a, SurfaceFilterProperties& b);
 
@@ -548,14 +519,14 @@ inline SurfaceFilterCombination::SurfaceFilterCombination() : usesAnd_(true) {
 
 inline SurfaceFilterCombination& SurfaceFilterCombination::operator = (
         const SurfaceFilterCombination& src) {
-    ChangeEventSpan span(*this);
+    PacketChangeSpan span(*this);
     usesAnd_ = src.usesAnd_;
     return *this;
 }
 
 inline void SurfaceFilterCombination::swap(SurfaceFilterCombination& other) {
-    ChangeEventSpan span1(*this);
-    ChangeEventSpan span2(other);
+    PacketChangeSpan span1(*this);
+    PacketChangeSpan span2(other);
     std::swap(usesAnd_, other.usesAnd_);
 }
 
@@ -564,7 +535,7 @@ inline bool SurfaceFilterCombination::usesAnd() const {
 }
 inline void SurfaceFilterCombination::setUsesAnd(bool value) {
     if (usesAnd_ != value) {
-        ChangeEventSpan span(*this);
+        PacketChangeSpan span(*this);
         usesAnd_ = value;
     }
 }
@@ -574,11 +545,6 @@ inline bool SurfaceFilterCombination::operator == (
     return usesAnd_ == other.usesAnd_;
 }
 
-inline bool SurfaceFilterCombination::operator != (
-        const SurfaceFilterCombination& other) const {
-    return usesAnd_ != other.usesAnd_;
-}
-
 inline void SurfaceFilterCombination::writeTextShort(std::ostream& o) const {
     o << (usesAnd_ ? "AND" : "OR") << " filter";
 }
@@ -602,7 +568,7 @@ inline SurfaceFilterProperties::SurfaceFilterProperties() :
 
 inline SurfaceFilterProperties& SurfaceFilterProperties::operator = (
         const SurfaceFilterProperties& src) {
-    ChangeEventSpan span(*this);
+    PacketChangeSpan span(*this);
 
     eulerChar_ = src.eulerChar_;
     orientability_ = src.orientability_;
@@ -613,8 +579,8 @@ inline SurfaceFilterProperties& SurfaceFilterProperties::operator = (
 }
 
 inline void SurfaceFilterProperties::swap(SurfaceFilterProperties& other) {
-    ChangeEventSpan span1(*this);
-    ChangeEventSpan span2(other);
+    PacketChangeSpan span1(*this);
+    PacketChangeSpan span2(other);
 
     eulerChar_.swap(other.eulerChar_);
     std::swap(orientability_, other.orientability_);
@@ -642,38 +608,38 @@ inline BoolSet SurfaceFilterProperties::realBoundary() const {
 template <typename Iterator>
 inline void SurfaceFilterProperties::setEulerChars(
         Iterator beginEuler, Iterator endEuler) {
-    ChangeEventSpan span(*this);
+    PacketChangeSpan span(*this);
     eulerChar_.clear();
     eulerChar_.insert(beginEuler, endEuler);
 }
 
 inline void SurfaceFilterProperties::addEulerChar(const LargeInteger& ec) {
-    ChangeEventSpan span(*this);
+    PacketChangeSpan span(*this);
     eulerChar_.insert(ec);
 }
 inline void SurfaceFilterProperties::removeEulerChar(const LargeInteger& ec) {
-    ChangeEventSpan span(*this);
+    PacketChangeSpan span(*this);
     eulerChar_.erase(ec);
 }
 inline void SurfaceFilterProperties::removeAllEulerChars() {
-    ChangeEventSpan span(*this);
+    PacketChangeSpan span(*this);
     eulerChar_.clear();
 }
 inline void SurfaceFilterProperties::setOrientability(BoolSet value) {
     if (orientability_ != value) {
-        ChangeEventSpan span(*this);
+        PacketChangeSpan span(*this);
         orientability_ = value;
     }
 }
 inline void SurfaceFilterProperties::setCompactness(BoolSet value) {
     if (compactness_ != value) {
-        ChangeEventSpan span(*this);
+        PacketChangeSpan span(*this);
         compactness_ = value;
     }
 }
 inline void SurfaceFilterProperties::setRealBoundary(BoolSet value) {
     if (realBoundary_ != value) {
-        ChangeEventSpan span(*this);
+        PacketChangeSpan span(*this);
         realBoundary_ = value;
     }
 }
@@ -686,14 +652,6 @@ inline bool SurfaceFilterProperties::operator == (
         eulerChar_ == other.eulerChar_;
 }
 
-inline bool SurfaceFilterProperties::operator != (
-        const SurfaceFilterProperties& other) const {
-    return orientability_ != other.orientability_ ||
-        compactness_ != other.compactness_ ||
-        realBoundary_ != other.realBoundary_ ||
-        eulerChar_ != other.eulerChar_;
-}
-
 inline std::shared_ptr<Packet> SurfaceFilterProperties::internalClonePacket()
         const {
     return std::make_shared<SurfaceFilterProperties>(*this);
