@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -91,9 +89,6 @@ namespace {
             bool operator == (const ReorderIterator& rhs) const {
                 return it_ == rhs.it_;
             }
-            bool operator != (const ReorderIterator& rhs) const {
-                return it_ != rhs.it_;
-            }
             ReorderIterator& operator ++() {
                 ++it_;
                 return *this;
@@ -135,9 +130,6 @@ Triangulation<dim-1>* BoundaryComponentBase<dim>::buildRealBoundary() const {
     // this function to capture by reference, not by value.
     auto* ans = new Triangulation<dim-1>();
 
-    // Ensure only one event pair is fired in this sequence of changes.
-    typename Triangulation<dim-1>::ChangeEventSpan span(*ans);
-
     for (auto s : allFacets)
         bdrySimplex[s->index()] = ans->newSimplex();
 
