@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -72,7 +70,7 @@ class ExampleFromLowDim {
          * triangulation.
          *
          * If the given triangulation represents the manifold `M`, then
-         * this returns an ideal triangulation of the product `M x I`
+         * this returns an ideal triangulation of the product `M × I`
          * (with two ideal boundary components).  A copy of the original
          * triangulation \a base can be found at the centre of this
          * construction, formed from the <i>dim</i>-simplices that sit
@@ -86,7 +84,10 @@ class ExampleFromLowDim {
          * This construction is essentially the suspension of the
          * triangulation \a base.  We do not call it this however, since
          * from a topological point of view, to form the ideal triangulation
-         * of `M x I` we "remove" the vertices at the apex of each cone.
+         * of `M × I` we "remove" the vertices at the apex of each cone.
+         *
+         * If the given 3-dimensional triangulation is oriented, then the
+         * resulting 4-dimensional triangulation will be oriented also.
          *
          * \warning If the given (<i>dim</i>-1)-dimensional triangulation has
          * any boundary whatsoever (either real or ideal), then unless it is
@@ -102,11 +103,14 @@ class ExampleFromLowDim {
          * triangulation.
          *
          * If the given triangulation represents the manifold `M`, then
-         * this returns a triangulation of the product `M x I` that has
+         * this returns a triangulation of the product `M × I` that has
          * one real boundary component and one ideal boundary component.
          * The triangulation of the real boundary component will be identical
          * to the original (<i>dim-1</i>)-dimensional triangulation \a base.
          *
+         * If the given 3-dimensional triangulation is oriented, then the
+         * resulting 4-dimensional triangulation will be oriented also.
+         *
          * \warning If the given (<i>dim</i>-1)-dimensional triangulation has
          * any boundary whatsoever (either real or ideal), then unless it is
          * a (<i>dim</i>-1)-ball, you will obtain an invalid
@@ -173,6 +177,9 @@ class ExampleBase : public ExampleFromLowDim<dim, dim != 2> {
         /**
          * Returns a two-simplex triangulation of the <i>dim</i>-sphere.
          *
+         * Although the sphere is orientable, this triangulation will _not_ be
+         * oriented since the gluings will all be identity permutations.
+         *
          * \return a two-simplex <i>dim</i>-sphere.
          */
         static Triangulation<dim> sphere();
@@ -181,15 +188,23 @@ class ExampleBase : public ExampleFromLowDim<dim, dim != 2> {
          * Returns the standard (<i>dim</i>+2)-simplex triangulation of the
          * <i>dim</i>-sphere as the boundary of a (<i>dim</i>+1)-simplex.
          *
+         * Note that the current construction does _not_ give an oriented
+         * triangulation (due to the specific choice of labelling); this may
+         * change in a future version of Regina.
+         *
          * \return the standard simplicial <i>dim</i>-sphere.
          */
         static Triangulation<dim> simplicialSphere();
 
         /**
          * Returns a two-simplex triangulation of the product space
-         * `S^(dim-1) x S¹`.
+         * `S^(dim-1) × S¹`.
          *
-         * \return the product `S^(dim-1) x S¹`.
+         * Note that the current construction does _not_ give an oriented
+         * triangulation (due to the specific choice of labelling); this may
+         * change in a future version of Regina.
+         *
+         * \return the product `S^(dim-1) × S¹`.
          */
         static Triangulation<dim> sphereBundle();
 
@@ -215,12 +230,18 @@ class ExampleBase : public ExampleFromLowDim<dim, dim != 2> {
         static Triangulation<dim> ball();
 
         /**
-         * Returns a triangulation of the product space
-         * `B^(dim-1) x S¹`.
-         * This will use one simplex in odd dimensions, or two simplices
-         * in even dimensions.
+         * Returns a triangulation of the product space `B^(dim-1) × S¹`.
          *
-         * \return the product `B^(dim-1) x S¹`.
+         * - In odd dimensions this will use one simplex, and will therefore
+         *   be oriented.
+         *
+         * - In even dimensions this will use two simplices, and will be built
+         *   as the double cover of the one-simplex `B^(dim-1) x~ S¹`.
+         *   The labelling is chosen to highlight this structure, and so even
+         *   though the space is orientable, the resulting triangulation will
+         *   _not_ be oriented.
+         *
+         * \return the product `B^(dim-1) × S¹`.
          */
         static Triangulation<dim> ballBundle();
 
@@ -246,8 +267,6 @@ template <int dim, bool available>
 Triangulation<dim> ExampleFromLowDim<dim, available>::singleCone(
         const Triangulation<dim-1>& base) {
     Triangulation<dim> ans;
-    // Ensure only one event pair is fired in this sequence of changes.
-    typename Triangulation<dim>::ChangeEventSpan span(ans);
 
     size_t n = base.size();
     if (n == 0)
@@ -290,8 +309,6 @@ template <int dim, bool available>
 Triangulation<dim> ExampleFromLowDim<dim, available>::doubleCone(
         const Triangulation<dim-1>& base) {
     Triangulation<dim> ans;
-    // Ensure only one event pair is fired in this sequence of changes.
-    typename Triangulation<dim>::ChangeEventSpan span(ans);
 
     size_t n = base.size();
     if (n == 0)
@@ -309,8 +326,15 @@ Triangulation<dim> ExampleFromLowDim<dim, available>::doubleCone(
     for (i = 0; i < 2 * n; ++i)
         simp[i] = ans.newSimplex();
 
+    // For one side of the cone, we use the same vertex numbering as in
+    // base (much like singleCone() does).
+    // For the other side of the cone, we swap vertices 0,1 of every
+    // pentachoron so that, if base is oriented, then the resulting
+    // triangulation can be oriented also.
+    static constexpr Perm<dim+1> swap(0, 1);
+
     for (i = 0; i < n; ++i) {
-        simp[i]->join(dim, simp[i + n], Perm<dim+1>());
+        simp[i]->join(dim, simp[i + n], swap);
 
         f = base.simplex(i);
         for (facet = 0; facet < dim; ++facet) {
@@ -327,8 +351,8 @@ Triangulation<dim> ExampleFromLowDim<dim, available>::doubleCone(
                 continue;
 
             simp[i]->join(facet, simp[adjIndex], Perm<dim+1>::extend(map));
-            simp[i + n]->join(facet, simp[adjIndex + n],
-                Perm<dim+1>::extend(map));
+            simp[i + n]->join(facet < 2 ? (facet ^ 1) : facet /* swap[facet] */,
+                simp[adjIndex + n], swap * Perm<dim+1>::extend(map) * swap);
         }
     }
 
@@ -343,8 +367,6 @@ Triangulation<dim> ExampleBase<dim>::sphere() {
     // Take two simplices and join their entire boundaries according to
     // the identity map.
     Triangulation<dim> ans;
-    // Ensure only one event pair is fired in this sequence of changes.
-    typename Triangulation<dim>::ChangeEventSpan span(ans);
 
     auto [p, q] = ans.template newSimplices<2>();
     for (int i = 0; i <= dim; ++i)
@@ -356,11 +378,9 @@ Triangulation<dim> ExampleBase<dim>::sphere() {
 template <int dim>
 Triangulation<dim> ExampleBase<dim>::simplicialSphere() {
     Triangulation<dim> ans;
-    // Ensure only one event pair is fired in this sequence of changes.
-    typename Triangulation<dim>::ChangeEventSpan span(ans);
 
     // One top-dimensional simplex for every vertex of the (dim+1)-simplex
-    auto simps = ans.template newSimplices<dim + 2>(); // One for ever
+    auto simps = ans.template newSimplices<dim + 2>();
 
     // One gluing for every distinct pair of vertices of the (dim+1)-simplex.
     // We are gluing facet j-1 of simplex i to facet i of simplex j
@@ -383,11 +403,9 @@ Triangulation<dim> ExampleBase<dim>::simplicialSphere() {
 
 template <int dim>
 Triangulation<dim> ExampleBase<dim>::sphereBundle() {
-    // Make two simplex, and join all but two of the facets according
+    // Make two simplices, and join all but two of the facets according
     // to the identity map.  Only facets 0 and dim of each simplex remain.
     Triangulation<dim> ans;
-    // Ensure only one event pair is fired in this sequence of changes.
-    typename Triangulation<dim>::ChangeEventSpan span(ans);
 
     auto [p, q] = ans.template newSimplices<2>();
     for (int i = 1; i < dim; ++i)
@@ -415,8 +433,6 @@ Triangulation<dim> ExampleBase<dim>::twistedSphereBundle() {
     // Make two simplex, and join all but two of the facets according
     // to the identity map.  Only facets 0 and dim of each simplex remain.
     Triangulation<dim> ans;
-    // Ensure only one event pair is fired in this sequence of changes.
-    typename Triangulation<dim>::ChangeEventSpan span(ans);
 
     auto [p, q] = ans.template newSimplices<2>();
     for (int i = 1; i < dim; ++i)
@@ -442,8 +458,6 @@ Triangulation<dim> ExampleBase<dim>::twistedSphereBundle() {
 template <int dim>
 Triangulation<dim> ExampleBase<dim>::ball() {
     Triangulation<dim> ans;
-    // Ensure only one event pair is fired in this sequence of changes.
-    typename Triangulation<dim>::ChangeEventSpan span(ans);
 
     ans.newSimplex();
     return ans;
@@ -455,8 +469,6 @@ Triangulation<dim> ExampleBase<dim>::ballBundle() {
     // In even dimensions the corresponding construction is non-orientable,
     // and we need to take its orientable double cover.
     Triangulation<dim> ans;
-    // Ensure only one event pair is fired in this sequence of changes.
-    typename Triangulation<dim>::ChangeEventSpan span(ans);
 
     // Now join facet 0 to a facet dim to join up the S1 loop:
     //   0, 1, ..., dim -> dim, 0, 1, 2, ..., dim-1
@@ -480,11 +492,9 @@ Triangulation<dim> ExampleBase<dim>::twistedBallBundle() {
     // This is the higher-dimensional analogy of a layered solid torus.
     // In even dimensions the corresponding construction is non-orientable.
     // In odd dimensions the construction is orientable, and so we
-    // double it (giving a two-vertex, two-simplex Bn x S1) but fiddle
+    // double it (giving a two-vertex, two-simplex Bn × S1) but fiddle
     // with the second map to make it non-orientable.
     Triangulation<dim> ans;
-    // Ensure only one event pair is fired in this sequence of changes.
-    typename Triangulation<dim>::ChangeEventSpan span(ans);
 
     // Now join facet 0 to a facet dim to join up the S1 loop:
     //   0, 1, ..., dim -> dim, 0, 1, 2, ..., dim-1
