@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -53,7 +51,70 @@
 #include <deque>
 #include <vector>
 
-namespace regina::detail {
+namespace regina {
+
+/**
+ * The combinatorial _type_ of a triangle, which indicates how the vertices
+ * and edges of the triangle are identified together.  Here the vertices of
+ * the triangle are considered unlabelled (so a relabelling will not change
+ * the combinatorial type).
+ *
+ * This is the result of calling `f.triangleType()`, where \a f is a 2-face
+ * within a triangulation of any dimension ≥ 3.
+ *
+ * \ingroup triangulation
+ */
+enum class TriangleType {
+        /**
+         * Indicates that the triangle type has not yet been determined.
+         */
+        Unknown = 0,
+        /**
+         * Specifies a triangle with no identified vertices or edges.
+         */
+        Triangle = 1,
+        /**
+         * Specifies a triangle with two identified vertices, and no other
+         * edge or vertex identifications.
+         */
+        Scarf = 2,
+        /**
+         * Specifies a triangle with three identified vertices, but no edge
+         * identifications.
+         */
+        Parachute = 3,
+        /**
+         * Specifies a triangle with two edges identified to form a cone.
+         * The apex of the cone is not identified with the other two vertices,
+         * and the base of the cone is not identified with the other two edges.
+         */
+        Cone = 4,
+        /**
+         * Specifies a triangle with two edges identified to form a Möbius band.
+         * The boundary of the Möbius band is not identified with the other
+         * two edges.
+         */
+        Mobius = 5,
+        /**
+         * Specifies a triangle with two edges identified to form a cone, and
+         * with all three vertices identified.  The base of the cone is not
+         * identified with the other two edges.
+         */
+        Horn = 6,
+        /**
+         * Specifies a triangle with all three edges identified, some via
+         * orientation-preserving and some via orientation-reversing gluings.
+         */
+        DunceHat = 7,
+        /**
+         * Specifies a triangle with all three edges identified using
+         * orientation-reversing gluings.  Note that this forms a spine
+         * for the lens space `L(3,1)`.
+         */
+        L31 = 8
+};
+
+namespace detail {
 
 template <int dim> class TriangulationBase;
 
@@ -205,31 +266,6 @@ class FaceEmbeddingBase :
          */
         bool operator == (const FaceEmbeddingBase& rhs) const;
 
-        /**
-         * Tests whether this and the given object are not identical.
-         *
-         * Here _identical_ means that two FaceEmbedding objects refer to
-         * the same-numbered face of the same-numbered simplex, _and_ have
-         * the same embedding permutations as returned by vertices().
-         *
-         * In particular, since this test only examines face/simplex/vertex
-         * _numbers_ (not object pointers), it is meaningful to compare two
-         * FaceEmbedding objects from different underlying triangulations.
-         *
-         * \warning The meaning of this comparison changed in Regina 7.0.
-         * In older versions of Regina, to compare as equal, two FaceEmbedding
-         * objects (i) had to be faces of the same Simplex object (a stronger
-         * requirement that effectively restricted this test to faces of the
-         * same triangulation); but also (ii) only had to refer to the
-         * same-numbered face, not use the same full embedding permutations
-         * (a weaker requirement that nowadays would incur an unacceptable
-         * performance cost).
-         *
-         * \param rhs the object to compare with this.
-         * \return \c true if and only if both object are identical.
-         */
-        bool operator != (const FaceEmbeddingBase& rhs) const;
-
         /**
          * Writes a short text representation of this object to the
          * given output stream.
@@ -351,6 +387,9 @@ class FaceBase :
         /**
          * Possible values of \a whyInvalid_.
          * These can be combined using bitwise OR.
+         *
+         * It would be nice to make this a scoped enumeration; if we do this,
+         * `whyInvalid_` would need to have type `Flags<Validity>`.
          */
         enum Validity {
             /**
@@ -388,6 +427,15 @@ class FaceBase :
             /**< Is this face valid?  This is for use in non-standard
                  dimensions, where we only test for one type of validity
                  (bad self-identifications). */
+        EnableIf<subdim == 2, TriangleType, TriangleType::Unknown>
+                triangleType_;
+            /**< The combinatorial type of this triangle, or
+                 TriangleType::Unknown if this has not yet been determined. */
+        EnableIf<subdim == 2, int, -1> triangleSubtype_;
+            /**< Indicates the vertex or edge number that plays a special role
+                 for the triangle type specified by triangleType_.  This is only
+                 relevant for some triangle types, and it will be -1 if this is
+                 either irrelevant or not yet determined. */
 
     public:
         /**
@@ -985,6 +1033,203 @@ class FaceBase :
          */
         Perm<dim + 1> pentachoronMapping(int face) const;
 
+        /**
+         * For boundary facets, joins this to another boundary facet using the
+         * given gluing.
+         *
+         * This is a convenience method that calls Simplex<dim>::join().
+         * Where it differs is that:
+         *
+         * - you directly pass the two `(dim-1)`-faces that need to be joined,
+         *   as opposed to working with `dim`-dimensional simplices;
+         *
+         * - the gluing permutation is relative to the inherent labellings of
+         *   the vertices of the (`dim-1`)-faces, _not_ the vertices of the
+         *   top-dimensional simplices.
+         *
+         * By "inherent labelling of vertices" of a face \a f we mean the way
+         * that the vertices of \a f are labelled according to
+         * FaceEmbedding::vertices().  This labelling is independent of the
+         * vertex numbers in any top-dimensional simplices that contain \a f.
+         *
+         * \pre The facial dimension \a subdim is precisely `dim-1`.
+         * \pre This and the given face are distinct boundary facets of the
+         * same triangulation.
+         *
+         * \warning As soon as the join takes place, both this and the given
+         * facet will be destroyed (since the skeleton of a triangulation
+         * is rebuilt whenever the triangulation changes).
+         *
+         * \exception InvalidArgument At least one of the preconditions above
+         * fails; that is, this and the given face are the same, or belong to
+         * different triangulations, or are not both boundary facets.
+         *
+         * \exception LockViolation Either this or the given face is a locked
+         * facet.  This exception will be thrown before any change is made.
+         * See Simplex::lockFacet() for further details on how facet locks
+         * work and what their implications are.
+         *
+         * \param you the other boundary facet that this should be glued to.
+         * \param gluing a permutation that describes how the inherent vertices
+         * of this boundary facet will map to the inherent vertices of the
+         * given boundary facet across the new gluing.
+         */
+        void join(Face<dim, subdim>* you, Perm<dim> gluing);
+
+        /**
+         * For edges, determines whether this face is a loop.
+         * A _loop_ is an edge whose two endpoints are identified.
+         *
+         * \pre The facial dimension \a subdim is precisely 1.
+         *
+         * \return \c true if and only if this edge is a loop.
+         */
+        bool isLoop() const;
+
+        /**
+         * For triangles, returns the combinatorial type of this face.
+         * This will be one of the eight shapes described by the TriangleType
+         * enumeration, which indicates how the edges and vertices of the
+         * triangle are identified.
+         *
+         * If one or more edges of this triangle are invalid due to bad
+         * self-identifications, then the triangle type might not be
+         * well-defined and so the return value will likewise be undefined.
+         *
+         * The reason this routine is non-const is because the triangle type
+         * and subtype are cached when first computed.
+         *
+         * \pre The facial dimension \a subdim is precisely 2, and the
+         * triangulation dimension \a dim is at least 3.
+         *
+         * \return the combinatorial type of this triangle.  This routine will
+         * never return TriangleType::Unknown.
+         */
+        TriangleType triangleType();
+
+        /**
+         * For triangles, returns the vertex or edge number in this face
+         * that plays a special role for this triangle's combinatorial type.
+         * Note that only some triangle types have a special vertex or edge.
+         * The triangle type itself is returned by triangleType().
+         *
+         * If one or more edges of this triangle are invalid due to bad
+         * self-identifications, then the triangle type might not be
+         * well-defined and so the return value will likewise be undefined.
+         *
+         * The reason this routine is non-const is because the triangle type
+         * and subtype are cached when first computed.
+         *
+         * \pre The facial dimension \a subdim is precisely 2, and the
+         * triangulation dimension \a dim is at least 3.
+         *
+         * \return The vertex or edge number (0, 1 or 2) that plays a special
+         * role, or -1 if this triangle's combinatorial type has no special
+         * vertex or edge.
+         */
+        int triangleSubtype();
+
+        /**
+         * For triangles, determines whether this face is wrapped up to form
+         * a Möbius band, possibly with or without additional identifications
+         * between its vertices and/or edges.
+         *
+         * Note that several different triangle types (as returned by
+         * triangleType()) can produce this result.
+         * Note also that a triangle can satisfy both formsMobiusBand() and
+         * formsCone().
+         *
+         * The reason this routine is non-const is because the triangle type
+         * is cached when first computed.
+         *
+         * \pre The facial dimension \a subdim is precisely 2, and the
+         * triangulation dimension \a dim is at least 3.
+         *
+         * \return \c true if and only if this triangle forms a Mobius band.
+         */
+        bool formsMobiusBand();
+
+        /**
+         * For triangles, determines whether this face is wrapped up to form
+         * a cone, possibly with or without additional identifications between
+         * its vertices and/or edges.
+         *
+         * Note that several different triangle types (as returned by
+         * triangleType()) can produce this result.
+         * Note also that a triangle can satisfy both formsMobiusBand() and
+         * formsCone().
+         *
+         * The reason this routine is non-const is because the triangle type
+         * is cached when first computed.
+         *
+         * \pre The facial dimension \a subdim is precisely 2, and the
+         * triangulation dimension \a dim is at least 3.
+         *
+         * \return \c true if and only if this triangle forms a cone.
+         */
+        bool formsCone();
+
+        /**
+         * Locks this codimension-1-face.
+         *
+         * Essentially, locking a face of dimension (<i>dim</i>-1) means
+         * that the face must not change.  See Simplex<dim>::lockFacet()
+         * for full details on how locks work and what their implications are.
+         *
+         * These locks are actually stored within the top-dimensional simplices
+         * on either side of this facet.  This means that, even if the
+         * underlying triangulation changes (which means all
+         * (<i>dim</i>-1)-faces will be destroyed and re-created as part of the
+         * skeleton recomputation), this lock will nevertheless be preserved.
+         *
+         * This is equivalent to calling Simplex<dim>::lockFacet() from
+         * one of the simplices on either side of this (<i>dim</i>-1)-face.
+         *
+         * It is safe to call this function even if this face is already locked.
+         *
+         * \pre The facial dimension \a subdim is precisely <i>dim</i>-1.
+         */
+        void lock();
+        /**
+         * Unlocks this codimension-1-face.
+         *
+         * Essentially, locking a face of dimension (<i>dim</i>-1) means
+         * that the face must not change.  See Simplex<dim>::lockFacet()
+         * for full details on how locks work and what their implications are.
+         *
+         * This is equivalent to calling Simplex<dim>::unlockFacet() from
+         * one of the simplices on either side of this (<i>dim</i>-1)-face.
+         *
+         * It is safe to call this function even if this face is already
+         * unlocked.
+         *
+         * See Triangulation<dim>::unlockAll() for a convenient way to unlock
+         * all top-dimensional simplices and (<i>dim</i>-1)-faces across an
+         * entire triangulation.
+         *
+         * \pre The facial dimension \a subdim is precisely <i>dim</i>-1.
+         */
+        void unlock();
+        /**
+         * Determines whether this codimension-1-face is locked.
+         *
+         * Essentially, locking a face of dimension (<i>dim</i>-1) means
+         * that the face must not change.  See Simplex<dim>::lockFacet()
+         * for full details on how locks work and what their implications are.
+         *
+         * This is equivalent to calling Simplex<dim>::isFacetLocked() from
+         * one of the simplices on either side of this (<i>dim</i>-1)-face.
+         *
+         * See Triangulation<dim>::hasLocks() for a convenient way to test
+         * whether any top-dimensional simplex and/or (<i>dim</i>-1)-face
+         * is locked across an entire triangulation.
+         *
+         * \pre The facial dimension \a subdim is precisely <i>dim</i>-1.
+         *
+         * \return \c true if and only if this (<i>dim</i>-1)-face is locked.
+         */
+        bool isLocked() const;
+
         /**
          * Writes a short text representation of this object to the
          * given output stream.
@@ -1051,13 +1296,6 @@ inline bool FaceEmbeddingBase<dim, subdim>::operator == (
         vertices_ == rhs.vertices_;
 }
 
-template <int dim, int subdim>
-inline bool FaceEmbeddingBase<dim, subdim>::operator != (
-        const FaceEmbeddingBase& rhs) const {
-    return simplex_->index() != rhs.simplex_->index() ||
-        vertices_ != rhs.vertices_;
-}
-
 template <int dim, int subdim>
 inline void FaceEmbeddingBase<dim, subdim>::writeTextShort(std::ostream& out)
         const {
@@ -1298,6 +1536,169 @@ inline Perm<dim + 1> FaceBase<dim, subdim>::pentachoronMapping(int face) const {
     return faceMapping<4>(face);
 }
 
+template <int dim, int subdim>
+inline void FaceBase<dim, subdim>::join(Face<dim, subdim>* you,
+        Perm<dim> gluing) {
+    static_assert(subdim == dim - 1, "Face<dim, subdim>::join() is only "
+        "available for faces of dimension subdim == dim - 1.");
+
+    // The preconditions and locks will be checked by Simplex::join().
+    // All we need to do is pull together the correct arguments.
+    auto emb0 = front();
+    auto emb1 = you->front();
+    emb0.simplex()->join(emb0.vertices()[dim], emb1.simplex(),
+        emb1.vertices() * Perm<dim+1>::extend(gluing) *
+            emb0.vertices().inverse());
+}
+
+template <int dim, int subdim>
+inline bool FaceBase<dim, subdim>::isLoop() const {
+    static_assert(subdim == 1, "isLoop() is only available for edges.");
+
+    const auto& emb = front();
+    const Simplex<dim>* simp = emb.simplex();
+    return simp->vertex(emb.vertices()[0]) == simp->vertex(emb.vertices()[1]);
+}
+
+template <int dim, int subdim>
+inline TriangleType FaceBase<dim, subdim>::triangleType() {
+    static_assert(subdim == 2,
+        "triangleType() is only available for triangles.");
+    static_assert(dim >= 3,
+        "triangleType() is only available in triangulations of dimension ≥ 3.");
+
+    if (triangleType_.value != TriangleType::Unknown)
+        return triangleType_.value;
+
+    triangleSubtype_.value = -1;
+
+    // Determine the triangle type.
+    Vertex<dim>* v[3];
+    Edge<dim>* e[3];
+    for (int i = 0; i < 3; i++) {
+        v[i] = vertex(i);
+        e[i] = edge(i);
+    }
+
+    if (e[0] != e[1] && e[1] != e[2] && e[2] != e[0]) {
+        // Three distinct edges.
+        if (v[0] == v[1] && v[1] == v[2])
+            return (triangleType_.value = TriangleType::Parachute);
+        for (int i = 0; i < 3; i++)
+            if (v[(i+1)%3] == v[(i+2)%3]) {
+                triangleSubtype_.value = i;
+                return (triangleType_.value = TriangleType::Scarf);
+            }
+        return (triangleType_.value = TriangleType::Triangle);
+    }
+
+    if (e[0] == e[1] && e[1] == e[2]) {
+        // All edges identified.
+        if (edgeMapping(0).sign() == edgeMapping(1).sign() &&
+                edgeMapping(1).sign() == edgeMapping(2).sign())
+            return (triangleType_.value = TriangleType::L31);
+
+        for (int i = 0; i < 3; i++)
+            if (edgeMapping((i+1)%3).sign() ==
+                    edgeMapping((i+2)%3).sign()) {
+                triangleSubtype_.value = i;
+                return (triangleType_.value = TriangleType::DunceHat);
+            }
+    }
+
+    // Two edges identified.
+    for (int i = 0; i < 3; i++)
+        if (e[(i+1)%3] == e[(i+2)%3]) {
+            triangleSubtype_.value = i;
+
+            if (edgeMapping((i+1)%3).sign() ==
+                    edgeMapping((i+2)%3).sign())
+                return (triangleType_.value = TriangleType::Mobius);
+
+            if (v[0] == v[1] && v[1] == v[2])
+                return (triangleType_.value = TriangleType::Horn);
+
+            return (triangleType_.value = TriangleType::Cone);
+        }
+
+    // We should never reach this point.
+    return TriangleType::Unknown;
+}
+
+template <int dim, int subdim>
+inline int FaceBase<dim, subdim>::triangleSubtype() {
+    static_assert(subdim == 2,
+        "triangleSubtype() is only available for triangles.");
+    static_assert(dim >= 3,
+        "triangleSubtype() is only available in triangulations of "
+        "dimension ≥ 3.");
+
+    triangleType();
+    return triangleSubtype_.value;
+}
+
+template <int dim, int subdim>
+inline bool FaceBase<dim, subdim>::formsMobiusBand() {
+    static_assert(subdim == 2,
+        "formsMobiusBand() is only available for triangles.");
+    static_assert(dim >= 3,
+        "formsMobiusBand() is only available in triangulations of "
+        "dimension ≥ 3.");
+
+    switch (triangleType()) {
+        case TriangleType::L31:
+        case TriangleType::DunceHat:
+        case TriangleType::Mobius:
+            return true;
+        default:
+            return false;
+    }
+}
+
+template <int dim, int subdim>
+inline bool FaceBase<dim, subdim>::formsCone() {
+    static_assert(subdim == 2,
+        "formsCone() is only available for triangles.");
+    static_assert(dim >= 3,
+        "formsCone() is only available in triangulations of dimension ≥ 3.");
+
+    switch (triangleType()) {
+        case TriangleType::DunceHat:
+        case TriangleType::Cone:
+        case TriangleType::Horn:
+            return true;
+        default:
+            return false;
+    }
+}
+
+template <int dim, int subdim>
+inline void FaceBase<dim, subdim>::lock() {
+    static_assert(subdim == dim - 1,
+        "lock() is only available for faces of codimension 1.");
+
+    auto emb = front();
+    emb.simplex()->lockFacet(emb.vertices()[dim]);
+}
+
+template <int dim, int subdim>
+inline void FaceBase<dim, subdim>::unlock() {
+    static_assert(subdim == dim - 1,
+        "unlock() is only available for faces of codimension 1.");
+
+    auto emb = front();
+    emb.simplex()->unlockFacet(emb.vertices()[dim]);
+}
+
+template <int dim, int subdim>
+inline bool FaceBase<dim, subdim>::isLocked() const {
+    static_assert(subdim == dim - 1,
+        "isLocked() is only available for faces of codimension 1.");
+
+    auto emb = front();
+    return emb.simplex()->isFacetLocked(emb.vertices()[dim]);
+}
+
 template <int dim, int subdim>
 inline FaceBase<dim, subdim>::FaceBase(Component<dim>* component) :
         component_(component), boundaryComponent_(nullptr) {
@@ -1309,17 +1710,17 @@ void FaceBase<dim, subdim>::writeTextShort(std::ostream& out) const {
     if constexpr (dim == 3 && subdim == 0) {
         // Identify vertex links in dimension 3 in more detail.
         switch (static_cast<const Face<dim, subdim>*>(this)->linkType()) {
-            case Face<dim, subdim>::SPHERE:
+            case Face<dim, subdim>::Link::Sphere:
                 out << "internal"; break;
-            case Face<dim, subdim>::DISC:
+            case Face<dim, subdim>::Link::Disc:
                 out << "boundary"; break;
-            case Face<dim, subdim>::TORUS:
+            case Face<dim, subdim>::Link::Torus:
                 out << "torus cusp"; break;
-            case Face<dim, subdim>::KLEIN_BOTTLE:
+            case Face<dim, subdim>::Link::KleinBottle:
                 out << "Klein bottle cusp"; break;
-            case Face<dim, subdim>::NON_STANDARD_CUSP:
+            case Face<dim, subdim>::Link::NonStandardCusp:
                 out << "ideal"; break;
-            case Face<dim, subdim>::INVALID:
+            case Face<dim, subdim>::Link::Invalid:
                 out << "invalid"; break;
         }
     } else if constexpr (dim == 4 && subdim == 0) {
@@ -1354,7 +1755,7 @@ void FaceBase<dim, subdim>::writeTextShort(std::ostream& out) const {
     }
 }
 
-} // namespace regina::detail
+} } // namespace regina::detail
 
 #endif
 
