@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -429,10 +427,11 @@ bool FacetPairingBase<dim>::isCanonicalInternal(
     if (isUnmatched(0, 0)) {
         // We must have just one simplex with no facet gluings at all.
         if (list) {
-            for (int i = 0; i < Perm<dim+1>::nPerms; ++i) {
+            // TODO: Probably this should use Sn, not orderedSn.
+            for (auto p: Perm<dim+1>::orderedSn) {
                 Isomorphism<dim> ans(1);
                 ans.simpImage(0) = 0;
-                ans.facetPerm(0) = Perm<dim+1>::orderedSn[i];
+                ans.facetPerm(0) = p;
                 list->push_back(std::move(ans));
             }
         }
