@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -50,6 +48,7 @@
 #include "triangulation/generic/facetpairing.h"
 #include "maths/perm.h"
 #include "utilities/exception.h"
+#include "utilities/fixedarray.h"
 #include "utilities/stringutils.h"
 #include "utilities/typeutils.h"
 
@@ -110,17 +109,12 @@ bool FacetPairingBase<dim>::isClosed() const {
 }
 
 template <int dim>
-bool FacetPairingBase<dim>::operator == (const FacetPairing<dim>& other) const {
+bool FacetPairingBase<dim>::operator == (const FacetPairingBase<dim>& other)
+        const {
     return size_ == other.size_ &&
         std::equal(pairs_, pairs_ + (size_ * (dim + 1)), other.pairs_);
 }
 
-template <int dim>
-bool FacetPairingBase<dim>::operator != (const FacetPairing<dim>& other) const {
-    return size_ != other.size_ ||
-        ! std::equal(pairs_, pairs_ + (size_ * (dim + 1)), other.pairs_);
-}
-
 template <int dim>
 bool FacetPairingBase<dim>::isConnected() const {
     if (size_ <= 1)
@@ -157,6 +151,53 @@ bool FacetPairingBase<dim>::isConnected() const {
     return false;
 }
 
+template <int dim>
+template <int k>
+bool FacetPairingBase<dim>::hasMultiEdge() const {
+    static_assert(2 <= k && k <= dim + 1,
+        "FacetPairing::hasMultiEdge() requires the edge multiplicity to be "
+        "between 2 and dim+1 inclusive.");
+
+    // Let n be the size of this facet pairing (i.e., the number of nodes).
+    // The running time must be at least O(n*dim), which is the number of
+    // edges in the underlying graph.  We want to engineer this test so that
+    // it runs in time O(n*dim) and nothing worse.
+
+    FixedArray<int> freq(size_, 0);
+
+    size_t index = 0;
+    for (size_t i = 0; i < size_; ++i) {
+        // Build a frequency array for this simplex.
+        for (int j = 0; j <= dim; ++j) {
+            const auto& dest = pairs_[index++];
+            if (! (dest.isBoundary(size_) || dest.simp == i)) {
+                if (++freq[dest.simp] >= k)
+                    return true;
+            }
+        }
+        // Reset the frequency array for the next simplex.
+        index -= (dim + 1);
+        for (int j = 0; j <= dim; ++j) {
+            const auto& dest = pairs_[index++];
+            if (! (dest.isBoundary(size_) || dest.simp == i)) {
+                --freq[dest.simp];
+            }
+        }
+    }
+
+    return false;
+}
+
+template <int dim>
+bool FacetPairingBase<dim>::hasMultiEdge(int k) const {
+    if (k < 2 || k > dim + 1)
+        throw InvalidArgument("hasMultiEdge(): unsupported multiplicity k");
+
+    return select_constexpr<2, dim + 2, bool>(k, [this](auto k) {
+        return hasMultiEdge<k>();
+    });
+}
+
 template <int dim>
 void FacetPairingBase<dim>::writeTextShort(std::ostream& out) const {
     for (FacetSpec<dim> f(0, 0); ! f.isPastEnd(size_, true); ++f) {
