@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -605,7 +603,7 @@ void TriangulationBase<dim>::clearBaseProperties() {
     }
 
     // Clear properties.
-    if (! topologyLock_) {
+    if (! topologyLocked()) {
         fundGroup_.reset();
         H1_.reset();
     }
@@ -719,8 +717,8 @@ void TriangulationBase<dim>::cloneSkeleton(const TriangulationBase<dim>& src) {
         auto you = src.simplices_.begin();
         for ( ; me != simplices_.end(); ++me, ++you) {
             for_constexpr<0, dim>([this, me, you](auto subdim) {
-                auto dest = std::get<subdim.value>((*me)->faces_).begin();
-                for (auto f : std::get<subdim.value>((*you)->faces_))
+                auto dest = std::get<subdim>((*me)->faces_).begin();
+                for (auto f : std::get<subdim>((*you)->faces_))
                     *dest++ = clonedFace(f);
             });
             (*me)->mappings_ = (*you)->mappings_;
