@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,26 +23,17 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
-// We use M_PI from <cmath>, which seems to cause problems under windows.
-// The fix seems to be to include <cmath> before anything else, *and*
-// to set _USE_MATH_DEFINES beforehand.
-#if defined(_WIN32)
-  #define _USE_MATH_DEFINES
-#endif
-#include <cmath>
-
 #include "maths/matrixops.h"
 #include "maths/primes.h"
 #include "triangulation/dim3/homologicaldata.h"
 #include <list>
 #include <iostream>
+#include <numbers>
 #include <sstream>
 
 namespace regina {
@@ -1527,7 +1518,8 @@ void HomologicalData::computeTorsionLinkingForm() {
                     Integer tD = tSum.denominator();
                     auto [tQ, tR] = tN.divisionAlg(tD);
                     long double tLD =
-                        (Rational(tR, tD) * twoPow).doubleApprox() * M_PI;
+                        (Rational(tR, tD) * twoPow).doubleApprox() *
+                        std::numbers::pi_v<long double>;
                     // we ignore `inrange' parameter as the number is reduced
                     // mod 1, so either way it is
                     // returning essentially the correct number.
@@ -1662,15 +1654,16 @@ void HomologicalData::computeTorsionLinkingForm() {
                 }
             }
     }
-    if (starti==1) // have 2-torsion
-    { // all the sigmas need to be 0 or inf.
+    if (starti==1) {
+        // have 2-torsion: all the sigmas need to be 0 or inf.
         for (i=0; i<twoTorSigmaV.size(); i++)
             if ( (twoTorSigmaV[i]!=0) &&
                     (twoTorSigmaV[i]!=LargeInteger::infinity) )
                 torsionLinkingFormIsSplit=false;
     }
 
-    if (torsionLinkingFormIsSplit==false) torsionLinkingFormIsHyperbolic=false;
+    if (torsionLinkingFormIsSplit==false)
+        torsionLinkingFormIsHyperbolic=false;
 
     if ( (torsionLinkingFormIsSplit) && (starti==1) ) {
         torsionLinkingFormIsHyperbolic = true;
@@ -1682,7 +1675,8 @@ void HomologicalData::computeTorsionLinkingForm() {
     Rational tRat;
 
     torsionLinkingFormSatisfiesKKtwoTorCondition=true;
-    if (starti==1) { // for each k need to compute 2^{k-1}*form(x,x) on all
+    if (starti==1) {
+        // for each k need to compute 2^{k-1}*form(x,x) on all
         // elements of order 2^k, check to see if it is zero.
         // so this is not yet quite implemented, yet....
         // std::vector< std::pair< Integer,
@@ -1706,8 +1700,10 @@ void HomologicalData::computeTorsionLinkingForm() {
     }
 
     torsionRankString.assign("");
-    if (torRankV.size()==0) torsionRankString.append("no torsion");
-    else for (i=0; i<torRankV.size(); i++) {
+    if (torRankV.size()==0)
+        torsionRankString.append("no torsion");
+    else
+        for (i=0; i<torRankV.size(); i++) {
             torsionRankString.append(torRankV[i].first.stringValue());
             torsionRankString.append("(");
             for (j=0; j<torRankV[i].second.size(); j++) {
@@ -1719,37 +1715,41 @@ void HomologicalData::computeTorsionLinkingForm() {
             torsionRankString.append(")");
             if (i<(torRankV.size()-1))
                 torsionRankString.append(" ");
-    }
+        }
 
     if (tri.isOrientable()) {
         torsionSigmaString.assign("");
-        if (twoTorSigmaV.size()==0) torsionSigmaString.append("no 2-torsion");
-        else for (i=0; i<twoTorSigmaV.size(); i++) {
-            torsionSigmaString.append(twoTorSigmaV[i].stringValue());
-            if (i<(twoTorSigmaV.size()-1)) torsionSigmaString.append(" ");
+        if (twoTorSigmaV.size()==0)
+            torsionSigmaString.append("no 2-torsion");
+        else
+            for (i=0; i<twoTorSigmaV.size(); i++) {
+                torsionSigmaString.append(twoTorSigmaV[i].stringValue());
+                if (i<(twoTorSigmaV.size()-1))
+                    torsionSigmaString.append(" ");
             }
-        }
-    else torsionSigmaString.assign("manifold is non-orientable");
+    } else
+        torsionSigmaString.assign("manifold is non-orientable");
 
     if (tri.isOrientable()) {
         torsionLegendreString.assign("");
         if (oddTorLegSymV.size()==0)
             torsionLegendreString.append("no odd p-torsion");
-        else for (i=0; i<oddTorLegSymV.size(); i++) {
-            torsionLegendreString.append(oddTorLegSymV[i].first.stringValue());
-            torsionLegendreString.append("(");
-            for (j=0; j<oddTorLegSymV[i].second.size(); j++) {
-                torsionLegendreString.append( Integer(
-                    oddTorLegSymV[i].second[j]).stringValue());
-                if (j<oddTorLegSymV[i].second.size()-1)
+        else
+            for (i=0; i<oddTorLegSymV.size(); i++) {
+                torsionLegendreString.append(
+                    oddTorLegSymV[i].first.stringValue());
+                torsionLegendreString.append("(");
+                for (j=0; j<oddTorLegSymV[i].second.size(); j++) {
+                    torsionLegendreString.append( Integer(
+                        oddTorLegSymV[i].second[j]).stringValue());
+                    if (j<oddTorLegSymV[i].second.size()-1)
+                        torsionLegendreString.append(" ");
+                }
+                torsionLegendreString.append(")");
+                if (i<(oddTorLegSymV.size()-1))
                     torsionLegendreString.append(" ");
             }
-            torsionLegendreString.append(")");
-            if (i<(oddTorLegSymV.size()-1))
-                torsionLegendreString.append(" ");
-            }
-        }
-    else
+    } else
         torsionLegendreString.append("manifold is non-orientable");
 
     torsionFormComputed = true;
@@ -1763,28 +1763,25 @@ void HomologicalData::computeEmbeddabilityString() {
     // Dereference the SnapshotRef just once.
     const Triangulation<3>& tri(*tri_);
 
-    if (tri.isEmpty())
-      {
+    if (tri.isEmpty()) {
         // special-case the empty triangulation
         embeddabilityString = "Manifold is empty.";
-      }
-    else if (tri.isOrientable())
-      { // orientable -- we need the torsion linking form
+    } else if (tri.isOrientable()) {
+        // orientable -- we need the torsion linking form
         computeTorsionLinkingForm();
 
-        if (bdryHomology(0).isTrivial()) 
-        { // no boundary : orientable
-            if (torRankV.size()==0) 
-            { // no torsion : no boundary, orientable
+        if (bdryHomology(0).isTrivial()) {
+            // no boundary : orientable
+            if (torRankV.size()==0) {
+                // no torsion : no boundary, orientable
                 if (tri.knowsSphere() && tri.isSphere())
                     embeddabilityString = "This manifold is S^3.";
                 else if (dualHomology(1).isTrivial())
                     embeddabilityString = "Manifold is a homology 3-sphere.";
                 else
                     embeddabilityString = "No information.";
-            } // no torsion : no boundary, orientable 
-            else 
-            {// torsion : no boundary, orientable
+            } else {
+                // torsion : no boundary, orientable
                 if (!torsionLinkingFormSatisfiesKKtwoTorCondition)
                     embeddabilityString =
                         "This manifold, once-punctured, "
@@ -1798,124 +1795,102 @@ void HomologicalData::computeEmbeddabilityString() {
                 if (dualHomology(1).rank()==0)
                     embeddabilityString += "  Manifold is a rational "
                         "homology sphere.";
-            } // torsion : no boundary, orientable
-        } // no boundary : orientable
-        else 
-        { // boundary : orientable
-            if (torRankV.size()==0) 
-                {
+            }
+        } else {
+            // boundary : orientable
+            if (torRankV.size()==0) {
                 // orientable with boundary, no torsion. We have no tests
                 // so far for checking if it embeds in a homology 4-sphere
                 // unless we implement the Kojima alexander polynomials.
                 // H1 map check... boundary map has full rank iff embeds in
                 // rational homology 3-sphere,
                 // boundary map epic iff embeds in homology 3-sphere
-                 if (bdryHomologyMap(1).isEpic())
-                    {
-                    embeddabilityString =
-                        "Embeds in a homology 3-sphere as a ";
-                    if (bdryHomology(1).rank() ==
-                            2*bdryHomology(0).rank())
-                        {
+                if (bdryHomologyMap(1).isEpic()) {
+                    embeddabilityString = "Embeds in a homology 3-sphere as a ";
+                    if (bdryHomology(1).rank() == 2*bdryHomology(0).rank()) {
                         if (bdryHomology(0).rank()==1)
                             embeddabilityString += "knot complement.";
                         else
                             embeddabilityString += "link complement.";
-                        }
-                    else
-                        {
+                    } else {
                         if (bdryHomology(1).rank() == 0)
                             embeddabilityString += "ball complement.";
                         else
                             embeddabilityString += "graph complement.";
-                        }
                     }
-                 else if (bdryHomologyMap(1).cokernel().rank()==0)
-                    {
+                } else if (bdryHomologyMap(1).cokernel().rank()==0) {
                     embeddabilityString =
                         "Embeds in a rational homology 3-sphere as a ";
-                    if (bdryHomology(1).rank() ==
-                            2*bdryHomology(0).rank() )
-                        {
+                    if (bdryHomology(1).rank() == 2*bdryHomology(0).rank() ) {
                         if (bdryHomology(0).rank()==1)
                             embeddabilityString += "knot complement.";
                         else
                             embeddabilityString += "link complement.";
-                        }
-                    else
-                        {
+                    } else {
                         if (bdryHomology(1).rank() == 0)
                             embeddabilityString += "ball complement.";
                         else
                             embeddabilityString += "graph complement.";
-                        }
-                    } 
-                 else
+                    }
+                } else
                     embeddabilityString =
                         "Does not embed in a rational homology 3-sphere.";
-                 } // no torsion : boundary, orientable
-            else
-                { // torsion : boundary, orientable
-                if (!torsionLinkingFormSatisfiesKKtwoTorCondition)
-                 { // two tor condition not satisfied
-                 if (bdryHomologyMap(1).isEpic())
-                   embeddabilityString =
-                        "Embeds in homology 3-sphere "
-                        "but not homology 4-sphere.";
-                 else if (bdryHomologyMap(1).cokernel().rank()==0)
-                   embeddabilityString =
-                        "Embeds in rational homology 3-sphere but not "
-                        "homology 4-sphere.";
-                 else 
-                    embeddabilityString =
-                        "Does not embed in homology 3-sphere, "
-                        "nor homology 4-sphere.";
+            } else {
+                // torsion : boundary, orientable
+                if (!torsionLinkingFormSatisfiesKKtwoTorCondition) {
+                    // two tor condition not satisfied
+                    if (bdryHomologyMap(1).isEpic())
+                        embeddabilityString =
+                            "Embeds in homology 3-sphere "
+                            "but not homology 4-sphere.";
+                    else if (bdryHomologyMap(1).cokernel().rank()==0)
+                        embeddabilityString =
+                            "Embeds in rational homology 3-sphere but not "
+                            "homology 4-sphere.";
+                    else
+                        embeddabilityString =
+                            "Does not embed in homology 3-sphere, "
+                            "nor homology 4-sphere.";
+                } else {
+                    // KK twotor condition satisfied...
+                    if (bdryHomologyMap(1).isEpic())
+                        embeddabilityString =
+                            "Embeds in homology 3-sphere.  "
+                            "KK 2-tor condition satisfied.";
+                    else if (bdryHomologyMap(1).cokernel().rank()==0)
+                        embeddabilityString =
+                            "Embeds in rational homology 3-sphere.  "
+                            "KK 2-tor condition satisfied.";
+                    else
+                        embeddabilityString =
+                            "Does not embed in homology 3-sphere.  "
+                            "KK 2-tor condition satisfied.";
                  }
-                else
-                 { // KK twotor condition satisfied...
-                 if (bdryHomologyMap(1).isEpic())
-                   embeddabilityString =
-                        "Embeds in homology 3-sphere.  "
-                        "KK 2-tor condition satisfied.";
-                 else if (bdryHomologyMap(1).cokernel().rank()==0)
-                   embeddabilityString =
-                        "Embeds in rational homology 3-sphere.  "
-                        "KK 2-tor condition satisfied.";
-                 else 
-                    embeddabilityString =
-                        "Does not embed in homology 3-sphere.  "
-                        "KK 2-tor condition satisfied.";
-                 }
-                } // torsion : boundary, orientable
-        } // boundary : orientable 
-     } // end orientable 
-     else 
-     { // triangulation is NOT orientable, therefore can not embed
-       // in any rational homology 3-sphere.  So we look at the
-       // orientation cover...
-       Triangulation<3> orTri(tri, false);
-       orTri.makeDoubleCover();
-       HomologicalData covHomol(orTri);
+            }
+        }
+    } else {
+        // triangulation is NOT orientable, therefore can not embed in any
+        // rational homology 3-sphere.  So we look at the orientation cover...
+        Triangulation<3> orTri = tri.doubleCover();
+        HomologicalData covHomol(orTri);
         // break up into two cases, boundary and no boundary...
-        if (covHomol.bdryHomology(0).isTrivial())
-         { // no boundary
-          if (covHomol.formIsHyperbolic())
-            embeddabilityString = "Orientation cover has hyperbolic"
-                                  " torsion linking form.";
-          else
-            embeddabilityString = "Does not embed in homology 4-sphere.";
-         }
-        else
-         {// boundary
-          if (covHomol.formSatKK())
-            embeddabilityString = "Orientation cover satisfies"
-                                      " KK 2-torsion condition.";
-          else
-            embeddabilityString = "Does not embed in homology 4-sphere.";
-         }
-     }
-} // end computeEmbeddabilityString()
-
+        if (covHomol.bdryHomology(0).isTrivial()) {
+            // no boundary
+            if (covHomol.formIsHyperbolic())
+                embeddabilityString =
+                    "Orientation cover has hyperbolic torsion linking form.";
+            else
+                embeddabilityString = "Does not embed in homology 4-sphere.";
+        } else {
+            // boundary
+            if (covHomol.formSatKK())
+                embeddabilityString =
+                    "Orientation cover satisfies KK 2-torsion condition.";
+            else
+                embeddabilityString = "Does not embed in homology 4-sphere.";
+        }
+    }
+}
 
 bool HomologicalData::formIsHyperbolic() {
     if (torsionFormComputed)
