@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -99,9 +97,7 @@ Triangulation<3> Triangulation<3>::rehydrate(const std::string& dehydration) {
     }
 
     // Create the tetrahedra and start gluing.
-    // Ensure only one event pair is fired in this sequence of changes.
     Triangulation<3> ans;
-    ChangeEventSpan span(ans);
 
     auto* tet = new Tetrahedron<3>*[nTet];
     for (unsigned i = 0; i < nTet; i++)
@@ -117,7 +113,6 @@ Triangulation<3> Triangulation<3>::rehydrate(const std::string& dehydration) {
     unsigned permIndex;         // The index of the gluing permutation to use.
     Perm<4> adjPerm;              // The gluing permutation to use.
     Perm<4> identity;             // The identity permutation.
-    Perm<4> reverse(3,2,1,0);     // The reverse permutation.
 
     while (currTet < nTet) {
         // Is this face already glued?
@@ -160,7 +155,7 @@ Triangulation<3> Triangulation<3>::rehydrate(const std::string& dehydration) {
                 break;
             }
 
-            adjPerm = Perm<4>::orderedS4[permIndex] * reverse;
+            adjPerm = Perm<4>::orderedSn[permIndex].reverse();
 
             if (tet[adjTet]->adjacentTetrahedron(adjPerm[currFace]) ||
                     (adjTet == currTet && adjPerm[currFace] == currFace)) {
@@ -293,17 +288,10 @@ std::string Triangulation<3>::dehydrate() const {
                 // Don't forget that our permutation abcd becomes dcba
                 // in dehydration language.
                 destChars[currGluingPos] = LETTER(image[dest]);
-                Perm<4> map = vertexMap[dest] *
+                Perm<4> map = (vertexMap[dest] *
                     simplices_[tet]->adjacentGluing(face) *
-                    vertexMap[tet].inverse() * Perm<4>(3, 2, 1, 0);
-                // Just loop to find the index of the corresponding
-                // gluing permutation.  There's only 24 permutations and
-                // at most 25 tetrahedra; we'll live with it.
-                int mapIndex;
-                for (mapIndex = 0; mapIndex < 24; mapIndex++)
-                    if (map == Perm<4>::orderedS4[mapIndex])
-                        break;
-                permChars[currGluingPos] = LETTER(mapIndex);
+                    vertexMap[tet].inverse()).reverse();
+                permChars[currGluingPos] = LETTER(map.orderedSnIndex());
 
                 currGluingPos++;
             }
