@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -39,12 +37,23 @@
 namespace regina {
 
 namespace detail {
+    /**
+     * Provides domain-specific details for the 3-D retriangulation process.
+     *
+     * For propagation of 3-D triangulations, we do not make use of the
+     * options type `Retriangulator::PropagationOptions`.
+     */
     template <>
     struct RetriangulateParams<Triangulation<3>> {
         static std::string sig(const Triangulation<3>& tri) {
             return tri.isoSig<IsoSigEdgeDegrees<3>>();
         }
 
+        static std::string rigidSig(const Triangulation<3>& tri) {
+            // Currently rigidity is not supported for triangulations.
+            return tri.isoSig<IsoSigEdgeDegrees<3>>();
+        }
+
         static constexpr const char* progressStage = "Exploring triangulations";
 
         template <class Retriangulator>
@@ -53,21 +62,15 @@ namespace detail {
             Triangulation<3> t = Triangulation<3>::fromIsoSig(sig);
             size_t i;
             for (i = 0; i < t.countEdges(); ++i)
-                if (t.pachner(t.edge(i), true, false)) {
-                    Triangulation<3> alt(t, false);
-                    alt.pachner(alt.edge(i), false, true);
-                    if (retriang->candidate(std::move(alt), sig))
+                if (auto alt = t.withPachner(t.edge(i)))
+                    if (retriang->candidate(std::move(*alt), sig))
                         return;
-                }
 
             if (t.size() < maxSize)
                 for (i = 0; i < t.countTriangles(); ++i)
-                    if (t.pachner(t.triangle(i), true, false)) {
-                        Triangulation<3> alt(t, false);
-                        alt.pachner(alt.triangle(i), false, true);
-                        if (retriang->candidate(std::move(alt), sig))
+                    if (auto alt = t.withPachner(t.triangle(i)))
+                        if (retriang->candidate(std::move(*alt), sig))
                             return;
-                    }
         }
     };
 } // namespace detail
@@ -76,47 +79,47 @@ namespace detail {
 // so the full implementation can stay out of the headers.
 
 template bool regina::detail::retriangulateInternal<Triangulation<3>, true>(
-    const Triangulation<3>&, int, unsigned, ProgressTrackerOpen*,
+    const Triangulation<3>&, bool, int, int, ProgressTrackerOpen*,
     regina::detail::RetriangulateActionFunc<Triangulation<3>, true>&&);
 
 template bool regina::detail::retriangulateInternal<Triangulation<3>, false>(
-    const Triangulation<3>&, int, unsigned, ProgressTrackerOpen*,
+    const Triangulation<3>&, bool, int, int, ProgressTrackerOpen*,
     regina::detail::RetriangulateActionFunc<Triangulation<3>, false>&&);
 
-// This could be inlined, but we pull it out of the header because otherwise
-// it interferes with Link's rewrite() implementation.
+// These could be inlined, but we pull them out of the header because otherwise
+// they interfere with Link's rewrite() implementation.
 //
 // Basically the problem is that link/rewrite.cpp includes retriangulate-impl.h,
-// which then complains about the inlined Triangulation<3>::simplifyExhaustive()
-// using an undefined specialisation RetriangulateParams<Triangulation<3>>.
+// which then complains about the inlined Triangulation<3> code using an
+// undefined specialisation RetriangulateParams<Triangulation<3>>.
 //
 // This would not have been a problem if link.h did not have to include
 // triangulation/dim3.h (which is included just to inline Link::complement()).
-//
-// Since we're here anyway, implement this using retriangulateInternal(), not
-// retriangulate(), to avoid an extra level of lambdas/functionals.
-//
-bool Triangulation<3>::simplifyExhaustive(int height, unsigned nThreads,
+
+bool Triangulation<3>::simplifyExhaustive(int height, int threads,
         ProgressTrackerOpen* tracker) {
-    if (countComponents() != 1) {
+    if (countComponents() > 1) {
         if (tracker)
             tracker->setFinished();
         throw FailedPrecondition(
             "simplifyExhaustive() requires a connected triangulation");
     }
 
-    size_t minSimp = size();
-    return regina::detail::retriangulateInternal<Triangulation<3>, false>(
-        *this, height, nThreads, tracker,
-        [this, minSimp](Triangulation<3>&& alt) {
-            if (alt.size() < minSimp) {
-                ChangeEventSpan span(*this);
-                *this = std::move(alt);
-                intelligentSimplify();
-                return true;
-            } else
-                return false;
-        });
+    return regina::detail::simplifyExhaustiveInternal<Triangulation<3>>(
+        *this, height, threads, tracker);
+}
+
+bool Triangulation<3>::improveTreewidth(ssize_t maxAttempts, int height,
+        int threads, ProgressTrackerOpen* tracker) {
+    if (countComponents() > 1) {
+        if (tracker)
+            tracker->setFinished();
+        throw FailedPrecondition(
+            "improveTreewidth() requires a connected triangulation");
+    }
+
+    return regina::detail::improveTreewidthInternal<Triangulation<3>>(
+        *this, maxAttempts, height, threads, tracker);
 }
 
 } // namespace regina
