@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,18 +23,14 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
-#define _USE_MATH_DEFINES // for M_PI, which is non-standard
-
 #include <algorithm>
-#include <cmath>
 #include <complex>
+#include <numbers>
 #include <numeric> // for std::gcd()
 #include <thread>
 #include "regina-config.h"
@@ -191,7 +187,7 @@ namespace {
             bracket_(new TVResult[r]),
             fact_(new TVResult[r]),
             inv_(new TVResult[r]) {
-        TVResult angle = (M_PI * whichRoot) / r;
+        TVResult angle = (std::numbers::pi_v<TVResult> * whichRoot) / r;
         bracket_[0] = bracket_[1] = fact_[0] = fact_[1] =
             inv_[0] = inv_[1] = 1.0;
         for (unsigned long i = 2; i < r; i++) {
@@ -398,7 +394,7 @@ namespace {
             whichRoot(newWhichRoot),
             halfField(r % 2 != 0 && whichRoot % 2 == 0),
             fact(r, whichRoot) {
-        double tmp = sin(M_PI * whichRoot / r);
+        double tmp = sin(std::numbers::pi_v<double> * whichRoot / r);
         vertexContrib = 2.0 * tmp * tmp / r;
     }
 
@@ -725,7 +721,7 @@ namespace {
             // Have we found an admissible colouring?
             if (curr >= static_cast<ssize_t>(nEdges)) {
 #ifdef TV_BACKTRACK_DUMP_COLOURINGS
-                for (i = 0; i < nEdges; ++i) {
+                for (size_t i = 0; i < nEdges; ++i) {
                     if (i > 0)
                         std::cout << ' ';
                     std::cout << colour[i];
@@ -872,18 +868,18 @@ namespace {
                 ++nEasyBags;
                 std::fill(seenDegree[index].begin(),
                     seenDegree[index].end(), 0);
-            } else if (bag->type() == NICE_INTRODUCE) {
+            } else if (bag->niceType() == NiceType::Introduce) {
                 // Introduce bag.
                 ++nEasyBags;
                 child = bag->children();
                 std::copy(seenDegree[child->index()].begin(),
                     seenDegree[child->index()].end(),
                     seenDegree[index].begin());
-            } else if (bag->type() == NICE_FORGET) {
+            } else if (bag->niceType() == NiceType::Forget) {
                 // Forget bag.
                 hardBagWeightSum += HARD_BAG_WEIGHT(bag);
                 child = bag->children();
-                tet = tri.tetrahedron(child->element(bag->subtype()));
+                tet = tri.tetrahedron(child->element(bag->niceIndex()));
                 std::copy(seenDegree[child->index()].begin(),
                     seenDegree[child->index()].end(),
                     seenDegree[index].begin());
@@ -964,7 +960,7 @@ namespace {
 
                 partial[index] = new SolnSet;
                 partial[index]->emplace(std::move(seq), std::move(val));
-            } else if (bag->type() == NICE_INTRODUCE) {
+            } else if (bag->niceType() == NiceType::Introduce) {
                 // Introduce bag.
                 if (tracker) {
                     if (tracker->isCancelled())
@@ -978,7 +974,7 @@ namespace {
                 child = bag->children();
                 partial[index] = partial[child->index()];
                 partial[child->index()] = nullptr;
-            } else if (bag->type() == NICE_FORGET) {
+            } else if (bag->niceType() == NiceType::Forget) {
                 // Forget bag.
                 if (tracker) {
                     if (tracker->isCancelled())
@@ -990,7 +986,7 @@ namespace {
                 }
 
                 child = bag->children();
-                tet = tri.tetrahedron(child->element(bag->subtype()));
+                tet = tri.tetrahedron(child->element(bag->niceIndex()));
 
                 for (int i = 5; i >= 0; --i) {
                     tetEdge[i] = tet->edge(i)->index();
@@ -1230,8 +1226,8 @@ namespace {
 
 #ifdef TV_BACKTRACK_DUMP_COLOURINGS
             std::cout << "Bag " << bag->index() << ":" << std::endl;
-            for (const auto& soln : partial[index])
-                std::cout << soln.first << " -> " soln.second << std::endl;
+            for (const auto& soln : *(partial[index]))
+                std::cout << soln.first << " -> " << soln.second << std::endl;
 #endif
         }
 
@@ -1339,22 +1335,27 @@ namespace {
 double Triangulation<3>::turaevViroApprox(unsigned long r,
         unsigned long whichRoot, Algorithm alg) const {
     // Do some basic parameter checks.
+    if (isEmpty() || ! (isValid() && isClosed()))
+        throw FailedPrecondition("turaevViroApprox() requires a "
+            "valid, closed, non-empty triangulation");
     if (r < 3)
-        return 0;
-    if (whichRoot >= 2 * r)
-        return 0;
+        throw InvalidArgument("turaevViroApprox() requires the argument r ≥ 3");
+    if (whichRoot <= 0 || whichRoot >= 2 * r)
+        throw InvalidArgument("turaevViroApprox() requires the argument "
+            "whichRoot to be strictly between 0 and 2r");
     if (std::gcd(r, whichRoot) > 1)
-        return 0;
+        throw InvalidArgument("turaevViroApprox() requires the arguments "
+            "r and whichRoot to be coprime");
 
     // Set up our initial data.
     InitialData<false> init(r, whichRoot);
 
     InitialData<false>::TVType ans;
     switch (alg) {
-        case ALG_BACKTRACK:
+        case Algorithm::Backtrack:
             ans = turaevViroBacktrack(*this, init, nullptr);
             break;
-        case ALG_NAIVE:
+        case Algorithm::Naive:
             ans = turaevViroNaive(*this, init, nullptr);
             break;
         default:
@@ -1384,10 +1385,16 @@ double Triangulation<3>::turaevViroApprox(unsigned long r,
 Cyclotomic Triangulation<3>::turaevViro(unsigned long r, bool parity,
         Algorithm alg, ProgressTracker* tracker) const {
     // Do some basic parameter checks.
+    if (isEmpty() || ! (isValid() && isClosed())) {
+        if (tracker)
+            tracker->setFinished();
+        throw FailedPrecondition(
+            "turaevViro() requires a valid, closed, non-empty triangulation");
+    }
     if (r < 3) {
         if (tracker)
             tracker->setFinished();
-        return Cyclotomic();
+        throw InvalidArgument("turaevViro() requires the argument r ≥ 3");
     }
     if (r % 2 == 0)
         parity = false; // As required by allCalculatedTuraevViroInvariants().
@@ -1408,10 +1415,10 @@ Cyclotomic Triangulation<3>::turaevViro(unsigned long r, bool parity,
 
     InitialData<true>::TVType ans;
     switch (alg) {
-        case ALG_BACKTRACK:
+        case Algorithm::Backtrack:
             ans = turaevViroBacktrack(*this, init, tracker);
             break;
-        case ALG_NAIVE:
+        case Algorithm::Naive:
             ans = turaevViroNaive(*this, init, tracker);
             break;
         default:
