@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,17 +23,16 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
 #include "triangulation/detail/algebra-impl.h"
 #include "triangulation/detail/isosig-impl.h"
-#include "triangulation/detail/pachner-impl.h"
+#include "triangulation/detail/moves-impl.h"
 #include "triangulation/detail/skeleton-impl.h"
+#include "triangulation/detail/triangulation-impl.h"
 #include "triangulation/generic.h"
 
 namespace regina::detail {
@@ -96,16 +95,31 @@ template void TriangulationBase<10>::cloneSkeleton(
 template void TriangulationBase<10>::clearBaseProperties();
 template void TriangulationBase<10>::swapBaseData(TriangulationBase<10>&);
 
-template bool TriangulationBase<10>::pachner(Face<10, 0>*, bool, bool);
-template bool TriangulationBase<10>::pachner(Face<10, 1>*, bool, bool);
-template bool TriangulationBase<10>::pachner(Face<10, 2>*, bool, bool);
-template bool TriangulationBase<10>::pachner(Face<10, 3>*, bool, bool);
-template bool TriangulationBase<10>::pachner(Face<10, 4>*, bool, bool);
-template bool TriangulationBase<10>::pachner(Face<10, 5>*, bool, bool);
-template bool TriangulationBase<10>::pachner(Face<10, 6>*, bool, bool);
-template bool TriangulationBase<10>::pachner(Face<10, 7>*, bool, bool);
-template bool TriangulationBase<10>::pachner(Face<10, 8>*, bool, bool);
-template bool TriangulationBase<10>::pachner(Face<10, 9>*, bool, bool);
-template bool TriangulationBase<10>::pachner(Face<10, 10>*, bool, bool);
+template bool TriangulationBase<10>::internalPachner(Face<10, 0>*, bool, bool);
+template bool TriangulationBase<10>::internalPachner(Face<10, 1>*, bool, bool);
+template bool TriangulationBase<10>::internalPachner(Face<10, 2>*, bool, bool);
+template bool TriangulationBase<10>::internalPachner(Face<10, 3>*, bool, bool);
+template bool TriangulationBase<10>::internalPachner(Face<10, 4>*, bool, bool);
+template bool TriangulationBase<10>::internalPachner(Face<10, 5>*, bool, bool);
+template bool TriangulationBase<10>::internalPachner(Face<10, 6>*, bool, bool);
+template bool TriangulationBase<10>::internalPachner(Face<10, 7>*, bool, bool);
+template bool TriangulationBase<10>::internalPachner(Face<10, 8>*, bool, bool);
+template bool TriangulationBase<10>::internalPachner(Face<10, 9>*, bool, bool);
+template bool TriangulationBase<10>::internalPachner(Face<10, 10>*, bool, bool);
+
+template bool TriangulationBase<10>::internal20(Face<10, 0>*, bool, bool);
+template bool TriangulationBase<10>::internal20(Face<10, 1>*, bool, bool);
+template bool TriangulationBase<10>::internal20(Face<10, 2>*, bool, bool);
+
+template void TriangulationBase<10>::writeTextShort(std::ostream&) const;
+template void TriangulationBase<10>::writeTextLong(std::ostream&) const;
+
+template void TriangulationBase<10>::reorderBFS(bool);
+template Triangulation<10> TriangulationBase<10>::doubleCover() const;
+template Triangulation<10> TriangulationBase<10>::doubleOverBoundary() const;
+template bool TriangulationBase<10>::makeIdeal();
+
+template std::string TriangulationBase<10>::source(Language) const;
+template void TriangulationBase<10>::writeDot(std::ostream&, bool) const;
 
 } // namespace regina::detail
