@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,17 +23,16 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
 #include "triangulation/detail/algebra-impl.h"
 #include "triangulation/detail/isosig-impl.h"
-#include "triangulation/detail/pachner-impl.h"
+#include "triangulation/detail/moves-impl.h"
 #include "triangulation/detail/skeleton-impl.h"
+#include "triangulation/detail/triangulation-impl.h"
 #include "triangulation/generic.h"
 
 namespace regina::detail {
@@ -104,18 +103,33 @@ template void TriangulationBase<12>::cloneSkeleton(
 template void TriangulationBase<12>::clearBaseProperties();
 template void TriangulationBase<12>::swapBaseData(TriangulationBase<12>&);
 
-template bool TriangulationBase<12>::pachner(Face<12, 0>*, bool, bool);
-template bool TriangulationBase<12>::pachner(Face<12, 1>*, bool, bool);
-template bool TriangulationBase<12>::pachner(Face<12, 2>*, bool, bool);
-template bool TriangulationBase<12>::pachner(Face<12, 3>*, bool, bool);
-template bool TriangulationBase<12>::pachner(Face<12, 4>*, bool, bool);
-template bool TriangulationBase<12>::pachner(Face<12, 5>*, bool, bool);
-template bool TriangulationBase<12>::pachner(Face<12, 6>*, bool, bool);
-template bool TriangulationBase<12>::pachner(Face<12, 7>*, bool, bool);
-template bool TriangulationBase<12>::pachner(Face<12, 8>*, bool, bool);
-template bool TriangulationBase<12>::pachner(Face<12, 9>*, bool, bool);
-template bool TriangulationBase<12>::pachner(Face<12, 10>*, bool, bool);
-template bool TriangulationBase<12>::pachner(Face<12, 11>*, bool, bool);
-template bool TriangulationBase<12>::pachner(Face<12, 12>*, bool, bool);
+template bool TriangulationBase<12>::internalPachner(Face<12, 0>*, bool, bool);
+template bool TriangulationBase<12>::internalPachner(Face<12, 1>*, bool, bool);
+template bool TriangulationBase<12>::internalPachner(Face<12, 2>*, bool, bool);
+template bool TriangulationBase<12>::internalPachner(Face<12, 3>*, bool, bool);
+template bool TriangulationBase<12>::internalPachner(Face<12, 4>*, bool, bool);
+template bool TriangulationBase<12>::internalPachner(Face<12, 5>*, bool, bool);
+template bool TriangulationBase<12>::internalPachner(Face<12, 6>*, bool, bool);
+template bool TriangulationBase<12>::internalPachner(Face<12, 7>*, bool, bool);
+template bool TriangulationBase<12>::internalPachner(Face<12, 8>*, bool, bool);
+template bool TriangulationBase<12>::internalPachner(Face<12, 9>*, bool, bool);
+template bool TriangulationBase<12>::internalPachner(Face<12, 10>*, bool, bool);
+template bool TriangulationBase<12>::internalPachner(Face<12, 11>*, bool, bool);
+template bool TriangulationBase<12>::internalPachner(Face<12, 12>*, bool, bool);
+
+template bool TriangulationBase<12>::internal20(Face<12, 0>*, bool, bool);
+template bool TriangulationBase<12>::internal20(Face<12, 1>*, bool, bool);
+template bool TriangulationBase<12>::internal20(Face<12, 2>*, bool, bool);
+
+template void TriangulationBase<12>::writeTextShort(std::ostream&) const;
+template void TriangulationBase<12>::writeTextLong(std::ostream&) const;
+
+template void TriangulationBase<12>::reorderBFS(bool);
+template Triangulation<12> TriangulationBase<12>::doubleCover() const;
+template Triangulation<12> TriangulationBase<12>::doubleOverBoundary() const;
+template bool TriangulationBase<12>::makeIdeal();
+
+template std::string TriangulationBase<12>::source(Language) const;
+template void TriangulationBase<12>::writeDot(std::ostream&, bool) const;
 
 } // namespace regina::detail
