@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,17 +23,16 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
 #include "triangulation/detail/algebra-impl.h"
 #include "triangulation/detail/isosig-impl.h"
-#include "triangulation/detail/pachner-impl.h"
+#include "triangulation/detail/moves-impl.h"
 #include "triangulation/detail/skeleton-impl.h"
+#include "triangulation/detail/triangulation-impl.h"
 #include "triangulation/generic.h"
 
 namespace regina::detail {
@@ -116,21 +115,36 @@ template void TriangulationBase<15>::cloneSkeleton(
 template void TriangulationBase<15>::clearBaseProperties();
 template void TriangulationBase<15>::swapBaseData(TriangulationBase<15>&);
 
-template bool TriangulationBase<15>::pachner(Face<15, 0>*, bool, bool);
-template bool TriangulationBase<15>::pachner(Face<15, 1>*, bool, bool);
-template bool TriangulationBase<15>::pachner(Face<15, 2>*, bool, bool);
-template bool TriangulationBase<15>::pachner(Face<15, 3>*, bool, bool);
-template bool TriangulationBase<15>::pachner(Face<15, 4>*, bool, bool);
-template bool TriangulationBase<15>::pachner(Face<15, 5>*, bool, bool);
-template bool TriangulationBase<15>::pachner(Face<15, 6>*, bool, bool);
-template bool TriangulationBase<15>::pachner(Face<15, 7>*, bool, bool);
-template bool TriangulationBase<15>::pachner(Face<15, 8>*, bool, bool);
-template bool TriangulationBase<15>::pachner(Face<15, 9>*, bool, bool);
-template bool TriangulationBase<15>::pachner(Face<15, 10>*, bool, bool);
-template bool TriangulationBase<15>::pachner(Face<15, 11>*, bool, bool);
-template bool TriangulationBase<15>::pachner(Face<15, 12>*, bool, bool);
-template bool TriangulationBase<15>::pachner(Face<15, 13>*, bool, bool);
-template bool TriangulationBase<15>::pachner(Face<15, 14>*, bool, bool);
-template bool TriangulationBase<15>::pachner(Face<15, 15>*, bool, bool);
+template bool TriangulationBase<15>::internalPachner(Face<15, 0>*, bool, bool);
+template bool TriangulationBase<15>::internalPachner(Face<15, 1>*, bool, bool);
+template bool TriangulationBase<15>::internalPachner(Face<15, 2>*, bool, bool);
+template bool TriangulationBase<15>::internalPachner(Face<15, 3>*, bool, bool);
+template bool TriangulationBase<15>::internalPachner(Face<15, 4>*, bool, bool);
+template bool TriangulationBase<15>::internalPachner(Face<15, 5>*, bool, bool);
+template bool TriangulationBase<15>::internalPachner(Face<15, 6>*, bool, bool);
+template bool TriangulationBase<15>::internalPachner(Face<15, 7>*, bool, bool);
+template bool TriangulationBase<15>::internalPachner(Face<15, 8>*, bool, bool);
+template bool TriangulationBase<15>::internalPachner(Face<15, 9>*, bool, bool);
+template bool TriangulationBase<15>::internalPachner(Face<15, 10>*, bool, bool);
+template bool TriangulationBase<15>::internalPachner(Face<15, 11>*, bool, bool);
+template bool TriangulationBase<15>::internalPachner(Face<15, 12>*, bool, bool);
+template bool TriangulationBase<15>::internalPachner(Face<15, 13>*, bool, bool);
+template bool TriangulationBase<15>::internalPachner(Face<15, 14>*, bool, bool);
+template bool TriangulationBase<15>::internalPachner(Face<15, 15>*, bool, bool);
+
+template bool TriangulationBase<15>::internal20(Face<15, 0>*, bool, bool);
+template bool TriangulationBase<15>::internal20(Face<15, 1>*, bool, bool);
+template bool TriangulationBase<15>::internal20(Face<15, 2>*, bool, bool);
+
+template void TriangulationBase<15>::writeTextShort(std::ostream&) const;
+template void TriangulationBase<15>::writeTextLong(std::ostream&) const;
+
+template void TriangulationBase<15>::reorderBFS(bool);
+template Triangulation<15> TriangulationBase<15>::doubleCover() const;
+template Triangulation<15> TriangulationBase<15>::doubleOverBoundary() const;
+template bool TriangulationBase<15>::makeIdeal();
+
+template std::string TriangulationBase<15>::source(Language) const;
+template void TriangulationBase<15>::writeDot(std::ostream&, bool) const;
 
 } // namespace regina::detail
