@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,17 +23,16 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
 #include "triangulation/detail/algebra-impl.h"
 #include "triangulation/detail/isosig-impl.h"
-#include "triangulation/detail/pachner-impl.h"
+#include "triangulation/detail/moves-impl.h"
 #include "triangulation/detail/skeleton-impl.h"
+#include "triangulation/detail/triangulation-impl.h"
 #include "triangulation/generic.h"
 
 namespace regina::detail {
@@ -74,11 +73,26 @@ template void TriangulationBase<5>::cloneSkeleton(const TriangulationBase<5>&);
 template void TriangulationBase<5>::clearBaseProperties();
 template void TriangulationBase<5>::swapBaseData(TriangulationBase<5>&);
 
-template bool TriangulationBase<5>::pachner(Face<5, 0>*, bool, bool);
-template bool TriangulationBase<5>::pachner(Face<5, 1>*, bool, bool);
-template bool TriangulationBase<5>::pachner(Face<5, 2>*, bool, bool);
-template bool TriangulationBase<5>::pachner(Face<5, 3>*, bool, bool);
-template bool TriangulationBase<5>::pachner(Face<5, 4>*, bool, bool);
-template bool TriangulationBase<5>::pachner(Face<5, 5>*, bool, bool);
+template bool TriangulationBase<5>::internalPachner(Face<5, 0>*, bool, bool);
+template bool TriangulationBase<5>::internalPachner(Face<5, 1>*, bool, bool);
+template bool TriangulationBase<5>::internalPachner(Face<5, 2>*, bool, bool);
+template bool TriangulationBase<5>::internalPachner(Face<5, 3>*, bool, bool);
+template bool TriangulationBase<5>::internalPachner(Face<5, 4>*, bool, bool);
+template bool TriangulationBase<5>::internalPachner(Face<5, 5>*, bool, bool);
+
+template bool TriangulationBase<5>::internal20(Face<5, 0>*, bool, bool);
+template bool TriangulationBase<5>::internal20(Face<5, 1>*, bool, bool);
+template bool TriangulationBase<5>::internal20(Face<5, 2>*, bool, bool);
+
+template void TriangulationBase<5>::writeTextShort(std::ostream&) const;
+template void TriangulationBase<5>::writeTextLong(std::ostream&) const;
+
+template void TriangulationBase<5>::reorderBFS(bool);
+template Triangulation<5> TriangulationBase<5>::doubleCover() const;
+template Triangulation<5> TriangulationBase<5>::doubleOverBoundary() const;
+template bool TriangulationBase<5>::makeIdeal();
+
+template std::string TriangulationBase<5>::source(Language) const;
+template void TriangulationBase<5>::writeDot(std::ostream&, bool) const;
 
 } // namespace regina::detail
