@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,17 +23,16 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
 #include "triangulation/detail/algebra-impl.h"
 #include "triangulation/detail/isosig-impl.h"
-#include "triangulation/detail/pachner-impl.h"
+#include "triangulation/detail/moves-impl.h"
 #include "triangulation/detail/skeleton-impl.h"
+#include "triangulation/detail/triangulation-impl.h"
 #include "triangulation/generic.h"
 
 namespace regina::detail {
@@ -90,15 +89,30 @@ template void TriangulationBase<9>::cloneSkeleton(const TriangulationBase<9>&);
 template void TriangulationBase<9>::clearBaseProperties();
 template void TriangulationBase<9>::swapBaseData(TriangulationBase<9>&);
 
-template bool TriangulationBase<9>::pachner(Face<9, 0>*, bool, bool);
-template bool TriangulationBase<9>::pachner(Face<9, 1>*, bool, bool);
-template bool TriangulationBase<9>::pachner(Face<9, 2>*, bool, bool);
-template bool TriangulationBase<9>::pachner(Face<9, 3>*, bool, bool);
-template bool TriangulationBase<9>::pachner(Face<9, 4>*, bool, bool);
-template bool TriangulationBase<9>::pachner(Face<9, 5>*, bool, bool);
-template bool TriangulationBase<9>::pachner(Face<9, 6>*, bool, bool);
-template bool TriangulationBase<9>::pachner(Face<9, 7>*, bool, bool);
-template bool TriangulationBase<9>::pachner(Face<9, 8>*, bool, bool);
-template bool TriangulationBase<9>::pachner(Face<9, 9>*, bool, bool);
+template bool TriangulationBase<9>::internalPachner(Face<9, 0>*, bool, bool);
+template bool TriangulationBase<9>::internalPachner(Face<9, 1>*, bool, bool);
+template bool TriangulationBase<9>::internalPachner(Face<9, 2>*, bool, bool);
+template bool TriangulationBase<9>::internalPachner(Face<9, 3>*, bool, bool);
+template bool TriangulationBase<9>::internalPachner(Face<9, 4>*, bool, bool);
+template bool TriangulationBase<9>::internalPachner(Face<9, 5>*, bool, bool);
+template bool TriangulationBase<9>::internalPachner(Face<9, 6>*, bool, bool);
+template bool TriangulationBase<9>::internalPachner(Face<9, 7>*, bool, bool);
+template bool TriangulationBase<9>::internalPachner(Face<9, 8>*, bool, bool);
+template bool TriangulationBase<9>::internalPachner(Face<9, 9>*, bool, bool);
+
+template bool TriangulationBase<9>::internal20(Face<9, 0>*, bool, bool);
+template bool TriangulationBase<9>::internal20(Face<9, 1>*, bool, bool);
+template bool TriangulationBase<9>::internal20(Face<9, 2>*, bool, bool);
+
+template void TriangulationBase<9>::writeTextShort(std::ostream&) const;
+template void TriangulationBase<9>::writeTextLong(std::ostream&) const;
+
+template void TriangulationBase<9>::reorderBFS(bool);
+template Triangulation<9> TriangulationBase<9>::doubleCover() const;
+template Triangulation<9> TriangulationBase<9>::doubleOverBoundary() const;
+template bool TriangulationBase<9>::makeIdeal();
+
+template std::string TriangulationBase<9>::source(Language) const;
+template void TriangulationBase<9>::writeDot(std::ostream&, bool) const;
 
 } // namespace regina::detail
