@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -50,8 +48,10 @@ class FacePair;
 /**
  * Represents the dual graph of a 3-manifold triangulation.
  *
- * This is a specialisation of the generic FacetPairing class template;
- * see the FacetPairing documentation for an overview of how this class works.
+ * This is a specialisation of the generic FacetPairing class template; see the
+ * generic FacetPairing documentation for an overview of how the facet pairing
+ * classes work.  In Python, you can read this generic documentation by
+ * looking at a higher dimension: try `help(FacetPairing5)`.
  *
  * This 3-dimensional specialisation contains some extra functionality.
  * In particular, it provides routines for finding informative subgraphs
@@ -236,6 +236,8 @@ class FacetPairing<3> : public detail::FacetPairingBase<3> {
          * enumeration", Benjamin A. Burton, J. Knot Theory Ramifications
          * 13 (2004), 1057--1101.
          *
+         * This routine is identical to calling `hasMultiEdge<3>()`.
+         *
          * \return \c true if and only if this face pairing contains a
          * triple edge.
          */
@@ -621,6 +623,10 @@ inline FacetPairing<3>::FacetPairing(size_t size) :
         detail::FacetPairingBase<3>(size) {
 }
 
+inline bool FacetPairing<3>::hasTripleEdge() const {
+    return hasMultiEdge<3>();
+}
+
 inline void FacetPairing<3>::followChain(size_t& tet, FacePair& faces) const {
     auto t = static_cast<ssize_t>(tet);
     followChain(t, faces);
