@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -237,35 +235,32 @@ struct FacetSpec : public TightEncodable<FacetSpec<dim>> {
     /**
      * Determines if this and the given specifier are identical.
      *
-     * \param other the specifier to compare with this.
+     * \param rhs the specifier to compare with this.
      * \return \c true if and only if this and the given specifier are
      * equal.
      */
-    bool operator == (const FacetSpec<dim>& other) const;
+    bool operator == (const FacetSpec<dim>& rhs) const;
     /**
-     * Determines if this and the given specifier are not identical.
+     * Compares two specifiers, following the same ordering that is used for
+     * iteration.
      *
-     * \param other the specifier to compare with this.
-     * \return \c true if and only if this and the given specifier are
-     * not equal.
-     */
-    bool operator != (const FacetSpec<dim>& other) const;
-    /**
-     * Determines if this is less than the given specifier.
+     * Specifically: specifiers are compared first by simplex number and then
+     * by facet number.  The overall boundary is considered greater than any
+     * "real" simplex facet, the before-the-start value is considered smaller
+     * than anything else, and the past-the-end value is considered greater
+     * than anything else.
      *
-     * \param other the specifier to compare with this.
-     * \return \c true if and only if this is less than the given
+     * This generates all of the usual comparison operators, including
+     * `<`, `<=`, `>`, and `>=`.
+     *
+     * \python This spaceship operator `x <=> y` is not available, but the
+     * other comparison operators that it generates _are_ available.
+     *
+     * \param rhs the specifier to compare with this.
+     * \return The result of the comparison between this and the given
      * specifier.
      */
-    bool operator < (const FacetSpec<dim>& other) const;
-    /**
-     * Determines if this is less than or equal to the given specifier.
-     *
-     * \param other the specifier to compare with this.
-     * \return \c true if and only if this is less than or equal to
-     * the given specifier.
-     */
-    bool operator <= (const FacetSpec<dim>& other) const;
+    std::strong_ordering operator <=> (const FacetSpec<dim>& rhs) const;
 
     /**
      * Writes the tight encoding of this specifier to the given output
@@ -287,7 +282,7 @@ struct FacetSpec : public TightEncodable<FacetSpec<dim>> {
      * The tight encoding will be read from the given input stream.
      * If the input stream contains leading whitespace then it will be
      * treated as an invalid encoding (i.e., this routine will throw an
-     * exception).  The input routine _may_ contain further data: if this
+     * exception).  The input stream _may_ contain further data: if this
      * routine is successful then the input stream will be left positioned
      * immediately after the encoding, without skipping any trailing
      * whitespace.
@@ -406,23 +401,19 @@ inline FacetSpec<dim> FacetSpec<dim>::operator -- (int) {
 }
 
 template <int dim>
-inline bool FacetSpec<dim>::operator == (const FacetSpec<dim>& other) const {
-    return (simp == other.simp && facet == other.facet);
+inline bool FacetSpec<dim>::operator == (const FacetSpec& rhs) const {
+    return (simp == rhs.simp && facet == rhs.facet);
 }
 
 template <int dim>
-inline bool FacetSpec<dim>::operator != (const FacetSpec<dim>& other) const {
-    return (simp != other.simp || facet != other.facet);
-}
-
-template <int dim>
-inline bool FacetSpec<dim>::operator < (const FacetSpec<dim>& other) const {
-    return (simp < other.simp || (simp == other.simp && facet < other.facet));
-}
-
-template <int dim>
-inline bool FacetSpec<dim>::operator <= (const FacetSpec<dim>& other) const {
-    return (simp < other.simp || (simp == other.simp && facet <= other.facet));
+inline std::strong_ordering FacetSpec<dim>::operator <=> (const FacetSpec& rhs)
+        const {
+    if (simp < rhs.simp)
+        return std::strong_ordering::less;
+    else if (simp > rhs.simp)
+        return std::strong_ordering::greater;
+    else
+        return facet <=> rhs.facet;
 }
 
 template <int dim>
