@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -376,6 +374,12 @@ class Isomorphism :
          * describes the mapping from the simplices of \a T and their facets
          * to the simplices of \a U and their facets.
          *
+         * If the given triangulation \a T has any locks on top-dimensional
+         * simplices and/or their facets, then the resulting triangulation \a U
+         * will have matching locks that have been carried through the
+         * isomorphism correctly (i.e., the locks will be copied over to the
+         * appropriate destination simplices and/or facets).
+         *
          * \pre The simplex images are precisely 0,1,...,size()-1 in some
          * order (i.e., this isomorphism does not represent a mapping from a
          * smaller triangulation into a larger triangulation).
@@ -463,6 +467,12 @@ class Isomorphism :
          * Deprecated routine that applies this isomorphism to the given
          * triangulation, and returns the result as a new triangulation.
          *
+         * If the given triangulation has any locks on top-dimensional
+         * simplices and/or their facets, then the triangulation that is
+         * returned will have matching locks that have been carried through
+         * the isomorphism correctly (i.e., the locks will be copied over
+         * to the appropriate destination simplices and/or facets).
+         *
          * \deprecated If this isomorphism is \a iso, then this routine
          * is equivalent to calling `iso(tri)`.  See the bracket
          * operator for further details.
@@ -486,6 +496,11 @@ class Isomorphism :
          * Deprecated routine that applies this isomorphism to the given
          * triangulation, modifying the given triangulation directly.
          *
+         * If the given triangulation has any locks on top-dimensional
+         * simplices and/or their facets, then these locks will be carried
+         * through the isomorphism correctly (i.e., the locks will be moved
+         * to the appropriate destination simplices and/or facets).
+         *
          * \deprecated If this isomorphism is \a iso, then this routine
          * is equivalent to calling `tri = iso(tri)`.  See the bracket
          * operator for further details.
@@ -632,7 +647,7 @@ class Isomorphism :
          * The tight encoding will be read from the given input stream.
          * If the input stream contains leading whitespace then it will be
          * treated as an invalid encoding (i.e., this routine will throw an
-         * exception).  The input routine _may_ contain further data: if this
+         * exception).  The input stream _may_ contain further data: if this
          * routine is successful then the input stream will be left positioned
          * immediately after the encoding, without skipping any trailing
          * whitespace.
@@ -692,29 +707,6 @@ class Isomorphism :
          */
         bool operator == (const Isomorphism& other) const;
 
-        /**
-         * Determines whether this and the given isomorphism are not identical.
-         *
-         * Two isomorphisms are considered _identical_ if they act on the
-         * same number of top-dimensional simplices, and all destination
-         * simplex numbers and facet permutations are the same for both
-         * isomorphisms.
-         *
-         * In particular it is only the simplex, facet and vertex _labels_
-         * that matter: an isomorphism does not refer to a specific
-         * triangulation, and there is no sense in which the two isomorphisms
-         * need to act on the same triangulations and/or point to the same
-         * destination Simplex objects.
-         *
-         * It is safe to compare isomorphisms of different sizes (in
-         * which case this routine will return \c true).
-         *
-         * \param other the isomorphism to compare with this.
-         * \return \c true if and only if this and the given isomorphism
-         * are not identical.
-         */
-        bool operator != (const Isomorphism& other) const;
-
         /**
          * Returns the identity isomorphism for the given number of simplices.
          * This isomorphism sends every simplex and every vertex to itself.
@@ -896,31 +888,42 @@ Triangulation<dim> Isomorphism<dim>::operator ()(
     Triangulation<dim> ans;
     auto* tet = new Simplex<dim>*[size_];
 
-    // Ensure only one event pair is fired in this sequence of changes.
-    typename Triangulation<dim>::ChangeEventSpan span(ans);
     for (size_t t = 0; t < size_; t++)
         tet[t] = ans.newSimplex();
 
-    for (size_t t = 0; t < size_; t++)
-        tet[simpImage_[t]]->setDescription(
-            original.simplex(t)->description());
+    const Simplex<dim> *src, *adj;
+    Simplex<dim> *dest;
 
-    const Simplex<dim> *myTet, *adjTet;
     for (size_t t = 0; t < size_; t++) {
-        myTet = original.simplex(t);
-        for (int f = 0; f <= dim; f++)
-            if ((adjTet = myTet->adjacentSimplex(f))) {
-                // We have an adjacent simplex.
-                size_t adjTetIndex = adjTet->index();
-                Perm<dim+1> gluingPerm = myTet->adjacentGluing(f);
+        src = original.simplex(t);
+        dest = tet[simpImage_[t]];
 
-                // Make the gluing from one side only.
+        dest->setDescription(src->description());
+        if (src->isLocked())
+            dest->lock();
+    }
+
+    for (size_t t = 0; t < size_; t++) {
+        src = original.simplex(t);
+        for (int f = 0; f <= dim; f++)
+            if ((adj = src->adjacentSimplex(f))) {
+                // We have an adjacent simplex.
+                size_t adjTetIndex = adj->index();
+                Perm<dim+1> gluingPerm = src->adjacentGluing(f);
+
+                // Make the gluing (and any necessary locks) from one side only.
                 if (adjTetIndex > t || (adjTetIndex == t &&
-                        gluingPerm[f] > f))
-                    tet[simpImage_[t]]->join(facetPerm_[t][f],
-                        tet[simpImage_[adjTetIndex]],
+                        gluingPerm[f] > f)) {
+                    dest = tet[simpImage_[t]];
+                    dest->join(facetPerm_[t][f], tet[simpImage_[adjTetIndex]],
                         facetPerm_[adjTetIndex] * gluingPerm *
                             facetPerm_[t].inverse());
+                    if (src->isFacetLocked(f))
+                        dest->lockFacet(facetPerm_[t][f]);
+                }
+            } else {
+                if (src->isFacetLocked(f))
+                    tet[simpImage_[t]]->lockFacet(facetPerm_[t][f]);
             }
     }
 
@@ -1097,11 +1100,6 @@ inline bool Isomorphism<dim>::operator == (const Isomorphism& other) const {
         std::equal(facetPerm_, facetPerm_ + size_, other.facetPerm_);
 }
 
-template <int dim>
-inline bool Isomorphism<dim>::operator != (const Isomorphism& other) const {
-    return ! ((*this) == other);
-}
-
 template <int dim>
 inline Isomorphism<dim> Isomorphism<dim>::identity(size_t nSimplices) {
     Isomorphism<dim> id(nSimplices);
