@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -64,8 +62,10 @@ namespace regina {
  * facets.  Typically (but not necessarily) such triangulations are used
  * to represent <i>dim</i>-manifolds.
  *
- * Such triangulations are not the same as pure simplicial complexes, for two
- * reasons:
+ * ### Structure of triangulations
+ *
+ * Triangulations in Regina are not the same as pure simplicial complexes,
+ * for two reasons:
  *
  * - The only identifications that the user can explicitly specify are
  *   gluings between <i>dim</i>-dimensional simplices along their
@@ -91,8 +91,10 @@ namespace regina {
  * You can construct a triangulation from scratch using routines such as
  * newSimplex() and Simplex<dim>::join().  There are also routines for
  * exporting and importing triangulations in bulk, such as isoSig() and
- * fromIsoSig() (which use _isomorphism signatures_), or dumpConstruction()
- * and fromGluings() (which use C++ code).
+ * fromIsoSig() (which use _isomorphism signatures_), or source() and
+ * fromGluings() (which use C++ or Python code).
+ *
+ * ### Skeleta and components
  *
  * In additional to top-dimensional simplices, this class also tracks:
  *
@@ -108,6 +110,8 @@ namespace regina {
  * Likewise, if the triangulation is deleted then all component objects
  * will be deleted alongside it.
  *
+ * ### The packet tree
+ *
  * Since Regina 7.0, this is no longer a "packet type" that can be
  * inserted directly into the packet tree.  Instead a Triangulation is now a
  * standalone mathematatical object, which makes it slimmer and faster
@@ -122,12 +126,13 @@ namespace regina {
  *   tags, child/parent packets, and event listeners.  It derives from
  *   Triangulation, and so inherits the full Triangulation interface.
  *
- * - If you are adding new functions to this class that edit the triangulation,
- *   you must still remember to create a ChangeEventSpan.  This will ensure
- *   that, if the triangulation is being managed by a PacketOf<Triangulation>,
- *   then the appropriate packet change events will be fired.  All other events
- *   (aside from packetToBeChanged() and packetWasChanged() are managed
- *   directly by the PacketOf<Triangulation> wrapper class.
+ * If you are adding new member functions that edit the internal data
+ * structures of a triangulation, you must remember to surround these changes
+ * with a ChangeAndClearSpan.  This manages bookkeeping such as clearing
+ * computed properties, snapshotting, and (if this link _does_ belong to a
+ * packet) firing packet change events.
+ *
+ * ### C++ housekeeping
  *
  * This class implements C++ move semantics and adheres to the C++ Swappable
  * requirement.  It is designed to avoid deep copies wherever possible,
@@ -185,37 +190,45 @@ class Triangulation : public detail::TriangulationBase<dim> {
          * edges, components, etc.).  In particular, the same numbering and
          * labelling will be used for all skeletal objects.
          *
-         * If you want a "clean" copy that resets all properties to unknown
-         * and leaves the skeleton uncomputed, you can use the two-argument
-         * copy constructor instead.
+         * If \a src has any locks on top-dimensional simplices and/or their
+         * facets, these locks will also be copied across.
+         *
+         * If you want a "clean" copy that resets all properties to unknown,
+         * you can use the two-argument copy constructor instead.
          *
          * \param src the triangulation to copy.
          */
         Triangulation(const Triangulation& src) = default;
         /**
          * Creates a new copy of the given triangulation, with the option
-         * of whether or not to clone its computed properties also.
+         * of whether or not to clone its computed properties and/or locks also.
          *
          * If \a cloneProps is \c true, then this constructor will also clone
          * any computed properties (such as homology, fundamental group, and
-         * so on), as well as the skeleton (vertices, edges, components, etc.).
-         * In particular, the same numbering and labelling will be used for
-         * all skeletal objects in both triangulations.
+         * so on).  If \a cloneProps is \c false, then these properties
+         * will be marked as unknown in the new triangulation, and will be
+         * recomputed on demand if/when they are required.
          *
-         * If \a cloneProps is \c false, then these properties and skeletal
-         * objects will be marked as unknown in the new triangulation, and
-         * will be recomputed on demand if/when they are required.  Note
-         * in particular that, when the skeleton is recomputed, there is
-         * no guarantee that the numbering and labelling for skeletal objects
-         * will be the same as in the source triangulation.
+         * Regardless of \a cloneProps, the skeleton (vertices, edges,
+         * components, etc.) will _always_ be cloned.  This is to ensure that
+         * the same numbering and labelling will be used for all skeletal
+         * objects in both triangulations.
+         *
+         * If \a cloneLocks is \c true then any locks on the top-dimensional
+         * simplices and/or facets of \a src will be copied across.
+         * If \a cloneLocks is \c false then the new triangulation will have
+         * no locks at all.
          *
          * \param src the triangulation to copy.
          * \param cloneProps \c true if this should also clone any computed
-         * properties as well as the skeleton of the given triangulation,
-         * or \c false if the new triangulation should have such properties
-         * and skeletal data marked as unknown.
+         * properties of the given triangulation, or \c false if the new
+         * triangulation should have such properties marked as unknown.
+         * \param cloneLocks \c true if this should also clone any simplex
+         * and/or facet locks from the given triangulation, or \c false if
+         * the new triangulation should have no locks at all.
          */
-        Triangulation(const Triangulation& src, bool cloneProps);
+        Triangulation(const Triangulation& src, bool cloneProps,
+            bool cloneLocks = true);
         /**
          * Moves the given triangulation into this new triangulation.
          *
@@ -230,6 +243,9 @@ class Triangulation : public detail::TriangulationBase<dim> {
          * BoundaryComponent<dim> objects will remain valid.  Likewise, all
          * cached properties will be moved into this triangulation.
          *
+         * If \a src has any locks on top-dimensional simplices and/or their
+         * facets, these locks will also be moved across.
+         *
          * The triangulation that is passed (\a src) will no longer be usable.
          *
          * \note This operator is marked \c noexcept, and in particular
@@ -264,6 +280,9 @@ class Triangulation : public detail::TriangulationBase<dim> {
          * will use the same numbering and labelling for all skeletal objects
          * as in the source triangulation.
          *
+         * If \a src has any locks on top-dimensional simplices and/or their
+         * facets, these locks will also be copied across.
+         *
          * \return a reference to this triangulation.
          */
         Triangulation& operator = (const Triangulation&) = default;
@@ -283,6 +302,9 @@ class Triangulation : public detail::TriangulationBase<dim> {
          * BoundaryComponent<dim> objects will remain valid.  Likewise, all
          * cached properties will be moved into this triangulation.
          *
+         * If \a src has any locks on top-dimensional simplices and/or their
+         * facets, these locks will also be moved across.
+         *
          * The triangulation that is passed (\a src) will no longer be usable.
          *
          * \note This operator is _not_ marked \c noexcept, since it fires
@@ -331,6 +353,10 @@ class Triangulation : public detail::TriangulationBase<dim> {
          *
          * In most cases this routine is followed immediately by firing
          * a change event.
+         *
+         * It is recommended that you use a local ChangeAndClearSpan object
+         * to manage both of these tasks (calling clearAllProperties() and
+         * firing change events), rather than calling this function manually.
          */
         void clearAllProperties();
 
@@ -490,7 +516,8 @@ inline Triangulation<dim>::Triangulation() : detail::TriangulationBase<dim>() {
 
 template <int dim>
 inline Triangulation<dim>::Triangulation(const Triangulation& src,
-        bool cloneProps) : detail::TriangulationBase<dim>(src, cloneProps) {
+        bool cloneProps, bool cloneLocks) :
+        detail::TriangulationBase<dim>(src, cloneProps, cloneLocks) {
     // All properties to clone are held by TriangulationBase.
 }
 
@@ -510,8 +537,11 @@ void Triangulation<dim>::swap(Triangulation<dim>& other) {
     if (&other == this)
         return;
 
-    typename Triangulation<dim>::ChangeEventSpan span1(*this);
-    typename Triangulation<dim>::ChangeEventSpan span2(other);
+    // We use a basic PacketChangeSpan here, not a richer ChangeAndClearSpan,
+    // since we do not want to touch computed properties.  Our intention here
+    // is to swap them, not clear them.
+    typename Triangulation<dim>::PacketChangeSpan span1(*this);
+    typename Triangulation<dim>::PacketChangeSpan span2(other);
 
     // Note: swapBaseData() calls Snapshottable::swap().
     this->swapBaseData(other);
