@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -74,8 +72,8 @@ std::string superscript(T value) {
     return ans;
 }
 
-template <bool supportInfinity>
-std::string superscript(const IntegerBase<supportInfinity>& value) {
+template <bool withInfinity>
+std::string superscript(const IntegerBase<withInfinity>& value) {
     std::string s = value.stringValue();
     std::string ans;
     for (auto c : s)
@@ -120,8 +118,8 @@ std::string subscript(T value) {
     return ans;
 }
 
-template <bool supportInfinity>
-std::string subscript(const IntegerBase<supportInfinity>& value) {
+template <bool withInfinity>
+std::string subscript(const IntegerBase<withInfinity>& value) {
     std::string s = value.stringValue();
     std::string ans;
     for (auto c : s)
