@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Computational Engine                                                  *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -295,17 +293,6 @@ class TableView {
                 bool operator == (const iterator& rhs) const {
                     return current_ == rhs.current_;
                 }
-                /**
-                 * Compares this with the given iterator for inequality.
-                 *
-                 * \param rhs the iterator to compare this with.
-                 * \return \c false if the iterators point to the same
-                 * subarray/element of the underlying table, or \c true
-                 * if they do not.
-                 */
-                bool operator != (const iterator& rhs) const {
-                    return current_ != rhs.current_;
-                }
 
                 /**
                  * The preincrement operator.
@@ -543,23 +530,6 @@ class TableView {
         constexpr bool operator == (const TableView& other) const {
             return (array_ == other.array_);
         }
-
-        /**
-         * Determines whether this and the given table view are accessing
-         * different underlying C-style arrays.
-         *
-         * To be considered the same array, the two arrays must have the same
-         * location in memory (i.e., the pointers that define the C-style arrays
-         * must be equal).  In particular, it is not enough for the two arrays
-         * just to have identical contents.
-         *
-         * \param other the table view to compare with this.
-         * \return \c true if and only if this and the given table use
-         * different underlying C-style arrays.
-         */
-        constexpr bool operator != (const TableView& other) const {
-            return (array_ != other.array_);
-        }
 };
 
 // Deduction guides (hide these from Doxygen, which cannot handle them):
