@@ -24,6 +24,9 @@
 /* Define if 64-bit integer literals are available using the LL suffix */
 #define NUMERIC_64_LL_FOUND
 
+/* Define if std::lexicographical_compare_three_way is available */
+#define LEXCMP_FOUND
+
 /* Define if we are supporting triangulations of dimensions 9-15. */
 /* #undef REGINA_HIGHDIM */
 
@@ -96,24 +99,24 @@
 #define REGINA_DB_EXT "tdb"
 
 /* Define to the full name and version of this package. */
-#define PACKAGE_STRING "Regina 7.3.1"
+#define PACKAGE_STRING "Regina 7.4"
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "7.3.1"
+#define PACKAGE_VERSION "7.4"
 
 /* Major version number of the package. */
 #define PACKAGE_VERSION_MAJOR 7
 
 /* Minor version number of the package. */
-#define PACKAGE_VERSION_MINOR 3
+#define PACKAGE_VERSION_MINOR 4
 
 /* Optional additional information about this specific build.
    This will always be defined, but it may be the empty string. */
 #define BUILD_INFO "Development build"
 
 /* A nicely formatted combination of PACKAGE_STRING and BUILD_INFO. */
-#define PACKAGE_BUILD_STRING "Regina 7.3.1 (Development build)"
+#define PACKAGE_BUILD_STRING "Regina 7.4 (Development build)"
 
 /* Define to the version of SnapPy that is bundled with Regina. */
-#define SNAPPY_VERSION "2.8"
+#define SNAPPY_VERSION "3.0.3"
 
