@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Python Interface                                                      *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -58,12 +56,12 @@ void addGroupPresentation(pybind11::module_& m) {
         .def(pybind11::init<>(), rdoc::__default)
         .def(pybind11::init<unsigned long, long>(), rdoc::__init)
         .def(pybind11::init<const GroupExpressionTerm&>(), rdoc::__copy)
-        .def(pybind11::self < pybind11::self, rdoc::__lt)
         .def("inverse", &GroupExpressionTerm::inverse, rdoc::inverse)
         .def(pybind11::self += pybind11::self, rdoc::__iadd)
     ;
     regina::python::add_output_ostream(c1);
-    regina::python::add_eq_operators(c1, rdoc::__eq, rdoc::__ne);
+    regina::python::add_eq_operators(c1, rdoc::__eq);
+    regina::python::add_cmp_operators(c1, rdoc::__cmp);
 
     RDOC_SCOPE_SWITCH(GroupExpression)
 
@@ -128,7 +126,7 @@ void addGroupPresentation(pybind11::module_& m) {
             rdoc::utf8)
     ;
     regina::python::add_output(c2);
-    regina::python::add_eq_operators(c2, rdoc::__eq, rdoc::__ne);
+    regina::python::add_eq_operators(c2, rdoc::__eq);
 
     regina::python::add_global_swap<GroupExpression>(m, rdoc::global_swap);
 
@@ -154,7 +152,9 @@ void addGroupPresentation(pybind11::module_& m) {
         .def("relations", &GroupPresentation::relations,
             pybind11::return_value_policy::reference_internal, rdoc::relations)
         .def("isValid", &GroupPresentation::isValid, rdoc::isValid)
-        .def("intelligentSimplify", &GroupPresentation::intelligentSimplify,
+        .def("simplify", &GroupPresentation::simplify,
+            rdoc::simplify)
+        .def("intelligentSimplify", &GroupPresentation::simplify, // deprecated
             rdoc::intelligentSimplify)
         .def("smallCancellation", &GroupPresentation::smallCancellation,
             rdoc::smallCancellation)
@@ -172,7 +172,8 @@ void addGroupPresentation(pybind11::module_& m) {
             pybind11::arg(), pybind11::arg(), pybind11::arg(),
             pybind11::arg("rightMult") = true,
             rdoc::nielsenCombine)
-        .def("intelligentNielsen", &GroupPresentation::intelligentNielsen,
+        .def("nielsen", &GroupPresentation::nielsen, rdoc::nielsen)
+        .def("intelligentNielsen", &GroupPresentation::nielsen, // deprecated
             rdoc::intelligentNielsen)
         .def("homologicalAlignment", &GroupPresentation::homologicalAlignment,
             rdoc::homologicalAlignment)
@@ -244,7 +245,7 @@ void addGroupPresentation(pybind11::module_& m) {
             pybind11::arg("groupVariable") = "g", rdoc::gap)
     ;
     regina::python::add_output(c3);
-    regina::python::add_eq_operators(c3, rdoc::__eq, rdoc::__ne);
+    regina::python::add_eq_operators(c3, rdoc::__eq);
 
     regina::python::add_global_swap<GroupPresentation>(m, rdoc::global_swap);
 
