@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Python Interface                                                      *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -76,11 +74,12 @@ void addHomGroupPresentation(pybind11::module_& m) {
         .def("invEvaluate", overload_cast<unsigned long>(
             &HomGroupPresentation::invEvaluate, pybind11::const_),
             rdoc::invEvaluate_2)
-        .def("intelligentSimplify",
-            &HomGroupPresentation::intelligentSimplify,
-            rdoc::intelligentSimplify)
-        .def("intelligentNielsen",
-            &HomGroupPresentation::intelligentNielsen, rdoc::intelligentNielsen)
+        .def("simplify", &HomGroupPresentation::simplify, rdoc::simplify)
+        .def("intelligentSimplify", // deprecated
+            &HomGroupPresentation::simplify, rdoc::intelligentSimplify)
+        .def("nielsen", &HomGroupPresentation::nielsen, rdoc::nielsen)
+        .def("intelligentNielsen", // deprecated
+            &HomGroupPresentation::nielsen, rdoc::intelligentNielsen)
         .def("smallCancellation",
             &HomGroupPresentation::smallCancellation, rdoc::smallCancellation)
         .def(pybind11::self * pybind11::self, rdoc::__mul)
@@ -93,7 +92,7 @@ void addHomGroupPresentation(pybind11::module_& m) {
             rdoc::markedAbelianisation)
     ;
     regina::python::add_output(c);
-    regina::python::add_eq_operators(c, rdoc::__eq, rdoc::__ne);
+    regina::python::add_eq_operators(c, rdoc::__eq);
 
     regina::python::add_global_swap<HomGroupPresentation>(m, rdoc::global_swap);
 
