@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Python Interface                                                      *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,14 +23,13 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
 #include <pybind11/pybind11.h>
+#include <pybind11/functional.h>
 #include "angle/anglestructures.h"
 #include "progress/progresstracker.h"
 #include "triangulation/dim3.h"
@@ -52,11 +51,11 @@ void addAngleStructures(pybind11::module_& m) {
 
     auto l = pybind11::class_<AngleStructures,
             std::shared_ptr<AngleStructures>>(m, "AngleStructures", rdoc_scope)
-        .def(pybind11::init<const Triangulation<3>&, bool, regina::AngleAlg,
-                ProgressTracker*>(),
+        .def(pybind11::init<const Triangulation<3>&, bool,
+                regina::Flags<regina::AngleAlg>, ProgressTracker*>(),
             pybind11::arg(),
             pybind11::arg("tautOnly") = false,
-            pybind11::arg("algHints") = regina::AS_ALG_DEFAULT,
+            pybind11::arg("algHints") = regina::AngleAlg::Default,
             pybind11::arg("tracker") = nullptr,
             pybind11::call_guard<GILScopedRelease>(),
             rdoc::__init)
@@ -80,18 +79,22 @@ void addAngleStructures(pybind11::module_& m) {
             rdoc::__iter__)
         .def("spansStrict", &AngleStructures::spansStrict, rdoc::spansStrict)
         .def("spansTaut", &AngleStructures::spansTaut, rdoc::spansTaut)
+        .def("sort", &AngleStructures::sort<const std::function<
+            bool(const regina::AngleStructure&,
+                const regina::AngleStructure&)>&>,
+            rdoc::sort)
     ;
     regina::python::add_output(l);
-    regina::python::packet_eq_operators(l, rdoc::__eq, rdoc::__ne);
+    regina::python::packet_eq_operators(l, rdoc::__eq);
     regina::python::add_packet_data(l);
 
     auto wrap = regina::python::add_packet_wrapper<AngleStructures>(
         m, "PacketOfAngleStructures");
     regina::python::add_packet_constructor<const Triangulation<3>&, bool,
-            regina::AngleAlg, ProgressTracker*>(wrap,
+            regina::Flags<regina::AngleAlg>, ProgressTracker*>(wrap,
         pybind11::arg(),
         pybind11::arg("tautOnly") = false,
-        pybind11::arg("algHints") = regina::AS_ALG_DEFAULT,
+        pybind11::arg("algHints") = regina::AngleAlg::Default,
         pybind11::arg("tracker") = nullptr,
         pybind11::call_guard<GILScopedRelease>(),
         rdoc::__init);
