@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Python Interface                                                      *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -50,10 +48,6 @@ void addFacePair(pybind11::module_& m) {
         .def("isBeforeStart", &FacePair::isBeforeStart, rdoc::isBeforeStart)
         .def("isPastEnd", &FacePair::isPastEnd, rdoc::isPastEnd)
         .def("complement", &FacePair::complement, rdoc::complement)
-        .def(pybind11::self < pybind11::self, rdoc::__lt)
-        .def(pybind11::self > pybind11::self, rdoc::__gt)
-        .def(pybind11::self <= pybind11::self, rdoc::__le)
-        .def(pybind11::self >= pybind11::self, rdoc::__ge)
         .def("inc", [](FacePair& p) {
             return p++;
         }, rdoc::__inc)
@@ -64,7 +58,8 @@ void addFacePair(pybind11::module_& m) {
         .def("oppositeEdge", &FacePair::oppositeEdge, rdoc::oppositeEdge)
     ;
     regina::python::add_output_ostream(c);
-    regina::python::add_eq_operators(c, rdoc::__eq, rdoc::__ne);
+    regina::python::add_eq_operators(c, rdoc::__eq);
+    regina::python::add_cmp_operators(c, rdoc::__cmp);
 
     RDOC_SCOPE_END
 }
