@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Python Interface                                                      *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -62,6 +60,15 @@ void addPentachoron4(pybind11::module_& m) {
         .def("unjoin", &Pentachoron<4>::unjoin,
             pybind11::return_value_policy::reference, rbase::unjoin)
         .def("isolate", &Pentachoron<4>::isolate, rbase::isolate)
+        .def("lock", &Pentachoron<4>::lock, rbase::lock)
+        .def("lockFacet", &Pentachoron<4>::lockFacet, rbase::lockFacet)
+        .def("unlock", &Pentachoron<4>::unlock, rbase::unlock)
+        .def("unlockFacet", &Pentachoron<4>::unlockFacet, rbase::unlockFacet)
+        .def("unlockAll", &Pentachoron<4>::unlockAll, rbase::unlockAll)
+        .def("isLocked", &Pentachoron<4>::isLocked, rbase::isLocked)
+        .def("isFacetLocked", &Pentachoron<4>::isFacetLocked,
+            rbase::isFacetLocked)
+        .def("lockMask", &Pentachoron<4>::lockMask, rbase::lockMask)
         .def("triangulation", &Pentachoron<4>::triangulation,
             rbase::triangulation)
         .def("component", &Pentachoron<4>::component,
