@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Python Interface                                                      *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -73,7 +71,7 @@ void addFace(pybind11::module_& m, pybind11::module_& internal,
         e.def("pentachoron", &FaceEmbedding<dim, subdim>::pentachoron,
             rbase2::pentachoron);
     regina::python::add_output(e);
-    regina::python::add_eq_operators(e, rbase::__eq, rbase::__ne);
+    regina::python::add_eq_operators(e, rbase::__eq);
 
     // We use the global scope here because all of Face's members are
     // inherited, and so Face's own docstring namespace does not exist.
@@ -107,8 +105,6 @@ void addFace(pybind11::module_& m, pybind11::module_& internal,
             pybind11::return_value_policy::reference, rbase::boundaryComponent)
         .def("isBoundary", &Face<dim, subdim>::isBoundary, rbase::isBoundary)
         .def_static("ordering", &Face<dim, subdim>::ordering, rbase2::ordering)
-        .def_static("faceNumber", &Face<dim, subdim>::faceNumber,
-            rbase2::faceNumber)
         .def_static("containsVertex", &Face<dim, subdim>::containsVertex,
             rbase2::containsVertex)
         .def_readonly_static("nFaces", &Face<dim, subdim>::nFaces)
@@ -117,6 +113,18 @@ void addFace(pybind11::module_& m, pybind11::module_& internal,
         .def_readonly_static("dimension", &Face<dim, subdim>::dimension)
         .def_readonly_static("subdimension", &Face<dim, subdim>::subdimension)
     ;
+    if constexpr (subdim == 1) {
+        c.def_static("faceNumber",
+            pybind11::overload_cast<regina::Perm<dim+1>>(
+                &Face<dim, subdim>::faceNumber),
+            rbase2::faceNumber);
+        c.def_static("faceNumber",
+            pybind11::overload_cast<int, int>(&Face<dim, subdim>::faceNumber),
+            rbase2::faceNumber);
+    } else {
+        c.def_static("faceNumber", &Face<dim, subdim>::faceNumber,
+            rbase2::faceNumber);
+    }
     if constexpr (subdim > 0) {
         c.def("face", &regina::python::face<Face<dim, subdim>, subdim, int>,
             pybind11::arg("lowerdim"), pybind11::arg("face"),
@@ -156,9 +164,26 @@ void addFace(pybind11::module_& m, pybind11::module_& internal,
         c.def("vertexMapping", &Face<dim, subdim>::vertexMapping,
             rbase::vertexMapping);
     }
-    if constexpr (dim - subdim == 1)
+    if constexpr (subdim == 1) {
+        c.def("isLoop", &Face<dim, subdim>::isLoop, rbase::isLoop);
+    }
+    if constexpr (subdim == 2) {
+        c.def("triangleType", &Face<dim, subdim>::triangleType,
+            rbase::triangleType);
+        c.def("triangleSubtype", &Face<dim, subdim>::triangleSubtype,
+            rbase::triangleSubtype);
+        c.def("formsMobiusBand", &Face<dim, subdim>::formsMobiusBand,
+            rbase::formsMobiusBand);
+        c.def("formsCone", &Face<dim, subdim>::formsCone, rbase::formsCone);
+    }
+    if constexpr (dim - subdim == 1) {
+        c.def("join", &Face<dim, subdim>::join, rbase::join);
+        c.def("lock", &Face<dim, subdim>::lock, rbase::lock);
+        c.def("unlock", &Face<dim, subdim>::unlock, rbase::unlock);
+        c.def("isLocked", &Face<dim, subdim>::isLocked, rbase::isLocked);
         c.def("inMaximalForest", &Face<dim, subdim>::inMaximalForest,
             rbase::inMaximalForest);
+    }
     regina::python::add_output(c);
     regina::python::add_eq_operators(c);
 
