@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Python Interface                                                      *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -43,9 +41,11 @@
 #include "../docstrings/triangulation/generic/triangulation.h"
 #include "../docstrings/triangulation/detail/triangulation.h"
 #include "../docstrings/utilities/snapshot.h"
+#include "../generic/isosig-bindings.h" // must come after docstrings
 
 using pybind11::overload_cast;
 using regina::AbelianGroup;
+using regina::Face;
 using regina::Isomorphism;
 using regina::MarkedAbelianGroup;
 using regina::MatrixInt;
@@ -61,7 +61,11 @@ void addTriangulation(pybind11::module_& m, pybind11::module_& internal,
             std::shared_ptr<Triangulation<dim>>>(m, name, rdoc_scope)
         .def(pybind11::init<>(), rdoc::__default)
         .def(pybind11::init<const Triangulation<dim>&>(), rdoc::__copy)
-        .def(pybind11::init<const Triangulation<dim>&, bool>(), rdoc::__init)
+        .def(pybind11::init<const Triangulation<dim>&, bool, bool>(),
+            pybind11::arg("src"),
+            pybind11::arg("cloneProps"),
+            pybind11::arg("cloneLocks") = true,
+            rdoc::__init)
         .def("isReadOnlySnapshot", &Triangulation<dim>::isReadOnlySnapshot,
             rbase2::isReadOnlySnapshot)
         .def("size", &Triangulation<dim>::size, rbase::size)
@@ -93,6 +97,10 @@ void addTriangulation(pybind11::module_& m, pybind11::module_& internal,
         .def("swap", &Triangulation<dim>::swap, rdoc::swap)
         .def("moveContentsTo", &Triangulation<dim>::moveContentsTo,
             rbase::moveContentsTo)
+        .def("hasLocks", &Triangulation<dim>::hasLocks, rbase::hasLocks)
+        .def("lockBoundary", &Triangulation<dim>::lockBoundary,
+            rbase::lockBoundary)
+        .def("unlockAll", &Triangulation<dim>::unlockAll, rbase::unlockAll)
         .def("countComponents", &Triangulation<dim>::countComponents,
             rbase::countComponents)
         .def("countBoundaryComponents",
@@ -141,19 +149,27 @@ void addTriangulation(pybind11::module_& m, pybind11::module_& internal,
             pybind11::return_value_policy::reference_internal, rbase::vertex)
         .def("edge", &Triangulation<dim>::edge,
             pybind11::return_value_policy::reference_internal, rbase::edge)
-        // Use static casts because GCC struggles with overload_cast here:
         .def("triangle",
-            static_cast<regina::Face<dim, 2>* (Triangulation<dim>::*)(size_t)>(
-                &Triangulation<dim>::triangle),
+            // gcc-10 struggles with casting: even a static_cast fails here
+            // because gcc-10 cannot handle the "auto" return type.
+            // Just use face<2>(), which triangle() is an alias for.
+            overload_cast<size_t>(&Triangulation<dim>::template face<2>,
+                pybind11::const_),
             pybind11::return_value_policy::reference_internal, rbase::triangle)
         .def("tetrahedron",
-            static_cast<regina::Face<dim, 3>* (Triangulation<dim>::*)(size_t)>(
-                &Triangulation<dim>::tetrahedron),
+            // gcc-10 struggles with casting: even a static_cast fails here
+            // because gcc-10 cannot handle the "auto" return type.
+            // Just use face<3>(), which tetrahedron() is an alias for.
+            overload_cast<size_t>(&Triangulation<dim>::template face<3>,
+                pybind11::const_),
             pybind11::return_value_policy::reference_internal,
             rbase::tetrahedron)
         .def("pentachoron",
-            static_cast<regina::Face<dim, 4>* (Triangulation<dim>::*)(size_t)>(
-                &Triangulation<dim>::pentachoron),
+            // gcc-10 struggles with casting: even a static_cast fails here
+            // because gcc-10 cannot handle the "auto" return type.
+            // Just use face<4>(), which pentachoron() is an alias for.
+            overload_cast<size_t>(&Triangulation<dim>::template face<4>,
+                pybind11::const_),
             pybind11::return_value_policy::reference_internal,
             rbase::pentachoron)
         .def("pairing", &Triangulation<dim>::pairing, rbase::pairing)
@@ -171,6 +187,11 @@ void addTriangulation(pybind11::module_& m, pybind11::module_& internal,
         .def("isOriented", &Triangulation<dim>::isOriented, rbase::isOriented)
         .def("isConnected", &Triangulation<dim>::isConnected,
             rbase::isConnected)
+        .def("reorderBFS", &Triangulation<dim>::reorderBFS,
+            pybind11::arg("reverse") = false, rbase::reorderBFS)
+        .def("randomiseLabelling", &Triangulation<dim>::randomiseLabelling,
+            pybind11::arg("preserveOrientation") = true,
+            rbase::randomiseLabelling)
         .def("orient", &Triangulation<dim>::orient, rbase::orient)
         .def("reflect", &Triangulation<dim>::reflect, rbase::reflect)
         .def("triangulateComponents",
@@ -183,8 +204,11 @@ void addTriangulation(pybind11::module_& m, pybind11::module_& internal,
         .def("fundamentalGroup", &Triangulation<dim>::fundamentalGroup,
             pybind11::return_value_policy::reference_internal,
             rbase::fundamentalGroup)
-        .def("simplifiedFundamentalGroup",
-            &Triangulation<dim>::simplifiedFundamentalGroup,
+        .def("setGroupPresentation",
+             &Triangulation<dim>::setGroupPresentation,
+            rbase::setGroupPresentation)
+        .def("simplifiedFundamentalGroup", // deprecated
+            &Triangulation<dim>::setGroupPresentation,
             rbase::simplifiedFundamentalGroup)
         .def("homology",
             static_cast<AbelianGroup (Triangulation<dim>::*)(int) const>(
@@ -203,10 +227,25 @@ void addTriangulation(pybind11::module_& m, pybind11::module_& internal,
         .def("dualToPrimal",
             static_cast<MatrixInt (Triangulation<dim>::*)(int) const>(
             &Triangulation<dim>::dualToPrimal), rbase::dualToPrimal)
+        .def("makeIdeal", &Triangulation<dim>::makeIdeal, rbase::makeIdeal)
         .def("finiteToIdeal", &Triangulation<dim>::finiteToIdeal,
             rbase::finiteToIdeal)
-        .def("makeDoubleCover", &Triangulation<dim>::makeDoubleCover,
-            rbase::makeDoubleCover)
+        .def("move20", &Triangulation<dim>::template move20<0>, rbase::move20)
+        .def("move20", &Triangulation<dim>::template move20<1>, rbase::move20)
+        .def("move20", &Triangulation<dim>::template move20<2>, rbase::move20)
+        .def("has20", &Triangulation<dim>::template has20<0>, rbase::has20)
+        .def("has20", &Triangulation<dim>::template has20<1>, rbase::has20)
+        .def("has20", &Triangulation<dim>::template has20<2>, rbase::has20)
+        .def("with20", &Triangulation<dim>::template with20<0>, rbase::with20)
+        .def("with20", &Triangulation<dim>::template with20<1>, rbase::with20)
+        .def("with20", &Triangulation<dim>::template with20<2>, rbase::with20)
+        .def("doubleCover", &Triangulation<dim>::doubleCover,
+            rbase::doubleCover)
+        .def("makeDoubleCover", [](Triangulation<dim>& tri) { // deprecated
+            tri = tri.doubleCover();
+        }, rbase::makeDoubleCover)
+        .def("doubleOverBoundary", &Triangulation<dim>::doubleOverBoundary,
+            rbase::doubleOverBoundary)
         .def("isIsomorphicTo", &Triangulation<dim>::isIsomorphicTo,
             rbase::isIsomorphicTo)
         .def("isContainedIn", &Triangulation<dim>::isContainedIn,
@@ -241,50 +280,116 @@ void addTriangulation(pybind11::module_& m, pybind11::module_& internal,
         }, pybind11::arg("other"), rbase::findAllSubcomplexesIn)
         .def("makeCanonical", &Triangulation<dim>::makeCanonical,
             rbase::makeCanonical)
-        .def("insertTriangulation", &Triangulation<dim>::insertTriangulation,
+        .def("insertTriangulation",
+            overload_cast<const Triangulation<dim>&>(
+                &Triangulation<dim>::insertTriangulation),
             rbase::insertTriangulation)
-        .def("isoSig", &Triangulation<dim>::template isoSig<>, rbase::isoSig)
-        .def("isoSig_EdgeDegrees", &Triangulation<dim>::
-            template isoSig<regina::IsoSigEdgeDegrees<dim>>, rbase::isoSig)
-        .def("isoSig_RidgeDegrees", &Triangulation<dim>::
-            template isoSig<regina::IsoSigRidgeDegrees<dim>>, rbase::isoSig)
-        .def("isoSigDetail", &Triangulation<dim>::template isoSigDetail<>,
-            rbase::isoSigDetail)
-        .def("isoSigDetail_EdgeDegrees", &Triangulation<dim>::
-            template isoSigDetail<regina::IsoSigEdgeDegrees<dim>>,
-            rbase::isoSigDetail)
-        .def("isoSigDetail_RidgeDegrees", &Triangulation<dim>::
-            template isoSigDetail<regina::IsoSigRidgeDegrees<dim>>,
-            rbase::isoSigDetail)
+        .def("sig", &Triangulation<dim>::template sig<>, rbase::sig)
+        // Variants of isoSig() are handled through isosig_options() below.
         .def_static("fromIsoSig", &Triangulation<dim>::fromIsoSig,
             rbase::fromIsoSig)
         .def_static("fromSig", &Triangulation<dim>::fromSig, rbase::fromSig)
         .def_static("isoSigComponentSize",
             &Triangulation<dim>::isoSigComponentSize,
             rbase::isoSigComponentSize)
-        .def("dumpConstruction", &Triangulation<dim>::dumpConstruction,
-            rbase::dumpConstruction)
+        .def("source", &Triangulation<dim>::source,
+            // The default should be Language::Current, but in C++ that
+            // evaluates to Language::Cxx.  We need it to evaluate to
+            // Language::Python (i.e., the Python implementation of
+            // Language::Current), and so we explicitly use that as our
+            // default instead.
+            pybind11::arg("language") = regina::Language::Python,
+            rbase::source)
+        .def("dumpConstruction", [](const Triangulation<dim>& tri) {
+            // Deprecated, so reimplement this ourselves.
+            return tri.source(regina::Language::Cxx);
+        }, rbase::dumpConstruction)
+        .def("dot", &Triangulation<dim>::dot,
+            pybind11::arg("labels") = false, rbase::dot)
         .def_static("fromGluings", [](size_t size, const std::vector<
                 std::tuple<size_t, int, size_t, regina::Perm<dim+1>>>& g) {
             return Triangulation<dim>::fromGluings(size, g.begin(), g.end());
         }, pybind11::arg("size"), pybind11::arg("gluings"), rbase::fromGluings)
         .def_readonly_static("dimension", &Triangulation<dim>::dimension)
     ;
+    #if defined(__GNUC__)
+    // The following routines are deprecated, but we still need to bind
+    // them.  Silence the inevitable deprecation warnings that will occur.
+    #pragma GCC diagnostic push
+    #if defined(__clang__)
+    #pragma GCC diagnostic ignored "-Wdeprecated"
+    #else
+    #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+    #endif
+    #endif
+    // For twoZeroMove(), the new function has a different name (move20).
+    // We therefore give a default value for "ignored" in order to preserve
+    // backward compatibility in cases where both boolean arguments are omitted.
+    c.def("twoZeroMove", &Triangulation<dim>::template twoZeroMove<0>,
+            pybind11::arg(),
+            pybind11::arg("ignored") = true,
+            pybind11::arg("perform") = true,
+            rbase::twoZeroMove) // deprecated
+        .def("twoZeroMove", &Triangulation<dim>::template twoZeroMove<1>,
+            pybind11::arg(),
+            pybind11::arg("ignored") = true,
+            pybind11::arg("perform") = true,
+            rbase::twoZeroMove) // deprecated
+        .def("twoZeroMove", &Triangulation<dim>::template twoZeroMove<2>,
+            pybind11::arg(),
+            pybind11::arg("ignored") = true,
+            pybind11::arg("perform") = true,
+            rbase::twoZeroMove) // deprecated
+    ;
+    #if defined(__GNUC__)
+    #pragma GCC diagnostic pop
+    #endif
     regina::for_constexpr<0, dim>([&c](auto k) {
-        c.def("translate", &Triangulation<dim>::template translate<k.value>,
+        c.def("translate", overload_cast<const regina::Face<dim, k>*>(
+                &Triangulation<dim>::template translate<k>, pybind11::const_),
             pybind11::return_value_policy::reference_internal,
             rbase::translate);
+        c.def("translate", overload_cast<const regina::FaceEmbedding<dim, k>&>(
+                &Triangulation<dim>::template translate<k>, pybind11::const_),
+            rbase::translate_2);
     });
+    c.def("translate", overload_cast<const regina::Simplex<dim>*>(
+            &Triangulation<dim>::template translate<dim>, pybind11::const_),
+        pybind11::return_value_policy::reference_internal, rbase::translate);
     regina::for_constexpr<0, dim + 1>([&c](auto k) {
-        c.def("pachner", &Triangulation<dim>::template pachner<k.value>,
-            pybind11::arg(),
-            pybind11::arg("check") = true,
-            pybind11::arg("perform") = true,
+        c.def("pachner",
+            overload_cast<Face<dim, k>*>(
+                &Triangulation<dim>::template pachner<k>),
             rbase::pachner);
+        c.def("hasPachner", &Triangulation<dim>::template hasPachner<k>,
+            rbase::hasPachner);
+        c.def("withPachner", &Triangulation<dim>::template withPachner<k>,
+            rbase::withPachner);
+        #if defined(__GNUC__)
+        // The following routines are deprecated, but we still need to bind
+        // them.  Silence the inevitable deprecation warnings that will occur.
+        #pragma GCC diagnostic push
+        #if defined(__clang__)
+        #pragma GCC diagnostic ignored "-Wdeprecated"
+        #else
+        #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+        #endif
+        #endif
+        c.def("pachner",
+            overload_cast<Face<dim, k>*, bool, bool>(
+                &Triangulation<dim>::template pachner<k>),
+            pybind11::arg(),
+            pybind11::arg("ignored"),
+            pybind11::arg("perform") = true,
+            rbase::pachner_2); // deprecated
+        #if defined(__GNUC__)
+        #pragma GCC diagnostic pop
+        #endif
     });
+    regina::python::isosig_options<dim>(c);
     regina::python::add_output(c);
     regina::python::add_tight_encoding(c);
-    regina::python::packet_eq_operators(c, rbase::__eq, rbase::__ne);
+    regina::python::packet_eq_operators(c, rbase::__eq);
     regina::python::add_packet_data(c);
 
     // The ListView classes for faces() are wrapped in face-bindings.h,
@@ -298,8 +403,12 @@ void addTriangulation(pybind11::module_& m, pybind11::module_& internal,
     auto wrap = regina::python::add_packet_wrapper<Triangulation<dim>>(
         m, (std::string("PacketOf") + name).c_str());
     regina::python::add_packet_constructor<>(wrap, rdoc::__default);
-    regina::python::add_packet_constructor<const Triangulation<dim>&, bool>(
-        wrap, rdoc::__init);
+    regina::python::add_packet_constructor<const Triangulation<dim>&, bool,
+        bool>(wrap,
+        pybind11::arg("src"),
+        pybind11::arg("cloneProps"),
+        pybind11::arg("cloneLocks") = true,
+        rdoc::__init);
 
     // We cannot use add_global_swap() here, since add_global_swap() cannot
     // resolve regina::swap to the templated triangulation swap function.
