@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Python Interface                                                      *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -34,6 +32,7 @@ namespace pybind11 { class module_; }
 
 void addExampleLink(pybind11::module_& m);
 void addLink(pybind11::module_& m, pybind11::module_& internal);
+void addSpatialLink(pybind11::module_& m, pybind11::module_& internal);
 void addModelLinkGraph(pybind11::module_& m, pybind11::module_& internal);
 void addTangle(pybind11::module_& m);
 
@@ -41,6 +40,7 @@ void addLinkClasses(pybind11::module_& m, pybind11::module_& internal) {
     addExampleLink(m);
     addLink(m, internal);
     addModelLinkGraph(m, internal);
+    addSpatialLink(m, internal);
     addTangle(m);
 }
 
