@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Python Interface                                                      *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -58,7 +56,13 @@ void addTangle(pybind11::module_& m) {
             pybind11::keep_alive<0, 1>(), rdoc::crossings)
         .def("begin", &Tangle::begin, rdoc::begin)
         .def("end", &Tangle::end, rdoc::end)
-        .def("translate", &Tangle::translate, rdoc::translate)
+        .def("translate",
+            overload_cast<const StrandRef&>(
+                &Tangle::translate, pybind11::const_),
+            rdoc::translate)
+        .def("translate",
+            overload_cast<Crossing*>(&Tangle::translate, pybind11::const_),
+            rdoc::translate_2)
         .def("swap", &Tangle::swap, rdoc::swap)
         .def("twist", &Tangle::twist,
             pybind11::arg("sign") = 1, rdoc::twist)
@@ -70,21 +74,23 @@ void addTangle(pybind11::module_& m) {
         .def("negate", &Tangle::negate, rdoc::negate)
         .def("numClosure", &Tangle::numClosure, rdoc::numClosure)
         .def("denClosure", &Tangle::denClosure, rdoc::denClosure)
-        .def("r1", &Tangle::r1,
-            pybind11::arg(),
-            pybind11::arg("check") = true,
-            pybind11::arg("perform") = true,
-            rdoc::r1)
-        .def("r2", overload_cast<StrandRef, bool, bool>(&Tangle::r2),
-            pybind11::arg(),
-            pybind11::arg("check") = true,
-            pybind11::arg("perform") = true,
-            rdoc::r2)
-        .def("r2", overload_cast<Crossing*, bool, bool>(&Tangle::r2),
-            pybind11::arg(),
-            pybind11::arg("check") = true,
-            pybind11::arg("perform") = true,
-            rdoc::r2_2)
+        .def("r1", overload_cast<Crossing*>(&Tangle::r1), rdoc::r1)
+        .def("r2", overload_cast<StrandRef>(&Tangle::r2), rdoc::r2)
+        .def("r2", overload_cast<Crossing*>(&Tangle::r2), rdoc::r2_2)
+        .def("hasR1", &Tangle::hasR1, rdoc::hasR1)
+        .def("hasR2",
+            overload_cast<StrandRef>(&Tangle::hasR2, pybind11::const_),
+            rdoc::hasR2)
+        .def("hasR2",
+            overload_cast<Crossing*>(&Tangle::hasR2, pybind11::const_),
+            rdoc::hasR2_2)
+        .def("withR1", &Tangle::withR1, rdoc::withR1)
+        .def("withR2",
+            overload_cast<StrandRef>(&Tangle::withR2, pybind11::const_),
+            rdoc::withR2)
+        .def("withR2",
+            overload_cast<Crossing*>(&Tangle::withR2, pybind11::const_),
+            rdoc::withR2_2)
         .def("simplifyToLocalMinimum", &Tangle::simplifyToLocalMinimum,
             pybind11::arg("perform") = true, rdoc::simplifyToLocalMinimum)
         .def("brief", overload_cast<>(&Tangle::brief, pybind11::const_),
@@ -104,8 +110,37 @@ void addTangle(pybind11::module_& m) {
             return Tangle::fromOrientedGauss(v.begin(), v.end());
         }, pybind11::arg("tokens"), rdoc::fromOrientedGauss_2)
     ;
+    #if defined(__GNUC__)
+    // The following routines are deprecated, but we still need to bind
+    // them.  Silence the inevitable deprecation warnings that will occur.
+    #pragma GCC diagnostic push
+    #if defined(__clang__)
+    #pragma GCC diagnostic ignored "-Wdeprecated"
+    #else
+    #pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+    #endif
+    #endif
+    c.def("r1", overload_cast<Crossing*, bool, bool>(&Tangle::r1),
+            pybind11::arg(),
+            pybind11::arg("ignored"),
+            pybind11::arg("perform") = true,
+            rdoc::r1_2) // deprecated
+        .def("r2", overload_cast<StrandRef, bool, bool>(&Tangle::r2),
+            pybind11::arg(),
+            pybind11::arg("ignored"),
+            pybind11::arg("perform") = true,
+            rdoc::r2_3) // deprecated
+        .def("r2", overload_cast<Crossing*, bool, bool>(&Tangle::r2),
+            pybind11::arg(),
+            pybind11::arg("ignored"),
+            pybind11::arg("perform") = true,
+            rdoc::r2_4) // deprecated
+    ;
+    #if defined(__GNUC__)
+    #pragma GCC diagnostic pop
+    #endif
     regina::python::add_output(c);
-    regina::python::add_eq_operators(c, rdoc::__eq, rdoc::__ne);
+    regina::python::add_eq_operators(c, rdoc::__eq);
 
     // No need to register the ListView class for crossings(), since
     // this is the same class used by Link.
