@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Python Interface                                                      *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,14 +23,16 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
-#include <pybind11/pybind11.h>
+#include "regina-config.h" // for REGINA_PYBIND11_VERSION
+#include "pybind11/pybind11.h"
+#if REGINA_PYBIND11_VERSION == 3
+#include <pybind11/native_enum.h>
+#endif
 #include <pybind11/operators.h>
 #include <pybind11/stl.h>
 #include "algebra/abeliangroup.h"
@@ -52,17 +54,17 @@ void addSFSpace(pybind11::module_& m) {
         .def(pybind11::init<const SFSFibre&>(), rdoc::__copy)
         .def_readwrite("alpha", &SFSFibre::alpha)
         .def_readwrite("beta", &SFSFibre::beta)
-        .def(pybind11::self < pybind11::self, rdoc::__lt)
     ;
     regina::python::add_output_ostream(f);
-    regina::python::add_eq_operators(f, rdoc::__eq, rdoc::__ne);
+    regina::python::add_eq_operators(f, rdoc::__eq);
+    regina::python::add_cmp_operators(f, rdoc::__cmp);
 
     RDOC_SCOPE_SWITCH(SFSpace)
 
     auto s = pybind11::class_<SFSpace, regina::Manifold>(m, "SFSpace",
             rdoc_scope)
         .def(pybind11::init<>(), rdoc::__default)
-        .def(pybind11::init<SFSpace::ClassType, unsigned long,
+        .def(pybind11::init<SFSpace::Class, unsigned long,
             unsigned long, unsigned long,
             unsigned long, unsigned long>(),
             pybind11::arg(), pybind11::arg(),
@@ -115,31 +117,54 @@ void addSFSpace(pybind11::module_& m) {
         .def("reduce", &SFSpace::reduce,
             pybind11::arg("mayReflect") = true, rdoc::reduce)
         .def("isLensSpace", &SFSpace::isLensSpace, rdoc::isLensSpace)
-        // Do not bind <, since this is already inherited from Manifold
-        // and we do not want to hide that more general version.
     ;
-    regina::python::add_eq_operators(s, rdoc::__eq, rdoc::__ne);
+    regina::python::add_eq_operators(s, rdoc::__eq);
+    // Do not bind comparison operators, since these are already inherited
+    // from Manifold and we do not want to hide those more general versions.
     regina::python::add_output(s);
 
     regina::python::add_global_swap<SFSpace>(m, rdoc::global_swap);
 
-    RDOC_SCOPE_INNER_BEGIN(ClassType)
+    RDOC_SCOPE_INNER_BEGIN(Class)
 
-    pybind11::enum_<SFSpace::ClassType>(s, "ClassType", rdoc_inner_scope)
-        .value("o1", SFSpace::o1, rdoc_inner::o1)
-        .value("o2", SFSpace::o2, rdoc_inner::o2)
-        .value("n1", SFSpace::n1, rdoc_inner::n1)
-        .value("n2", SFSpace::n2, rdoc_inner::n2)
-        .value("n3", SFSpace::n3, rdoc_inner::n3)
-        .value("n4", SFSpace::n4, rdoc_inner::n4)
-        .value("bo1", SFSpace::bo1, rdoc_inner::bo1)
-        .value("bo2", SFSpace::bo2, rdoc_inner::bo2)
-        .value("bn1", SFSpace::bn1, rdoc_inner::bn1)
-        .value("bn2", SFSpace::bn2, rdoc_inner::bn2)
-        .value("bn3", SFSpace::bn3, rdoc_inner::bn3)
-        .export_values()
+#if REGINA_PYBIND11_VERSION == 3
+    pybind11::native_enum<SFSpace::Class>(s, "Class", "enum.Enum",
+            rdoc_inner_scope)
+#elif REGINA_PYBIND11_VERSION == 2
+    pybind11::enum_<SFSpace::Class>(s, "Class", rdoc_inner_scope)
+#else
+    #error "Unsupported pybind11 version"
+#endif
+        .value("o1", SFSpace::Class::o1, rdoc_inner::o1)
+        .value("o2", SFSpace::Class::o2, rdoc_inner::o2)
+        .value("n1", SFSpace::Class::n1, rdoc_inner::n1)
+        .value("n2", SFSpace::Class::n2, rdoc_inner::n2)
+        .value("n3", SFSpace::Class::n3, rdoc_inner::n3)
+        .value("n4", SFSpace::Class::n4, rdoc_inner::n4)
+        .value("bo1", SFSpace::Class::bo1, rdoc_inner::bo1)
+        .value("bo2", SFSpace::Class::bo2, rdoc_inner::bo2)
+        .value("bn1", SFSpace::Class::bn1, rdoc_inner::bn1)
+        .value("bn2", SFSpace::Class::bn2, rdoc_inner::bn2)
+        .value("bn3", SFSpace::Class::bn3, rdoc_inner::bn3)
+#if REGINA_PYBIND11_VERSION == 3
+        .finalize()
+#endif
         ;
 
+    // Deprecated type alias and constants:
+    s.attr("ClassType") = s.attr("Class");
+    s.attr("o1") = SFSpace::Class::o1;
+    s.attr("o2") = SFSpace::Class::o2;
+    s.attr("n1") = SFSpace::Class::n1;
+    s.attr("n2") = SFSpace::Class::n2;
+    s.attr("n3") = SFSpace::Class::n3;
+    s.attr("n4") = SFSpace::Class::n4;
+    s.attr("bo1") = SFSpace::Class::bo1;
+    s.attr("bo2") = SFSpace::Class::bo2;
+    s.attr("bn1") = SFSpace::Class::bn1;
+    s.attr("bn2") = SFSpace::Class::bn2;
+    s.attr("bn3") = SFSpace::Class::bn3;
+
     RDOC_SCOPE_INNER_END
     RDOC_SCOPE_END
 }
