@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Python Interface                                                      *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -38,6 +36,7 @@
 #include "../docstrings/maths/integer.h"
 
 using pybind11::overload_cast;
+using regina::python::doc::common::neq_value;
 
 template <bool inf>
 void addIntegerBase(pybind11::module_& m, const char* className) {
@@ -68,6 +67,7 @@ void addIntegerBase(pybind11::module_& m, const char* className) {
         .def("stringValue", &Int::stringValue,
             pybind11::arg("base") = 10,
             rdoc::stringValue)
+        .def("str", &Int::str, rdoc::str)
         .def("pythonValue", [](const Int& i) {
             if (i.isNative())
                 return pybind11::int_(i.longValue());
@@ -81,16 +81,12 @@ void addIntegerBase(pybind11::module_& m, const char* className) {
         .def("swap", &Int::swap, rdoc::swap)
         .def(pybind11::self == AltInt(), rdoc::__eq_2)
         .def(pybind11::self == long(), rdoc::__eq_3)
-        .def(pybind11::self != AltInt(), rdoc::__ne_2)
-        .def(pybind11::self != long(), rdoc::__ne_3)
-        .def(pybind11::self < pybind11::self, rdoc::__lt)
-        .def(pybind11::self < long(), rdoc::__lt_2)
-        .def(pybind11::self > pybind11::self, rdoc::__gt)
-        .def(pybind11::self > long(), rdoc::__gt_2)
-        .def(pybind11::self <= pybind11::self, rdoc::__le)
-        .def(pybind11::self <= long(), rdoc::__le_2)
-        .def(pybind11::self >= pybind11::self, rdoc::__ge)
-        .def(pybind11::self >= long(), rdoc::__ge_2)
+        .def(pybind11::self != AltInt(), neq_value)
+        .def(pybind11::self != long(), neq_value)
+        .def(pybind11::self < long(), rdoc::__cmp_2)
+        .def(pybind11::self > long(), rdoc::__cmp_2)
+        .def(pybind11::self <= long(), rdoc::__cmp_2)
+        .def(pybind11::self >= long(), rdoc::__cmp_2)
         .def("inc", [](Int& i) {
             return i++;
         }, rdoc::__inc)
@@ -153,6 +149,7 @@ void addIntegerBase(pybind11::module_& m, const char* className) {
         .def("tryReduce", &Int::tryReduce, rdoc::tryReduce)
         .def(long() + pybind11::self, rdoc_global::__add)
         .def(long() * pybind11::self, rdoc_global::__mul)
+        .def_readonly_static("supportsInfinity", &Int::supportsInfinity)
         .def_readonly_static("zero", &Int::zero)
         .def_readonly_static("one", &Int::one)
     ;
@@ -160,9 +157,10 @@ void addIntegerBase(pybind11::module_& m, const char* className) {
         c.def_readonly_static("infinity", &Int::infinity);
 
     regina::python::add_tight_encoding(c, rdoc::tightEncoding,
-        rdoc::tightDecoding);
-    regina::python::add_eq_operators(c, rdoc::__eq, rdoc::__ne);
-    regina::python::add_output_ostream(c, regina::python::PYTHON_REPR_SLIM);
+        rdoc::tightDecoding, rdoc::hash);
+    regina::python::add_eq_operators(c, rdoc::__eq);
+    regina::python::add_cmp_operators(c, rdoc::__cmp);
+    regina::python::add_output_ostream(c, regina::python::ReprStyle::Slim);
 
     m.def("tightEncoding", static_cast<std::string(&)(Int)>(
         regina::tightEncoding), rdoc_global::tightEncoding);
