@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Python Interface                                                      *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,15 +23,15 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
 namespace pybind11 { class module_; }
 
+void add3D(pybind11::module_& m);
+void addArrow(pybind11::module_& m);
 void addBinom(pybind11::module_& m);
 void addMatrixOps(pybind11::module_& m);
 void addCyclotomic(pybind11::module_& m);
@@ -49,6 +49,7 @@ void addPerm6(pybind11::module_& m);
 void addPerm7(pybind11::module_& m);
 void addPerm(pybind11::module_& m);
 void addPermGroup(pybind11::module_& m);
+void addPermSn(pybind11::module_& m);
 void addPolynomial(pybind11::module_& m);
 void addPrimes(pybind11::module_& m);
 void addRational(pybind11::module_& m);
@@ -63,6 +64,7 @@ void addMathsClasses(pybind11::module_& m) {
     addMatrix2(m);
     addMatrix(m);
 
+    add3D(m);
     addBinom(m);
     addMatrixOps(m);
     addPrimes(m);
@@ -75,9 +77,11 @@ void addMathsClasses(pybind11::module_& m) {
     addPerm7(m);
     addPerm(m);
     addPermGroup(m);
+    addPermSn(m);
     addPolynomial(m);
     addCyclotomic(m);
     addLaurent(m);
     addLaurent2(m);
+    addArrow(m);
 }
 
