@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Python Interface                                                      *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -66,15 +64,24 @@ void addSatBlock(pybind11::module_& m) {
             pybind11::return_value_policy::reference, rdoc::nextBoundaryAnnulus)
         .def("abbr", &SatBlock::abbr,
             pybind11::arg("tex") = false, rdoc::abbr)
-        // We cannot bind the < operator in the normal way:
+        // We cannot bind the comparison operators in the normal way:
         // see https://github.com/pybind/pybind11/issues/1487 for details.
         .def("__lt__", [](const SatBlock& lhs, const SatBlock& rhs) {
             return lhs < rhs;
-        }, rdoc::__lt)
+        }, rdoc::__cmp)
+        .def("__le__", [](const SatBlock& lhs, const SatBlock& rhs) {
+            return lhs <= rhs;
+        }, rdoc::__cmp)
+        .def("__gt__", [](const SatBlock& lhs, const SatBlock& rhs) {
+            return lhs > rhs;
+        }, rdoc::__cmp)
+        .def("__ge__", [](const SatBlock& lhs, const SatBlock& rhs) {
+            return lhs >= rhs;
+        }, rdoc::__cmp)
     ;
     // Leave the output routines for subclasses to wrap, since __repr__
     // will include the (derived) class name.
-    regina::python::add_eq_operators(c, rdoc::__eq, rdoc::__ne);
+    regina::python::add_eq_operators(c, rdoc::__eq);
 
     RDOC_SCOPE_SWITCH(SatBlockModel)
 
@@ -86,7 +93,7 @@ void addSatBlock(pybind11::module_& m) {
         .def("block", &SatBlockModel::block, rdoc::block)
     ;
     regina::python::add_output(d);
-    regina::python::add_eq_operators(d, rdoc::__eq, rdoc::__ne);
+    regina::python::add_eq_operators(d, rdoc::__eq);
 
     regina::python::add_global_swap<SatBlockModel>(m, rdoc::global_swap);
 
