@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Qt User Interface                                                     *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -49,54 +47,54 @@ using regina::Triangle;
 namespace Coordinates {
     const char* name(NormalCoords coordSystem, bool capitalise) {
         if (capitalise) {
-            if (coordSystem == regina::NS_STANDARD)
+            if (coordSystem == NormalCoords::Standard)
                 return QT_TR_NOOP("Standard normal (tri-quad)");
-            if (coordSystem == regina::NS_AN_STANDARD)
+            if (coordSystem == NormalCoords::AlmostNormal)
                 return QT_TR_NOOP("Standard almost normal (tri-quad-oct)");
-            if (coordSystem == regina::NS_AN_LEGACY)
+            if (coordSystem == NormalCoords::LegacyAlmostNormal)
                 return QT_TR_NOOP("Legacy almost normal (pruned tri-quad-oct)");
-            if (coordSystem == regina::NS_QUAD)
+            if (coordSystem == NormalCoords::Quad)
                 return QT_TR_NOOP("Quad normal");
-            if (coordSystem == regina::NS_QUAD_CLOSED)
+            if (coordSystem == NormalCoords::QuadClosed)
                 return QT_TR_NOOP("Closed quad (non-spun)");
-            if (coordSystem == regina::NS_AN_QUAD_OCT)
+            if (coordSystem == NormalCoords::QuadOct)
                 return QT_TR_NOOP("Quad-oct almost normal");
-            if (coordSystem == regina::NS_AN_QUAD_OCT_CLOSED)
+            if (coordSystem == NormalCoords::QuadOctClosed)
                 return QT_TR_NOOP("Closed quad-oct (non-spun)");
-            if (coordSystem == regina::NS_EDGE_WEIGHT)
+            if (coordSystem == NormalCoords::Edge)
                 return QT_TR_NOOP("Edge weight");
-            if (coordSystem == regina::NS_TRIANGLE_ARCS)
+            if (coordSystem == NormalCoords::Arc)
                 return QT_TR_NOOP("Triangle arc");
 #ifdef SUPPORT_TONS
-            if (coordSystem == regina::NS_ORIENTED)
+            if (coordSystem == NormalCoords::Oriented)
                 return QT_TR_NOOP("Transversely oriented normal");
-            if (coordSystem == regina::NS_ORIENTED_QUAD)
+            if (coordSystem == NormalCoords::OrientedQuad)
                 return QT_TR_NOOP("Transversely oriented quad normal");
 #endif
             return QT_TR_NOOP("Unknown");
         } else {
-            if (coordSystem == regina::NS_STANDARD)
+            if (coordSystem == NormalCoords::Standard)
                 return QT_TR_NOOP("standard normal (tri-quad)");
-            if (coordSystem == regina::NS_AN_STANDARD)
+            if (coordSystem == NormalCoords::AlmostNormal)
                 return QT_TR_NOOP("standard almost normal (tri-quad-oct)");
-            if (coordSystem == regina::NS_AN_LEGACY)
+            if (coordSystem == NormalCoords::LegacyAlmostNormal)
                 return QT_TR_NOOP("legacy almost normal (pruned tri-quad-oct)");
-            if (coordSystem == regina::NS_QUAD)
+            if (coordSystem == NormalCoords::Quad)
                 return QT_TR_NOOP("quad normal");
-            if (coordSystem == regina::NS_QUAD_CLOSED)
+            if (coordSystem == NormalCoords::QuadClosed)
                 return QT_TR_NOOP("closed quad (non-spun)");
-            if (coordSystem == regina::NS_AN_QUAD_OCT)
+            if (coordSystem == NormalCoords::QuadOct)
                 return QT_TR_NOOP("quad-oct almost normal");
-            if (coordSystem == regina::NS_AN_QUAD_OCT_CLOSED)
+            if (coordSystem == NormalCoords::QuadOctClosed)
                 return QT_TR_NOOP("closed quad-oct (non-spun)");
-            if (coordSystem == regina::NS_EDGE_WEIGHT)
+            if (coordSystem == NormalCoords::Edge)
                 return QT_TR_NOOP("edge weight");
-            if (coordSystem == regina::NS_TRIANGLE_ARCS)
+            if (coordSystem == NormalCoords::Arc)
                 return QT_TR_NOOP("triangle arc");
 #ifdef SUPPORT_TONS
-            if (coordSystem == regina::NS_ORIENTED)
+            if (coordSystem == NormalCoords::Oriented)
                 return QT_TR_NOOP("transversely oriented normal");
-            if (coordSystem == regina::NS_ORIENTED_QUAD)
+            if (coordSystem == NormalCoords::OrientedQuad)
                 return QT_TR_NOOP("transversely oriented quad normal");
 #endif
             return QT_TR_NOOP("unknown");
@@ -105,54 +103,54 @@ namespace Coordinates {
 
     const char* adjective(NormalCoords coordSystem, bool capitalise) {
         if (capitalise) {
-            if (coordSystem == regina::NS_STANDARD)
+            if (coordSystem == NormalCoords::Standard)
                 return QT_TR_NOOP("Standard");
-            if (coordSystem == regina::NS_AN_STANDARD)
+            if (coordSystem == NormalCoords::AlmostNormal)
                 return QT_TR_NOOP("Almost normal");
-            if (coordSystem == regina::NS_AN_LEGACY)
+            if (coordSystem == NormalCoords::LegacyAlmostNormal)
                 return QT_TR_NOOP("Legacy");
-            if (coordSystem == regina::NS_QUAD)
+            if (coordSystem == NormalCoords::Quad)
                 return QT_TR_NOOP("Quad");
-            if (coordSystem == regina::NS_QUAD_CLOSED)
+            if (coordSystem == NormalCoords::QuadClosed)
                 return QT_TR_NOOP("Closed quad");
-            if (coordSystem == regina::NS_AN_QUAD_OCT)
+            if (coordSystem == NormalCoords::QuadOct)
                 return QT_TR_NOOP("Quad-oct");
-            if (coordSystem == regina::NS_AN_QUAD_OCT_CLOSED)
+            if (coordSystem == NormalCoords::QuadOctClosed)
                 return QT_TR_NOOP("Closed quad-oct");
-            if (coordSystem == regina::NS_EDGE_WEIGHT)
+            if (coordSystem == NormalCoords::Edge)
                 return QT_TR_NOOP("Edge weight");
-            if (coordSystem == regina::NS_TRIANGLE_ARCS)
+            if (coordSystem == NormalCoords::Arc)
                 return QT_TR_NOOP("Triangle arc");
 #ifdef SUPPORT_TONS
-            if (coordSystem == regina::NS_ORIENTED)
+            if (coordSystem == NormalCoords::Oriented)
                 return QT_TR_NOOP("Transversely oriented");
-            if (coordSystem == regina::NS_ORIENTED_QUAD)
+            if (coordSystem == NormalCoords::OrientedQuad)
                 return QT_TR_NOOP("Transversely oriented quad");
 #endif
             return QT_TR_NOOP("Unknown");
         } else {
-            if (coordSystem == regina::NS_STANDARD)
+            if (coordSystem == NormalCoords::Standard)
                 return QT_TR_NOOP("standard");
-            if (coordSystem == regina::NS_AN_STANDARD)
+            if (coordSystem == NormalCoords::AlmostNormal)
                 return QT_TR_NOOP("almost normal");
-            if (coordSystem == regina::NS_AN_LEGACY)
+            if (coordSystem == NormalCoords::LegacyAlmostNormal)
                 return QT_TR_NOOP("legacy");
-            if (coordSystem == regina::NS_QUAD)
+            if (coordSystem == NormalCoords::Quad)
                 return QT_TR_NOOP("quad");
-            if (coordSystem == regina::NS_QUAD_CLOSED)
+            if (coordSystem == NormalCoords::QuadClosed)
                 return QT_TR_NOOP("closed quad");
-            if (coordSystem == regina::NS_AN_QUAD_OCT)
+            if (coordSystem == NormalCoords::QuadOct)
                 return QT_TR_NOOP("quad-oct");
-            if (coordSystem == regina::NS_AN_QUAD_OCT_CLOSED)
+            if (coordSystem == NormalCoords::QuadOctClosed)
                 return QT_TR_NOOP("closed quad-oct");
-            if (coordSystem == regina::NS_EDGE_WEIGHT)
+            if (coordSystem == NormalCoords::Edge)
                 return QT_TR_NOOP("edge weight");
-            if (coordSystem == regina::NS_TRIANGLE_ARCS)
+            if (coordSystem == NormalCoords::Arc)
                 return QT_TR_NOOP("triangle arc");
 #ifdef SUPPORT_TONS
-            if (coordSystem == regina::NS_ORIENTED)
+            if (coordSystem == NormalCoords::Oriented)
                 return QT_TR_NOOP("transversely oriented");
-            if (coordSystem == regina::NS_ORIENTED_QUAD)
+            if (coordSystem == NormalCoords::OrientedQuad)
                 return QT_TR_NOOP("transversely oriented quad");
 #endif
             return QT_TR_NOOP("unknown");
@@ -161,19 +159,19 @@ namespace Coordinates {
 
     const char* name(HyperCoords coordSystem, bool capitalise) {
         if (capitalise) {
-            if (coordSystem == regina::HS_STANDARD)
+            if (coordSystem == HyperCoords::Standard)
                 return QT_TR_NOOP("Standard normal (tet-prism)");
-            if (coordSystem == regina::HS_PRISM)
+            if (coordSystem == HyperCoords::Prism)
                 return QT_TR_NOOP("Prism normal");
-            if (coordSystem == regina::HS_EDGE_WEIGHT)
+            if (coordSystem == HyperCoords::Edge)
                 return QT_TR_NOOP("Edge weight");
             return QT_TR_NOOP("Unknown");
         } else {
-            if (coordSystem == regina::HS_STANDARD)
+            if (coordSystem == HyperCoords::Standard)
                 return QT_TR_NOOP("standard normal (tet-prism)");
-            if (coordSystem == regina::HS_PRISM)
+            if (coordSystem == HyperCoords::Prism)
                 return QT_TR_NOOP("prism normal");
-            if (coordSystem == regina::HS_EDGE_WEIGHT)
+            if (coordSystem == HyperCoords::Edge)
                 return QT_TR_NOOP("edge weight");
             return QT_TR_NOOP("unknown");
         }
@@ -181,55 +179,55 @@ namespace Coordinates {
 
     const char* adjective(HyperCoords coordSystem, bool capitalise) {
         if (capitalise) {
-            if (coordSystem == regina::HS_STANDARD)
+            if (coordSystem == HyperCoords::Standard)
                 return QT_TR_NOOP("Standard");
-            if (coordSystem == regina::HS_PRISM)
+            if (coordSystem == HyperCoords::Prism)
                 return QT_TR_NOOP("Prism");
-            if (coordSystem == regina::HS_EDGE_WEIGHT)
+            if (coordSystem == HyperCoords::Edge)
                 return QT_TR_NOOP("Edge weight");
             return QT_TR_NOOP("Unknown");
         } else {
-            if (coordSystem == regina::HS_STANDARD)
+            if (coordSystem == HyperCoords::Standard)
                 return QT_TR_NOOP("standard");
-            if (coordSystem == regina::HS_PRISM)
+            if (coordSystem == HyperCoords::Prism)
                 return QT_TR_NOOP("prism");
-            if (coordSystem == regina::HS_EDGE_WEIGHT)
+            if (coordSystem == HyperCoords::Edge)
                 return QT_TR_NOOP("edge weight");
             return QT_TR_NOOP("unknown");
         }
     }
 
     bool generatesAlmostNormal(NormalCoords coordSystem) {
-        return (coordSystem == regina::NS_AN_STANDARD ||
-                coordSystem == regina::NS_AN_LEGACY ||
-                coordSystem == regina::NS_AN_QUAD_OCT ||
-                coordSystem == regina::NS_AN_QUAD_OCT_CLOSED);
+        return (coordSystem == NormalCoords::AlmostNormal ||
+                coordSystem == NormalCoords::LegacyAlmostNormal ||
+                coordSystem == NormalCoords::QuadOct ||
+                coordSystem == NormalCoords::QuadOctClosed);
     }
 
     size_t numColumns(NormalCoords coordSystem,
             const regina::Triangulation<3>& tri) {
-        if (coordSystem == regina::NS_STANDARD)
+        if (coordSystem == NormalCoords::Standard)
             return tri.size() * 7;
-        else if (coordSystem == regina::NS_AN_STANDARD)
+        else if (coordSystem == NormalCoords::AlmostNormal)
             return tri.size() * 10;
-        else if (coordSystem == regina::NS_AN_LEGACY)
+        else if (coordSystem == NormalCoords::LegacyAlmostNormal)
             return tri.size() * 10;
-        else if (coordSystem == regina::NS_QUAD)
+        else if (coordSystem == NormalCoords::Quad)
             return tri.size() * 3;
-        else if (coordSystem == regina::NS_QUAD_CLOSED)
+        else if (coordSystem == NormalCoords::QuadClosed)
             return tri.size() * 3;
-        else if (coordSystem == regina::NS_AN_QUAD_OCT)
+        else if (coordSystem == NormalCoords::QuadOct)
             return tri.size() * 6;
-        else if (coordSystem == regina::NS_AN_QUAD_OCT_CLOSED)
+        else if (coordSystem == NormalCoords::QuadOctClosed)
             return tri.size() * 6;
-        else if (coordSystem == regina::NS_EDGE_WEIGHT)
+        else if (coordSystem == NormalCoords::Edge)
             return tri.countEdges();
-        else if (coordSystem == regina::NS_TRIANGLE_ARCS)
+        else if (coordSystem == NormalCoords::Arc)
             return tri.countTriangles() * 3;
 #ifdef SUPPORT_TONS
-        else if (coordSystem == regina::NS_ORIENTED)
+        else if (coordSystem == NormalCoords::Oriented)
             return tri.size() * 14;
-        else if (coordSystem == regina::NS_ORIENTED_QUAD)
+        else if (coordSystem == NormalCoords::OrientedQuad)
             return tri.size() * 6;
 #endif
         else
@@ -238,11 +236,11 @@ namespace Coordinates {
 
     size_t numColumns(HyperCoords coordSystem,
             const regina::Triangulation<4>& tri) {
-        if (coordSystem == regina::HS_STANDARD)
+        if (coordSystem == HyperCoords::Standard)
             return tri.size() * 15;
-        else if (coordSystem == regina::HS_PRISM)
+        else if (coordSystem == HyperCoords::Prism)
             return tri.size() * 10;
-        else if (coordSystem == regina::HS_EDGE_WEIGHT)
+        else if (coordSystem == HyperCoords::Edge)
             return tri.countEdges();
         else
             return 0;
@@ -250,15 +248,15 @@ namespace Coordinates {
 
     QString columnName(NormalCoords coordSystem, size_t whichCoord,
             const regina::Triangulation<3>& tri) {
-        if (coordSystem == regina::NS_STANDARD) {
+        if (coordSystem == NormalCoords::Standard) {
             if (whichCoord % 7 < 4)
                 return QString("%1: %2").arg(whichCoord / 7).
                     arg(whichCoord % 7);
             else
                 return QString("%1: %2").arg(whichCoord / 7).
                     arg(regina::quadString[(whichCoord % 7) - 4].c_str());
-        } else if (coordSystem == regina::NS_AN_STANDARD ||
-                coordSystem == regina::NS_AN_LEGACY) {
+        } else if (coordSystem == NormalCoords::AlmostNormal ||
+                coordSystem == NormalCoords::LegacyAlmostNormal) {
             if (whichCoord % 10 < 4)
                 return QString("T%1: %2").arg(whichCoord / 10).
                     arg(whichCoord % 10);
@@ -268,26 +266,26 @@ namespace Coordinates {
             else
                 return QString("K%1: %2").arg(whichCoord / 10).
                     arg(regina::quadString[(whichCoord % 10) - 7].c_str());
-        } else if (coordSystem == regina::NS_QUAD ||
-                coordSystem == regina::NS_QUAD_CLOSED) {
+        } else if (coordSystem == NormalCoords::Quad ||
+                coordSystem == NormalCoords::QuadClosed) {
             return QString("%1: %2").arg(whichCoord / 3).
                 arg(regina::quadString[whichCoord % 3].c_str());
-        } else if (coordSystem == regina::NS_AN_QUAD_OCT ||
-                coordSystem == regina::NS_AN_QUAD_OCT_CLOSED) {
+        } else if (coordSystem == NormalCoords::QuadOct ||
+                coordSystem == NormalCoords::QuadOctClosed) {
             if (whichCoord % 6 < 3)
                 return QString("Q%1: %2").arg(whichCoord / 6).
                     arg(regina::quadString[whichCoord % 6].c_str());
             else
                 return QString("K%1: %2").arg(whichCoord / 6).
                     arg(regina::quadString[(whichCoord % 6) - 3].c_str());
-        } else if (coordSystem == regina::NS_EDGE_WEIGHT) {
+        } else if (coordSystem == NormalCoords::Edge) {
             if (! tri.edge(whichCoord)->isBoundary())
                 return QString::number(whichCoord);
             else if (ReginaPrefSet::global().displayUnicode)
                 return QString("%1: \u2202").arg(whichCoord);
             else
                 return QString("%1 (B)").arg(whichCoord);
-        } else if (coordSystem == regina::NS_TRIANGLE_ARCS) {
+        } else if (coordSystem == NormalCoords::Arc) {
             if (! tri.triangle(whichCoord / 3)->isBoundary())
                 return QString("%1: %2").
                     arg(whichCoord / 3).arg(whichCoord % 3);
@@ -298,7 +296,7 @@ namespace Coordinates {
                 return QString("B %1: %2").
                     arg(whichCoord / 3).arg(whichCoord % 3);
 #ifdef SUPPORT_TONS
-        } else if (coordSystem == regina::NS_ORIENTED) {
+        } else if (coordSystem == NormalCoords::Oriented) {
             size_t stdCoord = whichCoord / 2;
             if (whichCoord % 2 == 0) {
                 // "true" orientation.
@@ -320,7 +318,7 @@ namespace Coordinates {
                         arg(regina::quadDefn[(stdCoord % 7) - 4][2]).
                         arg(regina::quadDefn[(stdCoord % 7) - 4][3]);
             }
-        } else if (coordSystem == regina::NS_ORIENTED_QUAD) {
+        } else if (coordSystem == NormalCoords::OrientedQuad) {
             size_t quadCoord = whichCoord / 2;
             if (whichCoord % 2 == 0) {
                 // "true" orientation.
@@ -342,7 +340,7 @@ namespace Coordinates {
 
     QString columnName(HyperCoords coordSystem, size_t whichCoord,
             const regina::Triangulation<4>& tri) {
-        if (coordSystem == regina::HS_STANDARD) {
+        if (coordSystem == HyperCoords::Standard) {
             if (whichCoord % 15 < 5)
                 return QString("%1: %2").arg(whichCoord / 15).
                     arg(whichCoord % 15);
@@ -352,13 +350,13 @@ namespace Coordinates {
                         [(whichCoord % 15) - 5][0]).
                     arg(regina::FaceNumbering<4, 1>::edgeVertex
                         [(whichCoord % 15) - 5][1]);
-        } else if (coordSystem == regina::HS_PRISM) {
+        } else if (coordSystem == HyperCoords::Prism) {
             return QString("%1: %2%3").arg(whichCoord / 10).
                 arg(regina::FaceNumbering<4, 1>::edgeVertex
                     [whichCoord % 10][0]).
                 arg(regina::FaceNumbering<4, 1>::edgeVertex
                     [whichCoord % 10][1]);
-        } else if (coordSystem == regina::HS_EDGE_WEIGHT) {
+        } else if (coordSystem == HyperCoords::Edge) {
             if (! tri.edge(whichCoord)->isBoundary())
                 return QString::number(whichCoord);
             else if (ReginaPrefSet::global().displayUnicode)
@@ -372,7 +370,7 @@ namespace Coordinates {
 
     QString columnDesc(NormalCoords coordSystem, size_t whichCoord,
             const QObject *context, const regina::Triangulation<3>& tri) {
-        if (coordSystem == regina::NS_STANDARD) {
+        if (coordSystem == NormalCoords::Standard) {
             if (whichCoord % 7 < 4)
                 return context->tr("Tetrahedron %1, triangle about vertex %2").
                     arg(whichCoord / 7).arg(whichCoord % 7);
@@ -380,8 +378,8 @@ namespace Coordinates {
                 return context->tr("Tetrahedron %1, quad splitting vertices %2").
                     arg(whichCoord / 7).
                     arg(regina::quadString[(whichCoord % 7) - 4].c_str());
-        } else if (coordSystem == regina::NS_AN_STANDARD ||
-                coordSystem == regina::NS_AN_LEGACY) {
+        } else if (coordSystem == NormalCoords::AlmostNormal ||
+                coordSystem == NormalCoords::LegacyAlmostNormal) {
             if (whichCoord % 10 < 4)
                 return context->tr("Tetrahedron %1, triangle about vertex %2").
                     arg(whichCoord / 10).arg(whichCoord % 10);
@@ -393,13 +391,13 @@ namespace Coordinates {
                 return context->tr("Tetrahedron %1, oct partitioning vertices %2").
                     arg(whichCoord / 10).
                     arg(regina::quadString[(whichCoord % 10) - 7].c_str());
-        } else if (coordSystem == regina::NS_QUAD ||
-                coordSystem == regina::NS_QUAD_CLOSED) {
+        } else if (coordSystem == NormalCoords::Quad ||
+                coordSystem == NormalCoords::QuadClosed) {
             return context->tr("Tetrahedron %1, quad splitting vertices %2").
                 arg(whichCoord / 3).
                 arg(regina::quadString[whichCoord % 3].c_str());
-        } else if (coordSystem == regina::NS_AN_QUAD_OCT ||
-                coordSystem == regina::NS_AN_QUAD_OCT_CLOSED) {
+        } else if (coordSystem == NormalCoords::QuadOct ||
+                coordSystem == NormalCoords::QuadOctClosed) {
             if (whichCoord % 6 < 3)
                 return context->tr("Tetrahedron %1, quad splitting vertices %2").
                     arg(whichCoord / 6).
@@ -408,14 +406,14 @@ namespace Coordinates {
                 return context->tr("Tetrahedron %1, oct partitioning vertices %2").
                     arg(whichCoord / 6).
                     arg(regina::quadString[(whichCoord % 6) - 3].c_str());
-        } else if (coordSystem == regina::NS_EDGE_WEIGHT) {
+        } else if (coordSystem == NormalCoords::Edge) {
             if (tri.edge(whichCoord)->isBoundary())
                 return context->tr("Weight of (boundary) edge %1").
                     arg(whichCoord);
             else
                 return context->tr("Weight of (internal) edge %1").
                     arg(whichCoord);
-        } else if (coordSystem == regina::NS_TRIANGLE_ARCS) {
+        } else if (coordSystem == NormalCoords::Arc) {
             if (! tri.triangle(whichCoord / 3)->isBoundary())
                 return context->tr(
                     "Arcs on (internal) triangle %1 crossing triangle vertex %2").
@@ -425,7 +423,7 @@ namespace Coordinates {
                     "Arcs on (boundary) triangle %1 crossing triangle vertex %2").
                     arg(whichCoord / 3).arg(whichCoord % 3);
 #ifdef SUPPORT_TONS
-        } else if (coordSystem == regina::NS_ORIENTED) {
+        } else if (coordSystem == NormalCoords::Oriented) {
             size_t stdCoord = whichCoord / 2;
             if (whichCoord % 2 == 0) {
                 // "true" orientation.
@@ -455,7 +453,7 @@ namespace Coordinates {
                         arg(regina::quadDefn[(stdCoord % 7) - 4][2]).
                         arg(regina::quadDefn[(stdCoord % 7) - 4][3]);
             }
-        } else if (coordSystem == regina::NS_ORIENTED_QUAD) {
+        } else if (coordSystem == NormalCoords::OrientedQuad) {
             size_t quadCoord = whichCoord / 2;
             if (whichCoord % 2 == 0) {
                 // "true" orientation.
@@ -481,7 +479,7 @@ namespace Coordinates {
 
     QString columnDesc(HyperCoords coordSystem, size_t whichCoord,
             const QObject *context, const regina::Triangulation<4>& tri) {
-        if (coordSystem == regina::HS_STANDARD) {
+        if (coordSystem == HyperCoords::Standard) {
             if (whichCoord % 15 < 5)
                 return context->tr(
                     "Pentachoron %1, tetrahedron about vertex %2").
@@ -494,7 +492,7 @@ namespace Coordinates {
                         [(whichCoord % 15) - 5][0]).
                     arg(regina::FaceNumbering<4, 1>::edgeVertex
                         [(whichCoord % 15) - 5][1]);
-        } else if (coordSystem == regina::HS_PRISM) {
+        } else if (coordSystem == HyperCoords::Prism) {
             return context->tr(
                 "Pentachoron %1, prism beside vertices %2 and %3").
                 arg(whichCoord / 10).
@@ -502,7 +500,7 @@ namespace Coordinates {
                     [whichCoord % 10][0]).
                 arg(regina::FaceNumbering<4, 1>::edgeVertex
                     [whichCoord % 10][1]);
-        } else if (coordSystem == regina::HS_EDGE_WEIGHT) {
+        } else if (coordSystem == HyperCoords::Edge) {
             if (tri.edge(whichCoord)->isBoundary())
                 return context->tr("Weight of (boundary) edge %1").
                     arg(whichCoord);
@@ -516,34 +514,34 @@ namespace Coordinates {
 
     regina::LargeInteger getCoordinate(NormalCoords coordSystem,
             const regina::NormalSurface& surface, size_t whichCoord) {
-        if (coordSystem == regina::NS_STANDARD) {
+        if (coordSystem == NormalCoords::Standard) {
             if (whichCoord % 7 < 4)
                 return surface.triangles(whichCoord / 7, whichCoord % 7);
             else
                 return surface.quads(whichCoord / 7, (whichCoord % 7) - 4);
-        } else if (coordSystem == regina::NS_AN_STANDARD ||
-                coordSystem == regina::NS_AN_LEGACY) {
+        } else if (coordSystem == NormalCoords::AlmostNormal ||
+                coordSystem == NormalCoords::LegacyAlmostNormal) {
             if (whichCoord % 10 < 4)
                 return surface.triangles(whichCoord / 10, whichCoord % 10);
             else if (whichCoord % 10 < 7)
                 return surface.quads(whichCoord / 10, (whichCoord % 10) - 4);
             else
                 return surface.octs(whichCoord / 10, (whichCoord % 10) - 7);
-        } else if (coordSystem == regina::NS_QUAD ||
-                coordSystem == regina::NS_QUAD_CLOSED) {
+        } else if (coordSystem == NormalCoords::Quad ||
+                coordSystem == NormalCoords::QuadClosed) {
             return surface.quads(whichCoord / 3, whichCoord % 3);
-        } else if (coordSystem == regina::NS_AN_QUAD_OCT ||
-                coordSystem == regina::NS_AN_QUAD_OCT_CLOSED) {
+        } else if (coordSystem == NormalCoords::QuadOct ||
+                coordSystem == NormalCoords::QuadOctClosed) {
             if (whichCoord % 6 < 3)
                 return surface.quads(whichCoord / 6, whichCoord % 6);
             else
                 return surface.octs(whichCoord / 6, (whichCoord % 6) - 3);
-        } else if (coordSystem == regina::NS_EDGE_WEIGHT) {
+        } else if (coordSystem == NormalCoords::Edge) {
             return surface.edgeWeight(whichCoord);
-        } else if (coordSystem == regina::NS_TRIANGLE_ARCS) {
+        } else if (coordSystem == NormalCoords::Arc) {
             return surface.arcs(whichCoord / 3, whichCoord % 3);
 #ifdef SUPPORT_TONS
-        } else if (coordSystem == regina::NS_ORIENTED) {
+        } else if (coordSystem == NormalCoords::Oriented) {
             bool orientation = (whichCoord % 2 == 0);
             whichCoord /= 2;
             if (whichCoord % 7 < 4)
@@ -552,7 +550,7 @@ namespace Coordinates {
             else
                 return surface.orientedQuads(
                     whichCoord / 7, (whichCoord % 7) - 4, orientation);
-        } else if (coordSystem == regina::NS_ORIENTED_QUAD) {
+        } else if (coordSystem == NormalCoords::OrientedQuad) {
             bool orientation = (whichCoord % 2 == 0);
             whichCoord /= 2;
             return surface.orientedQuads(
@@ -565,14 +563,14 @@ namespace Coordinates {
 
     regina::LargeInteger getCoordinate(HyperCoords coordSystem,
             const regina::NormalHypersurface& surface, size_t whichCoord) {
-        if (coordSystem == regina::HS_STANDARD) {
+        if (coordSystem == HyperCoords::Standard) {
             if (whichCoord % 15 < 5)
                 return surface.tetrahedra(whichCoord / 15, whichCoord % 15);
             else
                 return surface.prisms(whichCoord / 15, (whichCoord % 15) - 5);
-        } else if (coordSystem == regina::HS_PRISM) {
+        } else if (coordSystem == HyperCoords::Prism) {
             return surface.prisms(whichCoord / 10, whichCoord % 10);
-        } else if (coordSystem == regina::HS_EDGE_WEIGHT) {
+        } else if (coordSystem == HyperCoords::Edge) {
             return surface.edgeWeight(whichCoord);
         }
 
