@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Qt User Interface                                                     *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -49,47 +47,51 @@
 
 namespace {
     bool has41(regina::Vertex<3>* v) {
-        return v->triangulation().pachner(v, true, false);
+        return v->triangulation().hasPachner(v);
     }
 
     bool has20v(regina::Vertex<3>* v) {
-        return v->triangulation().twoZeroMove(v, true, false);
+        return v->triangulation().has20(v);
     }
 
     bool has32(regina::Edge<3>* e) {
-        return e->triangulation().pachner(e, true, false);
+        return e->triangulation().hasPachner(e);
     }
 
     bool has20e(regina::Edge<3>* e) {
-        return e->triangulation().twoZeroMove(e, true, false);
+        return e->triangulation().has20(e);
     }
 
     bool hasCloseBook(regina::Edge<3>* e) {
-        return e->triangulation().closeBook(e, true, false);
+        return e->triangulation().hasCloseBook(e);
     }
 
     bool hasCollapseEdge(regina::Edge<3>* e) {
-        return e->triangulation().collapseEdge(e, true, false);
+        return e->triangulation().hasCollapseEdge(e);
     }
 
     bool has44(regina::Edge<3>* e, int axis) {
-        return e->triangulation().fourFourMove(e, axis, true, false);
+        return e->triangulation().has44(e, axis);
     }
 
     bool has21(regina::Edge<3>* e, int end) {
-        return e->triangulation().twoOneMove(e, end, true, false);
+        return e->triangulation().has21(e, end);
     }
 
     bool has23(regina::Triangle<3>* f) {
-        return f->triangulation().pachner(f, true, false);
+        return f->triangulation().hasPachner(f);
+    }
+
+    bool has14(regina::Tetrahedron<3>* f) {
+        return f->triangulation().hasPachner(f);
     }
 
     bool hasOpenBook(regina::Triangle<3>* f) {
-        return f->triangulation().openBook(f, true, false);
+        return f->triangulation().hasOpenBook(f);
     }
 
     bool hasShellBoundary(regina::Tetrahedron<3>* t) {
-        return t->triangulation().shellBoundary(t, true, false);
+        return t->triangulation().hasShellBoundary(t);
     }
 }
 
@@ -109,7 +111,6 @@ EltMoveDialog3::EltMoveDialog3(QWidget* parent,
     dialogLayout->addWidget(overview);
 
     auto* layout = new QGridLayout();
-      //, 10, 2, 0 /* margin */, spacingHint());
     dialogLayout->addLayout(layout);
 
     use41 = new QRadioButton(tr("4-1"), this);
@@ -117,8 +118,8 @@ EltMoveDialog3::EltMoveDialog3(QWidget* parent,
         "triangulation.<p>"
         "A <i>4-1 move</i> involves replacing four tetrahedra joined at "
         "a vertex of degree four with a single tetrahedron.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered in the adjacent drop-down list.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered in the adjacent drop-down list.</qt>"));
     layout->addWidget(use41, 0, 0);
     use32 = new QRadioButton(tr("&3-2"), this);
     use32->setWhatsThis( tr("<qt>Perform a 3-2 move on this "
@@ -126,8 +127,8 @@ EltMoveDialog3::EltMoveDialog3(QWidget* parent,
         "A <i>3-2 move</i> involves replacing three tetrahedra joined along "
         "an edge of degree three with two tetrahedra joined along a "
         "single triangle.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered in the adjacent drop-down list.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered in the adjacent drop-down list.</qt>"));
     layout->addWidget(use32, 1, 0);
     use23 = new QRadioButton(tr("&2-3"), this);
     use23->setWhatsThis( tr("<qt>Perform a 2-3 move on this "
@@ -135,15 +136,16 @@ EltMoveDialog3::EltMoveDialog3(QWidget* parent,
         "A <i>2-3 move</i> involves replacing two tetrahedra joined along "
         "a single triangle with three tetrahedra joined along an edge of "
         "degree three.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered in the adjacent drop-down list.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered in the adjacent drop-down list.</qt>"));
     layout->addWidget(use23, 2, 0);
     use14 = new QRadioButton(tr("1-4"), this);
     use14->setWhatsThis( tr("<qt>Perform a 1-4 move on this "
         "triangulation.<p>"
         "A <i>1-4 move</i> involves replacing one tetrahedron "
         "with four tetrahedra that meet at a new internal vertex.<p>"
-        "This move will never change the underlying 3-manifold.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered in the adjacent drop-down list.</qt>"));
     layout->addWidget(use14, 3, 0);
     use44 = new QRadioButton(tr("4-4"), this);
     use44->setWhatsThis( tr("<qt>Perform a 4-4 move on this "
@@ -151,24 +153,24 @@ EltMoveDialog3::EltMoveDialog3(QWidget* parent,
         "A <i>4-4 move</i> involves replacing four tetrahedra joined along "
         "an edge of degree four with four new tetrahedra joined along a "
         "different edge in a different position.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered in the adjacent drop-down list.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered in the adjacent drop-down list.</qt>"));
     layout->addWidget(use44, 4, 0);
     use20e = new QRadioButton(tr("2-0 (&edge)"), this);
     use20e->setWhatsThis( tr("<qt>Perform a 2-0 edge move on this "
         "triangulation.<p>"
         "A <i>2-0 edge move</i> involves taking two tetrahedra joined along "
         "an edge of degree two and squashing them flat.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered in the adjacent drop-down list.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered in the adjacent drop-down list.</qt>"));
     layout->addWidget(use20e, 5, 0);
     use20v = new QRadioButton(tr("2-0 (&vertex)"), this);
     use20v->setWhatsThis(tr("<qt>Perform a 2-0 vertex move on this "
         "triangulation.<p>"
         "A <i>2-0 vertex move</i> involves taking two tetrahedra meeting at "
         "a vertex of degree two and squashing them together.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered in the adjacent drop-down list.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered in the adjacent drop-down list.</qt>"));
     layout->addWidget(use20v, 6, 0);
     use21 = new QRadioButton(tr("2-&1"), this);
     use21->setWhatsThis( tr("<qt>Perform a 2-1 move on this "
@@ -176,8 +178,8 @@ EltMoveDialog3::EltMoveDialog3(QWidget* parent,
         "A <i>2-1 move</i> involves taking a tetrahedron joined to itself "
         "about an edge of degree one and merging it with an adjacent "
         "tetrahedron.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered in the adjacent drop-down list.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered in the adjacent drop-down list.</qt>"));
     layout->addWidget(use21, 7, 0);
     useOpenBook = new QRadioButton(tr("&Open book"), this);
     useOpenBook->setWhatsThis( tr("<qt>Perform a book opening "
@@ -188,8 +190,8 @@ EltMoveDialog3::EltMoveDialog3(QWidget* parent,
         "thereby &quot;opening "
         "out&quot; that triangle and exposing two more tetrahedron faces to "
         "the boundary.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered in the adjacent drop-down list.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered in the adjacent drop-down list.</qt>"));
     layout->addWidget(useOpenBook, 8, 0);
     useCloseBook = new QRadioButton(tr("C&lose book"), this);
     useCloseBook->setWhatsThis( tr("<qt>Perform a book closing "
@@ -198,8 +200,8 @@ EltMoveDialog3::EltMoveDialog3(QWidget* parent,
         "of the triangulation and folding together the two boundary triangles "
         "on either side.  The aim of this move is to simplify the boundary "
         "of the triangulation.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered in the adjacent drop-down list.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered in the adjacent drop-down list.</qt>"));
     layout->addWidget(useCloseBook, 9, 0);
     useShellBdry = new QRadioButton(tr("&Shell boundary"), this);
     useShellBdry->setWhatsThis( tr("<qt>Perform a boundary shelling "
@@ -207,8 +209,8 @@ EltMoveDialog3::EltMoveDialog3(QWidget* parent,
         "A <i>boundary shelling move</i> simply involves removing a "
         "tetrahedron that meets the triangulation boundary along one or "
         "more of its faces.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered in the adjacent drop-down list.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered in the adjacent drop-down list.</qt>"));
     layout->addWidget(useShellBdry, 10, 0);
     useCollapseEdge = new QRadioButton(tr("&Collapse edge"), this);
     useCollapseEdge->setWhatsThis( tr("<qt>Collapse an edge in this "
@@ -216,8 +218,8 @@ EltMoveDialog3::EltMoveDialog3(QWidget* parent,
         "<i>Collapsing an edge</i> involves taking an edge between two "
         "distinct vertices and collapsing that edge to a point.  Any "
         "tetrahedra containing that edge will be flattened into triangles.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered in the adjacent drop-down list.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered in the adjacent drop-down list.</qt>"));
     layout->addWidget(useCollapseEdge, 11, 0);
 
     box41 = new FaceChooser<3, 0>(tri, &has41, this, false);
@@ -225,30 +227,30 @@ EltMoveDialog3::EltMoveDialog3(QWidget* parent,
         "the 4-1 move will be performed.  The vertex numbers in this list "
         "correspond to the vertex numbers seen when viewing the "
         "triangulation skeleton.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered.</qt>"));
     layout->addWidget(box41, 0, 1);
     box32 = new FaceChooser<3, 1>(tri, &has32, this, false);
     box32->setWhatsThis( tr("<qt>Select the degree three edge about which "
         "the 3-2 move will be performed.  The edge numbers in this list "
         "correspond to the edge numbers seen when viewing the "
         "triangulation skeleton.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered.</qt>"));
     layout->addWidget(box32, 1, 1);
     box23 = new FaceChooser<3, 2>(tri, &has23, this, false);
     box23->setWhatsThis( tr("<qt>Select the triangle about which "
         "the 2-3 move will be performed.  The triangle numbers in this list "
         "correspond to the triangle numbers seen when viewing the "
         "triangulation skeleton.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered.</qt>"));
     layout->addWidget(box23, 2, 1);
-    box14 = new SimplexChooser<3>(tri, nullptr, this, false);
+    box14 = new SimplexChooser<3>(tri, &has14, this, false);
     box14->setWhatsThis( tr("<qt>Select the tetrahedron upon which "
         "the 1-4 move will be performed.<p>"
-        "All tetrahedra are offered here, since "
-        "this move will never change the underlying 3-manifold.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered.</qt>"));
     layout->addWidget(box14, 3, 1);
     box44 = new EdgeIntChooser(tri, 0, 1, tr("axis"), &has44, this, false);
     box44->setWhatsThis( tr("<qt>Select the degree four edge about which "
@@ -257,24 +259,24 @@ EltMoveDialog3::EltMoveDialog3(QWidget* parent,
         "two different ways in which this can be done).<p>"
         "The edge numbers in this list correspond to the edge numbers seen "
         "when viewing the triangulation skeleton.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered.</qt>"));
     layout->addWidget(box44, 4, 1);
     box20e = new FaceChooser<3, 1>(tri, &has20e, this, false);
     box20e->setWhatsThis( tr("<qt>Select the degree two edge about which "
         "the 2-0 edge move will be performed.  The edge numbers in this list "
         "correspond to the edge numbers seen when viewing the "
         "triangulation skeleton.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered.</qt>"));
     layout->addWidget(box20e, 5, 1);
     box20v = new FaceChooser<3, 0>(tri, &has20v, this, false);
     box20v->setWhatsThis( tr("<qt>Select the degree two vertex about "
         "which the 2-0 vertex move will be performed.  The vertex numbers "
         "in this list correspond to the vertex numbers seen when viewing the "
         "triangulation skeleton.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered.</qt>"));
     layout->addWidget(box20v, 6, 1);
     box21 = new EdgeIntChooser(tri, 0, 1, tr("end"), &has21, this, false);
     box21->setWhatsThis( tr("<qt>Select the degree one edge about which "
@@ -283,39 +285,39 @@ EltMoveDialog3::EltMoveDialog3(QWidget* parent,
         "its neighbour.<p>"
         "The edge numbers in this list correspond to the edge numbers seen "
         "when viewing the triangulation skeleton.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered.</qt>"));
     layout->addWidget(box21, 7, 1);
     boxOpenBook = new FaceChooser<3, 2>(tri, &hasOpenBook, this, false);
     boxOpenBook->setWhatsThis( tr("<qt>Select the internal triangle "
         "that should be opened out.  The triangle numbers in this list "
         "correspond to the triangle numbers seen when viewing the "
         "triangulation skeleton.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered.</qt>"));
     layout->addWidget(boxOpenBook, 8, 1);
     boxCloseBook = new FaceChooser<3, 1>(tri, &hasCloseBook, this, false);
     boxCloseBook->setWhatsThis( tr("<qt>Select the boundary edge "
         "around which the book will be closed.  The edge numbers in this list "
         "correspond to the edge numbers seen when viewing the "
         "triangulation skeleton.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered.</qt>"));
     layout->addWidget(boxCloseBook, 9, 1);
     boxShellBdry = new SimplexChooser<3>(tri, &hasShellBoundary, this, false);
     boxShellBdry->setWhatsThis( tr("<qt>Select the boundary tetrahedron "
         "that should be removed.  The tetrahedron numbers in this list "
         "are the usual tetrahedron numbers seen in the gluings editor.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered.</qt>"));
     layout->addWidget(boxShellBdry, 10, 1);
     boxCollapseEdge = new FaceChooser<3, 1>(tri, &hasCollapseEdge, this, false);
     boxCollapseEdge->setWhatsThis( tr("<qt>Select the edge joining "
         "two distinct vertices that should be collapsed.  "
         "The edge numbers in this list correspond to the edge numbers seen "
         "when viewing the triangulation skeleton.<p>"
-        "Only moves that do not change the underlying 3-manifold are "
-        "offered.</qt>"));
+        "Only moves that do not change the underlying 3-manifold or "
+        "violate any locks are offered.</qt>"));
     layout->addWidget(boxCollapseEdge, 11, 1);
 
     moveTypes = new QButtonGroup();
@@ -377,19 +379,19 @@ void EltMoveDialog3::clicked(QAbstractButton* btn) {
     } else if (use44->isChecked()) {
         std::pair<regina::Edge<3>*, int> s = box44->selected();
         if (s.first)
-            tri->fourFourMove(s.first, s.second);
+            tri->move44(s.first, s.second);
     } else if (use20e->isChecked()) {
         regina::Edge<3>* e = box20e->selected();
         if (e)
-            tri->twoZeroMove(e);
+            tri->move20(e);
     } else if (use20v->isChecked()) {
         regina::Vertex<3>* v = box20v->selected();
         if (v)
-            tri->twoZeroMove(v);
+            tri->move20(v);
     } else if (use21->isChecked()) {
         std::pair<regina::Edge<3>*, int> s = box21->selected();
         if (s.first)
-            tri->twoOneMove(s.first, s.second);
+            tri->move21(s.first, s.second);
     } else if (useOpenBook->isChecked()) {
         regina::Triangle<3>* f = boxOpenBook->selected();
         if (f)
