@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Qt User Interface                                                     *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -63,7 +61,7 @@ void HyperModel::rebuildUnicode() {
         emit dataChanged(index(0, 2, QModelIndex()),
             index(surfaces_->size() - 1, 2, QModelIndex()));
 
-    if (coordSystem_ == regina::HS_EDGE_WEIGHT)
+    if (coordSystem_ == regina::HyperCoords::Edge)
         emit headerDataChanged(Qt::Horizontal, propertyColCount(),
             columnCount(QModelIndex()) - 1);
 }
@@ -281,7 +279,7 @@ QVariant HyperModel::headerData(int section, Qt::Orientation orientation,
             return Coordinates::columnName(coordSystem_, section - propCols,
                 surfaces_->triangulation());
     } else if (role == Qt::ForegroundRole) {
-        if (coordSystem_ == regina::HS_EDGE_WEIGHT)
+        if (coordSystem_ == regina::HyperCoords::Edge)
             if (section >= propertyColCount() && surfaces_->triangulation().
                     edge(section - propertyColCount())->isBoundary())
                 return QColor(Qt::darkYellow);
@@ -313,7 +311,7 @@ bool HyperModel::setData(const QModelIndex& index, const QVariant& value,
         // At present, NormalHypersurface::setName() does not fire a change
         // event (since a normal surface does not know what list it
         // belongs to).  Fire it here instead.
-        regina::NormalHypersurfaces::ChangeEventSpan span(*surfaces_);
+        NormalHypersurfaces::PacketChangeSpan span(*surfaces_);
         const_cast<regina::NormalHypersurface&>((*surfaces_)[index.row()]).
             setName(value.toString().toUtf8().constData());
         return true;
@@ -384,7 +382,7 @@ QString HyperModel::propertyColDesc(int whichCol) const {
 }
 
 HyperCoordinateUI::HyperCoordinateUI(
-        regina::PacketOf<regina::NormalHypersurfaces>* packet,
+        regina::PacketOf<NormalHypersurfaces>* packet,
         PacketTabbedUI* useParentUI) :
         PacketEditorTab(useParentUI), surfaces(packet),
         currentlyResizing(false) {
@@ -455,15 +453,15 @@ HyperCoordinateUI::HyperCoordinateUI(
 
     actTriangulate = new QAction(this);
     actTriangulate->setText(tr("&Triangulate Hypersurface"));
-    actTriangulate->setToolTip(tr("Builds a 3-manifold triangulation "
-        "of the selected hypersurface"));
+    actTriangulate->setIcon(ReginaSupport::regIcon("packet_triangulation3"));
+    actTriangulate->setToolTip(tr("Triangulate the selected hypersurface"));
     actTriangulate->setEnabled(false);
-    actTriangulate->setWhatsThis(tr("<qt>Builds a 3-manifold triangulation "
+    actTriangulate->setWhatsThis(tr("Builds a 3-manifold triangulation "
         "of the selected hypersurface.<p>"
         "The new triangulation will have the same <i>topology</i> as the "
         "selected hypersurface.  However, it will be simplified, "
         "which means that information about the <i>combinatorics</i> "
-        "of the hypersurface will be lost.</qt>"));
+        "of the hypersurface will be lost."));
     connect(actTriangulate, SIGNAL(triggered()), this, SLOT(triangulate()));
     surfaceActionList.push_back(actTriangulate);
 
