@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Qt User Interface                                                     *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -64,12 +62,21 @@ class LinkPolynomialUI : public QObject, public PacketViewerTab {
          * Internal components
          */
         QWidget* ui;
+        QWidget* alexanderBlock;
+        QWidget* homflyBlock;
+        QWidget* affineIndexBlock;
+        QWidget* arrowBlock;
+        QLabel* alexander;
         QLabel* jones;
         QLabel* homfly;
         QLabel* bracket;
+        QLabel* affineIndex;
+        QLabel* arrow;
+        QAbstractButton* btnAlexander;
         QAbstractButton* btnJones;
         QAbstractButton* btnHomfly;
         QAbstractButton* btnBracket;
+        QAbstractButton* btnArrow;
         QRadioButton* btnAZ;
         QRadioButton* btnLM;
 
@@ -91,9 +98,11 @@ class LinkPolynomialUI : public QObject, public PacketViewerTab {
         /**
          * Calculate properties.
          */
+        void calculateAlexander();
         void calculateJones();
         void calculateHomfly();
         void calculateBracket();
+        void calculateArrow();
 
         /**
          * Change the display style.
@@ -108,15 +117,24 @@ class LinkPolynomialUI : public QObject, public PacketViewerTab {
         /**
          * Support clipboard actions.
          */
+        void contextAlexander(const QPoint& pos);
         void contextJones(const QPoint& pos);
         void contextHomfly(const QPoint& pos);
         void contextBracket(const QPoint& pos);
+        void contextAffineIndex(const QPoint& pos);
+        void contextArrow(const QPoint& pos);
+        void copyAlexander();
         void copyJones();
         void copyHomfly();
         void copyBracket();
+        void copyAffineIndex();
+        void copyArrow();
+        void copyAlexanderPlain();
         void copyJonesPlain();
         void copyHomflyPlain();
         void copyBracketPlain();
+        void copyAffineIndexPlain();
+        void copyArrowPlain();
 
     private:
         /**
