@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Qt User Interface                                                     *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -190,15 +188,15 @@ QVariant Vertex3Model::data(const QModelIndex& index, int role) const {
                 return index.row();
             case 1: {
                 switch (item->linkType()) {
-                    case Vertex<3>::SPHERE:
+                    case Vertex<3>::Link::Sphere:
                         return QString();
-                    case Vertex<3>::DISC:
+                    case Vertex<3>::Link::Disc:
                         return tr("Bdry");
-                    case Vertex<3>::TORUS:
+                    case Vertex<3>::Link::Torus:
                         return tr("Ideal: Torus");
-                    case Vertex<3>::KLEIN_BOTTLE:
+                    case Vertex<3>::Link::KleinBottle:
                         return tr("Ideal: Klein bottle");
-                    case Vertex<3>::NON_STANDARD_CUSP: {
+                    case Vertex<3>::Link::NonStandardCusp: {
                         if (item->isLinkOrientable())
                             return tr("Ideal: Genus %1 orbl").arg(
                                 1 - (item->linkEulerChar() / 2));
@@ -206,7 +204,7 @@ QVariant Vertex3Model::data(const QModelIndex& index, int role) const {
                             return tr("Ideal: Genus %1 non-orbl").arg(
                                 2 - item->linkEulerChar());
                     }
-                    case Vertex<3>::INVALID:
+                    case Vertex<3>::Link::Invalid:
                         return tr("Invalid");
                     default:
                         return tr("Unknown");
@@ -297,11 +295,11 @@ QVariant Edge3Model::data(const QModelIndex& index, int role) const {
                 return index.row();
             case 1:
                 if (! item->isValid())
-                    return tr("Invalid");
+                    return item->isLoop() ? tr("Invalid, loop") : tr("Invalid");
                 else if (item->isBoundary())
-                    return tr("Bdry");
+                    return item->isLoop() ? tr("Bdry, loop") : tr("Bdry");
                 else
-                    return QString();
+                    return item->isLoop() ? tr("Loop") : QString();
             case 2:
                 return static_cast<unsigned>(item->degree());
             case 3:
@@ -389,22 +387,22 @@ QVariant Triangle3Model::data(const QModelIndex& index, int role) const {
                 if (item->isBoundary())
                     prefix = tr("(Bdry) ");
 
-                int type = item->type();
-                if (type == Triangle<3>::TRIANGLE)
+                auto type = item->triangleType();
+                if (type == regina::TriangleType::Triangle)
                     return prefix + tr("Triangle");
-                if (type == Triangle<3>::SCARF)
+                if (type == regina::TriangleType::Scarf)
                     return prefix + tr("Scarf");
-                if (type == Triangle<3>::PARACHUTE)
+                if (type == regina::TriangleType::Parachute)
                     return prefix + tr("Parachute");
-                if (type == Triangle<3>::MOBIUS)
+                if (type == regina::TriangleType::Mobius)
                     return prefix + tr("Möbius band");
-                if (type == Triangle<3>::CONE)
+                if (type == regina::TriangleType::Cone)
                     return prefix + tr("Cone");
-                if (type == Triangle<3>::HORN)
+                if (type == regina::TriangleType::Horn)
                     return prefix + tr("Horn");
-                if (type == Triangle<3>::DUNCEHAT)
+                if (type == regina::TriangleType::DunceHat)
                     return prefix + tr("Dunce hat");
-                if (type == Triangle<3>::L31)
+                if (type == regina::TriangleType::L31)
                     return prefix + tr("L(3,1)");
                 return prefix + tr("UNKNOWN");
             }
@@ -776,9 +774,9 @@ QVariant Edge2Model::data(const QModelIndex& index, int role) const {
                 return index.row();
             case 1:
                 if (item->isBoundary())
-                    return tr("Bdry");
+                    return item->isLoop() ? tr("Bdry, loop") : tr("Bdry");
                 else
-                    return QString();
+                    return item->isLoop() ? tr("Loop") : QString();
             case 2:
                 return static_cast<unsigned>(item->degree());
             case 3:
@@ -1120,17 +1118,19 @@ QVariant Edge4Model::data(const QModelIndex& index, int role) const {
                 return index.row();
             case 1:
                 if (! item->isValid()) {
+                    QString suffix = (item->isLoop() ? tr(", loop") :
+                        QString());
                     if (item->hasBadIdentification())
-                        return tr("Invalid (reverse gluing)");
+                        return tr("Invalid (reverse gluing)") + suffix;
                     else if (item->hasBadLink())
-                        return tr("Invalid (bad link)");
+                        return tr("Invalid (bad link)") + suffix;
                     else // should never happen
-                        return tr("Invalid (unknown reason)");
+                        return tr("Invalid (unknown reason)") + suffix;
                 }
                 else if (item->isBoundary())
-                    return tr("Bdry");
+                    return item->isLoop() ? tr("Bdry, loop") : tr("Bdry");
                 else
-                    return QString();
+                    return item->isLoop() ? tr("Loop") : QString();
             case 2:
                 return static_cast<unsigned>(item->degree());
             case 3:
@@ -1213,13 +1213,33 @@ QVariant Triangle4Model::data(const QModelIndex& index, int role) const {
         switch (index.column()) {
             case 0:
                 return index.row();
-            case 1:
+            case 1: {
                 if (! item->isValid())
                     return tr("Invalid");
-                else if (item->isBoundary())
-                    return tr("Bdry");
-                else
-                    return QString();
+
+                QString prefix;
+                if (item->isBoundary())
+                    prefix = tr("(Bdry) ");
+
+                auto type = item->triangleType();
+                if (type == regina::TriangleType::Triangle)
+                    return prefix + tr("Triangle");
+                if (type == regina::TriangleType::Scarf)
+                    return prefix + tr("Scarf");
+                if (type == regina::TriangleType::Parachute)
+                    return prefix + tr("Parachute");
+                if (type == regina::TriangleType::Mobius)
+                    return prefix + tr("Möbius band");
+                if (type == regina::TriangleType::Cone)
+                    return prefix + tr("Cone");
+                if (type == regina::TriangleType::Horn)
+                    return prefix + tr("Horn");
+                if (type == regina::TriangleType::DunceHat)
+                    return prefix + tr("Dunce hat");
+                if (type == regina::TriangleType::L31)
+                    return prefix + tr("L(3,1)");
+                return prefix + tr("UNKNOWN");
+            }
             case 2:
                 return static_cast<unsigned>(item->degree());
             case 3:
