@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Qt User Interface                                                     *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -261,82 +259,89 @@ SnapPeaShapesUI::SnapPeaShapesUI(
     actRandomise = new QAction(this);
     actRandomise->setText(tr("&Randomise"));
     actRandomise->setIcon(ReginaSupport::regIcon("randomise"));
-    actRandomise->setToolTip(tr(
-        "Randomise this triangulation"));
-    actRandomise->setWhatsThis(tr("Randomise this triangulation.  "
+    actRandomise->setToolTip(tr("Randomise the triangulation"));
+    actRandomise->setWhatsThis(tr("Randomises this triangulation.  "
         "The manifold will be randomly retriangulated using local moves "
         "that preserve the topology."));
     triActionList.push_back(actRandomise);
     requiresNonNull.push_back(actRandomise);
     connect(actRandomise, SIGNAL(triggered()), this, SLOT(randomise()));
 
-    auto* actCanonise = new QAction(this);
-    actCanonise->setText(tr("&Canonical Retriangulation"));
+    sep = new QAction(this);
+    sep->setSeparator(true);
+    triActionList.push_back(sep);
+
+    actFill = new QAction(this);
+    actFill->setText(tr("Build &Filled Manifold..."));
+    actFill->setIconText(tr("Fill"));
+    actFill->setIcon(ReginaSupport::regIcon("fill"));
+    actFill->setToolTip(tr("Build a new manifold that fills one or all cusps"));
+    actFill->setWhatsThis(tr("Builds a new manifold that permanently "
+        "fills either all cusps or one chosen cusp, using the current "
+        "filling coefficients.<p>"
+        "This triangulation will not be changed – the filled manifold "
+        "will be added as a new triangulation beneath it in the packet tree."));
+    triActionList.push_back(actFill);
+    requiresNonNull.push_back(actFill);
+    connect(actFill, SIGNAL(triggered()), this, SLOT(fill()));
+
+    actCanonise = new QAction(this);
+    actCanonise->setText(tr("Build &Canonical Retriangulation"));
+    actCanonise->setIconText(tr("Canonical"));
     actCanonise->setIcon(ReginaSupport::regIcon("canonical"));
-    actCanonise->setToolTip(tr(
-        "Build the canonical retriangulation of the canonical "
-        "cell decomposition"));
-    actCanonise->setWhatsThis(tr("<qt>Build the canonical retriangulation "
-        "of the canonical cell decomposition.<p>"
-        "The canonical cell decomposition is described in "
+    actCanonise->setToolTip(tr("Build the canonical retriangulation"));
+    actCanonise->setWhatsThis(tr("Builds the canonical retriangulation "
+        "of the canonical cell decomposition, as described in "
         "<i>Convex hulls and isometries of cusped hyperbolic 3-manifolds</i>, "
         "Jeffrey R. Weeks, Topology Appl. 52 (1993), 127-149.<p>"
-        "If this canonical cell decomposition contains non-tetrahedron "
+        "If the canonical cell decomposition contains non-tetrahedron "
         "cells, then SnapPea will canonically retriangulate it by introducing "
-        "internal vertices.  See the user handbook for details.<p>"
+        "internal vertices.<p>"
         "<b>Warning:</b> SnapPea might not compute the canonical "
         "cell decomposition correctly.  However, it does guarantee "
-        "that the resulting manifold is homeomorphic to the original.</qt>"));
+        "that the resulting manifold is homeomorphic to the original.<p>"
+        "This triangulation will not be changed – the canonical "
+        "retriangulation will be added beneath it in the packet tree."));
     triActionList.push_back(actCanonise);
     requiresNonNull.push_back(actCanonise);
     connect(actCanonise, SIGNAL(triggered()), this, SLOT(canonise()));
 
-    auto* actVertexLinks = new QAction(this);
-    actVertexLinks->setText(tr("&Vertex Links..."));
-    actVertexLinks->setIcon(ReginaSupport::regIcon("vtxlinks"));
-    actVertexLinks->setToolTip(tr(
-        "Build a 2-manifold triangulation from a vertex link"));
-    actVertexLinks->setWhatsThis(tr("<qt>Build a 2-manifold triangulation "
-        "from the link of a vertex of this triangulation.<p>"
-        "If <i>V</i> is a vertex, then the <i>link</i> of <i>V</i> is the "
-        "frontier of a small regular neighbourhood of <i>V</i>.  "
-        "The triangles that make up this link sit inside "
-        "the tetrahedron corners that meet together at <i>V</i>.</qt>"));
-    triActionList.push_back(actVertexLinks);
-    requiresNonNull.push_back(actVertexLinks);
-    connect(actVertexLinks, SIGNAL(triggered()), this, SLOT(vertexLinks()));
-
-    actFill = new QAction(this);
-    actFill->setText(tr("Permanently &Fill Cusps..."));
-    actFill->setIcon(ReginaSupport::regIcon("fill"));
-    actFill->setToolTip(tr(
-        "Permanently fill one cusp or all cusps of this manifold"));
-    actFill->setWhatsThis(tr("<qt>Retriangulate to permanently "
-        "fill either one cusp or all cusps of this manifold.  "
-        "The original triangulation will be left untouched.</qt>"));
-    triActionList.push_back(actFill);
-    requiresNonNull.push_back(actFill);
-    connect(actFill, SIGNAL(triggered()), this, SLOT(fill()));
+    actToRegina = new QAction(this);
+    actToRegina->setText(tr("&Convert to Regina"));
+    actToRegina->setIconText(tr("Regina"));
+    actToRegina->setIcon(ReginaSupport::regIcon("packet_triangulation3"));
+    actToRegina->setToolTip(tr("Convert this to a Regina triangulation"));
+    actToRegina->setWhatsThis(tr("Converts this into one of Regina's native "
+        "3-manifold triangulations.  This original SnapPea triangulation "
+        "will be kept, and the new Regina triangulation will be added "
+        "beneath it in the packet tree.<p>"
+        "A native Regina triangulation allows you to use Regina's "
+        "full suite of tools to edit and analyse the triangulation.  "
+        "However, the native Regina "
+        "triangulation will lose any SnapPea-specific "
+        "information (such as peripheral curves on cusps)."));
+    triActionList.push_back(actToRegina);
+    requiresNonNull.push_back(actToRegina);
+    connect(actToRegina, SIGNAL(triggered()), this, SLOT(toRegina()));
 
     sep = new QAction(this);
     sep->setSeparator(true);
     triActionList.push_back(sep);
 
-    actToRegina = new QAction(this);
-    actToRegina->setText(tr("&Convert to Regina"));
-    actToRegina->setIcon(ReginaSupport::regIcon("packet_triangulation3"));
-    actToRegina->setToolTip(tr("Convert this to a Regina triangulation"));
-    actToRegina->setWhatsThis(tr("<qt>Convert this to one of Regina's native "
-        "3-manifold triangulations.  The original SnapPea triangulation "
-        "will be kept and left untouched.<p>"
-        "A native Regina triangulation will allow you to use Regina's "
-        "full suite of tools to edit and analyse the triangulation.  "
-        "However, the native Regina "
-        "triangulation will lose any SnapPea-specific "
-        "information (such as peripheral curves on cusps).</qt>"));
-    triActionList.push_back(actToRegina);
-    requiresNonNull.push_back(actToRegina);
-    connect(actToRegina, SIGNAL(triggered()), this, SLOT(toRegina()));
+    actVertexLinks = new QAction(this);
+    actVertexLinks->setText(tr("&Vertex Links..."));
+    actVertexLinks->setIconText(tr("Vertex Links"));
+    actVertexLinks->setIcon(ReginaSupport::regIcon("vtxlinks"));
+    actVertexLinks->setToolTip(tr("Build a chosen vertex link"));
+    actVertexLinks->setWhatsThis(tr("Builds a 2-manifold triangulation "
+        "from the link of a chosen vertex of this triangulation.<p>"
+        "If <i>V</i> is a vertex, then the <i>link</i> of <i>V</i> is the "
+        "frontier of a small regular neighbourhood of <i>V</i>.  "
+        "The triangles that make up this link sit inside "
+        "the tetrahedron corners that meet together at <i>V</i>."));
+    triActionList.push_back(actVertexLinks);
+    requiresNonNull.push_back(actVertexLinks);
+    connect(actVertexLinks, SIGNAL(triggered()), this, SLOT(vertexLinks()));
 
     // Tidy up.
     refresh();
@@ -351,9 +356,19 @@ const std::vector<QAction*>& SnapPeaShapesUI::getPacketTypeActions() {
 }
 
 void SnapPeaShapesUI::fillToolBar(QToolBar* bar) {
-    bar->addAction(actRandomise);
-    bar->addAction(actFill);
-    bar->addAction(actToRegina);
+    if (ReginaPrefSet::global().displaySimpleToolbars) {
+        bar->addAction(actRandomise);
+        bar->addAction(actFill);
+        bar->addAction(actToRegina);
+    } else {
+        bar->addAction(actRandomise);
+        bar->addSeparator();
+        bar->addAction(actFill);
+        bar->addAction(actCanonise);
+        bar->addAction(actToRegina);
+        bar->addSeparator();
+        bar->addAction(actVertexLinks);
+    }
 }
 
 regina::Packet* SnapPeaShapesUI::getPacket() {
@@ -390,8 +405,8 @@ void SnapPeaShapesUI::refresh() {
         updateNonNullActions();
         return;
     }
-    if (tri->solutionType() == SnapPeaTriangulation::not_attempted ||
-            tri->solutionType() == SnapPeaTriangulation::no_solution) {
+    if (tri->solutionType() == SnapPeaTriangulation::Solution::NotAttempted ||
+            tri->solutionType() == SnapPeaTriangulation::Solution::None) {
         updateNonNullActions();
         return;
     }
