@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Qt User Interface                                                     *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -60,31 +58,37 @@ namespace {
     /**
      * Triangulation type IDs that correspond to indices in the
      * triangulation type combo box.
+     *
+     * These _must_ be kept in sync with the order in which types are added to
+     * the combo box, and they _must_ include gaps for any separators.
      */
     enum {
-        TRI_EMPTY,
-        TRI_IBUNDLE,
+        TRI_EMPTY = 0,
+        TRI_EXAMPLE = 1,
+        TRI_ISOSIG = 2,
+        // --- separator ---
+        TRI_IBUNDLE = 4,
         TRI_S1BUNDLE,
-        TRI_ISOSIG,
-        TRI_EXAMPLE
+        TRI_SINGLECONE
     };
 
     /**
      * The list of ready-made example triangulations.
      */
-    std::vector<ExampleCreator<4>> examples = {
-        ExampleCreator<4>(QObject::tr("4-sphere (minimal)"), &regina::Example<4>::sphere),
-        ExampleCreator<4>(QObject::tr("4-sphere (simplex boundary)"), &regina::Example<4>::simplicialFourSphere),
-        ExampleCreator<4>(QObject::tr("Cappell-Shaneson knot complement"), &regina::Example<4>::cappellShaneson),
-        ExampleCreator<4>(QObject::tr("ℂP²"), &regina::Example<4>::cp2),
-        ExampleCreator<4>(QObject::tr("K3 surface"), &regina::Example<4>::k3),
-        ExampleCreator<4>(QObject::tr("Product B³ × S¹"), &regina::Example<4>::ballBundle),
-        ExampleCreator<4>(QObject::tr("Product S³ × S¹"), &regina::Example<4>::sphereBundle),
-        ExampleCreator<4>(QObject::tr("Product S² × S²"), &regina::Example<4>::s2xs2),
-        ExampleCreator<4>(QObject::tr("ℝP⁴"), &regina::Example<4>::rp4),
-        ExampleCreator<4>(QObject::tr("Twisted product B³ ×~ S¹"), &regina::Example<4>::twistedBallBundle),
-        ExampleCreator<4>(QObject::tr("Twisted product S³ ×~ S¹"), &regina::Example<4>::twistedSphereBundle),
-        ExampleCreator<4>(QObject::tr("Twisted product S² ×~ S²"), &regina::Example<4>::s2xs2Twisted)
+    std::vector<ExampleCreator<Triangulation<4>>> examples = {
+        { QObject::tr("4-sphere (minimal)"), &regina::Example<4>::sphere },
+        { QObject::tr("4-sphere (simplex boundary)"), &regina::Example<4>::simplicialFourSphere },
+        { QObject::tr("4-torus"), &regina::Example<4>::fourTorus },
+        { QObject::tr("Cappell-Shaneson knot complement"), &regina::Example<4>::cappellShaneson },
+        { QObject::tr("ℂP²"), &regina::Example<4>::cp2 },
+        { QObject::tr("K3 surface"), &regina::Example<4>::k3 },
+        { QObject::tr("Product B³ × S¹"), &regina::Example<4>::ballBundle },
+        { QObject::tr("Product S³ × S¹"), &regina::Example<4>::sphereBundle },
+        { QObject::tr("Product S² × S²"), &regina::Example<4>::s2xs2 },
+        { QObject::tr("ℝP⁴"), &regina::Example<4>::rp4 },
+        { QObject::tr("Twisted product B³ ×~ S¹"), &regina::Example<4>::twistedBallBundle },
+        { QObject::tr("Twisted product S³ ×~ S¹"), &regina::Example<4>::twistedSphereBundle },
+        { QObject::tr("Twisted product S² ×~ S²"), &regina::Example<4>::s2xs2Twisted }
     };
 
     /**
@@ -115,53 +119,33 @@ Tri4Creator::Tri4Creator(ReginaMain* mainWindow) {
     layout->addWidget(details, 1);
 
     // Set up the individual types of triangulation.
-    // Note that the order in which these options are added to the combo
-    // box must correspond precisely to the type IDs defined at the head
-    // of this file.
+    // The order in which these options are added to the combo box _must_
+    // correspond precisely to the type IDs defined at the head of this file.
     QWidget* area;
     QBoxLayout* subLayout;
+    QBoxLayout* lineLayout;
 
     type->addItem(QObject::tr("Empty"));
     details->addWidget(new QWidget());
 
-    type->addItem(QObject::tr("I-bundle"));
+    type->addItem(QObject::tr("Example triangulation"));
     area = new QWidget();
-    subLayout = new QVBoxLayout();
+    subLayout = new QHBoxLayout();
     subLayout->setContentsMargins(0, 0, 0, 0);
     area->setLayout(subLayout);
-    expln = QObject::tr("<qt>Select the 3-manifold triangulation <i>M</i> "
-        "that you wish to use to form the I-bundle "
-        "<i>M</i>&nbsp;×&nbsp;I.</qt>");
-    label = new QLabel(QObject::tr("Select a 3-manifold to build an "
-        "I-bundle from:"));
+    expln = QObject::tr(
+        "<qt>Specifies which particular example triangulation to create.<p>"
+        "A selection of ready-made 4-manifold triangulations is offered "
+        "here to help you experiment and see how Regina works.</qt>");
+    label = new QLabel(QObject::tr("Example:"));
     label->setWhatsThis(expln);
     subLayout->addWidget(label);
-    iBundleFrom = new PacketChooser(mainWindow->getPacketTree(),
-        new SubclassFilter<regina::Triangulation<3>>(),
-        PacketChooser::ROOT_AS_PACKET);
-    iBundleFrom->setWhatsThis(expln);
-    iBundleFrom->selectPacket(mainWindow->selectedPacket());
-    subLayout->addWidget(iBundleFrom, 1);
-    details->addWidget(area);
-
-    type->addItem(QObject::tr("S¹-bundle"));
-    area = new QWidget();
-    subLayout = new QVBoxLayout();
-    subLayout->setContentsMargins(0, 0, 0, 0);
-    area->setLayout(subLayout);
-    expln = QObject::tr("<qt>Select the 3-manifold triangulation <i>M</i> "
-        "that you wish to use to form the S¹-bundle "
-        "<i>M</i>&nbsp;×&nbsp;S¹.</qt>");
-    label = new QLabel(QObject::tr("Select a 3-manifold to build an "
-        "S¹-bundle from:"));
-    label->setWhatsThis(expln);
-    subLayout->addWidget(label);
-    s1BundleFrom = new PacketChooser(mainWindow->getPacketTree(),
-        new SubclassFilter<regina::Triangulation<3>>(),
-        PacketChooser::ROOT_AS_PACKET);
-    s1BundleFrom->setWhatsThis(expln);
-    s1BundleFrom->selectPacket(mainWindow->selectedPacket());
-    subLayout->addWidget(s1BundleFrom, 1);
+    exampleWhich = new QComboBox(area);
+    for (const auto& e : examples)
+        exampleWhich->addItem(e.name());
+    exampleWhich->setCurrentIndex(0);
+    exampleWhich->setWhatsThis(expln);
+    subLayout->addWidget(exampleWhich, 1);
     details->addWidget(area);
 
     type->addItem(QObject::tr("From isomorphism signature"));
@@ -189,24 +173,72 @@ Tri4Creator::Tri4Creator(ReginaMain* mainWindow) {
     subLayout->addWidget(isoSig, 1);
     details->addWidget(area);
 
-    type->addItem(QObject::tr("Example triangulation"));
+    type->insertSeparator(type->count());
+    details->addWidget(new QWidget()); // keep indices for type/details in sync
+
+    type->addItem(QObject::tr("I-bundle over…"));
     area = new QWidget();
-    subLayout = new QHBoxLayout();
+    subLayout = new QVBoxLayout();
     subLayout->setContentsMargins(0, 0, 0, 0);
     area->setLayout(subLayout);
-    expln = QObject::tr(
-        "<qt>Specifies which particular example triangulation to create.<p>"
-        "A selection of ready-made 4-manifold triangulations is offered "
-        "here to help you experiment and see how Regina works.</qt>");
-    label = new QLabel(QObject::tr("Example:"));
+    lineLayout = new QHBoxLayout();
+    subLayout->addLayout(lineLayout);
+    expln = QObject::tr("Select the source 3-manifold triangulation <i>M</i> "
+        "that you wish to use to form the I-bundle "
+        "<i>M</i>&nbsp;×&nbsp;I.");
+    label = new QLabel(QObject::tr("Source 3-manifold:"));
     label->setWhatsThis(expln);
-    subLayout->addWidget(label);
-    exampleWhich = new QComboBox(area);
-    for (const auto& e : examples)
-        exampleWhich->addItem(e.name());
-    exampleWhich->setCurrentIndex(0);
-    exampleWhich->setWhatsThis(expln);
-    subLayout->addWidget(exampleWhich, 1);
+    lineLayout->addWidget(label);
+    iBundleFrom = new PacketChooser(mainWindow->getPacketTree(),
+        new SubclassFilter<regina::Triangulation<3>>(),
+        PacketChooser::RootRole::Packet);
+    iBundleFrom->setWhatsThis(expln);
+    iBundleFrom->selectPacket(mainWindow->selectedPacket());
+    lineLayout->addWidget(iBundleFrom, 1);
+    subLayout->addStretch(); // avoids awkward stretching around labels
+    details->addWidget(area);
+
+    type->addItem(QObject::tr("S¹-bundle over…"));
+    area = new QWidget();
+    subLayout = new QVBoxLayout();
+    subLayout->setContentsMargins(0, 0, 0, 0);
+    area->setLayout(subLayout);
+    lineLayout = new QHBoxLayout();
+    subLayout->addLayout(lineLayout);
+    expln = QObject::tr("Select the source 3-manifold triangulation <i>M</i> "
+        "that you wish to use to form the S¹-bundle "
+        "<i>M</i>&nbsp;×&nbsp;S¹.");
+    label = new QLabel(QObject::tr("Source 3-manifold:"));
+    label->setWhatsThis(expln);
+    lineLayout->addWidget(label);
+    s1BundleFrom = new PacketChooser(mainWindow->getPacketTree(),
+        new SubclassFilter<regina::Triangulation<3>>(),
+        PacketChooser::RootRole::Packet);
+    s1BundleFrom->setWhatsThis(expln);
+    s1BundleFrom->selectPacket(mainWindow->selectedPacket());
+    lineLayout->addWidget(s1BundleFrom, 1);
+    subLayout->addStretch(); // avoids awkward stretching around labels
+    details->addWidget(area);
+
+    type->addItem(QObject::tr("Cone over…"));
+    area = new QWidget();
+    subLayout = new QVBoxLayout();
+    subLayout->setContentsMargins(0, 0, 0, 0);
+    area->setLayout(subLayout);
+    lineLayout = new QHBoxLayout();
+    subLayout->addLayout(lineLayout);
+    expln = QObject::tr("Select the source 3-manifold triangulation that you "
+        "wish to cone over.");
+    label = new QLabel(QObject::tr("Source 3-manifold:"));
+    label->setWhatsThis(expln);
+    lineLayout->addWidget(label);
+    singleConeFrom = new PacketChooser(mainWindow->getPacketTree(),
+        new SubclassFilter<regina::Triangulation<3>>(),
+        PacketChooser::RootRole::Packet);
+    singleConeFrom->setWhatsThis(expln);
+    singleConeFrom->selectPacket(mainWindow->selectedPacket());
+    lineLayout->addWidget(singleConeFrom, 1);
+    subLayout->addStretch(); // avoids awkward stretching around labels
     details->addWidget(area);
 
     // Tidy up.
@@ -249,7 +281,7 @@ std::shared_ptr<regina::Packet> Tri4Creator::createPacket(
         }
         auto& from = regina::static_triangulation3_cast(*fromPacket);
         auto ans = regina::make_packet(Example<4>::iBundle(from));
-        ans->intelligentSimplify();
+        ans->simplify();
         if (fromPacket->label().empty())
             ans->setLabel("I-bundle");
         else
@@ -265,12 +297,27 @@ std::shared_ptr<regina::Packet> Tri4Creator::createPacket(
         }
         auto& from = regina::static_triangulation3_cast(*fromPacket);
         auto ans = regina::make_packet(Example<4>::s1Bundle(from));
-        ans->intelligentSimplify();
+        ans->simplify();
         if (fromPacket->label().empty())
             ans->setLabel("S¹-bundle");
         else
             ans->setLabel(fromPacket->label() + " × S¹");
         return ans;
+    } else if (typeId == TRI_SINGLECONE) {
+        auto fromPacket = singleConeFrom->selectedPacket();
+        if (! fromPacket) {
+            ReginaSupport::info(parentWidget, QObject::tr(
+                "Please select a 3-manifold triangulation to cone over."));
+            return nullptr;
+        }
+        auto& from = regina::static_triangulation3_cast(*fromPacket);
+        auto ans = regina::make_packet(Example<4>::singleCone(from));
+        ans->simplify();
+        if (fromPacket->label().empty())
+            ans->setLabel("Cone");
+        else
+            ans->setLabel("Cone over " + fromPacket->label());
+        return ans;
     } else if (typeId == TRI_ISOSIG) {
         auto match = reIsoSig.match(isoSig->text());
         if (! match.hasMatch()) {
