@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Qt User Interface                                                     *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -93,7 +91,7 @@ void PacketTabbedUI::addTab(PacketViewerTab* viewer, const QString& label) {
     if (viewerTabs.empty() && ! editorTab)
         viewer->refresh();
     else
-        viewer->queuedAction = PacketViewerTab::Refresh;
+        viewer->queuedAction = PacketViewerTab::Action::Refresh;
 
     tabs->addTab(viewer->getInterface(), label);
 
@@ -171,9 +169,9 @@ void PacketTabbedUI::refresh() {
         if (v) {
             if (v == visibleViewer) {
                 v->refresh();
-                v->queuedAction = PacketViewerTab::None;
+                v->queuedAction = PacketViewerTab::Action::None;
             } else
-                v->queuedAction = PacketViewerTab::Refresh;
+                v->queuedAction = PacketViewerTab::Action::Refresh;
         }
 }
 
@@ -205,9 +203,9 @@ void PacketTabbedUI::notifyTabSelected(int newTab) {
 
     // Perform any pending actions.
     if (visibleViewer) {
-        if (visibleViewer->queuedAction == PacketViewerTab::Refresh)
+        if (visibleViewer->queuedAction == PacketViewerTab::Action::Refresh)
             visibleViewer->refresh();
-        visibleViewer->queuedAction = PacketViewerTab::None;
+        visibleViewer->queuedAction = PacketViewerTab::Action::None;
     }
 }
 
@@ -287,9 +285,9 @@ void PacketTabbedViewerTab::refresh() {
     for (PacketViewerTab* v : viewerTabs)
         if (v == visibleViewer) {
             v->refresh();
-            v->queuedAction = PacketViewerTab::None;
+            v->queuedAction = PacketViewerTab::Action::None;
         } else
-            v->queuedAction = PacketViewerTab::Refresh;
+            v->queuedAction = PacketViewerTab::Action::Refresh;
 }
 
 void PacketTabbedViewerTab::notifyTabSelected(int newTab) {
@@ -305,8 +303,8 @@ void PacketTabbedViewerTab::notifyTabSelected(int newTab) {
     visibleViewer = viewerTabs[newTab];
 
     // Perform any pending actions.
-    if (visibleViewer->queuedAction == PacketViewerTab::Refresh)
+    if (visibleViewer->queuedAction == PacketViewerTab::Action::Refresh)
         visibleViewer->refresh();
-    visibleViewer->queuedAction = PacketViewerTab::None;
+    visibleViewer->queuedAction = PacketViewerTab::Action::None;
 }
 
