@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Qt User Interface                                                     *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -199,7 +197,7 @@ class PacketViewerTab : public PacketReadOnlyUI {
          * Events that can be delayed until just before the viewer
          * is made visible.
          */
-        enum Action { None = 0, Refresh };
+        enum class Action { None = 0, Refresh };
 
         /**
          * External components
@@ -353,6 +351,9 @@ class PacketTabbedViewerTab : public QObject, public PacketViewerTab {
          * Notification that a new tab has been selected.
          */
         void notifyTabSelected(int newTab);
+
+    protected:
+        void renameTab(int index, const QString& label);
 };
 
 inline PacketPane* PacketTabbedUI::getEnclosingPane() {
@@ -372,12 +373,12 @@ inline void PacketTabbedUI::endEdit() {
 
 inline PacketViewerTab::PacketViewerTab(PacketTabbedUI* useParentUI) :
         PacketReadOnlyUI(useParentUI->getEnclosingPane()),
-        parentUI(useParentUI), queuedAction(None) {
+        parentUI(useParentUI), queuedAction(Action::None) {
 }
 
 inline PacketViewerTab::PacketViewerTab(PacketTabbedViewerTab* useParentUI) :
         PacketReadOnlyUI(useParentUI->getEnclosingPane()),
-        parentUI(useParentUI), queuedAction(None) {
+        parentUI(useParentUI), queuedAction(Action::None) {
 }
 
 inline QString PacketViewerTab::getPacketMenuText() const {
@@ -400,4 +401,8 @@ inline unsigned PacketTabbedViewerTab::tabCount() {
     return tabs->count();
 }
 
+inline void PacketTabbedViewerTab::renameTab(int index, const QString& label) {
+    tabs->setTabText(index, label);
+}
+
 #endif
