@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Qt User Interface                                                     *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -101,17 +99,22 @@ class ReginaPrefSet : public QObject {
 
         // The preferences themselves:
 
-        enum LinkCodeType { Gauss, DowkerThistlethwaite, KnotSig, Jenkins,
-            PlanarDiagram };
-            /**< Possible export codes that can be displayed for links. */
-        enum LinkCrossingsStyle { PictorialCrossings, TextCrossings };
-            /**< Possible styles for displaying crossings for links. */
-        enum LinkHomflyType { HomflyAZ, HomflyLM };
-            /**< Possible flavours of the HOMFLY-PT polynomial to display. */
-        enum SurfacesCompatMatrix { LocalCompat, GlobalCompat };
+        enum class CompatMatrix { Local, Global };
             /**< Possible compatibility matrices that can be displayed for a
                  normal surface list. */
-        enum TriGraphType { DualGraph, TreeDecomposition,
+        enum class CrossingStyle { Pictorial, Text };
+            /**< Possible styles for displaying crossings for links. */
+        enum class GroupSimplification { Regina, GAP };
+            /**< Available methods for simplifying group presentations. */
+        enum class HomflyStyle { AZ, LM };
+            /**< Possible flavours of the HOMFLY-PT polynomial to display. */
+        enum class LinkCode { Gauss, DowkerThistlethwaite, KnotSig, Jenkins,
+            PlanarDiagram };
+            /**< Possible export codes that can be displayed for links. */
+        enum class ThreadCount { Single, Polite, All };
+            /**< Options for how aggressively we use multithreading in long
+                 computation. */
+        enum class TriGraph { DualGraph, TreeDecomposition,
                 NiceTreeDecomposition };
             /**< Possible types of graph that can be displayed in a
                  (2,3,4)-manifold graph viewer. */
@@ -119,32 +122,38 @@ class ReginaPrefSet : public QObject {
         bool anglesCreationTaut;
             /**< When enumerating angle structures, should the taut
                  structures option be enabled by default? */
+        bool displaySimpleToolbars;
+            /**< Should we use simple toolbars with few actions and text labels
+                 (as opposed to rich toolbars with many actions and icons
+                 only)? */
         bool displayTagsInTree;
             /**< Should we display packet tags in the visual tree? */
         bool displayUnicode;
             /**< Should we use unicode liberally throughout the GUI? */
         QByteArray fileImportExportCodec;
             /**< The codec to use for imports and exports. */
+        GroupSimplification groupSimplification;
+            /**< The preferred method for simplifying group presentations. */
         bool helpIntroOnStartup;
             /**< Should we display introductory help on startup? */
         regina::HyperCoords hypersurfacesCreationCoords;
             /**< The default coordinate system for normal hypersurface
                  creation in a 4-manifold triangulation. */
-        regina::HyperList hypersurfacesCreationList;
+        regina::Flags<regina::HyperList> hypersurfacesCreationList;
             /**< The default options for which normal hypersurfaces to
                  enumerate in a 4-manifold triangulation. */
-        LinkCodeType linkCodeType;
+        LinkCode linkCodeType;
             /**< The export code to display for knots and links. */
         int linkCreationType;
             /**< The initial option to select in the list of link types
                  when creating a new link.  This is given as an
                  index into the list of options. */
-        LinkCrossingsStyle linkCrossingsStyle;
+        CrossingStyle linkCrossingsStyle;
             /**< The style for displaying crossings for knots and links. */
-        LinkHomflyType linkHomflyType;
+        HomflyStyle linkHomflyType;
             /**< The flavour of HOMFLY-PT polynomial to display for
                  knots and links. */
-        TriGraphType linkInitialGraphType;
+        TriGraph linkInitialGraphType;
             /**< Indicates which graph to initially display in a
                  link viewer.  Must not be DualGraph. */
         bool pythonAutoIndent;
@@ -154,16 +163,20 @@ class ReginaPrefSet : public QObject {
                  python console. */
         bool pythonWordWrap;
             /**< Should python consoles be word wrapped? */
+        int snapPeaCreationType;
+            /**< The initial option to select in the list of creation options
+                 when creating a new SnapPea triangulation.  This is given as
+                 an index into the list. */
         unsigned surfacesCompatThreshold;
             /**< The maximum number of normal surfaces in a list for which the
                  compatibility matrices will be automatically calculated. */
         regina::NormalCoords surfacesCreationCoords;
             /**< The default coordinate system for normal surface creation
                  in a 3-manifold triangulation. */
-        regina::NormalList surfacesCreationList;
+        regina::Flags<regina::NormalList> surfacesCreationList;
             /**< The default options for which normal surfaces to enumerate
                  in a 3-manifold triangulation. */
-        SurfacesCompatMatrix surfacesInitialCompat;
+        CompatMatrix surfacesInitialCompat;
             /**< The matrix first shown when the compatibility tab is opened
                  for a normal surface list in a 3-manifold triangulation. */
         bool surfacesSupportOriented;
@@ -200,6 +213,9 @@ class ReginaPrefSet : public QObject {
         int tabLink;
             /**< The index of the initial sub-tab to open in a knot/link
                  viewer. */
+        int tabLinkAlgebra;
+            /**< The index of the initial sub-tab to open in a knot/link
+                 algebra viewer. */
         int tabSnapPeaTri;
             /**< The index of the initial tab to open in a SnapPea
                  triangulation viewer. */
@@ -209,6 +225,9 @@ class ReginaPrefSet : public QObject {
         int tabSurfaceList;
             /**< The index of the initial sub-tab to open in a normal
                  surface list viewer. */
+        ThreadCount threadCount;
+            /**< Indicates how aggressively we should use multithreading in
+                 long computations. */
         unsigned treeJumpSize;
             /**< The number of steps corresponding to a jump up or down in
                  the packet tree. */
@@ -231,7 +250,7 @@ class ReginaPrefSet : public QObject {
             /**< Indicates whether tetrahedron/pentachoron numbers should
                  be used to label vertices in face/facet pairing graphs
                  for 3/4-manifold triangulations. */
-        TriGraphType triInitialGraphType;
+        TriGraph triInitialGraphType;
             /**< Indicates which graph to initially display in a
                  (2,3,4)-manifold graph viewer. */
         unsigned triSurfacePropsThreshold;
@@ -296,6 +315,18 @@ class ReginaPrefSet : public QObject {
          */
         static Codec importExportCodec();
 
+        /**
+         * Returns a sensible number of threads to use for a long computation,
+         * according to the user's thread count setting.
+         */
+        static int threads();
+
+        /**
+         * Returns the Qt tool button style corresponding to the "simple
+         * toolbars" setting.
+         */
+        static Qt::ToolButtonStyle toolButtonStyle();
+
         /**
          * Opens the given section of an arbitrary handbook in an appropriate
          * manner.  If the handbook is in fact the users' handbook then
@@ -389,5 +420,10 @@ inline const QList<QUrl>& ReginaPrefSet::recentFiles() {
     return instance_.fileRecent_;
 }
 
+inline Qt::ToolButtonStyle ReginaPrefSet::toolButtonStyle() {
+    return (global().displaySimpleToolbars ?
+        Qt::ToolButtonTextBesideIcon : Qt::ToolButtonIconOnly);
+}
+
 #endif
 
