@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Form a census of splitting surface signatures of given order          *
  *                                                                        *
- *  Copyright (c) 2013-2023, Ben Burton                                   *
+ *  Copyright (c) 2013-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -114,10 +112,10 @@ int main(int argc, char* argv[]) {
 
         std::cout << "PROCESSING: " << argv[i] << std::endl;
         if (mode == 's' || mode == 'q' || mode == 'a' || mode == 'o') {
-            NormalCoords coords = (mode == 's' ? NS_STANDARD :
-                mode == 'q' ? NS_QUAD :
-                mode == 'a' ? NS_AN_STANDARD :
-                NS_AN_QUAD_OCT);
+            NormalCoords coords = (mode == 's' ? NormalCoords::Standard :
+                mode == 'q' ? NormalCoords::Quad :
+                mode == 'a' ? NormalCoords::AlmostNormal :
+                NormalCoords::QuadOct);
             try {
                 TreeEnumeration<> search(t, coords);
                 search.run([](const auto& /* tree */) {
@@ -139,7 +137,8 @@ int main(int argc, char* argv[]) {
         } else {
             try {
                 TreeSingleSoln<LPConstraintEulerPositive>
-                    search(t, mode == '3' ? NS_AN_STANDARD : NS_STANDARD);
+                    search(t, mode == '3' ? NormalCoords::AlmostNormal :
+                        NormalCoords::Standard);
                 if (search.find()) {
                     std::cout << "Found non-trivial Euler > 0:"
                         << std::endl;
