@@ -4,7 +4,7 @@
  *  Regina - A Normal Surface Theory Calculator                           *
  *  Compare two data files in search of isomorphic triangulations         *
  *                                                                        *
- *  Copyright (c) 1999-2023, Ben Burton                                   *
+ *  Copyright (c) 1999-2025, Ben Burton                                   *
  *  For further details contact Ben Burton (bab@debian.org).              *
  *                                                                        *
  *  This program is free software; you can redistribute it and/or         *
@@ -23,10 +23,8 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
  *  General Public License for more details.                              *
  *                                                                        *
- *  You should have received a copy of the GNU General Public             *
- *  License along with this program; if not, write to the Free            *
- *  Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,       *
- *  MA 02110-1301, USA.                                                   *
+ *  You should have received a copy of the GNU General Public License     *
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>. *
  *                                                                        *
  **************************************************************************/
 
@@ -87,18 +85,18 @@ void runMatches(const Packet& tree1, const Packet& tree2, std::ostream& out) {
     long nMatches = 0;
 
     for (const Packet& p1 : tree1)
-        if (p1.type() == regina::PACKET_TRIANGULATION3) {
+        if (p1.type() == regina::PacketType::Triangulation3) {
             for (const Packet& p2 : tree2)
-                if (p2.type() == regina::PACKET_TRIANGULATION3)
+                if (p2.type() == regina::PacketType::Triangulation3)
                     if (compare<3>(p1, p2)) {
                         out << "    " << p1.humanLabel()
                             << (subcomplexTesting ? "  <=  " : "  ==  ")
                             << p2.humanLabel() << std::endl;
                         nMatches++;
                     }
-        } else if (p1.type() == regina::PACKET_TRIANGULATION4) {
+        } else if (p1.type() == regina::PacketType::Triangulation4) {
             for (const Packet& p2 : tree2)
-                if (p2.type() == regina::PACKET_TRIANGULATION4)
+                if (p2.type() == regina::PacketType::Triangulation4)
                     if (compare<4>(p1, p2)) {
                         out << "    " << p1.label()
                             << (subcomplexTesting ? "  <=  " : "  ==  ")
@@ -124,10 +122,10 @@ void runNonMatches(const std::string& file1, const Packet& tree1,
 
     bool matched;
     for (const Packet& p1 : tree1)
-        if (p1.type() == regina::PACKET_TRIANGULATION3) {
+        if (p1.type() == regina::PacketType::Triangulation3) {
             matched = false;
             for (const Packet& p2 : tree2)
-                if (p2.type() == regina::PACKET_TRIANGULATION3)
+                if (p2.type() == regina::PacketType::Triangulation3)
                     if (compare<3>(p1, p2)) {
                         matched = true;
                         break;
@@ -136,10 +134,10 @@ void runNonMatches(const std::string& file1, const Packet& tree1,
                 out << "    " << p1.humanLabel() << std::endl;
                 nMissing++;
             }
-        } else if (p1.type() == regina::PACKET_TRIANGULATION4) {
+        } else if (p1.type() == regina::PacketType::Triangulation4) {
             matched = false;
             for (const Packet& p2 : tree2)
-                if (p2.type() == regina::PACKET_TRIANGULATION4)
+                if (p2.type() == regina::PacketType::Triangulation4)
                     if (compare<4>(p1, p2)) {
                         matched = true;
                         break;
